Type: Package
Package: rticles
Title: Article Formats for R Markdown
Version: 0.27
Authors@R: c(
    person("JJ", "Allaire", , "jj@posit.co", role = "aut"),
    person("Yihui", "Xie", , "xie@yihui.name", role = "aut",
           comment = c(ORCID = "0000-0003-0645-5666")),
    person("Christophe", "Dervieux", , "cderv@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-4474-2498")),
    person(given = "Posit Software, PBC", role = c("cph", "fnd")),
    person(, "R Foundation", role = c("aut", "cph")),
    person("Hadley", "Wickham", , "hadley@posit.co", role = "aut"),
    person(, "Journal of Statistical Software", role = c("aut", "cph")),
    person("Ramnath ", "Vaidyanathan", , "ramnath.vaidya@gmail.com", role = c("aut", "cph")),
    person(, "Association for Computing Machinery", role = c("aut", "cph")),
    person("Carl", "Boettiger", , "cboettig@gmail.com", role = c("aut", "cph")),
    person(, "Elsevier", role = c("aut", "cph")),
    person("Karl", "Broman", , "kbroman@gmail.com", role = c("aut", "cph")),
    person("Kirill", "Mueller", , "kirill.mueller@ivt.baug.ethz.ch", role = c("aut", "cph")),
    person("Bastiaan", "Quast", , "bquast@gmail.com", role = c("aut", "cph")),
    person("Randall ", "Pruim", , "rpruim@gmail.com", role = c("aut", "cph")),
    person("Ben", "Marwick", , "bmarwick@uw.edu", role = c("aut", "cph")),
    person("Charlotte", "Wickham", , "cwickham@gmail.com", role = c("aut", "cph")),
    person("Oliver", "Keyes", , "okeyes@wikimedia.org", role = c("aut", "cph")),
    person("Miao", "Yu", , "yufreecas@gmail.com", role = c("aut", "cph")),
    person("Daniel", "Emaasit", , "daniel.emaasit@gmail.com", role = c("aut", "cph")),
    person("Thierry", "Onkelinx", , "thierry.onkelinx@inbo.be", role = c("aut", "cph")),
    person("Alessandro", "Gasparini", , "ellessenne@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-8319-7624")),
    person("Marc-Andre", "Desautels", , "marc-andre.desautels@cstjean.qc.ca", role = c("aut", "cph")),
    person("Dominik", "Leutnant", , "leutnant@fh-muenster.de", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-3293-2315")),
    person(, "MDPI", role = c("aut", "cph")),
    person(, "Taylor and Francis", role = c("aut", "cph")),
    person("Oğuzhan", "Öğreden", role = "aut",
           comment = c(ORCID = "0000-0002-9949-3348")),
    person("Dalton", "Hance", , "dhance@usgs.gov", role = "aut"),
    person("Daniel", "Nüst", , "daniel.nuest@uni-muenster.de", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-0024-5046")),
    person("Petter", "Uvesten", , "petter.uvesten.7362@student.lu.se", role = c("aut", "cph")),
    person("Elio", "Campitelli", , "elio.campitelli@cima.fcen.uba.ar", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-7742-9230")),
    person("John", "Muschelli", , "muschellij2@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0001-6469-1750")),
    person("Alex", "Hayes", , "alexpghayes@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-4985-5160")),
    person("Zhian N.", "Kamvar", , "zkamvar@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-1458-7108")),
    person("Noam", "Ross", , "noam.ross@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-2136-0000")),
    person("Robrecht", "Cannoodt", , "rcannood@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-3641-729X", github = "rcannood")),
    person("Duncan", "Luguern", , "duncan.luguern@gmail.com", role = "aut"),
    person("David M.", "Kaplan", , "dmkaplan2000@gmail.com", role = c("aut", "ctb"),
           comment = c(ORCID = "0000-0001-6087-359X", github = "dmkaplan2000")),
    person("Sebastian", "Kreutzer", , "sebastian.kreutzer@aber.ac.uk", role = "aut",
           comment = c(ORCID = "0000-0002-0734-2199")),
    person("Shixiang", "Wang", , "w_shixiang@163.com", role = c("aut", "ctb"),
           comment = c(ORCID = "0000-0001-9855-7357")),
    person("Jay", "Hesselberth", , "jay.hesselberth@gmail.com", role = c("aut", "ctb"),
           comment = c(ORCID = "0000-0002-6299-179X")),
    person("Alfredo", "Hernández", , "aldomann.designs@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-2660-4545")),
    person("Stefano", "Coretta", , "stefano.coretta@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-9627-5532", github = "stefanocoretta")),
    person("Greg", "Macfarlane", , "gregmacfarlane@gmail.com", role = "ctb",
           comment = c(github = "gregmacfarlane")),
    person("Matthias", "Templ", , "matthias.templ@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-8638-5276", github = "matthias-da")),
    person("Alvaro", "Uzaheta", , "alvaro.uzaheta@gess.ethz.ch", role = "ctb",
           comment = c(github = "auzaheta")),
    person("JooYoung", "Seo", , "jseo1005@illinois.edu", role = "ctb",
           comment = c(ORCID = "0000-0002-4064-6012")),
    person("Callum", "Arnold", , "cal.rk.arnold@gmail.com", role = "ctb",
           comment = c(github = "arnold-c")),
    person("Rob", "Hyndman", , "Rob.Hyndman@monash.edu", role = "aut",
           comment = c(ORCID = "0000-0002-2140-5352")),
    person("Dmytro", "Perepolkin", , "dperepolkin@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-8558-6183", github = "dmi3kno")),
    person("Tom", "Palmer", , "remlapmot@hotmail.com", role = "ctb",
           comment = c(ORCID = "0000-0003-4655-4511", github = "remlapmot"))
  )
Description: A suite of custom R Markdown formats and templates for
    authoring journal articles and conference submissions.
License: GPL-3
URL: https://github.com/rstudio/rticles,
        https://pkgs.rstudio.com/rticles/
BugReports: https://github.com/rstudio/rticles/issues
Imports: knitr (>= 1.30), lifecycle, rmarkdown (>= 2.14), tinytex (>=
        0.30), utils, xfun, yaml
Suggests: bookdown, withr, covr, testit, testthat (>= 3.2.0), xtable
Config/Needs/website: magick, pdftools, gifski, tidyverse/tidytemplate,
        rstudio/quillt
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.1
SystemRequirements: GNU make
NeedsCompilation: no
Packaged: 2024-04-06 20:51:20 UTC; chris
Author: JJ Allaire [aut],
  Yihui Xie [aut] (<https://orcid.org/0000-0003-0645-5666>),
  Christophe Dervieux [aut, cre]
    (<https://orcid.org/0000-0003-4474-2498>),
  Posit Software, PBC [cph, fnd],
  R Foundation [aut, cph],
  Hadley Wickham [aut],
  Journal of Statistical Software [aut, cph],
  Ramnath Vaidyanathan [aut, cph],
  Association for Computing Machinery [aut, cph],
  Carl Boettiger [aut, cph],
  Elsevier [aut, cph],
  Karl Broman [aut, cph],
  Kirill Mueller [aut, cph],
  Bastiaan Quast [aut, cph],
  Randall Pruim [aut, cph],
  Ben Marwick [aut, cph],
  Charlotte Wickham [aut, cph],
  Oliver Keyes [aut, cph],
  Miao Yu [aut, cph],
  Daniel Emaasit [aut, cph],
  Thierry Onkelinx [aut, cph],
  Alessandro Gasparini [aut, cph]
    (<https://orcid.org/0000-0002-8319-7624>),
  Marc-Andre Desautels [aut, cph],
  Dominik Leutnant [aut, cph] (<https://orcid.org/0000-0003-3293-2315>),
  MDPI [aut, cph],
  Taylor and Francis [aut, cph],
  Oğuzhan Öğreden [aut] (<https://orcid.org/0000-0002-9949-3348>),
  Dalton Hance [aut],
  Daniel Nüst [aut, cph] (<https://orcid.org/0000-0002-0024-5046>),
  Petter Uvesten [aut, cph],
  Elio Campitelli [aut, cph] (<https://orcid.org/0000-0002-7742-9230>),
  John Muschelli [aut, cph] (<https://orcid.org/0000-0001-6469-1750>),
  Alex Hayes [aut] (<https://orcid.org/0000-0002-4985-5160>),
  Zhian N. Kamvar [aut, cph] (<https://orcid.org/0000-0003-1458-7108>),
  Noam Ross [aut, cph] (<https://orcid.org/0000-0002-2136-0000>),
  Robrecht Cannoodt [aut, cph] (<https://orcid.org/0000-0003-3641-729X>,
    rcannood),
  Duncan Luguern [aut],
  David M. Kaplan [aut, ctb] (<https://orcid.org/0000-0001-6087-359X>,
    dmkaplan2000),
  Sebastian Kreutzer [aut] (<https://orcid.org/0000-0002-0734-2199>),
  Shixiang Wang [aut, ctb] (<https://orcid.org/0000-0001-9855-7357>),
  Jay Hesselberth [aut, ctb] (<https://orcid.org/0000-0002-6299-179X>),
  Alfredo Hernández [ctb] (<https://orcid.org/0000-0002-2660-4545>),
  Stefano Coretta [ctb] (<https://orcid.org/0000-0001-9627-5532>,
    stefanocoretta),
  Greg Macfarlane [ctb] (gregmacfarlane),
  Matthias Templ [ctb] (<https://orcid.org/0000-0002-8638-5276>,
    matthias-da),
  Alvaro Uzaheta [ctb] (auzaheta),
  JooYoung Seo [ctb] (<https://orcid.org/0000-0002-4064-6012>),
  Callum Arnold [ctb] (arnold-c),
  Rob Hyndman [aut] (<https://orcid.org/0000-0002-2140-5352>),
  Dmytro Perepolkin [ctb] (<https://orcid.org/0000-0001-8558-6183>,
    dmi3kno),
  Tom Palmer [ctb] (<https://orcid.org/0000-0003-4655-4511>, remlapmot)
Maintainer: Christophe Dervieux <cderv@posit.co>
Repository: CRAN
Date/Publication: 2024-04-06 23:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 14:47:54 UTC; unix

Type: Package
Package: rticles
Title: Article Formats for R Markdown
Version: 0.27
Authors@R: c(
    person("JJ", "Allaire", , "jj@posit.co", role = "aut"),
    person("Yihui", "Xie", , "xie@yihui.name", role = "aut",
           comment = c(ORCID = "0000-0003-0645-5666")),
    person("Christophe", "Dervieux", , "cderv@posit.co", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0003-4474-2498")),
    person(given = "Posit Software, PBC", role = c("cph", "fnd")),
    person(, "R Foundation", role = c("aut", "cph")),
    person("Hadley", "Wickham", , "hadley@posit.co", role = "aut"),
    person(, "Journal of Statistical Software", role = c("aut", "cph")),
    person("Ramnath ", "Vaidyanathan", , "ramnath.vaidya@gmail.com", role = c("aut", "cph")),
    person(, "Association for Computing Machinery", role = c("aut", "cph")),
    person("Carl", "Boettiger", , "cboettig@gmail.com", role = c("aut", "cph")),
    person(, "Elsevier", role = c("aut", "cph")),
    person("Karl", "Broman", , "kbroman@gmail.com", role = c("aut", "cph")),
    person("Kirill", "Mueller", , "kirill.mueller@ivt.baug.ethz.ch", role = c("aut", "cph")),
    person("Bastiaan", "Quast", , "bquast@gmail.com", role = c("aut", "cph")),
    person("Randall ", "Pruim", , "rpruim@gmail.com", role = c("aut", "cph")),
    person("Ben", "Marwick", , "bmarwick@uw.edu", role = c("aut", "cph")),
    person("Charlotte", "Wickham", , "cwickham@gmail.com", role = c("aut", "cph")),
    person("Oliver", "Keyes", , "okeyes@wikimedia.org", role = c("aut", "cph")),
    person("Miao", "Yu", , "yufreecas@gmail.com", role = c("aut", "cph")),
    person("Daniel", "Emaasit", , "daniel.emaasit@gmail.com", role = c("aut", "cph")),
    person("Thierry", "Onkelinx", , "thierry.onkelinx@inbo.be", role = c("aut", "cph")),
    person("Alessandro", "Gasparini", , "ellessenne@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-8319-7624")),
    person("Marc-Andre", "Desautels", , "marc-andre.desautels@cstjean.qc.ca", role = c("aut", "cph")),
    person("Dominik", "Leutnant", , "leutnant@fh-muenster.de", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-3293-2315")),
    person(, "MDPI", role = c("aut", "cph")),
    person(, "Taylor and Francis", role = c("aut", "cph")),
    person("Oğuzhan", "Öğreden", role = "aut",
           comment = c(ORCID = "0000-0002-9949-3348")),
    person("Dalton", "Hance", , "dhance@usgs.gov", role = "aut"),
    person("Daniel", "Nüst", , "daniel.nuest@uni-muenster.de", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-0024-5046")),
    person("Petter", "Uvesten", , "petter.uvesten.7362@student.lu.se", role = c("aut", "cph")),
    person("Elio", "Campitelli", , "elio.campitelli@cima.fcen.uba.ar", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-7742-9230")),
    person("John", "Muschelli", , "muschellij2@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0001-6469-1750")),
    person("Alex", "Hayes", , "alexpghayes@gmail.com", role = "aut",
           comment = c(ORCID = "0000-0002-4985-5160")),
    person("Zhian N.", "Kamvar", , "zkamvar@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-1458-7108")),
    person("Noam", "Ross", , "noam.ross@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0002-2136-0000")),
    person("Robrecht", "Cannoodt", , "rcannood@gmail.com", role = c("aut", "cph"),
           comment = c(ORCID = "0000-0003-3641-729X", github = "rcannood")),
    person("Duncan", "Luguern", , "duncan.luguern@gmail.com", role = "aut"),
    person("David M.", "Kaplan", , "dmkaplan2000@gmail.com", role = c("aut", "ctb"),
           comment = c(ORCID = "0000-0001-6087-359X", github = "dmkaplan2000")),
    person("Sebastian", "Kreutzer", , "sebastian.kreutzer@aber.ac.uk", role = "aut",
           comment = c(ORCID = "0000-0002-0734-2199")),
    person("Shixiang", "Wang", , "w_shixiang@163.com", role = c("aut", "ctb"),
           comment = c(ORCID = "0000-0001-9855-7357")),
    person("Jay", "Hesselberth", , "jay.hesselberth@gmail.com", role = c("aut", "ctb"),
           comment = c(ORCID = "0000-0002-6299-179X")),
    person("Alfredo", "Hernández", , "aldomann.designs@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-2660-4545")),
    person("Stefano", "Coretta", , "stefano.coretta@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-9627-5532", github = "stefanocoretta")),
    person("Greg", "Macfarlane", , "gregmacfarlane@gmail.com", role = "ctb",
           comment = c(github = "gregmacfarlane")),
    person("Matthias", "Templ", , "matthias.templ@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0002-8638-5276", github = "matthias-da")),
    person("Alvaro", "Uzaheta", , "alvaro.uzaheta@gess.ethz.ch", role = "ctb",
           comment = c(github = "auzaheta")),
    person("JooYoung", "Seo", , "jseo1005@illinois.edu", role = "ctb",
           comment = c(ORCID = "0000-0002-4064-6012")),
    person("Callum", "Arnold", , "cal.rk.arnold@gmail.com", role = "ctb",
           comment = c(github = "arnold-c")),
    person("Rob", "Hyndman", , "Rob.Hyndman@monash.edu", role = "aut",
           comment = c(ORCID = "0000-0002-2140-5352")),
    person("Dmytro", "Perepolkin", , "dperepolkin@gmail.com", role = "ctb",
           comment = c(ORCID = "0000-0001-8558-6183", github = "dmi3kno")),
    person("Tom", "Palmer", , "remlapmot@hotmail.com", role = "ctb",
           comment = c(ORCID = "0000-0003-4655-4511", github = "remlapmot"))
  )
Description: A suite of custom R Markdown formats and templates for
    authoring journal articles and conference submissions.
License: GPL-3
URL: https://github.com/rstudio/rticles,
        https://pkgs.rstudio.com/rticles/
BugReports: https://github.com/rstudio/rticles/issues
Imports: knitr (>= 1.30), lifecycle, rmarkdown (>= 2.14), tinytex (>=
        0.30), utils, xfun, yaml
Suggests: bookdown, withr, covr, testit, testthat (>= 3.2.0), xtable
Config/Needs/website: magick, pdftools, gifski, tidyverse/tidytemplate,
        rstudio/quillt
Config/testthat/edition: 3
Encoding: UTF-8
RoxygenNote: 7.3.1
SystemRequirements: GNU make
NeedsCompilation: no
Packaged: 2024-04-06 20:51:20 UTC; chris
Author: JJ Allaire [aut],
  Yihui Xie [aut] (<https://orcid.org/0000-0003-0645-5666>),
  Christophe Dervieux [aut, cre]
    (<https://orcid.org/0000-0003-4474-2498>),
  Posit Software, PBC [cph, fnd],
  R Foundation [aut, cph],
  Hadley Wickham [aut],
  Journal of Statistical Software [aut, cph],
  Ramnath Vaidyanathan [aut, cph],
  Association for Computing Machinery [aut, cph],
  Carl Boettiger [aut, cph],
  Elsevier [aut, cph],
  Karl Broman [aut, cph],
  Kirill Mueller [aut, cph],
  Bastiaan Quast [aut, cph],
  Randall Pruim [aut, cph],
  Ben Marwick [aut, cph],
  Charlotte Wickham [aut, cph],
  Oliver Keyes [aut, cph],
  Miao Yu [aut, cph],
  Daniel Emaasit [aut, cph],
  Thierry Onkelinx [aut, cph],
  Alessandro Gasparini [aut, cph]
    (<https://orcid.org/0000-0002-8319-7624>),
  Marc-Andre Desautels [aut, cph],
  Dominik Leutnant [aut, cph] (<https://orcid.org/0000-0003-3293-2315>),
  MDPI [aut, cph],
  Taylor and Francis [aut, cph],
  Oğuzhan Öğreden [aut] (<https://orcid.org/0000-0002-9949-3348>),
  Dalton Hance [aut],
  Daniel Nüst [aut, cph] (<https://orcid.org/0000-0002-0024-5046>),
  Petter Uvesten [aut, cph],
  Elio Campitelli [aut, cph] (<https://orcid.org/0000-0002-7742-9230>),
  John Muschelli [aut, cph] (<https://orcid.org/0000-0001-6469-1750>),
  Alex Hayes [aut] (<https://orcid.org/0000-0002-4985-5160>),
  Zhian N. Kamvar [aut, cph] (<https://orcid.org/0000-0003-1458-7108>),
  Noam Ross [aut, cph] (<https://orcid.org/0000-0002-2136-0000>),
  Robrecht Cannoodt [aut, cph] (<https://orcid.org/0000-0003-3641-729X>,
    rcannood),
  Duncan Luguern [aut],
  David M. Kaplan [aut, ctb] (<https://orcid.org/0000-0001-6087-359X>,
    dmkaplan2000),
  Sebastian Kreutzer [aut] (<https://orcid.org/0000-0002-0734-2199>),
  Shixiang Wang [aut, ctb] (<https://orcid.org/0000-0001-9855-7357>),
  Jay Hesselberth [aut, ctb] (<https://orcid.org/0000-0002-6299-179X>),
  Alfredo Hernández [ctb] (<https://orcid.org/0000-0002-2660-4545>),
  Stefano Coretta [ctb] (<https://orcid.org/0000-0001-9627-5532>,
    stefanocoretta),
  Greg Macfarlane [ctb] (gregmacfarlane),
  Matthias Templ [ctb] (<https://orcid.org/0000-0002-8638-5276>,
    matthias-da),
  Alvaro Uzaheta [ctb] (auzaheta),
  JooYoung Seo [ctb] (<https://orcid.org/0000-0002-4064-6012>),
  Callum Arnold [ctb] (arnold-c),
  Rob Hyndman [aut] (<https://orcid.org/0000-0002-2140-5352>),
  Dmytro Perepolkin [ctb] (<https://orcid.org/0000-0001-8558-6183>,
    dmi3kno),
  Tom Palmer [ctb] (<https://orcid.org/0000-0003-4655-4511>, remlapmot)
Maintainer: Christophe Dervieux <cderv@posit.co>
Repository: CRAN
Date/Publication: 2024-04-06 23:50:02 UTC
Built: R 4.6.0; ; 2026-04-28 20:46:32 UTC; unix

# Generated by roxygen2: do not edit by hand

export(acm_article)
export(acs_article)
export(aea_article)
export(agu_article)
export(ajs_article)
export(amq_article)
export(ams_article)
export(arxiv_article)
export(asa_article)
export(bioinformatics_article)
export(biometrics_article)
export(copernicus_article)
export(copernicus_journal_abbreviations)
export(ctex)
export(ctex_article)
export(elsevier_article)
export(frontiers_article)
export(glossa_article)
export(ieee_article)
export(ims_article)
export(informs_article)
export(iop_article)
export(isba_article)
export(jasa_article)
export(jedm_article)
export(joss_article)
export(journals)
export(jss_article)
export(lipics_article)
export(lncs_article)
export(mdpi_article)
export(mnras_article)
export(oup_article)
export(peerj_article)
export(pihph_article)
export(plos_article)
export(pnas_article)
export(rjournal_article)
export(rsos_article)
export(rss_article)
export(sage_article)
export(sim_article)
export(springer_article)
export(string_to_table)
export(tf_article)
export(trb_article)
export(wellcomeor_article)
importFrom(rmarkdown,includes_to_pandoc_args)
importFrom(rmarkdown,knitr_options)
importFrom(rmarkdown,output_format)
importFrom(rmarkdown,pandoc_options)
importFrom(rmarkdown,pandoc_variable_arg)

# Comment utiliser l'extension `amq_article`?

## Ajouter des packages

Vous pouvez ajouter des packages utiles pour vous dans le fichier `authorpackages.tex`. Vous pouvez laisser le fichier vide si vous n'avez aucun package à ajouter.

Voici quelques exemples de packages que vous pouvez ajouter:

```
\usepackage{pstricks}
\usepackage{enumitem}
```


## Ajouter des commandes

Vous pouvez ajouter des commandes utiles pour vous dans le fichier `authorcommands.tex`. Vous pouvez laisser le fichier vide si vous n'avez aucune commande à ajouter.

Voici quelques exemples de commandes que vous pouvez ajouter:

```
\newcommand{\lr}[1]{\left(#1\right)}
\newcommand{\abs}[1]{\left\vert#1\right\vert}
```

## Bibliographie

Le bulletin de l'AMQ ne vous permet pas d'utiliser `Bibtex` pour votre bibliographie. Vous devez donc entrer vos bibliographies dans le fichiers `mybibliography.tex`.

La liste des références apparaîtra entre les commandes `\begin{thebibliography}{10}` et `\end{thebibliography}{10}`, par ordre alphabétique du premier auteur.

Toutes les références bibliographiques apparaissant dans la liste des références devraient être citées dans le corps du texte. Réciproquement, toutes les références citées dans le corps du texte devraient apparaître en fin de texte dans la liste des 
références.

Chaque item de cette liste sera entré grâce à la commande `\bibitem`.

- Pour un livre: `\bibitem{étiquette} Nom de l'auteur, Initiale. (année de publication). {\em Titre du livre} (Numéro d'édition Éd.) (vol. numéro de volume) (Nom du traducteur trad.). Ville, Pays (sauf pour les USA où on mettra Ville, abr. postale de l'État): Éditeur.`

- Pour un article publié dans une revue: `\bibitem{étiquette} Nom de l'auteur, Initiale. (année de publication). Titre de l'article, {\em Nom de la revue, Numéro du volume} (no. numéro de fascicule), numéro de la première page--numéro de la dernière page.`

- Pour un chapitre dans un ouvrage collectif (plusieurs auteurs): `\bibitem{étiquette} Nom de l'auteur, Initiale. (année de publication). Titre du chapitre, Dans Initiale. Nom du directeur (dir.) {\em Titre de l'ouvrage}, (numéro d'édition ou de chapitre, p. numéro de la première page--numéro de la dernière page), Ville, Pays: Éditeur.`

- Pour un document en ligne: `\bibitem{étiquette} Nom de l'auteur, Initiale. (date de création, ou année de création mise à jour date de mise à jour). Titre du document (pour une section d'un document long, traiter comme pour un chapitre de livre en remplaçant les numéros de pages par le numéro de chapitre ou de section)`.

Pour invoquer une référence dans le texte, utiliser la commande `\cite{étiquette}`

Pour plus de renseignements, consultez [normes](http://benhur.teluq.uqam.ca/~mcouture/apa/normes_apa_francais.pdf). Pour les informations de localisation, consulter le même document

<!-- README.md is generated from README.Rmd. Please edit that file -->
<!-- badges: start -->

[![R-CMD-check](https://github.com/rstudio/rticles/actions/workflows/R-CMD-check.yaml/badge.svg)](https://github.com/rstudio/rticles/actions/workflows/R-CMD-check.yaml)
[![Downloads from the RStudio CRAN
mirror](https://cranlogs.r-pkg.org/badges/rticles)](https://cran.r-project.org/package=rticles)
[![CRAN
status](https://www.r-pkg.org/badges/version/rticles)](https://CRAN.R-project.org/package=rticles)
[![Codecov test
coverage](https://codecov.io/gh/rstudio/rticles/branch/main/graph/badge.svg)](https://app.codecov.io/gh/rstudio/rticles?branch=main)

<!-- badges: end -->

# rticles <a href="https://pkgs.rstudio.com/rticles/"><img src="man/figures/logo.png" align="right" height="138"/></a>

The **rticles** package provides a suite of custom [R
Markdown](https://rmarkdown.rstudio.com) LaTeX formats and templates for
various formats. Most of the templates are provided and maintained by
the community, and anyone can contribute a new template. See [How to
contribute](#how-to-contribute) below.

## Book

<a href="https://bookdown.org/yihui/rmarkdown/journals.html"><img src="https://bookdown.org/yihui/rmarkdown/images/cover.png" alt="R Markdown: The Definitive Guide" class="book" height="400"/></a>

## Installation

You can install and use **rticles** from CRAN as follows:

``` r
install.packages("rticles")
```

If you wish to install the development version from GitHub (which often
contains new article formats), you can do this:

``` r
# install.packages("pak")
pak::pak("rstudio/rticles")
```

## Using rticles

To use **rticles** from RStudio, you can access the templates through
`File -> New File -> R Markdown`. This will open the dialog box where
you can select from one of the available templates:

<figure>
<img
src="https://bookdown.org/yihui/rmarkdown/images/rticles-templates.png"
alt="New R Markdown" />
<figcaption aria-hidden="true">New R Markdown</figcaption>
</figure>

If you are not using RStudio, you’ll also need to install
[Pandoc](https://pandoc.org) following these
[instructions](https://bookdown.org/yihui/rmarkdown-cookbook/install-pandoc.html).
Then, use the `rmarkdown::draft()` function to create articles:

``` r
rmarkdown::draft(
    "MyJSSArticle.Rmd", template = "jss", package = "rticles"
)
rmarkdown::draft(
    "MyRJournalArticle", template = "rjournal", package = "rticles"
)
```

This will create a folder containing a Rmd file using the corresponding
output format and all the assets required by this format.

## Templates

Currently included templates and their contributors are the following:

| Journal                                                                                                                                                                           | Contributors                                                                                                                                                               | Pull request                                                                                                                                                                                                                                                                                                                     | Output format                                                                                       |
|-----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------|----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------|-----------------------------------------------------------------------------------------------------|
| [ACM: Association for Computings Machinery](https://www.acm.org/publications/about-publications)                                                                                  | [@ramnathv](https://github.com/ramnathv)                                                                                                                                   | [\#8](https://github.com/rstudio/rticles/pull/8)                                                                                                                                                                                                                                                                                 | `acm_article()`                                                                                     |
| ACS `https://pubs.acs.org`                                                                                                                                                        | [@yufree](https://github.com/yufree)                                                                                                                                       | [\#15](https://github.com/rstudio/rticles/pull/15)                                                                                                                                                                                                                                                                               | `acs_article()`                                                                                     |
| [AEA: American Economic Association](https://www.aeaweb.org/journals/policies/templates)                                                                                          | [@sboysel](https://github.com/sboysel)                                                                                                                                     | [\#86](https://github.com/rstudio/rticles/pull/86)                                                                                                                                                                                                                                                                               | `aea_articles()`                                                                                    |
| AGU `https://agupubs.onlinelibrary.wiley.com/`                                                                                                                                    | [@eliocamp](https://github.com/eliocamp)                                                                                                                                   | [\#199](https://github.com/rstudio/rticles/pull/199)                                                                                                                                                                                                                                                                             | `agu_article()`                                                                                     |
| [AJS: Austrian Journal of Statistics](https://www.ajs.or.at)                                                                                                                      | [@matthias-da](https://github.com/matthias-da)                                                                                                                             | [\#437](https://github.com/rstudio/rticles/pull/437)                                                                                                                                                                                                                                                                             | `ajs_article()`                                                                                     |
| [AMS: American Meteorological Society](https://www.ametsoc.org/)                                                                                                                  | [@yufree](https://github.com/yufree)                                                                                                                                       | [\#96](https://github.com/rstudio/rticles/pull/96)                                                                                                                                                                                                                                                                               | `ams_article()`                                                                                     |
| ASA: American Statistical Association `https://www.amstat.org/`                                                                                                                   |                                                                                                                                                                            | [\#111](https://github.com/rstudio/rticles/pull/111)                                                                                                                                                                                                                                                                             | `asa_article()`                                                                                     |
| [arXiv](https://arxiv.org/) pre-prints based on George Kour’s template                                                                                                            | [@alexpghayes](https://github.com)                                                                                                                                         | [\#236](https://github.com/rstudio/rticles/pull/236)                                                                                                                                                                                                                                                                             | `arxiv_article()`                                                                                   |
| [Bioinformatics](https://academic.oup.com/bioinformatics)                                                                                                                         | [@ShixiangWang](https://github.com/ShixiangWang)                                                                                                                           | [\#297](https://github.com/rstudio/rticles/pull/297)                                                                                                                                                                                                                                                                             | `bioinformatics_article()`                                                                          |
| [Biometrics](https://biometrics.biometricsociety.org)                                                                                                                             | [@daltonhance](https://github.com/daltonhance)                                                                                                                             | [\#170](https://github.com/rstudio/rticles/pull/170)                                                                                                                                                                                                                                                                             | `biometrics_article()`                                                                              |
| Bulletin de l’AMQ (`https://www.amq.math.ca/bulletin/`)                                                                                                                           | [@desautm](https://github.com/desautm)                                                                                                                                     | [\#145](https://github.com/rstudio/rticles/pull/145)                                                                                                                                                                                                                                                                             | `amq_article()`                                                                                     |
| [Copernicus Publications](https://publications.copernicus.org)                                                                                                                    | [@nuest](https://github.com/nuest), [@RLumSK](https://github.com/RLumSK)                                                                                                   | [\#172](https://github.com/rstudio/rticles/pull/172), [\#342](https://github.com/rstudio/rticles/pull/342)                                                                                                                                                                                                                       | `copernicus_article()`                                                                              |
| [CTeX](https://ctan.org/pkg/ctex)                                                                                                                                                 |                                                                                                                                                                            |                                                                                                                                                                                                                                                                                                                                  | `ctex()`                                                                                            |
| [Elsevier](https://www.elsevier.com)                                                                                                                                              | [@cboettig](https://github.com/cboettig), [@robjhyndman](https://github.com/robjhyndman)                                                                                   | [\#27](https://github.com/rstudio/rticles/pull/27), [\#467](https://github.com/rstudio/rticles/pull/467)                                                                                                                                                                                                                         | `elsevier_article()`                                                                                |
| [Frontiers](https://www.frontiersin.org/)                                                                                                                                         | [@muschellij2](https://github.com/muschellij2)                                                                                                                             | [\#211](https://github.com/rstudio/rticles/pull/211)                                                                                                                                                                                                                                                                             | `frontiers_article()`                                                                               |
| [Glossa](https://www.glossa-journal.org)                                                                                                                                          | [@stefanocoretta](https://github.com/stefanocoretta)                                                                                                                       | [\#361](https://github.com/rstudio/rticles/pull/361)                                                                                                                                                                                                                                                                             | `glossa_article()`                                                                                  |
| [IEEE Transaction](https://www.ieee.org/publications_standards/publications/authors/author_templates.html)                                                                        | [@Emaasit](https://github.com/Emaasit), [@espinielli](https://github.com/espinielli), [@nathanweeks](https://github.com/nathanweeks), [@DunLug](https://github.com/DunLug) | [\#97](https://github.com/rstudio/rticles/pull/97), [\#169](https://github.com/rstudio/rticles/pull/169), [\#227](https://github.com/rstudio/rticles/pull/227), [\#263](https://github.com/rstudio/rticles/pull/263), [\#264](https://github.com/rstudio/rticles/pull/264), [\#265](https://github.com/rstudio/rticles/pull/265) | `ieee_article()`                                                                                    |
| [IMS: Institute of Mathematical Statistics](https://imstat.org/) [AoAS: Annals of Applied Statistics](https://imstat.org/journals-and-publications/annals-of-applied-statistics/) | [@auzaheta](https://github.com/auzaheta)                                                                                                                                   | [\#372](https://github.com/rstudio/rticles/pull/372)                                                                                                                                                                                                                                                                             | `ims_article()`                                                                                     |
| [INFORMS: Institute for Operations Research and the Management Sciences](https://www.informs.org/)                                                                                | [@robjhyndman](https://github.com/robjhyndman)                                                                                                                             | [\#460](https://github.com/rstudio/rticles/pull/460)                                                                                                                                                                                                                                                                             | `informs_article()`                                                                                 |
| [ISBA: International Society for Bayesian Analysis](https://bayesian.org/)                                                                                                        | [@dmi3nko](https://github.com/dmi3kno)                                                                                                                                     | [\#461](https://github.com/rstudio/rticles/pull/461)                                                                                                                                                                                                                                                                             | `isba_article()`                                                                                    |
| IOP: Institute of Physics (`https://iopscience.iop.org`)                                                                                                                          | [@robjhyndman](https://github.com/robjhyndman)                                                                                                                             | [\#462](https://github.com/rstudio/rticles/pull/462)                                                                                                                                                                                                                                                                             | `iop_article()`                                                                                     |
| [JASA: Journal of the Acoustical Society of America](https://pubs.aip.org/asa/jasa)                                                                                               | [@stefanocoretta](https://github.com/stefanocoretta)                                                                                                                       | [\#364](https://github.com/rstudio/rticles/pull/364)                                                                                                                                                                                                                                                                             | `jasa_article()`                                                                                    |
| [Journal of Educational Data Mining](https://jedm.educationaldatamining.org/index.php/JEDM/about/submissions) journal submissions                                                 | [@jooyoungseo](https://github.com/jooyoungseo)                                                                                                                             | [\#251](https://github.com/rstudio/rticles/pull/251)                                                                                                                                                                                                                                                                             | `jedm_article()`                                                                                    |
| [JOSS: Journal of Open Source Software](https://joss.theoj.org/) [JOSE: Journal of Open Source Education](https://jose.theoj.org/)                                                | [@noamross](https://github.com/noamross)                                                                                                                                   | [\#229](https://github.com/rstudio/rticles/pull/229)                                                                                                                                                                                                                                                                             | `joss_article()`                                                                                    |
| [JSS: Journal of Statistical Software](https://www.jstatsoft.org/index)                                                                                                           |                                                                                                                                                                            |                                                                                                                                                                                                                                                                                                                                  | `jss_article()`                                                                                     |
| [LIPIcs](https://www.dagstuhl.de/en/publishing/series/details/lipics)                                                                                                             | [@nuest](https://github.com/nuest)                                                                                                                                         | [\#288](https://github.com/rstudio/rticles/pull/288)                                                                                                                                                                                                                                                                             | `lipics_article()`                                                                                  |
| [MDPI](https://www.mdpi.com)                                                                                                                                                      | [@dleutnant](https://github.com/dleutnant), [@mps9506](https://github.com/mps9506)                                                                                         | [\#147](https://github.com/rstudio/rticles/pull/147), [\#515](https://github.com/rstudio/rticles/pull/515)                                                                                                                                                                                                                       | `mdpi_article()`                                                                                    |
| [MNRAS: Monthly Notices of the Royal Astronomical Society](https://academic.oup.com/mnras)                                                                                        | [@oleskiewicz](https://github.com/oleskiewicz)                                                                                                                             | [\#175](https://github.com/rstudio/rticles/pull/175)                                                                                                                                                                                                                                                                             | `mnras_article()`                                                                                   |
| [OUP: Oxford University Press](https://academic.oup.com/pages/authoring/journals/preparing_your_manuscript)                                                                       | [@dmkaplan](https://github.com/dmkaplan)                                                                                                                                   | [\#284](https://github.com/rstudio/rticles/pull/284)                                                                                                                                                                                                                                                                             | `oup_articles()`                                                                                    |
| [PeerJ: Journal of Life and Environmental Sciences](https://peerj.com)                                                                                                            | [@zkamvar](https://github.com/zkamvar)                                                                                                                                     | [\#127](https://github.com/rstudio/rticles/pull/127)                                                                                                                                                                                                                                                                             | `peerj_article()`                                                                                   |
| [PiHPh: Papers in Historical Phonology](http://journals.ed.ac.uk/pihph/about/submissions)                                                                                         | [@stefanocoretta](https://github.com/stefanocoretta)                                                                                                                       | [\#362](https://github.com/rstudio/rticles/pull/362)                                                                                                                                                                                                                                                                             | `pihph_article()`                                                                                   |
| [PLOS](https://plos.org/#journals)                                                                                                                                                | [@sjmgarnier](https://github.com/sjmgarnier)                                                                                                                               | [\#12](https://github.com/rstudio/rticles/pull/12)                                                                                                                                                                                                                                                                               | `plos_article()`                                                                                    |
| PNAS: Proceedings of the National Academy of Sciences (`https://www.pnas.org/`)                                                                                                   | [@cboettig](https://github.com/cboettig)                                                                                                                                   | [\#72](https://github.com/rstudio/rticles/pull/72)                                                                                                                                                                                                                                                                               | `pnas_article()`                                                                                    |
| RSOS: Royal Society Open Science `https://www.royalsocietypublishing.org/journal/rsos`                                                                                            | [@ThierryO](https://github.com/ThierryO)                                                                                                                                   | [\#135](https://github.com/rstudio/rticles/pull/135)                                                                                                                                                                                                                                                                             | `rsos_article()`                                                                                    |
| [RSS: Royal Statistical Society](https://rss.org.uk/)                                                                                                                             | [@carlganz](https://github.com/carlganz)                                                                                                                                   | [\#110](https://github.com/rstudio/rticles/pull/110)                                                                                                                                                                                                                                                                             | `rss_article()`                                                                                     |
| [Sage](https://uk.sagepub.com/en-gb/eur/manuscript-submission-guidelines)                                                                                                         | [@oguzhanogreden](https://github.com/oguzhanogreden)                                                                                                                       | [\#181](https://github.com/rstudio/rticles/pull/181)                                                                                                                                                                                                                                                                             | `sage_article()`                                                                                    |
| [Springer](https://www.springernature.com/gp/authors/campaigns/latex-author-support)                                                                                              | [@strakaps](https://github.com/strakaps)                                                                                                                                   | [\#164](https://github.com/rstudio/rticles/pull/164)                                                                                                                                                                                                                                                                             | `springer_article()`                                                                                |
| [Springer Lecture Notes in Computer Science (LCNS)](https://www.springer.com/gp/computer-science/lncs/conference-proceedings-guidelines)                                          | [@eliocamp](https://github.com/eliocamp/)                                                                                                                                  | [\#445](https://github.com/rstudio/rticles/issues/445)                                                                                                                                                                                                                                                                           | `lncs_article()`                                                                                    |
| SIM: Statistics in Medicine `https://onlinelibrary.wiley.com/journal/10970258)`                                                                                                   | [@ellessenne](https://github.com/ellessenne)                                                                                                                               | [\#231](https://github.com/rstudio/rticles/pull/231)                                                                                                                                                                                                                                                                             | `sim_article()`                                                                                     |
| Taylor & Francis (`https://www.tandfonline.com/`)                                                                                                                                 | [@dleutnant](https://github.com/dleutnant)                                                                                                                                 | [\#218](https://github.com/rstudio/rticles/pull/218)                                                                                                                                                                                                                                                                             | `tf_article()`                                                                                      |
| [The R Journal](https://journal.r-project.org/)                                                                                                                                   |                                                                                                                                                                            |                                                                                                                                                                                                                                                                                                                                  | Use [rjtools](https://rjournal.github.io/rjtools/) package now. `rjournal_article()` is deprecated. |
| [TRB](https://trb.secure-platform.com/a/page/TRBPaperReview)                                                                                                                      | [@gregmacfarlane](https://github.com/gregmacfarlane)                                                                                                                       | [\#427](https://github.com/rstudio/rticles/pull/427)                                                                                                                                                                                                                                                                             | `trb_article()`                                                                                     |
| [Wellcome Open Research](https://wellcomeopenresearch.org)                                                                                                                        | [@arnold-c](https://github.com/arnold-c)                                                                                                                                   | [\#436](https://github.com/rstudio/rticles/pull/436)                                                                                                                                                                                                                                                                             | `wellcomeor_article()`                                                                              |

You can also get the list of available journal names with
`rticles::journals()`.

``` r
rticles::journals()
#>  [1] "acm"            "acs"            "aea"            "agu"           
#>  [5] "ajs"            "amq"            "ams"            "arxiv"         
#>  [9] "asa"            "bioinformatics" "biometrics"     "copernicus"    
#> [13] "ctex"           "elsevier"       "frontiers"      "glossa"        
#> [17] "ieee"           "ims"            "informs"        "iop"           
#> [21] "isba"           "jasa"           "jedm"           "joss"          
#> [25] "jss"            "lipics"         "lncs"           "mdpi"          
#> [29] "mnras"          "oup_v0"         "oup_v1"         "peerj"         
#> [33] "pihph"          "plos"           "pnas"           "rjournal"      
#> [37] "rsos"           "rss"            "sage"           "sim"           
#> [41] "springer"       "tf"             "trb"            "wellcomeor"
```

Those are the values to use within `rmarkdown::draft()`.

Under the hood, LaTeX templates are used to ensure that documents
conform precisely to submission standards. At the same time, composition
and formatting can be done using lightweight
[markdown](https://rmarkdown.rstudio.com/authoring_basics.html) syntax,
and R code and its output can be seamlessly included using
[knitr](https://yihui.org/knitr/).

## Getting help

There are two main places to get help:

1.  The [RStudio
    community](https://community.rstudio.com/tags/c/R-Markdown/10/rticles)
    is a friendly place to ask any questions about **rticles**. Be sure
    to use the `rticles` tag.

2.  [Stack Overflow](https://stackoverflow.com/questions/tagged/rticles)
    is a great source of answers to common **bookdown** questions. Use
    the tags
    [`[r][rticles]`](https://stackoverflow.com/questions/tagged/rticles+r)
    if you ask a question.

## Code of Conduct

Please note that the rticles project is released with a [Contributor
Code of Conduct](https://pkgs.rstudio.com/rticles/CODE_OF_CONDUCT.html).
By contributing to this project, you agree to abide by its terms.

## How to contribute?

Most of the templates are contributed directly by the users in the
community. If you want **rticles** to offer a new journal format, you
can contribute by the following way.

### Suggest an idea for new format opening an issue.

You may not feel confident enough or may not have time to contribute a
new format. By opening a new issue, you can share the idea for this
format, and see if someone in the community can help on it.  
This is not the best way to quickly get your format included but at
least it is a great way to see if others are interested too.

To see the existing suggested formats, just filter issues with the [help
wanted
:heart:](https://github.com/rstudio/rticles/labels/help%20wanted%20%3Aheart%3A)
label. You can then add a :+1: or help to add the template :wink:.

### Contribute a new template format opening a pull request.

To contribute a new format, you need to open a new pull request (PR).
When opening the PR, you’ll see the [PR
template](https://pkgs.rstudio.com/rticles/PULL_REQUEST_TEMPLATE.html)
explaining how to proceed and what is important to check. Please follow
it.  
Even if you are just starting or you are not finished, you share your
work by creating a [draft
PR](https://docs.github.com/en/github/collaborating-with-issues-and-pull-requests/about-pull-requests#draft-pull-requests).
It is a great way to let us know that you are still working on it (like
[these opened
ones](https://github.com/rstudio/rticles/pulls?q=is%3Apr+draft%3Atrue+)),
and it is also a great way to ask for help from the community.  
When you are ready, you can submit the PR for review, and we will
iterate until it is merged.

#### Technical resources helpful to contribute a template

The best way to get started is to look at the previous examples of
submitted PR. You’ll find links to them in the table [above](#overview).

All the `rticles` format are build similarly by providing a new pandoc
tex template to replace the default one. You’ll learn more about pandoc
templates in these places:

- [R Markdown
  Cookbook](https://bookdown.org/yihui/rmarkdown-cookbook/latex-template.html)
- [The Pandoc manual](https://pandoc.org/MANUAL.html#templates)

You can study [existing
formats](https://github.com/rstudio/rticles/tree/main/inst/rmarkdown/templates)
to see how all this works.

## Description:

The project hosts an aesthetic an simple LaTeX style suitable for "preprint" publications such as arXiv and bio-arXiv, etc. 
It is based on the [**nips_2018.sty**](https://media.nips.cc/Conferences/NIPS2018/Styles/nips_2018.sty) style.

This styling maintains the esthetic of NIPS but adding and changing features to make it (IMO) even better and nore suitable for preprints.
The result looks fairly different from NIPS style so that readers won't get confused to think that the preprint was published in NIPS. 

### Why NIPS? 
Because the NIPS styling is a comfortable single column format that is very esthetic and convenient for reading.

## Usage:
1. Use Document class **article**. 
2. Copy **arxiv.sty** to the folder containing your tex file.
3. add `\usepackage{arxiv}` after `\documentclass{article}`.
4. The only packages used in the style file are **geometry** and **fancyheader**. Do not reimport them.

See **template.tex** 

## Project files:
1. **arxiv.sty** - the style file.
2. **template.tex** - a sample template that uses the **arxiv style**.
3. **references.bib** - the bibliography source file for template.tex.
4. **template.pdf** - a sample output of the template file that demonstrated the design provided by the arxiv style.


## Handling References when submitting to arXiv.org
The most convenient way to manage references is using an external BibTeX file and pointing to it from the main file. 
However, this requires running the [bibtex](http://www.bibtex.org/) tool to "compile" the `.bib` file and create `.bbl` file containing "bibitems" that can be directly inserted in the main tex file. 
However, unfortunately the arXiv Tex environment ([Tex Live](https://www.tug.org/texlive/)) do not do that. 
So easiest way when submitting to arXiv is to create a single self-contained .tex file that contains the references.
This can be done by running the BibTeX command on your machine and insert the content of the generated `.bbl` file into the `.tex` file and commenting out the `\bibliography{references}` that point to the external references file.

Below are the commands that should be run in the project folder:
1. Run `$ latex template`
2. Run `$ bibtex template`
3. A `template.bbl` file will be generated (make sure it is there)
4. Copy the `template.bbl` file content to `template.tex` into the `\begin{thebibliography}` command.
5. Comment out the `\bibliography{references}` command in `template.tex`.
6. You ready to submit to arXiv.org.


## General Notes:
1. For help, comments, praises, bug reporting or change requests, you can contact the author at: kourgeorge/at/gmail.com.
2. You can use, redistribute and do whatever with this project, however, the author takes no responsibility on whatever usage of this project.
3. If you start another project based on this project, it would be nice to mention/link to this project.
4. You are very welcome to contribute to this project.
5. A good looking 2 column template can be found in https://github.com/brenhinkeller/preprint-template.tex.

# pandoc-shortpaper

A template for building shortpapers in pandoc using the sensys-abstract.csl latex documentclass

## Usage

To compile all markdown files to pdf

    make

## Example

[View example PDF](http://spanners.github.io/pandoc-shortpaper/example.pdf)

## Sources

* `acm-sig-proceedings.csl`: ACM SIG Proceedings Template.
  CC-SA Naeem Esfahani and Chris Horn.
  <https://github.com/citation-style-language/styles>
* `shortpaper.latex`: ...
* `sensys-abstract.cls`: ...
* ...

File: README_copernicus_package_7_8.txt
-------------------------------------------------------------------------
This is a README file for the Copernicus Publications LaTeX Macro Package 
copernicus_package.zip in the version 7.8, 18 March 2024
-------------------------------------------------------------------------
It consists of several files, each with its separate copyright.
This specific archive is collected for journals published by 
Copernicus Publications (Copernicus GmbH).

Copyright (C) 2024 Copernicus GmbH

E-mail: publications@copernicus.org
URL:   	https://publications.copernicus.org



Content:
- copernicus.cls: The LaTeX2e class file designed for Copernicus Publications journals. Current Version 10.1.11, 3 January 2024
- copernicus.cfg: The configuration file containing journal-specific information used by the class file. Last update 18 March 2024
- copernicus.bst: The bibliographic style file for BibTeX. Current Version 1.6, 20 October 2023 
- pdfscreencop.sty / pdfscreen.sty
- template.tex: A LaTeX template in journal style.

File: README_copernicus_package_7_5.txt
-------------------------------------------------------------------------
This is a README file for the Copernicus Publications LaTeX Macro Package 
copernicus_package.zip in the version 7.5, 20 October 2023
-------------------------------------------------------------------------
It consists of several files, each with its separate copyright.
This specific archive is collected for journals published by 
Copernicus Publications (Copernicus GmbH).

Copyright (C) 2023 Copernicus GmbH

E-mail: publications@copernicus.org
URL:   	https://publications.copernicus.org



Content:
- copernicus.cls: The LaTeX2e class file designed for Copernicus Publications journals. Current Version 10.1.9, 16 October 2023
- copernicus.cfg: The configuration file containing journal-specific information used by the class file. Last update 15 March 2023
- copernicus.bst: The bibliographic style file for BibTeX. Current Version 1.6, 20 October 2023 
- pdfscreencop.sty / pdfscreen.sty
- template.tex: A LaTeX template in journal style.

#' R Journal format.
#'
#' @description
#' `r lifecycle::badge('deprecated')`
#'
#' This function is now deprecated in favor of the [**rjtools**](https://rjournal.github.io/rjtools/) package
#' which is now officialy recommanded by R Journal <https://rjournal.github.io/submissions.html>. See below for document
#'
#' @details # About this format and the R Journal requirements
#'
#' Format for creating R Journal articles. Adapted from
#' <https://journal.r-project.org/submissions.html>.
#'
#' This file is only a basic article template. For full details of _The R
#' Journal_ style and information on how to prepare your article for submission,
#' see the [Instructions for Authors](https://journal.r-project.org/share/author-guide.pdf)
#'

#'
#' `rticles::rjournal_article` will help you build the correct files requirements:
#'
#' - A R file will be generated automatically using `knitr::purl` - see
#' https://bookdown.org/yihui/rmarkdown-cookbook/purl.html for more information.
#' - A tex file will be generated from this Rmd file and correctly included in
#' `RJwapper.tex` as expected to build `RJwrapper.pdf`.
#' - All figure files will be kept in the default rmarkdown `*_files` folder. This
#' happens because `keep_tex = TRUE` by default in `rticles::rjournal_article`
#' - Only the bib filename is to be modified. An example bib file is included in the
#' template (`RJreferences.bib`) and you will have to name your bib file as the
#' tex, R, and pdf files.
#'
#' # About YAML header fields
#'
#' This section documents some of the YAML fields that can be used with this
#' formats.
#'
#' ## The `author` field in the YAML header
#'
#' | FIELD  | TYPE | DESCRIPTION |
#' | ------ | ---- | ----------- |
#' | `name` | *required* | name and surname of the author |
#' | `affiliation` | *required* | name of the author's affiliation |
#' | `address` | *required* | at least one address line for the affiliation |
#' | `url` | *optional* | an additional url for the author or the main affiliation |
#' | `orcid` | *optional* | the authors ORCID if available |
#' | `email` | *required* | the author's e-mail address |
#' | `affiliation2` | *optional* | name of the author's 2nd affiliation |
#' | `address2` | *optional* | address lines belonging to the author's 2nd affiliation |
#'
#' *Please note: Only one `url`, `orcid` and `email` can be provided per author.*
#'
#' ## Other YAML fields
#'
#' | FIELD | TYPE | DESCRIPTION |
#' | ----- | ---- | ----------- |
#' | `bibliography` | *with default* | the BibTeX file with the reference entries |
#'
#' @inheritParams rmarkdown::pdf_document
#' @param ... Arguments to [rmarkdown::pdf_document()].
#' @export
rjournal_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {

  lifecycle::deprecate_warn("0.25", "rjournal_article()", "rjtools::rjournal_pdf_article()", details = "See official recommandation at https://rjournal.github.io/submissions.html")
  rmarkdown::pandoc_available("2.2", TRUE)

  base <- pdf_document_format(
    "rjournal",
    highlight = NULL, citation_package = citation_package,
    keep_tex = keep_tex, ...
  )

  # Render will generate tex file, post-knit hook gerenates the R file,
  # post-process hook generates appropriate RJwrapper.tex and
  # use pandoc to build pdf from that
  base$pandoc$to <- "latex"
  base$pandoc$ext <- ".tex"

  # Generates R file expected by R journal requirement.
  # We do that in the post-knit hook do access input file path.
  pk <- base$post_knit
  output_R <- NULL
  base$post_knit <- function(metadata, input_file, runtime, ...) {
    # run post_knit it exists
    if (is.function(pk)) pk(metadata, input_file, runtime, ...)

    # purl the Rmd file to R code per requirement
    temp_R <- tempfile(fileext = ".R")
    output_R <<- knitr::purl(input_file, temp_R, documentation = 1, quiet = TRUE)
    # Add magic comment about '"do not edit" (rstudio/rstudio#2082)
    xfun::write_utf8(c(
      "# Generated by `rjournal_article()` using `knitr::purl()`: do not edit by hand",
      sprintf("# Please edit %s to modify this file", input_file),
      "",
      xfun::read_utf8(output_R)
    ), output_R)

    NULL
  }

  base$post_processor <- function(metadata, utf8_input, output_file, clean, verbose) {
    filename <- basename(output_file)
    # underscores in the filename will be problematic in \input{filename};
    # pandoc will escape underscores but it should not, i.e., should be
    # \input{foo_bar} instead of \input{foo\_bar}
    if (filename != (filename2 <- gsub("_", "-", filename))) {
      file.rename(filename, filename2)
      filename <- filename2
    }

    # Copy purl-ed R file with the correct name
    dest_file <- xfun::with_ext(filename, "R")
    our_file <- TRUE
    if (file.exists(dest_file)) {
      # we check this file is generated by us
      # otherwise we leave it as is and warn
      current_r <- xfun::read_utf8(dest_file)
      our_file <- grepl("Generated.*rjournal_article.*do not edit by hand", current_r[1])
      if (!our_file) {
        warning(
          sprintf("R file with name '%s' already exists.", dest_file),
          "\nIt will not be overwritten by the one generated",
          " during rendering using `knitr::purl()`.",
          "\nRemove the existing file to obtain the generated one.",
          call. = FALSE
        )
      }
    }
    if (our_file) {
      # we only overwrite if it is our file
      file.copy(output_R, xfun::with_ext(filename, "R"), overwrite = TRUE)
    }
    unlink(output_R)

    # post process TEX file
    temp_tex <- xfun::read_utf8(filename)
    temp_tex <- post_process_authors(temp_tex)
    xfun::write_utf8(temp_tex, filename)

    # check bibliography name
    bib_filename <- metadata$bibliography
    if (length(bib_filename) == 1 &&
      xfun::sans_ext(bib_filename) != xfun::sans_ext(filename)) {
      msg <- paste0(
        "Per R journal requirement, bibliography file and tex file should",
        " have the same name. Currently, you have a bib file ", bib_filename,
        " and a tex file ", filename, ". Don't forget to rename and change",
        " the bibliography field in the YAML header."
      )
      warning(msg, call. = FALSE)
    }

    # Create RJwrapper.tex per R Journal requirement
    m <- list(filename = xfun::sans_ext(filename))
    h <- get_list_element(metadata, c("output", "rticles::rjournal_article", "includes", "in_header"))
    h <- c(h, if (length(preamble <- unlist(metadata[c("preamble", "header-includes")]))) {
      f <- tempfile(fileext = ".tex")
      on.exit(unlink(f), add = TRUE)
      xfun::write_utf8(preamble, f)
      f
    })
    t <- find_resource("rjournal", "RJwrapper.tex")
    template_pandoc(m, t, "RJwrapper.tex", h, verbose)

    tinytex::latexmk("RJwrapper.tex", base$pandoc$latex_engine, clean = clean)
  }

  # Mostly copied from knitr::render_sweave
  base$knitr$opts_chunk$comment <- "#>"

  set_sweave_hooks(base)
}

#' Copernicus journals format.
#'
#' Format for creating submissions to Copernicus journals.
#'
#' @inheritParams rmarkdown::pdf_document
#' @param ... Additional arguments to [rmarkdown::pdf_document()]. **Note**: `extra_dependencies` are not
#' allowed as Copernicus does not support additional packages included via \code{\\usepackage{}}.
#' @param journal_name A regular expression to filter the by the journal name, see `pattern` in [base::grep()]; defaults to `*`.
#'
#' @return An R Markdown output format.
#' @details This was adapted from
#' <https://publications.copernicus.org/for_authors/manuscript_preparation.html>.
#'
#' An number of required and optional manuscript sections, e.g. `acknowledgements`, `competinginterests`, or `authorcontribution`, must be declared using the respective properties of the R Markdown header - see skeleton file.
#'
#' **Version:** Based on `copernicus_package.zip` in the version 7.5, 20 October 2023, using `copernicus.cls` in version 10.1.9, 16 October 2023.
#'
#' **Copernicus journal abbreviations:** You can use the function `copernicus_journal_abbreviations()` to get the journal abbreviation for all journals supported by the Copernicus article template.
#'
#' **Important note:** The online guidelines by Copernicus are the official resource.
#' Copernicus is not responsible for the community contributions made to support the template in this package.
#' Copernicus converts all typeset TeX files into XML, the expressions and markups have to be highly standardized.
#' Therefore, please keep the following in mind:
#'
#' * Please provide only one figure file for figures with several panels, and please do not use `\subfloat` or similar commands.
#' * Please use only commands in which words, numbers, etc. are within braces (e.g. `\textrm{TEXT}` instead of `\rm TEXT`).
#' * For algorithms, please use the syntax given in template.tex or provide your algorithm as a figure.
#' * Please do not define new commands.
#' * Supported packages (`\usepackage{}`) are already integrated in the `copernicus.cls`.  Please do not insert additional ones in your `.tex` file.
#' * If you opt for syntax highlighting for your preprint or other reasons, please do not forget to use
#'   `highlight = NULL` for your final file upload once your manuscript was accepted for publication.
#' * Spaces in labels (`\label{}`) are not allowed; please make sure that no label name is assigned more than once.
#' * Please do not use `\paragraph{}`; only `\subsubsection{}` is allowed.
#' * It is not possible to add tables in colour.
#'
#' @note If you use [rmarkdown::pdf_document()], all internal references (i.e. tables and figures) must use `\ref{}` whereas with [bookdown::pdf_document2()], you can additionally use `\@ref()`.
#'
#' @references
#' Manuscript preparation guidelines for authors.
#' <https://publications.copernicus.org/for_authors/manuscript_preparation.html>
#'
#' @examples
#' names(copernicus_journal_abbreviations())
#' copernicus_journal_abbreviations(journal_name = "Science Data")
#' \dontrun{
#' library("rmarkdown")
#' draft("MyArticle.Rmd", template = "copernicus", package = "rticles")
#' render("MyArticle/MyArticle.Rmd")
#' }
#' @export
copernicus_article <- function(..., keep_tex = TRUE, highlight = NULL,
                               citation_package = "natbib",
                               md_extensions = c(
                                 "-autolink_bare_uris", # disables automatic links, needed for plain email in \correspondence
                                 "-auto_identifiers" # disables \hypertarget commands
                               )) {
  if ("extra_dependencies" %in% names(list(...))) {
    warning(
      "Copernicus does not support additional LaTeX packages and options!
          >> Please remove 'extra_dependencies' from your YAML header!",
      call. = FALSE
    )
  }

  pdf_document_format(
    "copernicus",
    citation_package = citation_package,
    keep_tex = keep_tex, highlight = highlight, md_extensions = md_extensions, ...
  )
}

# quick dev shortcut for Ubuntu: click "Install and restart" then run:
# unlink("MyArticle/", recursive = TRUE); rmarkdown::draft("MyArticle.Rmd", template = "copernicus", package = "rticles", edit = FALSE); rmarkdown::render("MyArticle/MyArticle.Rmd"); system(paste0("xdg-open ", here::here("MyArticle", "MyArticle.pdf")))

copernicus_journals <- list(
  "Advances in Geosciences" = "adgeo",
  "Advances in Radio Science" = "ars",
  "Advances in Science and Research" = "asr",
  "Advances in Statistical Climatology, Meteorology and Oceanography" = "ascmo",
  "Aerosol Research" = "ar",
  "Annales Geophysicae" = "angeo",
  "Archives Animal Breeding" = "aab",
  "Atmospheric Chemistry and Physics" = "acp",
  "Atmospheric Measurement Techniques" = "amt",
  "Biogeosciences" = "bg",
  "Climate of the Past" = "cp",
  "DEUQUA Special Publications" = "deuquasp",
  "Earth Surface Dynamics" = "esurf",
  "Earth System Dynamics" = "esd",
  "Earth System Science Data" = "essd",
  "E&G Quaternary Science Journal" = "egqsj",
  "EGUsphere" = "egusphere",
  "European Journal of Mineralogy" = "ejm",
  "Fossil Record" = "fr",
  "Geochronology" = "gchron",
  "Geographica Helvetica" = "gh",
  "Geoscience Communication" = "gc",
  "Geoscientific Instrumentation, Methods and Data Systems" = "gi",
  "Geoscientific Model Development" = "gmd",
  "History of Geo- and Space Sciences" = "hgss",
  "Hydrology and Earth System Sciences" = "hess",
  "Journal of Bone and Joint Infection" = "jbji",
  "Journal of Micropalaeontology" = "jm",
  "Journal of Sensors and Sensor Systems" = "jsss",
  "Magnetic Resonance" = "mr",
  "Mechanical Sciences" = "ms",
  "Natural Hazards and Earth System Sciences" = "nhess",
  "Nonlinear Processes in Geophysics" = "npg",
  "Ocean Science" = "os",
  "Primate Biology" = "pb",
  "Proceedings of the International Association of Hydrological Sciences" = "piahs",
  "Safety of Nuclear Waste Disposal" = "sand",
  "Scientific Drilling" = "sd",
  "SOIL" = "soil",
  "Solid Earth" = "se",
  "State of the Planet" = "sp",
  "The Cryosphere" = "tc",
  "Web Ecology" = "we",
  "Weather and Climate Dynamics" = "wcd",
  "Web Ecology" = "we",
  "Wind Energy Science" = "wes"
)

#' @rdname copernicus_article
#' @export
copernicus_journal_abbreviations <- function(journal_name = "*") {
  unlist(copernicus_journals[grep(
    journal_name, names(copernicus_journals),
    ignore.case = TRUE
  )])
}

#' IEEE Transactions journal format.
#'
#' Format for creating submissions to IEEE Transaction journals. Adapted from
#' <https://www.ieee.org/publications_standards/publications/authors/author_templates.html>
#'
#' Presently, only the `"conference"` paper mode offered by the
#' `IEEEtran.cls` is supported.
#'
#' @inheritParams rmarkdown::pdf_document
#' @param draftmode Specify the draft mode to control spacing and whether images
#' should be rendered. Valid options are: `"final"` (default), `"draft"`,
#' `"draftcls"`, or `"draftclsnofoot"`.
#' @param hyphenfixes A `character` value that provides the correct
#' hyphenations for ambiguous words. Separate new words with spaces.
#' @param IEEEspecialpaper  A `character` value containing the publication's
#' special paper designation.
#' @param with_ifpdf A `logical` value turning on (`TRUE`) or off
#' (`FALSE`) the `ifpdf` LaTeX package.
#' @param with_cite A `logical` value turning on (`TRUE`) or off
#' (`FALSE`) the `cite` LaTeX package.
#' @param with_amsmath A `logical` value turning on (`TRUE`) or off
#'  (`FALSE`) the `amsmath` LaTeX package.
#' @param with_algorithmic A `logical` value turning on (`TRUE`) or
#'  off (`FALSE`) the `algorithmic` LaTeX package.
#' @param with_subfig A `logical` value turning on (`TRUE`) or off
#' (`FALSE`) the `subfig` LaTeX package.
#' @param with_array A `logical` value turning on (`TRUE`) or off
#' (`FALSE`) the `array` LaTeX package.
#' @param with_dblfloatfix A `logical` value turning on (`TRUE`) or
#' off (`FALSE`) the `dblfloatfix` LaTeX package.
#' @param ... Additional arguments to [rmarkdown::pdf_document()]
#'
#' @references
#' Shell, Michael. "How to use the IEEEtran LATEX class." Journal of LATEX Class
#'  Files 1.11 (2002): 10-20.
#' <http://mirrors.rit.edu/CTAN/macros/latex/contrib/IEEEtran/IEEEtran_HOWTO.pdf>
#' @importFrom rmarkdown pandoc_variable_arg
#' @export
ieee_article <- function(draftmode = c("final", "draft", "draftcls", "draftclsnofoot"),
                         hyphenfixes = "op-tical net-works semi-conduc-tor",
                         IEEEspecialpaper = "",
                         with_ifpdf = FALSE,
                         with_cite = FALSE,
                         with_amsmath = FALSE,
                         with_algorithmic = FALSE,
                         with_subfig = FALSE,
                         with_array = FALSE,
                         with_dblfloatfix = FALSE,
                         keep_tex = TRUE,
                         pandoc_args = NULL,
                         md_extensions = c("-autolink_bare_uris"),
                         ...) {
  args <- c()

  draftmode <- match.arg(draftmode)
  args <- c(args, "draftmode" = draftmode)

  args <- c(args, "hyphenfixes" = hyphenfixes)

  # Avoid declaration of pandoc variable if field is empty
  if (nchar(IEEEspecialpaper) > 1) {
    args <- c(args, "IEEEspecialpaper" = IEEEspecialpaper)
  }

  plist <- c(
    "with_ifpdf" = with_ifpdf,
    "with_cite" = with_cite,
    "with_amsmath" = with_amsmath,
    "with_algorithmic" = with_algorithmic,
    "with_subfig" = with_subfig,
    "with_array" = with_array,
    "with_dblfloatfix" = with_dblfloatfix
  )

  args <- c(args, plist[plist])

  # Convert to pandoc arguments
  pandoc_arg_list <- list_to_pandoc_variable_args(args)

  pdf_document_format(
    "ieee",
    pandoc_args = c(pandoc_arg_list, pandoc_args),
    keep_tex = keep_tex, md_extensions = md_extensions,
    ...
  )
}

#' List available journals
#'
#' List available journal names in this package.
#'
#' These names can be useful in two ways:
#'
#' * You can add `_article` suffix to get the name of the output format (e.g.,
#' [rjournal_article()]).
#'
#' * You can use the name directly in the `template` argument of
#' [rmarkdown::draft()].
#' @return A character vector of the journal names.
#' @export
#' @md
#' @examples
#' rticles::journals()
journals <- function() {
  sort(dir(pkg_file_template()))
}

find_resource <- function(template, file = "template.tex") {
  res <- pkg_file_template(template, "resources", file)
  if (res == "") {
    stop(
      "Couldn't find template file ", template, "/resources/", file,
      call. = FALSE
    )
  }
  res
}

knitr_fun <- function(name) utils::getFromNamespace(name, "knitr")

output_asis <- knitr_fun("output_asis")

merge_list <- function(x, y) {
  fun <- knitr_fun("merge_list")
  fun(as.list(x), y)
}

#' Render a pandoc template.
#'
#' This is a hacky way to access the pandoc templating engine.
#'
#' @param metadata A named list containing metadata to pass to template.
#' @param template Path to a pandoc template.
#' @param output Path to save output.
#' @param in_header Paths to files to include in the header.
#' @return (Invisibly) The path of the generate file.
#' @examples
#' x <- rticles:::template_pandoc(
#'   list(preamble = "%abc", filename = "wickham"),
#'   rticles:::find_resource("rjournal", "RJwrapper.tex"),
#'   tempfile()
#' )
#' if (interactive()) file.show(x)
#' @noRd
template_pandoc <- function(metadata, template, output,
                            in_header = NULL, verbose = FALSE) {
  tmp <- tempfile(fileext = ".md")
  on.exit(unlink(tmp), add = TRUE)
  xfun::write_utf8(c("---", yaml::as.yaml(metadata), "---\n"), tmp)

  rmarkdown::pandoc_convert(
    tmp,
    output = output, verbose = verbose, wd = ".",
    options = c(
      "--template", rmarkdown::pandoc_path_arg(template),
      rmarkdown::pandoc_include_args(in_header)
    )
  )
  invisible(output)
}

# recursion into a list to get an element using a vector of names
get_list_element <- function(x, names) {
  n <- length(names)
  if (!is.list(x) || n == 0) {
    return()
  }
  for (i in names[seq_len(n - 1)]) if (!is.list(x <- x[[i]])) {
    return()
  }
  x[[names[n]]]
}

pkg_file <- function(...) system.file(..., package = "rticles")

pkg_file_template <- function(...) pkg_file("rmarkdown", "templates", ...)

# utils for post processing tex files

# correct authors field to the form "Author 1, Author 2, and Author 3"
post_process_authors <- function(text) {
  i1 <- grep("^\\\\author\\{", text)
  # if no author line do nothing
  if (length(i1) == 0L) {
    return(text)
  }
  # if multiple author line, do nothing and warn as it is unusual
  if (length(i1) > 1L) {
    warning(
      "There should be only one instance of '\\author{}' in the tex file. ",
      "Post-processing \\author{} is cancelled.",
      call. = FALSE
    )
    return(text)
  }
  i2 <- grep("\\}$", text)
  i2 <- i2[i2 >= i1][1] # the first line that ends with } after \author{
  i <- i1:i2 # the authors lines range
  # combine and write back
  x1 <- paste0(text[i], collapse = "\n")
  x2 <- knitr::combine_words(strsplit(x1, split = ", ")[[1]])
  text[i] <- xfun::split_lines(x2)
  # return modified text
  text
}


# render a skeleton in a temp directory
render_draft <- function(journal, output_options = NULL, quiet = FALSE) {
  dir <- tempfile()
  dir.create(dir)
  oldwd <- setwd(dir)
  on.exit(setwd(oldwd), add = TRUE)
  # create a draft of the format
  doc <- paste0(journal, "_article", ".Rmd")
  rmarkdown::draft(doc, template = journal, package = "rticles", create_dir = FALSE, edit = FALSE)
  # render the file in the temp dir
  message(
    "Rendering the ", journal, " format...",
    if (!is.null(output_options)) " (with output options)"
  )
  output_file <- xfun::Rscript_call(
    fun = rmarkdown::render,
    args = list(doc, output_options = output_options, quiet = quiet)
  )
}

# Use to create variables command for Pandoc from a named vector
list_to_pandoc_variable_args <- function(v_args) {
  # v_args must be named
  # stopifnot(length(names(v_args) > 0)

  truthy <- which(sapply(v_args, isTRUE))
  truthy_arg <- NULL
  if (length(truthy) > 0) {
    truthy_arg <- mapply(
      rmarkdown::pandoc_variable_arg,
      names(v_args[truthy]),
      SIMPLIFY = FALSE,
      USE.NAMES = FALSE
    )
    v_args <- v_args[-truthy]
  }

  # remove named args which are false
  falsy <- sapply(v_args, isFALSE)
  if (any(falsy)) {
    v_args <- v_args[-which(falsy)]
  }

  # Convert to pandoc arguments
  pandoc_arg_list <-  c(
    mapply(
      rmarkdown::pandoc_variable_arg,
      names(v_args),
      v_args,
      SIMPLIFY = FALSE,
      USE.NAMES = FALSE
    ),
    truthy_arg
  )
  unlist(pandoc_arg_list)
}

## takes a character string with names separated by comma (e.g. journal's names)
## and turns them into a table

#' Split character string into table
#'
#' It takes a character string with names separated by comma (e.g. journal's names)
#' and turns them into a table
#'
#' If the number of elements can't be split equally in the `n` column, blank
#' cells will be created and all placed in the last column.
#'
#' @param x string to split and convert to table
#' @param n number of bucket to create. It will be the number of column in the
#'   resulting data.frame
#' @param split_regex defaults to `, ?`. Pass to `split` in [base::strsplit()].
#'
#' @return a dataframe of `n` columns
#' @export
#'
#' @examples
#' string_to_table(paste(letters, collapse = ", "), 3)
string_to_table <- function(x, n, split_regex = ", ?") {
  vec <- unlist(strsplit(x, split_regex))
  vec_list <- split(vec, cut(seq_along(vec), n, labels = FALSE))
  max_n <- max(unlist(lapply(vec_list, length)))
  # fill with NA
  for (i in 1:n) {
    # resize bucket
    length(vec_list[[i]]) <- max_n
    # and move empty spot at the end
    if (i != n && any(ii  <- is.na(vec_list[[i]]))) {
      vec_list[[i]][ii] <- vec_list[[i + 1]][seq_along(which(ii))]
      vec_list[[i + 1]] <- vec_list[[i + 1]][-seq_along(which(ii))]
    }
  }
  df <- data.frame(vec_list)
  df[is.na(df)] <- ""
  df
}

# Helper function to create a custom format derived from pdf_document that
# includes a custom LaTeX template
pdf_document_format <- function(format,
                                template = find_resource(format, "template.tex"),
                                ...) {

  fmt <- rmarkdown::pdf_document(..., template = template)
  fmt$inherits <- "pdf_document"

  ## Set some variables to adapt template based on Pandoc version
  args <- list_to_pandoc_variable_args(list(
    pandoc3 = rmarkdown::pandoc_available("3"),
    pandoc317 = rmarkdown::pandoc_available("3.1.7"), # new citeproc command
    pandoc318 = rmarkdown::pandoc_available("3.1.8") # revised citeproc command
  ))
  fmt$pandoc$args <- c(fmt$pandoc$args, args)
  fmt
}


is_citeproc_pandoc_args <- function(args) {
  "--citeproc" %in% args || "--natbib" %notin% args || "--biblatex" %notin% args
}

`%notin%` <- Negate(`%in%`)

test_that("vec_to_table split using default separator", {
  x <- paste(letters, collapse = ", ")
  df <- string_to_table(x, 3)
  df_target <-
    structure(list(
      X1 = c("a", "b", "c", "d", "e", "f", "g", "h",
             "i"),
      X2 = c("j", "k", "l", "m", "n", "o", "p", "q", "r"),
      X3 = c("s",
             "t", "u", "v", "w", "x", "y", "z", "")
    ),
    row.names = c(NA, -9L),
    class = "data.frame")
  expect_identical(df, df_target)
})

test_that("vec_to_table split using custom separator", {
  x <- paste(letters, collapse = "#")
  df <- string_to_table(x, 3, "#")
  df_target <-
    structure(list(
      X1 = c("a", "b", "c", "d", "e", "f", "g", "h",
             "i"),
      X2 = c("j", "k", "l", "m", "n", "o", "p", "q", "r"),
      X3 = c("s",
             "t", "u", "v", "w", "x", "y", "z", "")
    ),
    row.names = c(NA, -9L),
    class = "data.frame")
  expect_identical(df, df_target)
})

# Run only on CI
skip_on_cran()

temp_file <- list.files(pkg_file_template(), recursive = TRUE, pattern = "template.tex$", full.names = TRUE)

# Rjournal template has another name
temp_file[grep("rjournal", temp_file)] <- pkg_file_template("rjournal", "resources", "RJwrapper.tex")

expect_contains <- function(file, pattern, nb = 1, ...) {
  content <- xfun::read_utf8(file)
  matched <- grepl(pattern, content, ...)
  if (any(matched) && sum(matched) == nb) {
    succeed()
    return(invisible(file))
  }
  msg <- if (!any(matched)) {
    sprintf(
      "%s template does not contains %s",
      sQuote(basename(dirname(dirname(file)))),
      dQuote(pattern)
    )
  } else {
    sprintf(
      "%s template contains %s instead of %s",
      sQuote(basename(dirname(dirname(file)))),
      sum(matched),
      nb
    )
  }
  fail(msg)
}


test_that("highlighting macros is in all templates", {
  for (f in temp_file) {
    expect_contains(f, "if(highlighting-macros)", fixed = TRUE)
  }
})


test_that("tightlist is defined in all templates", {
  for (f in temp_file) {
    expect_contains(f, "\\\\providecommand.\\\\tightlist..%")
  }
})

test_that("part for Pandoc's tables is defined in all templates", {
  for (f in temp_file) {
    expect_contains(f, "if(tables)", fixed = TRUE)
  }
})

test_that("CSL-ref part for Pandoc's citeproc are in all templates", {
  for (f in temp_file) {
    expect_contains(f, "if(csl-refs)", fixed = TRUE)
    expect_contains(f, "if(pandoc318)", fixed = TRUE)
  }
})

test_that("header-includes is in all templates", {
  for (f in temp_file) {
    expect_contains(f, "for(header-includes)", fixed = TRUE)
  }
})

test_that("include-before is in all templates", {
  for (f in temp_file) {
    expect_contains(f, "for(include-before)", fixed = TRUE)
  }
})

test_that("include-after is in all templates", {
  for (f in temp_file) {
    expect_contains(f, "for(include-after)", fixed = TRUE)
  }
})

#' Journal of Open Source Software (JOSS) format.
#'
#' Format for creating a Journal of Open Source Software (JOSS) or Journal of
#' Open Source Education (JOSE) articles. Adapted
#' from <https://github.com/openjournals/whedon>. As these journals take
#' articles as markdown, this format can be used to generate markdown from
#' R Markdown and to locally preview how the article will appear as PDF.
#'
#' The following variables may be set in YAML metadata to populate fields in the
#' article PDF, but are only necessary fo local preview:
#' `formatted_doi, citation_author, year, volume, issue, page, submitted, published,
#' review_url, repository`, and `archive_doi`.
#'
#' @param journal one of "JOSS" or"JOSE"
#' @param keep_md Whether to retain the intermediate markdown and images.
#'   Defaults to TRUE.
#' @param latex_engine,... Arguments passed to [rmarkdown::pdf_document()]
#' @export
joss_article <- function(journal = "JOSS",
                         keep_md = TRUE,
                         latex_engine = "xelatex",
                         ...) {
  rmarkdown::pandoc_available("2.2", TRUE)

  logo_path <- find_resource("joss", paste0(journal, "-logo.png"))
  journalname <- ifelse(journal == "JOSS",
    "Journal of Open Source Software",
    "Journal of Open Source Education"
  )

  pdf_document_format(
    "joss",
    latex_engine = latex_engine,
    citation_package = "default",
    keep_md = keep_md,
    pandoc_args = c(
      "-V", paste0("logo_path=", logo_path),
      "-V", paste0("journal_name=", journalname),
      "-V", "graphics=true"
    ),
    ...
  )
}

test_format <- function(name, output_options = NULL, skip = NULL) {

  withr::local_options(lifecycle_verbosity = "quiet")

  # don't run on CRAN due to complicated dependencies (Pandoc/LaTeX packages)
  if (!identical(Sys.getenv("NOT_CRAN"), "true")) return()
  # skip if requested
  if (!is.null(skip) && isTRUE(skip)) return()

  # work in a temp directory
  dir <- tempfile()
  dir.create(dir)
  oldwd <- setwd(dir)
  on.exit(setwd(oldwd), add = TRUE)

  # create a draft of the format
  testdoc <- paste0(name, "_article", ".Rmd")
  rmarkdown::draft(
    testdoc, pkg_file_template(name),
    create_dir = FALSE, edit = FALSE
  )

  message(
    "Rendering the ", name, " format...",
    if (!is.null(output_options)) " (with output options)"
  )
  output_file <- rmarkdown::render(testdoc, output_options = output_options, quiet = TRUE)
  assert(paste(name, "format works"), {
    file.exists(output_file)
  })
}

#--- NOTE to contributors ------------------------------------------------------
# Please order these tests by formats alphabetically.
#-------------------------------------------------------------------------------

test_format("acm")
test_format("acs")
test_format("aea")
test_format("agu")
test_format("ajs", skip = !rmarkdown::pandoc_available("2.7"))
test_format("amq")
test_format("ams", output_options = list(citation_package = "default"), skip = rmarkdown::pandoc_available("3.1.7")) # ISSUE TO SOLVE WITH NATBIB / CITEPROC - See #444
test_format("arxiv")
test_format("asa")
test_format("bioinformatics")
test_format("biometrics")
test_format("copernicus")
test_format("ctex", skip = !xfun::is_linux()) # only on linux due to fonts requirements
test_format("elsevier", skip = !rmarkdown::pandoc_available("2.10"))
test_format("frontiers")
test_format("frontiers", output_options = list(citation_package = "default"), skip = rmarkdown::pandoc_available("3.1.7"))
test_format("glossa")
test_format("ieee")
test_format("ims")
test_format("ims", output_options = list(journal = "aap"))
test_format("informs", skip = !rmarkdown::pandoc_available("2.10"))
test_format("isba", skip = !rmarkdown::pandoc_available("2.10"))
test_format("iop")
test_format("jasa")
test_format("jedm")
test_format("joss")
test_format("joss", output_options = list(journal = "JOSE"))
test_format("jss", skip = !rmarkdown::pandoc_available("2.7"))
test_format("lncs")
test_format("lncs", output_options = list(citation_package = "natbib"))
test_format("lipics")
test_format("mdpi")
test_format("mnras")
test_format("oup_v0")
test_format("oup_v1", skip = !rmarkdown::pandoc_available("2.10"))
test_format("peerj")
test_format("pihph")
test_format("plos")
test_format("pnas")
test_format("rjournal")
test_format("rsos")
test_format("rss")
test_format("sage")
test_format("sim")
test_format("springer", skip = !rmarkdown::pandoc_available("2.11.4"))
test_format("tf")
test_format("trb")
# Deactivate because of https://github.com/rstudio/rticles/issues/523
# test_format("wellcomeor")

#' Journal of Statistical Software (JSS) format.
#'
#' Format for creating a Journal of Statistical Software (JSS) articles. Adapted
#' from <https://www.jstatsoft.org/about/submissions>.
#' @inheritParams rmarkdown::pdf_document
#' @param ... Arguments to [rmarkdown::pdf_document()]
#' @export
jss_article <- function(..., keep_tex = TRUE, citation_package = "natbib",
                        pandoc_args = NULL) {

  rmarkdown::pandoc_available("2.7", TRUE)

  pandoc_args <- c(
    pandoc_args,
    "--lua-filter", pkg_file("rmarkdown", "lua", "short-title.lua")
  )

  base <- pdf_document_format(
    "jss",
    keep_tex = keep_tex, citation_package = citation_package,
    pandoc_args = pandoc_args, ...
  )

  # Mostly copied from knitr::render_sweave
  base$knitr$opts_knit$out.format <- "sweave"

  base$knitr$opts_chunk <- merge_list(base$knitr$opts_chunk, list(
    prompt = TRUE, comment = NA, highlight = FALSE, tidy = FALSE,
    dev.args = list(pointsize = 11), fig.align = "center",
    R.options = list(prompt = "R> ", continue = "+ "),
    fig.width = 4.9, # 6.125" * 0.8, as in template
    fig.height = 3.675 # 4.9 * 3:4
  ))

  base$pandoc$ext <- ".tex"
  post <- base$post_processor
  # a hack for https://github.com/rstudio/rticles/issues/100 to add \AND to the author list
  base$post_processor <- function(metadata, input, output, clean, verbose) {
    if (is.function(post)) output <- post(metadata, input, output, clean, verbose)
    f <- xfun::with_ext(output, ".tex")
    x <- xfun::read_utf8(f)
    x <- gsub("(\\\\AND )\\\\And ", "\\1", x)
    x <- gsub(" \\\\AND(\\\\\\\\)$", "\\1", x)
    xfun::write_utf8(x, f)
    tinytex::latexmk(
      f, base$pandoc$latex_engine,
      if ("--biblatex" %in% base$pandoc$args) "biber" else "bibtex"
    )
  }

  set_sweave_hooks(base, c("CodeInput", "CodeOutput", "CodeChunk"))
}

#' Austrian Journal of Statistics (AJS) format.
#'
#' Format for creating a Austrian Journal of Statistics (AJS) article. Adapted
#' from <https://www.jstatsoft.org/about/submissions>.
#' @inheritParams jss_article
#' @importFrom rmarkdown pandoc_variable_arg
#' @export
ajs_article <- function(..., keep_tex = TRUE, citation_package = "natbib",
                        pandoc_args = NULL) {

  rmarkdown::pandoc_available("2.7", TRUE)

  # set documentclass to ajs for this template
  pandoc_args <- c(
    pandoc_args,
    rmarkdown::pandoc_variable_arg("documentclass", "ajs")
  )

  jss_article(...,
    keep_tex = keep_tex,
    citation_package = citation_package,
    pandoc_args = pandoc_args
  )
}

# wrap the content in a raw latex block
latex_block <- function(hook) {
  force(hook)
  function(x, options) {
    x2 <- hook(x, options)
    x3 <- if (identical(x, x2)) x else paste0("```{=latex}\n", x2, "\n```")
    if (is.null(s <- options$indent)) return(x3)
    # knitr:::line_prompt equivalent
    paste0(s, gsub('(?<=\n)(?=.|\n)', s, x3, perl = TRUE))
  }
}

# use knitr's sweave hooks, but wrap chunk output in raw latex blocks
set_sweave_hooks <- function(base, ...) {
  hooks <- knitr::hooks_sweave(...)
  hooks[["chunk"]] <- latex_block(hooks[["chunk"]])
  base$knitr$knit_hooks <- merge_list(base$knitr$knit_hooks, hooks)
  base
}

assert("last author is prepend with and ", {
  # if no author line, unmodified
  unmodified <- c("No author line", "returns unmodified")
  (post_process_authors(unmodified) %==% unmodified)

  # one author is unchanged
  (post_process_authors("\\author{John Doe}") %==%
    "\\author{John Doe}")

  # when 2 or more, add a 'and'
  (post_process_authors(c("\\title{title}", "\\author{John, Bob}")) %==%
    c("\\title{title}", "\\author{John and Bob}"))
  (post_process_authors("\\author{John, Bob, Mary}") %==%
    "\\author{John, Bob, and Mary}")

  # Works also if authors on 2 or more lines in the tex file
  (post_process_authors(
    c("\\author{John, Bob,", "Mary, Dany}", "\\abstract{text}")
  ) %==%
    c("\\author{John, Bob,", "Mary, and Dany}", "\\abstract{text}"))
  (post_process_authors(
    c("\\title{title}", "\\author{John, Bob,", "Lucy, Ann,", "Mary, Dany}")
  ) %==%
    c("\\title{title}", "\\author{John, Bob,", "Lucy, Ann,", "Mary, and Dany}"))

  # handles the weird case where two or more \\authors are used in the document
  unmodified <- c("\\author{John, Bob}", "some text", "\\author{Mary, Dany}")
  (suppressWarnings(post_process_authors(unmodified)) %==% unmodified)
})

assert("all journals are listed and have a template folder", {
  all <- grep("_article$", getNamespaceExports("rticles"), value = TRUE)
  all <- gsub("_article$", "", all)
  folder_name <- journals()
  # Special case for format function handling several version of template
  folder_name <- unique(gsub("^([^_]+)_.*$", "\\1", folder_name))
  (folder_name %==% sort(all))
})

assert("Named vector is transformed to pandoc variable args", {
  (list_to_pandoc_variable_args(c(a = "b")) %==%
    c(rmarkdown::pandoc_variable_arg("a", "b"))
  )
  (list_to_pandoc_variable_args(c(a = "b", c = "d")) %==%
    c(
      rmarkdown::pandoc_variable_arg("a", "b"),
      rmarkdown::pandoc_variable_arg("c", "d")
    )
  )
  (list_to_pandoc_variable_args(list(c = TRUE)) %==%
    c(
      rmarkdown::pandoc_variable_arg("c")
    )
  )
  (list_to_pandoc_variable_args(list(c = TRUE, d = FALSE)) %==%
    c(
      rmarkdown::pandoc_variable_arg("c")
    )
  )
  (list_to_pandoc_variable_args(list(a = "b", c = TRUE, d = FALSE)) %==%
    c(
      rmarkdown::pandoc_variable_arg("a", "b"),
      rmarkdown::pandoc_variable_arg("c")
    )
  )
})

#' Oxford University Press.
#'
#' Format for creating submissions to many Oxford University Press journals.
#' Adapted from
#' <https://academic.oup.com/pages/authoring/journals/preparing_your_manuscript>
#' and <https://academic.oup.com/icesjms/pages/General_Instructions>. and the
#' `oup-authoring-template` available on CTAN at
#' <https://www.ctan.org/pkg/oup-authoring-template>.
#'
#' Note that for
#'
#' * `oup_version=0`, `citation_package="default"` by default,
#' * `oup_version=1`, `citation_package="natbib"` by default and
#' `citation_package="biblatex"` is not supported.
#'
#' # Pandoc requirement
#'
#' `oup_version = 1` requires a minimum version of 2.10.
#'
#' @inheritParams rmarkdown::pdf_document
#' @param oup_version set to 0 (default) to use the 2009 OUP `ouparticle.cls`
#'   included or set to 1 to use the newer 2020 OUP package
#'   `oup-authoring-template` available on CTAN.
#' @param journal journal Title. *(Only useful for `oup_version > 0`)*.
#' @param number_sections It will be passed to [rmarkdown::pdf_document()]. Set to
#'   TRUE by default when `oup_version = 1` is used.
#' @param document_style one of "contemporary" (default), "modern", or
#'   "traditional" setting overall style of document. *(Only useful for `oup_version > 0`)*
#' @param papersize one of "large" (default), "medium", or "small" setting
#'   output page size. *(Only useful for `oup_version > 0`)*
#' @param namedate a logical variable
#'   indicating if natbib citations should be in name-date format. Defaults to
#'   `FALSE`. *(Only useful for `oup_version > 0`)*
#' @param onecolumn a logical variable indicating if one column formatting
#'   should be used. Defaults to `FALSE`. *(Only useful for `oup_version > 0`)*
#' @param number_lines,number_lines_options Control the usage of CTAN package
#'   `lineno` in the template. Use `number_lines =TRUE` to activate and set
#'   `number_lines_options` to change options. *(Only useful for `oup_version > 0`)*
#' @param ... Additional arguments to [rmarkdown::pdf_document()]
#'
#' @export
#' @examples \dontrun{
#' # Use old template based on `ouparticle.cls`
#' rmarkdown::draft("MyArticle.Rmd", template = "oup_v0", package = "rticles")
#' # Use new template based on `oup-authoring-template` CTAN package
#' rmarkdown::draft("MyArticle.Rmd", template = "oup_v1", package = "rticles")
#' }
#' @importFrom rmarkdown pandoc_variable_arg
oup_article <- function( # Controls template to use. 1 for newer template.
                        oup_version = 0,
                        journal = NULL,
                        number_sections = FALSE,
                        citation_package = ifelse(oup_version == 0, "default", "natbib"),
                        papersize = c("large", "medium", "small"),
                        document_style = c("contemporary", "modern", "traditional"),
                        namedate = FALSE,
                        onecolumn = FALSE,
                        number_lines = FALSE,
                        number_lines_options = NULL,
                        keep_tex = TRUE,
                        md_extensions = c("-autolink_bare_uris"),
                        pandoc_args = NULL,
                        ...) {
  # Only two version available for now
  oup_version <- match.arg(as.character(oup_version), c("0", "1"))

  # Use old template
  if (oup_version == "0") {
    return(
      pdf_document_format("oup_v0",
        keep_tex = keep_tex,
        md_extensions = md_extensions,
        pandoc_args = pandoc_args,
        number_sections = number_sections,
        citation_package = citation_package,
        ...
      )
    )
  }

  # oup_version == "1" - new template --------------

  if (!rmarkdown::pandoc_available("2.10")) {
    stop("oup_article with oup_version > 0 requires a minimum of pandoc 2.10.")
  }

  # change of defaults
  if (missing(number_sections)) number_sections <- TRUE

  if (!citation_package %in% c("natbib", "default")) {
    stop("Only `natbib` or `default` is supported for `oup_version = 1`")
  }
  papersize <- match.arg(papersize)
  document_style <- match.arg(document_style)

  args <- c(
    journal = journal,
    papersize = papersize,
    document_style = document_style
  )

  # Convert to pandoc arguments
  args <- list_to_pandoc_variable_args(args)

  # namedate
  if (namedate) {
    args <- c(args, rmarkdown::pandoc_variable_arg("namedate"))
  }

  # onecolumn
  if (onecolumn) {
    args <- c(args, rmarkdown::pandoc_variable_arg("onecolumn"))
  }

  # line numbers
  if (number_lines) {
    args <- c(args, rmarkdown::pandoc_variable_arg("numberlines"))
    if (!is.null(number_lines_options)) {
      args <- c(
        args,
        rmarkdown::pandoc_variable_arg(
          "numberlines-options",
          paste(number_lines_options, collapse = ",")
        )
      )
    }
  }

  pdf_document_format(
    "oup_v1",
    keep_tex = keep_tex,
    md_extensions = md_extensions,
    citation_package = citation_package,
    pandoc_args = c(args, pandoc_args),
    number_sections = number_sections,
    ...
  )
}

# Helper script for updating .cls file in this package

# JSS article -------------------------------------------------------------
# From https://www.jstatsoft.org/pages/view/style
dir.create(tmp_dir <- tempfile())
bundle <- "https://www.jstatsoft.org/public/journals/1/jss-article-tex.zip"
new_jss <- xfun::in_dir(tmp_dir, {
  xfun::download_file(bundle)
  unzip(basename(bundle))
  xfun::normalize_path(
    c(cls = "jss.cls", bst = "jss.bst", logo = "jsslogo.jpg")
  )
})
file.copy(new_jss,
          "inst/rmarkdown/templates/jss/skeleton/",
          overwrite = TRUE)
unlink(tmp_dir, recursive = TRUE)
# Check git diff and commit

#--- NOTE to contributors ------------------------------------------------------
# Please order these format functions alphabetically.
#-------------------------------------------------------------------------------

#' R Markdown output formats for (journal) articles
#'
#' Most article formats are based on [rmarkdown::pdf_document()], with a
#' custom Pandoc LaTeX template and different default values for other arguments
#' (e.g., `keep_tex = TRUE`).
#'
#' @param
#' ...,number_sections,keep_tex,latex_engine,citation_package,highlight,fig_caption,md_extensions,template,pandoc_args
#' Arguments passed to [rmarkdown::pdf_document()].
#' @section Details: You can find more details about each output format below.
#' @name acm_article
#' @rdname article
NULL

#' @section `acm_article`: Format for creating an Association for Computing
#'   Machinery (ACM) articles. Adapted from
#'   <https://www.acm.org/publications/proceedings-template>.

#' @return An R Markdown output format.
#' @examples \dontrun{
#' rmarkdown::draft("MyArticle.Rmd", template = "acm", package = "rticles")
#' rmarkdown::draft("MyArticle.Rmd", template = "asa", package = "rticles")
#' }
#' @export
#' @rdname article
acm_article <- function(...) {
  pdf_document_format("acm", ...)
}

#' @section `acs_article`: Format for creating an American Chemical Society
#'   (ACS) Journal articles. Adapted from
#'   `https://pubs.acs.org/page/4authors/submission/tex.html`
#' @export
#' @rdname article
acs_article <- function(..., keep_tex = TRUE,
                        md_extensions = c("-autolink_bare_uris"),
                        fig_caption = TRUE) {
  pdf_document_format(
    "acs",
    keep_tex = keep_tex, md_extensions = md_extensions,
    fig_caption = fig_caption, ...
  )
}

#' @section `aea_article`: Format for creating submissions to the American
#'   Economic Association (AER, AEJ, JEL, PP).
#' @export
#' @rdname article
aea_article <- function(..., keep_tex = TRUE,
                        md_extensions = c("-autolink_bare_uris")) {
  pdf_document_format(
    "aea",
    keep_tex = keep_tex, md_extensions = md_extensions, ...
  )
}

#' @section `agu_article`: Format for creating a American Geophysical Union
#'   (AGU) article. Adapted from
#'   <https://www.agu.org/publish-with-agu/publish#1>.
#' @export
#' @rdname article
agu_article <- function(..., keep_tex = TRUE,
                        citation_package = "natbib", highlight = NULL,
                        md_extensions = c("-autolink_bare_uris", "-auto_identifiers")) {
  pdf_document_format(
    "agu",
    keep_tex = keep_tex, highlight = highlight,
    citation_package = citation_package, md_extensions = md_extensions, ...
  )
}

#' @section `amq_article`: Ce format a été adapté du format du bulletin de
#'   l'AMQ.
#' @export
#' @rdname article
amq_article <- function(..., latex_engine = "xelatex", keep_tex = TRUE,
                        fig_caption = TRUE, md_extensions = c("-autolink_bare_uris")) {
  pdf_document_format(
    "amq",
    latex_engine = latex_engine, highlight = NULL, keep_tex = keep_tex,
    md_extensions = md_extensions, fig_caption = fig_caption, ...
  )
}

#' @section `ams_article`: Format for creating an American Meteorological
#'   Society (AMS) Journal articles. Adapted from
#'   <https://www.ametsoc.org/ams/index.cfm/publications/authors/journal-and-bams-authors/author-resources/latex-author-info/>.
#' @export
#' @rdname article
ams_article <- function(..., keep_tex = TRUE,
                        md_extensions = c("-autolink_bare_uris")) {
  pdf_document_format(
    "ams",
    keep_tex = keep_tex, md_extensions = md_extensions, ...
  )
}

#' @section `asa_article`: This format was adapted from The American
#'   Statistician (TAS) format, but it should be fairly consistent across
#'   American Statistical Association (ASA) journals.
#' @export
#' @rdname article
asa_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  if (citation_package == "biblatex") {
    stop("ASA template does not support `biblatex` for citation processing.")
  }
  pdf_document_format(
    "asa",
    keep_tex = keep_tex, citation_package = citation_package, ...
  )
}

#' @section `arxiv_article`: Adapted from the George Kour's format for
#'   arXiv and bio-arXiv preprints. So far as I'm aware, entirely
#'   unofficial but still a staple.
#' @export
#' @rdname article
arxiv_article <- function(..., keep_tex = TRUE) {
  pdf_document_format(
    "arxiv",
    keep_tex = keep_tex, ...
  )
}

#' @section `bioinformatics_article`: Format for creating submissions to a Bioinformatics journal. Adapted from
#' <https://academic.oup.com/bioinformatics/pages/submission_online>.
#' @export
#' @rdname article
bioinformatics_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  pdf_document_format(
    "bioinformatics",
    keep_tex = keep_tex, citation_package = citation_package,
    md_extensions = "-auto_identifiers", ...
  )
}

#' @section `biometrics_article`: This format was adapted from the
#'   Biometrics journal.
#' @export
#' @rdname article
biometrics_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  pdf_document_format(
    "biometrics",
    keep_tex = keep_tex, citation_package = citation_package, ...
  )
}

#' @section `ctex_article`: A wrapper function for
#'   [rmarkdown::pdf_document()] and the default value of
#'   `latex_engine` is changed to \command{xelatex}, so it works better for
#'   typesetting Chinese documents with the LaTeX package \pkg{ctex}. The
#'   function `ctex` is an alias of `ctex_article`.
#' @export
#' @rdname article
ctex_article <- function(..., template = "default", latex_engine = "xelatex") {
  pdf_document_format(
    "ctex",
    latex_engine = latex_engine, template = template, ...
  )
}

#' @export
#' @rdname article
ctex <- ctex_article

#' @section `elsevier_article`: Format for creating submissions to Elsevier
#'   journals. Adapted from
#'   <https://www.elsevier.com/researcher/author/policies-and-guidelines/latex-instructions>.
#'
#' It requires a minimum version of 2.10 for Pandoc.
#' @export
#' @rdname article
elsevier_article <- function(..., keep_tex = TRUE,
                             md_extensions = c("-autolink_bare_uris"),
                             citation_package = "natbib") {
  if (citation_package == "biblatex") {
    stop("Elsevier template does not support `biblatex` for citation processing.")
  }
  if (!rmarkdown::pandoc_available("2.10")) {
    stop("`elsevier_article()` now requires a minimum of pandoc 2.10.")
  }
  pdf_document_format(
    "elsevier",
    keep_tex = keep_tex, md_extensions = md_extensions,
    citation_package = citation_package, ...
  )
}

#' @section `frontiers_article`: Format for creating Frontiers journal
#'   articles. Adapted from
#'   <https://www.frontiersin.org/about/author-guidelines>.
#' @export
#' @rdname article
frontiers_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  # check all arguments for format's default
  if (citation_package != "natbib" && rmarkdown::pandoc_available("3.1.7")) {
    stop("Frontiers template only supports 'natbib' for citation processing. Pandoc citeproc is no more compatible with the Frontier documentclass.")
  }
  pdf_document_format("frontiers", keep_tex = keep_tex, citation_package = citation_package,...)
}


#' @section `glossa_article`: Format for creating submissions to Glossa: a
#'   journal of general linguistics. Author Guidelines are available on
#'   [www.glossa-journal.org](https://www.glossa-journal.org/site/author-guidelines/).
#'    Template is adapted from <https://github.com/guidovw/Glossalatex>.
#' @export
#' @rdname article
glossa_article <- function(..., keep_tex = TRUE, latex_engine = "xelatex") {
  format <- pdf_document_format(
    "glossa",
    keep_tex = keep_tex, latex_engine = latex_engine, ...
  )
  if (tinytex::is_tinytex() && tinytex::check_installed("microtype")) {
    # TODO: known conflict - remove when fixed
    tinytex::tlmgr_remove("microtype")
    fun <- format$on_exit
    format$on_exit <- function() {
      if (is.function(fun)) fun()
      if (!tinytex::check_installed("microtype")) tinytex::tlmgr_install("microtype")
    }
  }
  format
}

#' @param journal one of `"aoas"`, `"aap"`, `"aop"`, `"aos"`, `"sts"` for `ims_article`
#' @section `ims_article`: Format for creating submissions to the Institute of Mathematical Statistics
#' [IMS](https://imstat.org/) journals and publications. Adapted from
#' <https://github.com/vtex-soft/texsupport.ims-aoas>.
#'
#' The argument `journal` accepts the acronym of any of the
#' [journals](https://www.e-publications.org/ims/support/ims-instructions.html) in IMS:
#' * `aap`: The Annals of Applied Probability
#' * `aoas`: The Annals of Applied Statistics
#' * `aop`: The Annals of Probability
#' * `aos`: The Annals of Statistics
#' * `sts`: Statistical Science
#' @export
#' @rdname article
ims_article <- function(journal = c("aoas", "aap", "aop", "aos", "sts"),
                        keep_tex = TRUE, citation_package = "natbib",
                        md_extensions = c(
                          "-autolink_bare_uris" # disables automatic links
                        ), pandoc_args = NULL, ...) {
  journal <- match.arg(journal)

  with_kwsc <- journal %in% c("aap", "aop", "aos") # with keyword_subclass

  args <- c(
    "journal" = journal,
    if (with_kwsc) c("with_kwsc" = with_kwsc)
  )

  # Convert to pandoc arguments
  pandoc_arg_list <- list_to_pandoc_variable_args(args)

  pdf_document_format(
    "ims",
    keep_tex = keep_tex, citation_package = citation_package,
    md_extensions = md_extensions, pandoc_args = c(pandoc_arg_list, pandoc_args),
    ...
  )
}

#' @section `informs_article`: Format for creating submissions to
#' INFORMS journals. Adapted from \samp{https://pubsonline.informs.org/authorportal/latex-style-files}.
#'
#' It requires a minimum version of 2.10 for Pandoc.
#' @export
#' @rdname article
informs_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  if (citation_package != "natbib") {
    stop("INFORMS template only supports `natbib` for citation processing.")
  }

  if (!rmarkdown::pandoc_available("2.10")) {
    stop("informs_article requires a minimum of pandoc 2.10.")
  }
  pdf_document_format(
    "informs",
    keep_tex = keep_tex, citation_package = citation_package, ...
  )
}

#' @section `iop_article`: Format for creating submissions to
#'   IOP journals. Adapted from \samp{https://publishingsupport.iopscience.iop.org/questions/latex-template/}.
#'   Please read the guidelines at this link when preparing your article.
#' @export
#' @rdname article
iop_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  pdf_document_format(
    "iop",
    keep_tex = keep_tex, citation_package = citation_package, ...
  )
}

#' @section `jasa_article`: Format for creating submissions to the
#'   Journal of the Acoustical Society of America. Adapted from
#'   <https://acousticalsociety.org/preparing-latex-manuscripts/>.
#' @export
#' @rdname article
jasa_article <- function(..., keep_tex = TRUE, latex_engine = "xelatex",
                         citation_package = "natbib") {
  pdf_document_format(
    "jasa",
    keep_tex = keep_tex, latex_engine = latex_engine,
    citation_package = citation_package, ...
  )
}

#' @section `lipics_article`: Format for creating submissions to
#'   LIPIcs - Leibniz International Proceedings Informatics - articles.
#'   Adapted from the official Instructions for Authors at
#'   <https://submission.dagstuhl.de/documentation/authors> and the
#'   template from the archive `authors-lipics-v2019.zip` downloaded
#'   with version tag v2019.2. The template is provided under The LaTeX
#'   Project Public License (LPPL), Version 1.3c.
#' @export
#' @rdname article
lipics_article <- function(..., latex_engine = "xelatex", # xelatex used for 'thin space' Unicode
                           # character, see YAML field 'authorrunning'
                           keep_tex = TRUE, citation_package = "natbib",
                           md_extensions = c(
                             "-autolink_bare_uris", # disables automatic links
                             "-auto_identifiers" # disables \hypertarget commands
                           )) {
  # quick dev shortcut for Ubuntu: click "Install and restart" then run:
  # unlink("MyArticle/", recursive = TRUE); rmarkdown::draft("MyArticle.Rmd", template = "lipics", package = "rticles", edit = FALSE); rmarkdown::render("MyArticle/MyArticle.Rmd"); system(paste0("xdg-open ", here::here("MyArticle", "MyArticle.pdf")))
  pdf_document_format(
    "lipics",
    latex_engine = latex_engine,
    citation_package = citation_package, keep_tex = keep_tex,
    md_extensions = md_extensions, ...
  )
}


#' @section `lncs_article`: Format for creating submissions to
#'   LNCS - Lecture Notes in Computer Science - articles.
#'   Adapted from the official Instructions for Authors at
#'   <https://www.springer.com/gp/computer-science/lncs/conference-proceedings-guidelines>
#'   and the  template from the archive `LaTeX2e+Proceedings+Templates+download.zip` downloaded
#'   with version tag 2.21.
#' @export
#' @rdname article
lncs_article <- function(..., keep_tex = TRUE, citation_package = c("default", "natbib")) {
  citation_package <- match.arg(citation_package)
  pdf_document_format("lncs", keep_tex = keep_tex, citation_package = citation_package, ...)
}


#' @section `jedm_article`: Format for creating Journal of Educational
#'   Data Mining (JEDM) articles. Adapted from
#'   <https://jedm.educationaldatamining.org/index.php/JEDM/information/authors>.
#' @export
#' @rdname article
jedm_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  pdf_document_format("jedm",
    keep_tex = keep_tex,
    citation_package = citation_package,
    ...
  )
}

#' @section `mdpi_article`: Format for creating submissions to
#'   Multidisciplinary Digital Publishing Institute (MDPI) journals. Adapted
#'   from <https://www.mdpi.com/authors/latex>.
#'
#' Possible arguments for the YAML header are:
#' * `title` title of the manuscript
#' * `author` list of authors, containing `name`, `affil`, and `orcid` (optional)
#' * `affiliation` list containing `num`, `address`, and `email` for defining `author` affiliations
#' * `authorcitation` string with last name and first intial of authors as expected to be shown in a reference
#' * `firstnote` can include `firstnote` through `eightnote` that correspond to footnote marks in `affil`
#' * `correspondence` contact information of the corresponding author
#' * `journal` short name (case sensitive) of the journal, see template for options
#' * `type` usually "article" but see template for options
#' * `status` usually "submit"
#' * `simplesummary` optional, may depend on specific journal
#' * `abstract` abstract, limited to 200 words
#' * `keywords` 3 to 10 keywords seperated with a semicolon
#' * `acknowledgement` acknowledgement backmatter (optional)
#' * `authorcontributions` report authorship contributions (optional)
#' * `funding` research funding statement
#' * `institutionalreview` IRB statements (optional)
#' * `informedconsent` Informed consent statements for human research (optional)
#' * `dataavailability` Links to datasets or archives (optional)
#' * `conflictsofinterest` Conflict of interest statement (see journal  instructions)
#' * `sampleavailability` Sample availability statement (optional)
#' * `supplementary` Supplementary data statement, see template for example (optional)
#' * `abbreviations` list of abbreviations containing `short` and `long`
#' * `bibliography` BibTeX `.bib` file
#' * `appendix` name of appendix tex file
#' * `endnote` boolean, if `TRUE` will print list of endnotes if included in text (optional)
#' * `header-includes`: custom additions to the header, before the `\begin{document}` statement
#' * `include-after`: for including additional LaTeX code before the `\end{document}` statement
#' @export
#' @rdname article
mdpi_article <- function(..., keep_tex = TRUE, latex_engine = "pdflatex", pandoc_args = NULL, citation_package = "natbib") {

  # check all arguments for format's default
  if (citation_package != "natbib") {
      stop("MDPI template only supports 'natbib' for citation processing.")
  }

  ## check if latex engine is pdflatex or xelatex
  if(!latex_engine %in% c("pdflatex", "xelatex")) {
    stop("`latex_engine` must be one of 'pdflatex' or 'xelatex' when using the MDPI template.")
  }

  ## check location of mdpi.cls file (new versions are in subfolder)
  ## to ensure compatibility with old versions
  cls_loc <- if(file.exists("mdpi.cls")) "mdpi" else "Definitions/mdpi"
  pandoc_args <- c(pandoc_args, rmarkdown::pandoc_variable_arg("cls", cls_loc))

  ## if latex engine is pdflatex, mdpi class argument must be pdftex
  if(latex_engine == "pdflatex") {
    pandoc_args <- c(pandoc_args, rmarkdown::pandoc_variable_arg("pdftex", "pdftex"))
  }

  base <- pdf_document_format(
    "mdpi",
    keep_tex = keep_tex,
    citation_package = "natbib",
    latex_engine = latex_engine,
    pandoc_args = pandoc_args,
    ...
  )

  base_pre_processor <- base$pre_processor

  ## pre_processor checks if author metadata > 1 and uses moreauthors mdpi class
  ## argument
  mdpi_pre_processor <- function(metadata,
                            input_file,
                            runtime,
                            knit_meta,
                            files_dir,
                            output_dir) {
    args <- c(
      # run the base prepocessor of the format
      if (is.function(base_pre_processor)) {
        base_pre_processor(
          metadata, input_file, runtime, knit_meta, files_dir, output_dir
        )
      },
      # Set a variable based on metadata field
      if (!is.null(metadata$author)) {
        if (length(metadata$author) > 1) {
          rmarkdown::pandoc_variable_arg("multipleauthors", "moreauthors")
        } else {
          rmarkdown::pandoc_variable_arg("multipleauthors", "oneauthor")
        }
      }
    )
    args
  }

  base$pre_processor <- mdpi_pre_processor
  base
}

#' @section `mnras_article`: Format for creating an Monthly Notices of
#'   Royal Astronomical Society (MNRAS) Journal articles. Adapted from
#'   <https://ras.ac.uk>.
#' @export
#' @rdname article
mnras_article <- function(..., keep_tex = TRUE, fig_caption = TRUE) {
  pdf_document_format(
    "mnras",
    keep_tex = keep_tex, fig_caption = fig_caption, ...
  )
}

#' @section `peerj_article`: Format for creating submissions to The PeerJ
#'   Journal. This was adapted from the
#'   [PeerJ
#'    Overleaf Template](https://www.overleaf.com/latex/templates/latex-template-for-peerj-journal-and-pre-print-submissions/ptdwfrqxqzbn).
#' @export
#' @rdname article
peerj_article <- function(..., keep_tex = TRUE) {
  pdf_document_format("peerj", keep_tex = keep_tex, ...)
}

#' @section `pihph_article`: Format for creating submissions to the Papers
#'   in Historical Phonology
#'   (<http://journals.ed.ac.uk/pihph/about/submissions>). Adapted from
#'   <https://github.com/pihph/templates>. This format works well with
#'   `latex_engine = "xelatex"` and `citation_package="biblatex"`,
#'   which are the default. It may not work correctly if you change these value.
#'   In that case, please open an issue and, a PR to contribute a change in the
#'   template.
#' @export
#' @rdname article
pihph_article <- function(..., keep_tex = TRUE, latex_engine = "xelatex",
                          citation_package = "biblatex") {
  pdf_document_format(
    "pihph",
    keep_tex = keep_tex, latex_engine = latex_engine,
    citation_package = citation_package, ...
  )
}

#' @section `plos_article`: Format for creating submissions to PLOS
#'   journals. Adapted from <https://journals.plos.org/ploscompbiol/s/latex>.
#' @export
#' @rdname article
plos_article <- function(..., keep_tex = TRUE,
                         md_extensions = c("-autolink_bare_uris")) {
  pdf_document_format(
    "plos",
    keep_tex = keep_tex, md_extensions = md_extensions, ...
  )
}

#' @section `pnas_article`: Format for creating submissions to PNAS
#'   journals.
#' @export
#' @rdname article
pnas_article <- function(..., keep_tex = TRUE) {
  pdf_document_format("pnas", keep_tex = keep_tex, ...)
}

#' @section `sage_article`: Format for creating submissions to Sage
#'   Journals. Based on the official Sage Journals Class.
#'   Available at `https://uk.sagepub.com/sites/default/files/sage_latex_template_4.zip`.
#'
#' Possible arguments for the YAML header are:
#' * `title` title of the manuscript
#' * `runninghead` short author list for header
#' * `author` list of authors, containing `name` and `num`
#' * `address` list containing `num` and `org` for defining `author` affiliations
#' * `corrauth` corresponding author name and address
#' * `email` correspondence email
#' * `abstract` abstract, limited to 200 words
#' * `keywords` keywords for the article
#' * `bibliography` BibTeX `.bib` file name
#' * `classoption` options of the `sagej` class
#' * `header-includes`: custom additions to the header, before the `\begin{document}` statement
#' * `include-after`: for including additional LaTeX code before the `\end\{document}` statement
#' @export
#' @rdname article
sage_article <- function(..., highlight = NULL, citation_package = "natbib") {
  pdf_document_format(
    "sage",
    highlight = highlight, citation_package = citation_package, ...
  )
}

#' @section `sim_article`: Format for creating submissions to Statistics in
#'   Medicine. Based on the official Statistics in Medicine
#'   at `https://authorservices.wiley.com/author-resources/Journal-Authors/Prepare/new-journal-design.html`.
#'
#'   This format uses xelatex by default as PDF engine to support the specific NJD fonts, per guideline.
#'
#' Possible arguments for the YAML header are:
#' * `title` title of the manuscript
#' * `author` list of authors, containing `name` and `num`
#' * `address` list containing `num` and `org` for defining `author` affiliations
#' * `presentaddress` not sure what they mean with this
#' * `corres` author and address for correspondence
#' * `authormark` short author list for header
#' * `received`, `revised`, `accepted` dates of submission, revision, and acceptance of the manuscript
#' * `abstract` abstract, limited to 250 words
#' * `keywords` up to 6 keywords
#' * `abbreviations`, list of abbreviations and description separated by a comma
#' * `bibliography` BibTeX `.bib` file
#' * `classoption` options of the `WileyNJD` class
#' * `longtable` set to `true` to include the `longtable` package, used by default from `pandoc` to convert markdown to LaTeX code
#' * `header-includes`: custom additions to the header, before the `\begin{document}` statement
#' * `include-after`: for including additional LaTeX code before the `\end{document}` statement
#' @export
#' @rdname article
sim_article <- function(..., highlight = NULL, citation_package = "natbib", latex_engine = "xelatex") {
  pdf_document_format(
    "sim",
    highlight = highlight, citation_package = citation_package, latex_engine = latex_engine, ...
  )
}

#' @section `springer_article`: This format was adapted from the Springer
#'   Macro package for Springer Journals.
#' @export
#' @rdname article
springer_article <- function(..., keep_tex = TRUE,  citation_package = "natbib",
                             number_sections = TRUE, latex_engine = "pdflatex",
                             pandoc_args = NULL) {

  if (!rmarkdown::pandoc_available("2.11.4")) {
    stop("`springer_article()` now requires a minimum of pandoc 2.11.4")
  }

  if (citation_package == "biblatex") {
    stop("'springer_article' does not support `biblatex` for citation processing. Use 'natbib' instead.")
  }

  # to compile with pdflatex/xelatex
  # use pdflatex option in the pandoc's template for the document class
  if(latex_engine %in% c("pdflatex", "xelatex")) {
    pandoc_args <- c(pandoc_args, rmarkdown::pandoc_variable_arg("pdflatex"))
  }

  if(!number_sections) {
    pandoc_args <- c(pandoc_args, rmarkdown::pandoc_variable_arg("unnumbered"))
  }

  format <- pdf_document_format(
    "springer",
    keep_tex = keep_tex,
    citation_package = citation_package,
    number_sections = number_sections,
    latex_engine = latex_engine,
    pandoc_args = pandoc_args, ...
  )

  pre_knit_fun <- format$pre_knit
  format$pre_knit <-  function(input, ...) {
    if (is.function(pre_knit_fun)) pre_knit_fun(input, ...)
    # for backward compatibility as we changed the template in
    # https://github.com/rstudio/rticles/pull/494
    options <- rmarkdown::yaml_front_matter(input)
    new_template_msg <- c("If you are rendering an old Rmd, be advise that the template has changed in version '0.25'\n",
    " and you should start from a fresh template to get latest resources and new YAML header format.")
    if (is.null(options[["classoptions"]])) {
      stop("`springer_article()` now requires the 'classoptions' field in YAML front matter. ",
           new_template_msg, call. = FALSE)
    }
    if (!is.null(options[["biblio-style"]])) {
      warning("`springer_article()` now ignores the 'biblio-style' field in YAML front matter. ",
      "Reference style for 'natbib' is now set using the 'classoptions' field.\n",
      new_template_msg)
    }
    if (!is.null(options[["PACS"]])) {
      warning("`springer_article()` now ignores the 'PACS' field in YAML front matter to use `pacs.jel` and `pacs.msc`. ",
              new_template_msg)
    }
    if (!is.null(options[["authors"]][["name"]])) {
      stop("`springer_article()` now uses different authors and affiliations fields.\n",
              new_template_msg, call. = FALSE)
    }
    return(invisible(NULL))
  }
  format
}

#' @section `tf_article`: Format for creating submissions to a Taylor & Francis journal. Adapted from
#' \samp{https://www.tandf.co.uk/journals/authors/InteractCADLaTeX.zip}.
#' @export
#' @rdname article
tf_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  pdf_document_format(
    "tf",
    keep_tex = keep_tex, citation_package = citation_package, ...
  )
}

#' @section \code{trb_article}: Format for creating submissions to the Transportation
#'   Research Board Annual Meeting. Adapted from
#'   \samp{https://www.overleaf.com/latex/templates/transportation-research-board-trb-latex-template/jkfndnnkkksw},
#'   which in turn is hosted at \samp{https://github.com/chiehrosswang/TRB_LaTeX_tex}
#' @export
#' @rdname article
trb_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  pdf_document_format(
    "trb",
    keep_tex = keep_tex, citation_package = citation_package, ...
  )
}

#' @section `wellcomeor_article`: Format for creating submissions to
#' Wellcome Open Research. Adapted from <overleaf.com/latex/templates/wellcome-open-research-article-template/hsmhhbpxvvbj>.
#' @export
#' @rdname article
wellcomeor_article <- function(..., number_sections = FALSE, keep_tex = TRUE,
                               citation_package = "natbib") {
  pdf_document_format(
    "wellcomeor",
    keep_tex = keep_tex, number_sections = number_sections,
    citation_package = citation_package, ...
  )
}

#' @section `isba_article`: Format for creating submissions to Bayesian analysis.
#' Based on the official Bayesian analysis [class](https://www.e-publications.org/isba/support/).
#' Template shows how to use this format as a base format for `bookdown::pdf_book`, but it can very well be used on its own (with limitations that figure referencing will not work).
#' Note that the template sets `md_extensions` to exclude `-autolink_bare_uris` because otherwise author emails produce error
#'
#' Possible arguments for the YAML header are:
#' * `title` title of the manuscript. Shorter version of the title can be provided as `runtitle`.
#' * `classoption` should equal `ba` or `ba,preprint` for supplementary article.``
#' * `author` list of authors, containing `firstname`, `lastname`, `email`, `url`, `affiliationref` (as code) and `footnoterefs` (as list of codes)
#' * `affiliations` list containing `ref` (code for defining `author` affiliations), institution `name` and `address` itself
#' * `footnotes` a list of two-element entries: `ref` and `text`
#' * `abstract` abstract, limited to 250 words
#' * `MSC2020primary`, `MSC2020primary` lists of codes from [MCS2020 database](https://mathscinet.ams.org/mathscinet/msc/msc2020.html)
#' * `keywords` a list of keywords
#' * `supplements` a list of entries with two elements `title` and `description`
#' * `doi` DOI of the article
#' * `arxiv` Arxiv id
#' * `acknowledgements` acknowledgement text, limited to 250 words
#' * `bibliography` BibTeX `.bib` file
#' * `longtable` set to `true` to include the `longtable` package, used by default from `pandoc` to convert markdown to LaTeX code
#' * `header-includes`: custom additions to the header, before the `\begin{document}` statement
#' * `include-after`: for including additional LaTeX code before the `\end{document}` statement
#' @export
#' @rdname article
isba_article <- function(..., keep_tex = TRUE, highlight = NULL, citation_package = "natbib") {
  if (citation_package != "natbib") {
    stop("ISBA template only supports `natbib` for citation processing.")
  }
  # from https://github.com/rstudio/rmarkdown/issues/372
  # md_extensions <- c("+ascii_identifiers", "+tex_math_single_backslash", "-autolink_bare_uris")
  if (!rmarkdown::pandoc_available("2.10")) {
    stop("`isba_article()` requires a minimum of pandoc 2.10.")
  }
  pdf_document_format(
    "isba",
    keep_tex = keep_tex, highlight = highlight, citation_package = citation_package, ...
  )
}

#' Royal Society Open Science journal format.
#'
#' Format for creating submissions to Royal Society Open Science journals.
#'
#' @inheritParams rmarkdown::pdf_document
#' @param ... Additional arguments to [rmarkdown::pdf_document()]
#' @export
#' @importFrom rmarkdown output_format knitr_options pandoc_options
#'   pandoc_variable_arg includes_to_pandoc_args
#' @author Thierry Onkelinx, \email{thierry.onkelinx@@inbo.be}
rsos_article <- function(..., keep_tex = TRUE, latex_engine = "xelatex", pandoc_args = NULL,
                         includes = NULL, fig_crop = TRUE) {
  extra <- list(...)

  template <- find_resource("rsos")
  args <- c(
    "--template", template, rmarkdown::pandoc_variable_arg("documentclass", "article"),
    pandoc_args, "--natbib", rmarkdown::includes_to_pandoc_args(includes)
  )

  if (length(extra) > 0) {
    args <- c(args, sapply(names(extra), function(x) {
      rmarkdown::pandoc_variable_arg(x, extra[[x]])
    }))
  }

  opts_chunk <- list(
    latex.options = "{}", dev = "pdf", fig.align = "center", dpi = 300,
    fig.width = 4.5, fig.height = 2.9, highlight = FALSE, echo = FALSE
  )
  crop <- fig_crop && !identical(.Platform$OS.type, "windows") &&
    nzchar(Sys.which("pdfcrop"))
  if (crop) {
    knit_hooks <- list(crop = knitr::hook_pdfcrop)
    opts_chunk$crop <- TRUE
  } else {
    knit_hooks <- NULL
  }

  post_processor <- function(metadata, input_file, output_file, clean, verbose) {
    text <- xfun::read_utf8(output_file)

    # set correct text in fmtext environment
    end_first_page <- grep("^\\\\EndFirstPage", text) # nolint
    if (length(end_first_page)) {
      maketitle <- grep("\\\\maketitle", text) # nolint
      text <- c(
        text[1:(maketitle - 1)],
        "\\begin{fmtext}",
        text[(maketitle + 1):(end_first_page - 1)],
        "\\end{fmtext}",
        "\\maketitle",
        text[(end_first_page + 1):length(text)]
      )
    }
    xfun::write_utf8(text, output_file)
    output_file
  }

  output_format(
    knitr = knitr_options(
      opts_knit = list(width = 75, concordance = TRUE),
      opts_chunk = opts_chunk, knit_hooks = knit_hooks
    ),
    pandoc = pandoc_options(
      to = "latex", latex_engine = latex_engine, args = args, keep_tex = keep_tex
    ),
    post_processor = post_processor,
    clean_supporting = !keep_tex
  )
}

#' Royal Statistical Society Journal Format
#'
#' Format for creating articles for Royal Statistical Society adapted from
#' <https://rss.org.uk/news-publication/publications/journals/submit-paper/>.
#' @inheritParams rmarkdown::pdf_document
#' @param ... Arguments to [rmarkdown::pdf_document()]
#' @export
rss_article <- function(..., keep_tex = TRUE, citation_package = "natbib") {
  fmt <- pdf_document_format(
    "rss",
    highlight = NULL, citation_package = citation_package,
    keep_tex = keep_tex, ...
  )
  fmt$knitr$knit_hooks$source <- function(x, options) {
    if (options$prompt && length(x)) {
      x <- gsub("\\n", paste0("\n", getOption("continue")), x)
      x <- paste0(getOption("prompt"), x)
    }
    paste0(
      c(
        "\n\\begin{lstlisting}[language=",
        options$engine,
        "]",
        x,
        "\\end{lstlisting}",
        ""
      ),
      collapse = "\n"
    )
  }
  fmt
}

---
author:
  - name: FirstName LastName
    affiliation: University/Company
    # use this syntax to add text on several lines
    address: |
      | First line
      | Second line
    email: \email{name@company.com}
    url: https://posit.co
  - name: Second Author
    affiliation: 'Affiliation \AND'
    # To add another line, use \AND at the end of the previous one as above
  - name: Third Author
    address: |
      | Department of Statistics and Mathematics,
      | Faculty of Biosciences,
      | Universitat Autònoma de Barcelona
    affiliation: |
      | Universitat Autònoma 
      | de Barcelona
    # use a different affiliation in adress field (differently formated here)
    affiliation2: Universitat Autònoma de Barcelona
title:
  formatted: "A Capitalized Title: Something about a Topic"
  # If you use tex in the formatted title, also supply version without
  plain:     "A Capitalized Title: Something about a Topic"
  # For running headers, if needed
  short:     "A Capitalized Title"
abstract: >
  This guide of the Austrian Journal of Statistics (AJS) shows the required style of manuscripts submitted to the Austrian Journal of Statistics. We strongly recommend to follow the given instructions exactly already when writing the paper. When submitting papers to AJS, it is essential to follow these guidelines. Manuscripts submitted without consideration of the AJS style guide will most likely not be forwarded for review, but rejected with the possibility of resubmission.
keywords:
  # at least one keyword must be supplied
  formatted: [keywords, not capitalized, "\\proglang{Java}"]
  plain:     [keywords, not capitalized, Java]
header-includes:
 - \usepackage{amsmath}
bibliography: ajs-template.bib
output: rticles::ajs_article
---

```{r, setup, include=FALSE}
options(prompt = 'R> ', continue = '+ ')
```


Before we look at style in more detail, the most common mistakes and errors are described:

# Frequently made style mistakes


- AJS style is not used
- Title in Capitalized style. See the title of the guidelines for illustration.
- Subsection in lower case style. See the subsection of the guidelines for illustration
- Capitalized Titles for references. E.g. \cite{fleet20} should appear in the reference list as "Fleet Management in Free-Floating Bike Sharing Systems Using
  Predictive Modelling and Exploratory Tools" and NOT as "Fleet management in free-floating bike sharing systems using
  predictive modelling and exploratory tools".
- Include DOI numbers for each citation (if possible)
- Use vector-based graphics such as \texttt{pdf}. Do not use pixel-based graphics like \texttt{png}, \texttt{jpeg}, and do not convert from \texttt{png} or \texttt{jpeg} to \texttt{pdf}


# Introduction

The style file of the Austrian Journal of Statistics is based on the style file of the Journal of Statistical Software (JSS) including minor modifications. We thank Achim Zeileis for his great work on the JSS style file.

The Austrian Journal of Statistics is freely available over the net. Free and open-source tools used for production of your manuscript are therefore also highly supported. Code to reproduce the figures and tables in manuscripts as well as methods implemented in software can be published as supplementary material. This increases usually the number of downloads of your article.


# Writing your manuscript

The Journal is produced on the basis of computer readable manuscripts provided by the authors. 

Footnotes should be avoided.

The article should be structured by enumerated sections and
subsections. The title should be in title case style, sections and subsections in section case style. Graphics and tables must contain captions, above
tables and below graphics (figures). Examples are (see Figure~\ref{Fig3.4} and Table~\ref{Tab3.4}).
Graphics \textbf{should be produced in \textbf{pdf} format} and included 
 at suitable places of the manuscript. 

\begin{figure}[hbt]
\begin{center}
\includegraphics{ajs-download20180210.pdf}
\caption{\label{Fig3.4}Download statistics of articles per month at the Austrian Journal of Statistics.} 
\end{center}
\end{figure}

\begin{table}[hbt]
\caption{\label{Tab3.4}80 measured values of access time.}
\vspace*{-5mm}
\small
\hspace{1.5cm}
\begin{center}
\begin{tabular}{|llllllll|}
\toprule
70.0 & 68.6 & 67.9 & 66.3 & 71.0 & 64.2 & 69.6 & 71.0\\
... & ... & ... & ... & ... & ... & ... & ...\\
%69.7 & 69.0 & 73.4 & 69.0 & 70.1 & 69.8 & 69.0 & 73.0\\
%70.0 & 69.1 & 69.5-& 67.9 & 72.8 & 72.1 & 69.5+& 70.1\\
%70.2 & 69.1 & 68.9 & 68.3 & 74.9 & 68.4 & 69.1 & 66.6\\
%71.1 & 69.2 & 71.2 & 68.9 & 70.9 & 70.6 & 69.9 & 69.9\\
%69.4 & 69.5+& 68.5+& 70.9 & 71.6 & 68.9 & 72.0 & 70.3\\
%68.6 & 68.5-& 67.8 & 72.2 & 68.7 & 70.6 & 66.9 & 69.3\\
%71.4 & 68.7 & 74.2 & 68.8 & 71.4 & 71.8 & 67.5-& 70.4\\
%71.4 & 67.4 & 69.5-& 72.4 & 70.4 & 69.3 & 68.2 & 67.0\\
71.7 & 70.5+& 72.5-& 68.2 & 67.6 & 68.6 & 70.5-& 65.8\\
\bottomrule
\end{tabular}
\end{center}
\end{table}

Mathematical formulas should be enumerated as far as they are
referenced \textbf{only}. E.g.~Equation~(\ref{form3.1}) shows the density 
\begin{equation}\label{form3.1}
f(x) =
\frac1{\sqrt{2\pi}\sigma}e^{-\frac{(x-\mu)^2}{2\sigma^2}}\,.
\end{equation}

Please consider 

- capitalized title case for titles and for all references and 
- sentence, non-capitalized case for sections and subsections.



Cited literature should be summarized at the end of the article in
form of a non-enumerated section. \cite{leisch02} is a reference
to an article. If the citation is in parentheses, it
should look like \citep{leisch02}.
References should be in title case.

Correspondence addresses of author(s) should be added at the end
of the manuscript. 


# Submission and refereeing


## Submission

Consideration of the previously stated rules are of great help for
the editing process. Whenever technically possible, manuscripts
should be submitted through the editorial system at \href{www.ajs.or.at}{www.ajs.or.at}. The authors must be registered at this website.

## Refereing

All contributions will be anonymously refereed. Cited literature which is
hardly available should accompany the submitted manuscript. It
should also be considered to place used and analyzed data at
disposal for the referees (if there are no legal or technical
arguments against).

Editor and referees must trust that the contribution has not been
submitted for publication at the same time at another place. It is
fair that the submitting author notifies if an earlier version has
already been submitted somewhere before.

## Copyrights and fees

The Austrian Journal of Statistics is free of
charge. Generally, we use the Creative Commons Attribution License (CC-BY).

For copyright issues, publication ethics and malpractice statements, please have a look at 
<www.ajs.or.at>





# Specifics to markdown

## Code formatting

In general, don't use Markdown, but use the more precise LaTeX commands instead:

* \proglang{Java}
* \pkg{plyr}

One exception is inline code, which can be written inside a pair of backticks (i.e., using the Markdown syntax).

If you want to use LaTeX commands in headers, you need to provide a `short-title` attribute. You can also provide a custom identifier if necessary. See the header of Section \ref{r-code} for example.

# \proglang{R} code {short-title="R code" #r-code}

Can be inserted in regular R markdown blocks.

```{r}
x <- 1:10
x
```

## Features specific to \pkg{rticles} {short-title="Features specific to rticles"}

* Adding short titles to section headers is a feature specific to \pkg{rticles} (implemented via a Pandoc Lua filter). This feature is currently not supported by Pandoc and we will update this template if [it is officially supported in the future](https://github.com/jgm/pandoc/issues/4409).
* Using the `\AND` syntax in the `author` field to add authors on a new line. This is a specific to the `rticles::ajs_article` format.


# Checklist

We list the most common mistakes when submitting manuscripts to the journal and formulate them in form of questions.

- Did you upload a pdf of your manuscript for review? (no Word, no .tex, ...)
- Did you use the style of AJS?  
- Are your graphics produced in pdf format? 
- Is your title captialized?
- Are the titles of your cited papers in your references capitalized?
- Are your section and subsection headers non-capitalized form?
- Are your tables produced with \LaTeX ? (no screenshots)
- Have you cited the software you used, e.g. R itself and R packages used? To not cite software is plagiarism and violates intellectual properties of the authors of the software.
- Did you proposed at least three independent reviewers?


# Frequently asked questions


- *My citation shows all authors and not the typically shown et al.*. Answer: this is ok. We like to show all authors in the text.
- *When I submit a paper, how long does it take to be published?*.  Answer: The average time from submission to publication is approx. 132 days. But it heavily depends if you can make satisfying revisions in time. 
- *In which databases is AJS indexed.* Answer: we are indexed in many of them, most notable is Scopus (from Elsevier). More information can be found at the website of AJS. 
- *Can I upload my paper on \href{https://arxiv.org/}{https://arxiv.org/} and distribute before the paper is online at AJS?*  Answer: Of course, you can do it. However, please clearly point out in the header of the paper that this paper is under review in the Austrian Journal of Statistics and will likely be published there. Note that the readers should check if the paper is already be published at AJS for correct citation, i.e. finally the journal should be cited. Update and upload  \href{https://arxiv.org/}{https://arxiv.org/} or similar sites with the final version in AJS style after the paper is published  in AJS. 

---
title: Title of submission to PLOS journal
author:
  - name: Alice Anonymous
    email: alice@example.com
    affiliation: Some Institute of Technology
    corresponding: alice@example.com
  - name: Bob Security
    email: bob@example.com
    affiliation: 
      - Another University
      - Some Institute of Technology
address:
  - code: Some Institute of Technology
    address: Department 1, Street, City, State, Zip
  - code: Another University
    address: Department 2, Street, City, State, Zip
abstract: |
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur eget porta erat. Morbi consectetur est vel gravida pretium. Suspendisse ut dui eu ante cursus gravida non sed sem. Nullam sapien tellus, commodo id velit id, eleifend volutpat quam. Phasellus mauris velit, dapibus finibus elementum vel, pulvinar non tellus. Nunc pellentesque pretium diam, quis maximus dolor faucibus id. Nunc convallis sodales ante, ut ullamcorper est egestas vitae. Nam sit amet enim ultrices, ultrices elit pulvinar, volutpat risus.
  
author_summary: |
  Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur eget porta erat. Morbi consectetur est vel gravida pretium. Suspendisse ut dui eu ante cursus gravida non sed sem. Nullam sapien tellus, commodo id velit id, eleifend volutpat quam. Phasellus mauris velit, dapibus finibus elementum vel, pulvinar non tellus. Nunc pellentesque pretium diam, quis maximus dolor faucibus id. Nunc convallis sodales ante, ut ullamcorper est egestas vitae. Nam sit amet enim ultrices, ultrices elit pulvinar, volutpat risus.

bibliography: mybibfile.bib
output: rticles::plos_article
# plos.csl can be download and used locally
csl: http://www.zotero.org/styles/plos
---

_Text based on plos sample manuscript, see <https://journals.plos.org/ploscompbiol/s/latex>_

# Introduction

Lorem ipsum dolor sit amet, consectetur adipiscing elit. Curabitur eget porta erat. Morbi consectetur est vel gravida pretium. Suspendisse ut dui eu ante cursus gravida non sed sem. Phasellus mauris velit, dapibus finibus elementum vel, pulvinar non tellus. Nunc pellentesque pretium diam, quis maximus dolor faucibus id. Nunc convallis sodales ante, ut ullamcorper est egestas vitae. Nam sit amet enim ultrices, ultrices elit pulvinar, volutpat risus.

A list

- Item 1
- Item 2

Here are two sample references: @Feynman1963118 [@Dirac1953888].

# References {#references .unnumbered}

---
title: "Get started"
---

```{r, include = FALSE}
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
```

## Accessing templates

```{r child="usage.md"} 
```


View the list of available journal names with `rticles::journals()`.

## Figure numbering & cross-references

You may want to use features of the [**bookdown** package](https://pkgs.rstudio.com/bookdown/) like automatic numbering and cross-referencing of figures and tables in your article. To do this, you'll need to follow [**bookdown** documentation](https://bookdown.org/yihui/bookdown/a-single-document.html), i.e. to edit your YAML to:

+ Switch to the `bookdown::pdf_book` output format, and

+ Supply your **rticles** template of choice as the `base_format`.

```{.yaml}
output:
  bookdown::pdf_book:
    base_format: rticles::peerj_article
```


Read more about using the **rticles** package here: https://bookdown.org/yihui/rmarkdown/journals.html

---
title: Bare Demo of IEEEtran.cls for IEEE Conferences
affiliation:
  ## Author mode :  use one only of the following --- +
  
  ## one column per author - using only the institution field
  # author-columnar: true # uncomment this line to use
  
  ## one column per institution - using only the institution field
  # institution-columnar: true # uncomment this line to use
  
  ## one column wide author/affiliation fields - using author or author_multiline and institution for mark
  wide: true # uncomment this line to use
  
  ## Author mode: End ----
  
  ## A custom author ordering field that breaks institution grouping (used with `wide: true`)
  ## Authors cited in institution field are ignored when this author field exists
  ## Comment / Uncomment below
  author:   
   - name: Eldon Tyrell
     mark: [2, 3]
     email: eldon@starfleet-academy.star
   - name: Michael Shell
     mark: 1
   - name: Roy Batty
     mark: 4
     email: roy@replicant.offworld
  
  ## Put authors in a given order, with multiline possibility (used with `wide: true` if `authors` above unset)
  ## Authors cited in institution are ignored if exists
  ## Comment / Uncomment below
  #author_multiline: 
  #  - line:         ## Create a new author line
  #    - name: Michael Shell
  #      mark: 1
  #    - name: Homer Simpson
  #      mark: 2
  #      email: homer@thesimsons.com
  #    - name: Roy Batty
  #      mark: 4
  #      email: roy@replicant.offworld
  #  - line:         ## Create a second author line
  #    - name: Montgomery Scott
  #      mark: 3
  #    - name: Eldon Tyrell
  #      mark: 4

  ## Define institution, and also authors used when `author-columnar: true` or `institution-columnar: true`
  institution:
    - name: Georgia Institute of Technology
      department: School of Electrical and Computer Engineering
      location: Atlanta, Georgia 30332--0250
      email: ece@datech.edu # if unset, authors' email will be used
      mark: 1
      author:
        - name: Michael Shell
    - name: Twentieth Century Fox
      location: Springfield, USA
      mark: 2
      author:
        - name: Homer Simpson
          email: homer@thesimpsons.com
    - name: Starfleet Academy
      location: San Francisco, California 96678-2391
      other: "Telephone: (800) 555--1212, Fax: (888) 555--1212"
      mark: 3
      author:
        - name: Montgomery Scott
    - name: Tyrell Inc.
      location: 123 Replicant Street, Los Angeles, USA 90210--4321
      mark: 4
      author:
        - name: Eldon Tyrell
          email: eldon@starfleet-academy.star
        - name: Roy Batty
          email: roy@replicant.offworld

keywords: ["keyword 1", "keyword 2"]
abstract: |
  The abstract goes here.
  On multiple lines eventually.

# use some specific Tex packages if needed. 
# with_ifpdf: true
# with_cite: true
# amsmath need to be true to use with bookdown for referencing equations.
with_amsmath: true
# with_algorithmic: true
# with_array: true
# with_dblfloatfix: true

bibliography: mybibfile.bib
output: rticles::ieee_article
#citation_sorting: none   ## used as sorting option of the biblatex package (if selected)
---

# Introduction

<!-- no \IEEEPARstart -->
This demo file is intended to serve as a ``starter file''
for IEEE conference papers produced under \LaTeX\ using
IEEEtran.cls version 1.8b and later.
<!-- You must have at least 2 lines in the paragraph with the drop letter
(should never be an issue) -->
I wish you the best of success.

## Subsection Heading Here
Subsection text here.

### Subsubsection Heading Here
Subsubsection text here.

<!-- An example of a floating figure using the graphicx package.
Note that \label must occur AFTER (or within) \caption.
For figures, \caption should occur after the \includegraphics.
Note that IEEEtran v1.7 and later has special internal code that
is designed to preserve the operation of \label within \caption
even when the captionsoff option is in effect. However, because
of issues like this, it may be the safest practice to put all your
\label just after \caption rather than within \caption{}.

Reminder: the "draftcls" or "draftclsnofoot", not "draft", class
option should be used if it is desired that the figures are to be
displayed while in draft mode.

\begin{figure}[!t]
\centering
\includegraphics[width=2.5in]{myfigure}
where an .eps filename suffix will be assumed under latex, 
and a .pdf suffix will be assumed for pdflatex; or what has been declared
via \DeclareGraphicsExtensions.
\caption{Simulation results for the network.}
\label{fig_sim}
\end{figure}

Note that the IEEE typically puts floats only at the top, even when this
results in a large percentage of a column being occupied by floats.


An example of a double column floating figure using two subfigures.
(The subfig.sty package must be loaded for this to work.)
The subfigure \label commands are set within each subfloat command,
and the \label for the overall figure must come after \caption.
\hfil is used as a separator to get equal spacing.
Watch out that the combined width of all the subfigures on a 
line do not exceed the text width or a line break will occur.

\begin{figure*}[!t]
\centering
\subfloat[Case I]{\includegraphics[width=2.5in]{box}%
\label{fig_first_case}}
\hfil
\subfloat[Case II]{\includegraphics[width=2.5in]{box}%
\label{fig_second_case}}
\caption{Simulation results for the network.}
\label{fig_sim}
\end{figure*}

Note that often IEEE papers with subfigures do not employ subfigure
captions (using the optional argument to \subfloat[]), but instead will
reference/describe all of them (a), (b), etc., within the main caption.
Be aware that for subfig.sty to generate the (a), (b), etc., subfigure
labels, the optional argument to \subfloat must be present. If a
subcaption is not desired, just leave its contents blank,
e.g., \subfloat[].


An example of a floating table. Note that, for IEEE style tables, the
\caption command should come BEFORE the table and, given that table
captions serve much like titles, are usually capitalized except for words
such as a, an, and, as, at, but, by, for, in, nor, of, on, or, the, to
and up, which are usually not capitalized unless they are the first or
last word of the caption. Table text will default to \footnotesize as
the IEEE normally uses this smaller font for tables.
The \label must come after \caption as always.

\begin{table}[!t]
% increase table row spacing, adjust to taste
\renewcommand{\arraystretch}{1.3}
if using array.sty, it might be a good idea to tweak the value of
\extrarowheight as needed to properly center the text within the cells
\caption{An Example of a Table}
\label{table_example}
\centering
% Some packages, such as MDW tools, offer better commands for making tables
% than the plain LaTeX2e tabular which is used here.
\begin{tabular}{|c||c|}
\hline
One & Two\\
\hline
Three & Four\\
\hline
\end{tabular}
\end{table}


Note that the IEEE does not put floats in the very first column
- or typically anywhere on the first page for that matter. Also,
in-text middle ("here") positioning is typically not used, but it
is allowed and encouraged for Computer Society conferences (but
not Computer Society journals). Most IEEE journals/conferences use
top floats exclusively. 
Note that, LaTeX2e, unlike IEEE journals/conferences, places
footnotes above bottom floats. This can be corrected via the
\fnbelowfloat command of the stfloats package. -->


# Conclusion

The conclusion goes here.

<!-- conference papers do not normally have an appendix -->

# Acknowledgment {#acknowledgment}

The authors would like to thank...

# Bibliography styles

Here are two sample references: @Feynman1963118 [@Dirac1953888].

\newpage
# References {#references .numbered}

---
classoption: "runningheads"
title: "Contribution Title\\thanks{Supported by organization x.}"
shorttitle: "Short title"
# If the paper title is too long for the 
# running head, you can set an abbreviated 
# paper title here.
# shorttitle: "Abbreviated paper title"
authors: 
  - name: "First Author"
    inst: "1"
    orcid: "0000-1111-2222-3333"
  - name: "Second Author"
    inst: "2,3"
    orcid: "1111-2222-3333-4444"
  - name: "Third Author"
    inst: "3"
    orcid: "2222--3333-4444-5555"
# First names are abbreviated in the running head.
# If there are more than two authors, 'et al.' is used.
authorrunning: "F. Author et al." 
institutes: 
  - name: "Princeton University, Princeton NJ 08544, USA"
  - name: "Springer Heidelberg, Tiergartenstr. 17, 69121 Heidelberg, Germany"
    email: "lncs@springer.com"
    url: "http://www.springer.com/gp/computer-science/lncs"
  - name: "ABC Institute, Rupert-Karls-University Heidelberg, Heidelberg, Germany"
    email: "dummy@uni-heidelberg.de"
abstract: | 
  The abstract should briefly summarize the contents of the paper in 150--250 words.
keywords: 
  - First keyword
  - Second keyword
  - Another keyword
bibliography: lncs-test.bib
# Use csl when using default citation_package for Pandoc citeproc
csl: https://www.zotero.org/styles/springer-lecture-notes-in-computer-science
# citations with arabic numbers is prefered when using natbib
natbiboptions: numbers

output: 
  rticles::lncs_article:
    citation_package: default # or natbib
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE,
                      out.extra = "")  # This forces knitr to label all figures.
```

# First Section

## A Subsection Sample

Please note that the first paragraph of a section or subsection is not indented. 
The first paragraph that follows a table, figure, equation etc. does not need an indent, either.

Subsequent paragraphs, however, are indented.

### Sample Heading (Third Level)

Only two levels of headings should be numbered. 
Lower level headings remain unnumbered; they are formatted as run-in headings.

#### Sample Heading (Fourth Level)

The contribution should contain no more than four levels of headings. 
Table\ \ref{tab:table} gives a summary of all heading levels.

```{r table}
knitr::kable(head(pressure), 
             format = "latex",
             caption = "Table captions should be placed above the tables.")
```

\noindent Displayed equations are centered and set on a separate line.

\begin{equation}
x + y = z
\end{equation}

Please try to avoid rasterized images for line-art diagrams and schemas. 
Whenever possible, use vector graphics instead (see Fig.\ \ref{fig:fig1}).

```{r fig1, fig.cap = "A figure caption is always placed below the illustration. Please note that short captions are centered, while long ones are justified by the macro package automatically."}
plot(pressure)
```

::: {.theorem latex=true}
This is a sample theorem. The run-in heading is set in bold, while the following text appears in italics. Definitions, lemmas, propositions, and corollaries are styled the same way.
:::

The environments 'definition', 'lemma', 'proposition', 'corollary', 'remark', and 'example' are defined in the LLNCS documentclass as well.

::: {.proof latex=true}
Proofs, examples, and remarks have the initial word in italics, while the following text appears in normal font.
:::

For citations of references, use [@Nuncio2011]

Multiple citations are grouped [@Levitus2012;@Raphael2004].

### Acknowledgements
Please place your acknowledgments at the end of the paper, preceded by an unnumbered run-in heading (i.e. 3rd-level heading).

# How to contribute a new output format ?

To contribute a new article template to this package, please make sure you have done the following things (note that `journalname_article` below is only an example name):

- [ ] This project uses a Contributor Licence Agreement (CLA) that you'll be asked to sign when opening a PR. This is required for a significant pull request (it is fine not to sign it if a PR is only intended to fix a few typos). Unless you have done it in any other RStudio / Posit projects before, sign the individual or corporate contributor agreement as appropriate. You can send the signed copy to <jj@posit.co>.

- [ ] Add the `journalname_article()` function to `R/article.R` if the output format is simple enough, otherwise create a separate `R/journalname_article.R`.

- [ ] Document your function using **roxygen2**. Markdown syntax is supported. Refer to <https://roxygen2.r-lib.org/articles/rd-formatting.html> for formatting references.

- [ ] Add the Pandoc LaTeX template `inst/rmarkdown/templates/journalname/resources/template.tex`.

- [ ] Add a skeleton article `inst/rmarkdown/templates/journalname/skeleton/skeleton.Rmd`.

- [ ] Add a description of the template `inst/rmarkdown/templates/journalname/template.yaml`.

- [ ] Please include the document class file (`*.cls`) if needed, but please do not include standard LaTeX packages (`*.sty`) that can be downloaded from CTAN. If you are using TinyTeX or TeX Live, you can verify if a package is available on CTAN via `tinytex::parse_packages(files = "FILENAME"")` (e.g., when `FILENAME` is `plain.bst`, it should return `"bibtex"`, which means this file is from a standard CTAN package). Please keep the number of new files absolutely minimal (e.g., do not include PDF output files), and also make examples minimal (e.g., if you need a `.bib` example, try to only leave one or two bibliography entries in it, and don't include too many items in it without using all of them).

- [ ] Update Rd and namespace (could be done by `devtools::document()`).

- [ ] Update NEWS.

- [ ] Update README with a link to the newly supported journal. Please add your Github username and the full name of the journal (follow other examples in the list). 

- [ ] Add a test to `tests/testit/test-formats.R` by adding a line `test_format("journalname")`. We try to keep them in alphabetical order.

- [ ] Add your name to the list of authors `Authors@R` in DESCRIPTION. You don't need to bump the package version in DESCRIPTION.

Lastly, please try your best to do only one thing per pull request (e.g., if you want to add two output formats, do them in two separate pull requests), and refrain from making cosmetic changes in the code base: https://yihui.name/en/2018/02/bite-sized-pull-requests/

Thank you!

---
# Choose from this list of Journals:
# JGR: Atmospheres, JGR: Biogeosciences, JGR: Earth Surface, 
# JGR: Oceans, JGR: Planets, JGR: Solid Earth, JGR: Space Physics, 
# Global Biogeochemical Cycles, Geophysical Research Letters, 
# Paleoceanography and Paleoclimatology, Radio Science, Reviews of Geophysics, 
# Tectonics, Space Weather, Water Resources Research, Geochemistry, Geophysics, 
# Geosystems, Journal of Advances in Modeling Earth Systems (JAMES),
# Earth's Future, Earth and Space Science, Geohealth
journal: "JGR: Atmospheres"
# Use draft to submit a paper
classoption: "draft,linenumbers"
# A title should be specific, informative, and brief. Use
# abbreviations only if they are defined in the abstract. Titles that
# start with general keywords then specific terms are optimized in
# searches
title: "The title of my paper"
# First name or initial followed by last name
# Authors are individuals who have significantly contributed to the
# research and preparation of the article. Group authors are allowed, if
# each author in the group is separately identified in an appendix.
# Additional author notes should be indicated with
authors:
  - name: Andrew N. Other
    affil: 1
    thanks: Andrew's thanks
  - name: Fred T. Secondauthor
    affil: 1
    thanks: "Current address: Some other place, Germany"
  - name: I. Ken Groupleader
    affil: "1, 2"
affiliations:
  - number: 1
    name: "The first affiliation"
  - number: 2
    name: "The second affiliation"
# More than one corresponding author is allowed in this LaTeX file and for
# publication; but only one corresponding author is allowed in our editorial system.
corresponding_author:
  - name: I. Ken Groupleader
    email: groupleader@fancy.university.com
keypoints:  
  - "List up to three key points (at least one is required)"
  - "Key Points summarize the main points and conclusions of the article"
  - "Each must be 100 characters or less with no special characters or punctuation"
abstract: "A good abstract will begin with a short description of the problem being addressed, briefly describe the new data or analyses, then briefly states the main conclusion(s) and how they are supported and uncertainties."
plain_language_summary: "Some journals require a plain language summary. See: https://publications.agu.org/author-resource-center/text-requirements/#abstract"
output: rticles::agu_article
bibliography: agutest.bib
header-includes: 
      - \usepackage{soulutf8}  # For UTF8 chars in TrackChanges
# AGU recommends using the trackchanges LaTeX package in the edition process
# which is available from this link:
# https://publications.agu.org/files/2019/02/January-14-2019-latex-templates.zip
---

```{r echo=FALSE}
# Some recommended settings. 
knitr::opts_chunk$set(
  echo = FALSE,
  fig.pos = 'h',
  out.extra = "",   # To force the use of figure enviroment
  fig.cap = "Please caption every figure"
)
```

```{r keypoints_check, echo=FALSE, results='asis', eval = TRUE}
# This chunk adds a warning if any keypoint is longer than 100 characters. 
# To disable it, you can remove it or set eval to FALSE.
if (any(nchar(rmarkdown::metadata$keypoints) > 100)) {
  cat("\\textcolor{red}{\\textbf{Warning}: keypoint(s)", 
      knitr::combine_words(which(nchar(rmarkdown::metadata$keypoints) > 100)), 
      "longer than 100 characters.}")
}
```

Suggested section heads

# Introduction

The main text should start with an introduction. Except for short manuscripts (such as comments and replies), the text should be divided into sections, each with its own heading.

Headings should be sentence fragments and do not begin with a lowercase letter or number. Capitalize the first letter of each word (except for prepositions, conjunctions, and articles that are three or fewer letters).

# Materials and Methods

Here is text on Materials and Methods.

Do not use bulleted lists; enumerated lists are okay. Use #. for list for a cleaner LaTeX output.

#. First element

#. Second element

## A descriptive heading about methods

Please use ONLY \\citet and \\citep for reference citations.
DO NOT use other cite commands (e.g., \\cite, \\citeyear, \\nocite, \\citealp, etc.).
Example \\citet and \\citep:
  ...as shown by \citet{Levitus2012}, \citet{Nuncio2011} and \citet{Raphael2004}
  ...as shown by \citep{Levitus2012}, \citep{Nuncio2011}, \citep{Raphael2004}.
  ...has been shown \citep[e.g.,][]{Levitus2012, Nuncio2011, Raphael2004}.

# Data

Or section title might be a descriptive heading about data

As of 2018 we recommend use of the TrackChanges package to mark revisions. The trackchanges package adds five new LaTeX commands:

\\note[editor]{The note}

\\annote[editor]{Text to annotate}{The note}

\\add[editor]{Text to add}

\\remove[editor]{Text to remove}

\\change[editor]{Text to remove}{Text to add}

complete documentation is here: http://trackchanges.sourceforge.net/

# Results

Or section title might be a descriptive heading about the results

Enter Figures and Tables near as possible to where they are first mentioned:
DO NOT USE \\psfrag or \\subfigure commands.
DO NOT USE \\newcommand, \\renewcommand, or \\def, etc.

```{r}
plot(pressure)
```

Example table

\begin{table}
 \caption{Time of the Transition Between Phase 1 and Phase 2$^{a}$}
 \centering
 \begin{tabular}{l c}
 \hline
  Run  & Time (min)  \\
 \hline
   $l1$  & 260   \\
   $l2$  & 300   \\
   $l3$  & 340   \\
   $h1$  & 270   \\
   $h2$  & 250   \\
   $h3$  & 380   \\
   $r1$  & 370   \\
   $r2$  & 390   \\
 \hline
 \multicolumn{2}{l}{$^{a}$Footnote text here.}
 \end{tabular}
 \end{table}

AGU prefers the use of {sidewaystable} over {landscapetable} as it causes fewer problems.

```{r, fig.env = "sidewaysfigure"}
plot(pressure)
```

\begin{sidewaystable}
\caption{Caption here}
\label{tab:signif_gap_clos}
\begin{tabular}{ccc}
one&two&three\\
four&five&six
\end{tabular}
\end{sidewaystable}

If using numbered lines, please surround equations with \\begin{linenomath\*}... \\end{linenomath\*}

\begin{linenomath*}
\begin{equation}
y|{f} \sim g(m, \sigma)
\end{equation}
\end{linenomath*}

# Conclusions

\appendix
\section{Here is a sample appendix}

Optional Appendix goes here

Optional Glossary, Notation or Acronym section goes here:

Glossary is only allowed in Reviews of Geophysics

\begin{glossary}
\term{Term}
 Term Definition here
\term{Term}
 Term Definition here
\term{Term}
 Term Definition here
\end{glossary}


\begin{acronyms}
\acro{Acronym}
 Definition here
\acro{EMOS}
 Ensemble model output statistics
\acro{ECMWF}
 Centre for Medium-Range Weather Forecasts
\end{acronyms}

\begin{notation}
\notation{$a+b$} Notation Definition here
\notation{$e=mc^2$}
Equation in German-born physicist Albert Einstein's theory of special
relativity that showed that the increased relativistic mass ($m$) of a
body comes from the energy of motion of the body—that is, its kinetic
energy ($E$)—divided by the speed of light squared ($c^2$).
\end{notation}


\acknowledgments
The acknowledgments must list:
A statement that indicates to the reader where the data
supporting the conclusions can be obtained (for example, in the
references, tables, supporting information, and other databases).

All funding sources related to this work from all authors

Any real or perceived financial conflicts of interests for any author

Other affiliations for any author that may be perceived as having a conflict of 
interest with respect to the results of this paper.

It is also the appropriate place to thank colleagues and other contributors.

AGU does not normally allow dedications. 

---
title: Title here

# set to 1 to the authors and acknowledgements, producing the required blinded version.
blinded: 0

authors: 
- name: Author 1
  thanks: The authors gratefully acknowledge ...
  affiliation: Department of YYY, University of XXX
  
- name: Author 2
  affiliation: Department of ZZZ, University of WWW

keywords:
- 3 to 6 keywords
- that do not appear in the title
abstract: |
  The text of your abstract.  200 or fewer words.

bibliography: bibliography.bib
biblio-style: apalike # default is using plain.bst
output: rticles::asa_article
---

# Introduction

This template demonstrates some of the basic latex you'll need to know to create a ASA article.
It is built from template find at Journal of the American Statistical Association [instruction for authors](https://www.tandfonline.com/action/authorSubmission?show=instructions&journalCode=uasa20#formatting)

## Plot

Plot example - LaTeX floating to be adjusted if you don't want it.

```{r, fig.cap = "A plot example", echo = FALSE}
plot(cars)
```

## Table

Table example

```{r, echo = FALSE}
knitr::kable(head(cars))
```

## Various guidelines

- Note that figures and tables should appear in the paper, not at the end or
in separate files.
- Remember that in the blind version, you should not identify authors indirectly in the text.  That is, don't say "In Smith et. al.  (2009) we showed that ...".  Instead, say "Smith et. al. (2009) showed that ...".
- These points are only intended to remind you of some requirements. Please refer to the instructions for authors
at <http://amstat.tandfonline.com/action/authorSubmission?journalCode=uasa20&page=instructions#.VFkk7fnF_0c>
- For more about ASA style, please see <http://journals.taylorandfrancis.com/amstat/asa-style-guide/>
- If you have supplementary material (e.g., software, data, technical proofs), identify them in the section below.  In early stages of the submission process, you may be unsure what to include as supplementary material.  Don't worry---this is something that can be worked out at later stages.

# Methods {#meth}

Don't take any of these section titles seriously.  They're just for illustration.

# Verifications {#verify}

This section will be just long enough to illustrate what a full page of
text looks like, for margins and spacing.

```{=latex}
\addtolength{\textheight}{.5in}%
```

See @Campbell02 and @Schubert13 or [@Chi81]

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
**With this spacing we have 25 lines per page.**
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

```{=latex}
\addtolength{\textheight}{-.3in}%
```

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.
The quick brown fox jumped over the lazy dog.

# Conclusion {#conc}

\bigskip
::: {.center latex=true}
**SUPPLEMENTARY MATERIAL**
:::

> Use [definition list syntax](https://pandoc.org/MANUAL.html#definition-lists) in this part

Title:
  ~ Brief description. (file type)

R-package for  MYNEW routine:
  ~ R-package **MYNEW** containing code to perform the diagnostic methods described in the article. The package also contains all datasets used as examples in the article. (GNU zipped tar file)

HIV data set:
  ~ Data set used in the illustration of MYNEW method in Section~ 3.2. (.txt file)

# Bibliography. 

Using `natbib` is the default with this format, using `plain.bst` by default on the template, and `apalike.bst` in this Rmd skeleton. Chante to your preference using the `biblio-style` in YAML

---
title: A sample article with some additional note
thanks: # delete thanks field if not require, here notes for title
  - ref: T1 
    text: A sample additional note to the title.
runtitle: A sample running head title
author:
  - name: First 
    surname: Author
    email: first@somewhere.com
    label: e1
    addressLabel: A
    sepNext: "," # use "," or \and; the last author not need this field
  - name: Second
    surname: Author
    email: second@somewhere.com
    label: e2,mark
    addressLabel: B
    sepNext: \and
  - name: Third
    surname: Author
    email: third@somewhere.com
    label: e3,mark
    addressLabel: B
affiliation:
  - label: A
    name: Department, University or Company Name
    authorsLabels: e1
  - label: B
    name: Department, University or Company Name
    authorsLabels: e2,e3
abstract: |
  The abstract should summarize the contents of the paper.
  It should be clear, descriptive, self-explanatory and not longer
  than 200 words. It should also be suitable for publication in
  abstracting services. Formulas should be used as sparingly as
  possible within the abstract. The abstract should not make
  reference to results, bibliography or formulas in the body
  of the paper---it should be self-contained.

  This is a sample input file.  Comparing it with the output it
  generates can show you how to produce a simple document of
  your own.
keyword-subclass: | 
 \begin{keyword}[class=MSC2020] % It must be define for aap, aop, aos journals. For aoas, sts is not used
 \kwd[Primary ]{00X00}
 \kwd{00X00}
 \kwd[; secondary ]{00X00}
 \end{keyword}
keywords: 
  - First keyword
  - Second keyword

predefined-theoremstyle: true # use in section Environments for Axiom, Theorem, etc
bibliography: ims.bib
biblio-style: imsart-nameyear # alternative: imsart-number
output:
  rticles::ims_article:
    journal: aoas # aap, aoas, aop, aos, sts. See documentation
    toc: false # Please use for articles with 50 pages and more
---

# Introduction
This template helps you to create a properly formatted \LaTeXe\ manuscript.
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- %% `\ ' is used here because TeX ignores    %% -->
<!-- %% spaces after text commands.              %% -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
Prepare your paper in the same style as used in this sample .pdf file.
Try to avoid excessive use of italics and bold face.
Please do not use any \LaTeXe\ or \TeX\ commands that affect the layout
or formatting of your document (i.e., commands like \verb|\textheight|,
\verb|\textwidth|, etc.).

# Section headings

Here are some sub-sections:

## A sub-section

Regular text.

### A sub-sub-section

Regular text.

# Text

## Lists

The following is an example of an *itemized* list, two levels deep.
 
* This is the first item of an itemized list.  Each item
  in the list is marked with a "tick." The document
  style determines what kind of tick mark is used.
* This is the second item of the list.  It contains another
  list nested inside it.
  - This is the first item of an itemized list that
    is nested within the itemized list.
  - This is the second item of the inner list.  \LaTeX\
    allows you to nest lists deeper than you really should.
- This is the third item of the list.

The following is an example of an *enumerated* list of one level.

\begin{longlist}
\item This is the first item of an enumerated list.
\item This is the second item of an enumerated list.
\end{longlist}

The following is an example of an *enumerated* list, two levels deep.
\begin{longlist}
\item[1.]
This is the first item of an enumerated list.  Each item
in the list is marked with a ``tick.''.  The document
style determines what kind of tick mark is used.
\item[2.]
This is the second item of the list.  It contains another
list nested inside of it.
\begin{longlist}
\item
This is the first item of an enumerated list that
is nested within.  
\item
This is the second item of the inner list.  \LaTeX\
allows you to nest lists deeper than you really should.
\end{longlist}
This is the rest of the second item of the outer list.
\item[3.]
This is the third item of the list.
\end{longlist}

## Punctuation

Dashes come in three sizes: a hyphen, an intra-word dash like "$U$-statistics" or "the time-homogeneous model";
a medium dash (also called an "en-dash") for number ranges or between two equal entities like "1--2" or "Cauchy--Schwarz inequality";
and a punctuation dash (also called an "em-dash") in place of a comma, semicolon,
colon or parentheses---like this.

Generating an ellipsis \ldots\ with the right spacing
around the periods requires a special command.

## Citation

Simple author and year cite: @billingsley2013convergence.
Multiple bibliography items cite: \cite{billingsley2013convergence,bourbaki1966general} or [@billingsley2013convergence; @bourbaki1966general].
Author only cite: \citeauthor{ethier1985markov}.
Year only cite: \citeyear{prokhorov1956convergence} or [-@prokhorov1956convergence].

# Fonts

Please use text fonts in text mode, e.g.:
\begin{itemize}
\item[]\textrm{Roman}
\item[]\textit{Italic}
\item[]\textbf{Bold}
\item[]\textsc{Small Caps}
\item[]\textsf{Sans serif}
\item[]\texttt{Typewriter}
\end{itemize}
Please use mathematical fonts in mathematical mode, e.g.:
\begin{itemize}
\item[] $\mathrm{ABCabc123}$
\item[] $\mathit{ABCabc123}$
\item[] $\mathbf{ABCabc123}$
\item[] $\boldsymbol{ABCabc123\alpha\beta\gamma}$
\item[] $\mathcal{ABC}$
\item[] $\mathbb{ABC}$
\item[] $\mathsf{ABCabc123}$
\item[] $\mathtt{ABCabc123}$
\item[] $\mathfrak{ABCabc123}$
\end{itemize}
Note that \verb|\mathcal, \mathbb| belongs to capital letters-only font typefaces.

# Notes

Footnotes[^1]
pose no problem.[^2]

[^1]: This is an example of a footnote.
[^2]: Note that footnote number is after punctuation.

# Quotations

Text is displayed by indenting it from the left margin. There are short quotations

> This is a short quotation.  It consists of a
> single paragraph of text.  There is no paragraph
> indentation.

and longer ones.

<!-- custom blocks syntax https://bookdown.org/yihui/rmarkdown-cookbook/custom-blocks.html -->

::: {.quotation data-latex=""}
This is a longer quotation.  It consists of two paragraphs
of text.  The beginning of each paragraph is indicated
by an extra indentation.

This is the second paragraph of the quotation.  It is just
as dull as the first paragraph.
:::

# Environments

## Examples for *`plain`-style environments*

::: {.axiom data-latex=""}
\label{ax1}
This is the body of Axiom \ref{ax1}.
:::

::: {.proof data-latex=""}
This is the body of the proof of the axiom above.
:::

::: {.claim data-latex=""}
\label{cl1}
This is the body of Claim \ref{cl1}. Claim \ref{cl1} is numbered after
Axiom \ref{ax1} because we used \verb|[axiom]| in \verb|\newtheorem|.
:::

::: {.theorem data-latex=""}
\label{th1}
This is the body of Theorem \ref{th1}. Theorem \ref{th1} numbering is
dependent on section because we used \verb|[section]| after \verb|\newtheorem|.
:::

::: {.theorem data-latex="[Title of the theorem]"}
\label{th2}
This is the body of Theorem \ref{th2}. Theorem \ref{th2} has additional title.
:::

::: {.lemma data-latex=""}
\label{le1}
This is the body of Lemma \ref{le1}. Lemma \ref{le1} is numbered after
Theorem \ref{th2} because we used \verb|[theorem]| in \verb|\newtheorem|.
:::

::: {.proof data-latex="[Proof of Lemma \ref{le1}]"}
This is the body of the proof of Lemma \ref{le1}.
:::

## Examples for *`remark`*-style environments
::: {.definition data-latex=""}
\label{de1}
This is the body of Definition \ref{de1}. Definition \ref{de1} is numbered after
Lemma \ref{le1} because we used \verb|[theorem]| in \verb|\newtheorem|.
:::

::: {.example data-latex=""}
This is the body of the example. Example is unnumbered because we used \verb|\newtheorem*|
instead of \verb|\newtheorem|.
:::

::: {.fact data-latex=""}
This is the body of the fact. Fact is unnumbered because we used \verb|\newtheorem*|
instead of \verb|\newtheorem|.
:::

# Tables and figures
Cross-references to labeled tables: As you can see in Table\ref{tab:mtc}
and also in Table\ref{parset}.

```{r mtc, echo = FALSE}
knitr::kable(mtcars, caption = "Table caption", format = "latex", vline = "", linesep = "")
```

\begin{table}
\caption{Sample posterior estimates for each model}
\label{parset}
%
\begin{tabular}{@{}lcrcrrr@{}}
\hline
&& & &\multicolumn{3}{c}{Quantile} \\
\cline{5-7}
Model &Parameter &
\multicolumn{1}{c}{Mean} &
Std. dev.&
\multicolumn{1}{c}{2.5\%} &
\multicolumn{1}{c}{50\%}&
\multicolumn{1}{c@{}}{97.5\%} \\
\hline
{Model 0} & $\beta_0$ & $-$12.29 & 2.29 & $-$18.04 & $-$11.99 & $-$8.56 \\
          & $\beta_1$  & 0.10   & 0.07 & $-$0.05  & 0.10   & 0.26  \\
          & $\beta_2$   & 0.01   & 0.09 & $-$0.22  & 0.02   & 0.16  \\[6pt]
{Model 1} & $\beta_0$   & $-$4.58  & 3.04 & $-$11.00 & $-$4.44  & 1.06  \\
          & $\beta_1$   & 0.79   & 0.21 & 0.38   & 0.78   & 1.20  \\
          & $\beta_2$   & $-$0.28  & 0.10 & $-$0.48  & $-$0.28  & $-$0.07 \\[6pt]
{Model 2} & $\beta_0$   & $-$11.85 & 2.24 & $-$17.34 & $-$11.60 & $-$7.85 \\
          & $\beta_1$   & 0.73   & 0.21 & 0.32   & 0.73   & 1.16  \\
          & $\beta_2$   & $-$0.60  & 0.14 & $-$0.88  & $-$0.60  & $-$0.34 \\
          & $\beta_3$   & 0.22   & 0.17 & $-$0.10  & 0.22   & 0.55  \\
\hline
\end{tabular}
%
\end{table}


```{r,echo=FALSE,fig.cap="Figure caption\\label{penG}"}
plot(1:10)
```

Sample of cross-reference to figure.
Figure\ref{penG} shows that it is not easy to get something on paper.

# Equations and the like

Two equations:
\begin{equation}
    C_{s}  =  K_{M} \frac{\mu/\mu_{x}}{1-\mu/\mu_{x}} \label{ccs}
\end{equation}
and
\begin{equation}
    G = \frac{P_{\mathrm{opt}} - P_{\mathrm{ref}}}{P_{\mathrm{ref}}}  100(\%).
\end{equation}

Equation arrays:
\begin{eqnarray}
  \frac{dS}{dt} & = & - \sigma X + s_{F} F,\\
  \frac{dX}{dt} & = &   \mu    X,\\
  \frac{dP}{dt} & = &   \pi    X - k_{h} P,\\
  \frac{dV}{dt} & = &   F.
\end{eqnarray}
One long equation:
\begin{eqnarray}
 \mu_{\text{normal}} & = & \mu_{x} \frac{C_{s}}{K_{x}C_{x}+C_{s}}  \nonumber\\
                     & = & \mu_{\text{normal}} - Y_{x/s}\bigl(1-H(C_{s})\bigr)(m_{s}+\pi /Y_{p/s})\\
                     & = & \mu_{\text{normal}}/Y_{x/s}+ H(C_{s}) (m_{s}+ \pi /Y_{p/s}).\nonumber
\end{eqnarray}

<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- %% Example with single Appendix:            %% -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->

::: {.appendix data-latex=""}
# Title {.unnumbered #appn}

Appendices should be provided in \verb|{appendix}| environment,
before Acknowledgements.

If there is only one appendix,
then please refer to it in text as \ldots\ in the \hyperref[appn]{Appendix}.
:::

<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- %% Example with multiple Appendixes:        %% -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->

::: {.appendix data-latex=""}
# Title of the first appendix {#appA}
If there are more than one appendix, then please refer to it
as \ldots\ in Appendix \ref{appA}, Appendix \ref{appB}, etc.

# Title of the second appendix {#appB}

## First subsection of Appendix \protect\ref{appB}
Use the standard \LaTeX\ commands for headings in \verb|{appendix}|.
Headings and other objects will be numbered automatically.

\begin{equation}
\mathcal{P}=(j_{k,1},j_{k,2},\dots,j_{k,m(k)}). \label{path}
\end{equation}

Sample of cross-reference to the formula (\ref{path}) in Appendix \ref{appB}.
:::

<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- %% Support information (funding), if any,   %% -->
<!-- %% should be provided in the                %% -->
<!-- %% Acknowledgements section.                %% -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->

## Acknowledgements {.unnumbered}

The authors would like to thank the anonymous referees, an Associate
Editor and the Editor for their constructive comments that improved the
quality of this paper.

The first author was supported by NSF Grant DMS-??-??????.

The second author was supported in part by NIH Grant ???????????.


<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- %% Supplementary Material, if any, should   %% -->
<!-- %% be provided in {supplement} environment  %% -->
<!-- %% with title and short description.        %% -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->

\begin{supplement}
\stitle{Title of Supplement A}
\sdescription{Short description of Supplement A.}
\end{supplement}
\begin{supplement}
\stitle{Title of Supplement B}
\sdescription{Short description of Supplement B.}
\end{supplement}

<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->
<!-- %%                  The Bibliography                       %% -->
<!-- %%                                                         %% -->
<!-- %%  imsart-nameyear.bst  will be used to                   %% -->
<!-- %%  create a .BBL file for submission.                     %% -->
<!-- %%                                                         %% -->
<!-- %%  Note that the displayed Bibliography will not          %% -->
<!-- %%  necessarily be rendered by Latex exactly as specified  %% -->
<!-- %%  in the online Instructions for Authors.                %% -->
<!-- %%                                                         %% -->
<!-- %%  MR numbers will be added by VTeX.                      %% -->
<!-- %%                                                         %% -->
<!-- %%  Use \cite{...} to cite references in text.             %% -->
<!-- %%                                                         %% -->
<!-- %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% -->

---
journal: ijds
title: Paper for INFORMS journal
shorttitle: "Untitled"
authors:
- familyname: Lee
  othernames: Sue
  affiliation: Department of YYY, University of XXX
  email: author@xxx.edu
- familyname: Li
  othernames: Xu
  affiliation: Department of ZZZ, University of WWW
  email: author@www.edu
- familyname: Leigh
  othernames:  Soo
  affiliation: Department of BBB, University of VVV
  email: author@www.edu
keywords:
  - 3 to 6 keywords
  - that do not appear in the title
abstract: |
  Abstract goes here
acknowledgment: |
  The authors would like to thank ...
bibliography: references.bib
blind: false
manuscriptno: to be added later
output: rticles::informs_article
---

Notes: the journal must be one of deca, ijds, ijoc, inte, isre, mnsc, mksc, moor, msom, opre, orsc, trsc, ited, serv, stsc, corresponding to the associated INFORMS journal.

# Section title {#sec:1}

Text with citations by @cleveland1990stl or in parentheses [@HK06].

## Subsection title {#sec:2}

Don't forget to give each section
and subsection a unique label (see Section \ref{sec:1} for an example).

#### Paragraph headings

Use paragraph headings if needed.

## Equations

Here is an equation:
$$ 
  f_{X}(x) = \left(\frac{\alpha}{\beta}\right)
  \left(\frac{x}{\beta}\right)^{\alpha-1}
  e^{-\left(\frac{x}{\beta}\right)^{\alpha}}; 
  \alpha,\beta,x > 0 .
$$
Here is another:
\begin{align}
  a^2+b^2=c^2.
\end{align}

Inline equations: $\sum_{i = 2}^\infty\{\alpha_i^\beta\}$

# Figures and tables

## Figures coming from R

Figure \ref{fig2} is generated using an R chunk.

```{r fig2, fig.width = 5, fig.height = 5, fig.align='center', out.width="50%", fig.cap = "\\label{fig2}A meaningless scatterplot.", echo = FALSE}
plot(runif(25), runif(25))
```

## Tables coming from R

Tables can also be generated using R chunks, as shown in Table \ref{tab1} for example.

```{r tab1, echo=FALSE}
knitr::kable(head(mtcars)[,1:4], 
    caption = "\\label{tab1}Caption centered above table"
)
```

\clearpage

::: {.APPENDIX latex="{General appendix}"}

Some content for the appendix.

:::

::: {.APPENDICES latex=true}

If there is more than one appendix (i.e., several unrelated sections), one should use `APPENDICES` instead, and add section headings like this.

# Section A

Content

# Section B

Content

:::

---
# This template is largely functionally equivalent to that for elsevier
# The two fields that are not in the elsevier format are:
#      `corresponding_author` and `acknowledgements`
title: Template for Oxford University Press papers
date: "`r Sys.Date()`"
author:
  - name: Alice Anonymous
    email: alice@example.com
    corresponding_author: yes # Footnote using corresponding_author
    affiliation:
      - ABC
      - DEF
  - name: Bob Security
    email: bob@example.com
    affiliation: DEF
    footnote: 1 # Footnote using reference
  - name: Cat Memes
    email: cat@anotheru.edu
    affiliation: Another University
    footnote:
        - 1
        - 2
address:
  - code: ABC
    address: Address ABC
  - code: DEF
    address: Address DEF
  - code: Another University
    address: Address for Another University
footnote:
  - code: 1
    text: "Equal contribution"
  - code: 2
    text: "Current email address: \\href{mailto:cat@example.com}{cat@example.com}"
abstract: |
  This is the abstract.

  It consists of two paragraphs.
acknowledgements: |
  This is an acknowledgement.

  It consists of two paragraphs.
keywords:
  - key
  - dictionary
  - word
bibliography: mybibfile.bib
# Use a CSL when `citation_package = "default"`
#csl: https://www.zotero.org/styles/oxford-university-press-note

## Example of some pandoc's variable to use
#fontsize: 12pt
#spacing: halfline # could also be oneline
#classoptions:
#  - endnotes
#link-citations: yes
#urlcolor: orange
#linkcolor: green
#citecolor: red
#header-includes:
#  - \usepackage[nomarkers,tablesfirst]{endfloat} # For figures and tables at end
#  - \usepackage{lineno} # For line numbering
#  - \linenumbers # For line numbering

output: 
  rticles::oup_article:
    oup_version: 0 # 1 = 2020 CTAN OUP CLS package; 0 = 2009 OUP CLS package
    extra_dependencies: booktabs # for kable example
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(
  echo = FALSE, # By default, hide code; set to TRUE to see code
  fig.pos = 'p', # Places figures on pages separate from text
  out.width = '100%', dpi = 300, # Figure resolution and size
  fig.env = "figure" # Latex figure environment
)
```

# Introduction

This template is based on the generic OUP template available [here](https://academic.oup.com/icesjms/pages/General_Instructions). The original OUP sample tex document, providing more details on prefered formatting for LaTeX documents, is included with the template in the file `ouparticle_sample.tex`.

**OUP template version**

This demo file will use the old template `ouparticle.cls`

```yaml
output: 
  rticles::oup_article:
    oup_version: 0
```

Set `oup_version: 1` to use the new template from  `oup-authoring-template` CTAN package. There is another Rmd template for this as example: Create it from RStudio IDE or using `rmarkdown::draft("MyArticle.Rmd", template = "oup_v0", package = "rticles")`

# Reference example

Here are two sample references: @Feynman1963118 [@Dirac1953888]. Bibliography will appear at the end of the document.

# Materials and methods

An equation with a label for cross-referencing:

\begin{equation}\label{eq:eq1}
\int^{r_2}_0 F(r,\varphi){\rm d}r\,{\rm d}\varphi = [\sigma r_2/(2\mu_0)]
\int^{\infty}_0\exp(-\lambda|z_j-z_i|)\lambda^{-1}J_1 (\lambda r_2)J_0
(\lambda r_i\,\lambda {\rm d}\lambda)
\end{equation}

This equation can be referenced as follows: Eq. \ref{eq:eq1}

## A subsection

A numbered list:

1) First point
2) Second point
    - Subpoint
    
A bullet list:

* First point
* Second point

# Results

## Generate a figure.

```{r fig1, fig.cap="This is the first figure.",echo=TRUE}
plot(1:10, main = "Some data", xlab = "Distance (cm)", ylab = "Time (hours)")
```

You can reference this figure as follows: Fig. \ref{fig:fig1}.

```{r fig2, fig.cap="This is the second figure.",echo=TRUE}
plot(1:5, pch = 19, main = "Some data", xlab = "Distance (cm)", ylab = "Time (hours)")
```

Reference to second figure: Fig. \ref{fig:fig2}

## Generate a table using `xtable`

```{r tab1, results="asis", echo=TRUE}
df <- data.frame(ID = 1:3, code = letters[1:3])

# Creates tables that follow OUP guidelines using xtable
library(xtable)
print(xtable(df, caption = "This is the table caption", label = "tab:tab1"),
  comment = FALSE
)
```

You can reference this table as follows: Table \ref{tab:tab1}.

## Generate a table using `kable`

```{r anothertable, echo=TRUE}
df <- data.frame(ID = 1:3, code = letters[1:3])

# kable can alse be used for creating tables
knitr::kable(df,
  caption = "This is the table caption", format = "latex",
  booktabs = TRUE, label = "tab2"
)
```

You can reference this table as follows: Table \ref{tab:tab2}.

# Discussion

You can cross-reference sections and subsections as follows: Section \ref{materials-and-methods} and Section \ref{a-subsection}.

***Note:*** the last section in the document will be used as the section title for the bibliography.

# References

To use **rticles** from RStudio, you can access the templates through `File -> New File -> R Markdown`. This will open the dialog box where you can select from one of the available templates:

![New R Markdown](https://bookdown.org/yihui/rmarkdown/images/rticles-templates.png)
    
 
If you are not using RStudio, you'll also need to install [Pandoc](https://pandoc.org) following these [instructions](https://bookdown.org/yihui/rmarkdown-cookbook/install-pandoc.html). Then, use the `rmarkdown::draft()` function to create articles:

```r
rmarkdown::draft(
    "MyJSSArticle.Rmd", template = "jss", package = "rticles"
)
rmarkdown::draft(
    "MyRJournalArticle", template = "rjournal", package = "rticles"
)
```
   
   This will create a folder containing a Rmd file using the corresponding output format and all the assets required by this format. 

## R CMD check results

We checked 16 reverse dependencies, comparing R CMD check results across CRAN and dev versions of this package.

 * We saw 1 new problems
 * We failed to check 0 packages

Issues with CRAN packages are summarised below.

### New problems
(This reports the first line of each new failure)

* markovchain
  checking re-building of vignette outputs ... ERROR
  
  This is on system with Pandoc < 2.7 due to new requirement from one of the output format. 

  An issue has been raised upstream: https://github.com/spedygiorgio/markovchain/issues/219
  
  On system with latest Pandoc, there should be no error.

---
title: Submission Instructions
author:
- name: First Author
  institution: First author address
  email: First author email
- name: Second Author
  institution: Second author address
  email: Second author email
abstract: |
  This document serves both as JEDM submission instruction and as a template file.  This is the abstract. It should contain from 100 to 250 words.
keywords: submission, JEDM, abstract, instructions, style
bibliography: ref.bib
output: rticles::jedm_article
---

```{r setup, include = FALSE, echo = FALSE, purl = FALSE}
knitr::opts_chunk$set(echo = FALSE)
```

# Paper format

Manuscripts should be formatted for letter sized paper, one side only, leaving 2.75cm margins on the right and left sides and 2.25cm on the top and bottom. Body font should be Times Roman 12pt and sections, title, and authors font should be Helvetica.

# Style files

For LaTeX, a style file named \texttt{jedm.cls} is provided on the journal's web site.  An MS Word file containing this example text is also provided, \texttt{jedm.doc}, which can be used as a template (see the Styles menu). Note that copy/pasting into the template may not ensure correct formatting but selecting a region of text and applying the appropriate style should always work. 

# Figures and tables

Each figure and table must be mentioned in the text, and must be numbered consecutively in order of appearance (with captions in lower case). For the review process, the figures should be integrated into the text rather than being inserted at the end of the document.

As JEDM is an electronic journal, authors are encouraged to use colours when it enhances visibility and understanding of figures.

Examples of a figure and a table are given in Figure~\ref{tab:fig1} and Table~\ref{tab:1}.

```{=latex}
\begin{figure}
  \centerline{\fbox{\parbox{.66\textwidth}{\centering \raisebox{0pt}[2cm][2cm]{%
        \begin{tabular}{c}
          \cellcolor{blue!35}{\sf This is a figure}\\
          \cellcolor{blue!25}{\sf And yes, you can use colors!}\\
          \cellcolor{blue!15}{\sf As long as it enhances visibility and understanding}\\
        \end{tabular}
  }}}}
  \caption{This is the figure's caption.  It should be a centered paragraph of width 193mm (7.6in). Font size should be 11pt.}
  \label{tab:fig1}
\end{figure}
```

```{=latex}
\begin{table}
  \caption{This is an example of a table that lists the margins of this template.  Captions should follow the same rules as a figure, except that they are put on top of the table.}\vspace*{1ex}
  \label{tab:1}
  \centering
  \begin{tabular}{| l | l |}
    \hline
    \multicolumn{1}{|c|}{\textbf{Margin}} & \multicolumn{1}{c|}{\textbf{Size}} \\
    \hline
    left&2.75cm\\
    right&2.75cm\\
    top&2.25cm\\
    bottom&2.25cm\\
    \hline
  \end{tabular}
\end{table}
```

# Appendices

Supplementary technical material (e.g., mathematical proofs or descriptions of experimental procedures) should be collected in an appendix at the end of the paper (before the acknowledgements and the references sections).

# Footnotes and acknowledgments

Footnotes should be used sparingly and indicated by consecutive superscript numbers in the text. Material to be footnoted should appear at the bottom of the page on which it is referenced. Acknowledgments and grant numbers should be put into a separate 'Acknowledgment' section right before the list of references.

# References

References should follow the ACM standard.  The example provided here uses the \texttt{jedm.cls} class file and \texttt{acmtrans.bst} bib style file.  For example, we could write that \citeN{JEDM:baker2009} published a review on EDM in this journal; other reviews were published later \cite[for eg.]{romero2010educational}. The provided ref.bib file contains examples of virtually every possible citation type.

# Supporting materials

Authors are encouraged to submit the data they use and the analysis code in order to replicate and perform rigorous comparisons across studies.  The data and code can be stored on the \texttt{educationaldatamining.org} site for public reference, or stored privately for reviewing purpose only if required. See the online submission instructions for guidance on using and citing code repositories.

# Page numbering and sectioning

For the manuscript to be reviewed, page number should appear at the bottom of each page.  \textbf{For the final version, they must be taken out as the standard JEDM footer is be added.}

## Sections and subsections

Section style should follow the example in this document.

### Subsection levels

There should be no more than three levels of sections.

#### Fourth level.

The fourth level should simply have their title in the same font style as those of of subsections, without numbering and at the beginning of a paragraph.

# Submission

The journal prefers PDF format, but can also accommodate most other popular formats.  Care should be taken to embed fonts in the rendered PDF. The provided Word template has a larger filesize because it contains embedded fonts.

Instructions for submitting the papers on the website are at \\
\url{http://jedm.educationaldatamining.org/index.php/JEDM/about/submissions#onlineSubmissions}.  You first need to register and log in to the site.  When registering, you must activate your role as ``author''.

# References {-}

---
title: Template for preparing your manuscript submission to Copernicus journals using RMarkdown
journal: "`r rticles::copernicus_journal_abbreviations(journal_name = 'communication')`"
author:
  - given_name: Daniel
    surname: Nüst
    affiliation: "1, *"
    email: daniel.nuest@uni-muenster.de
    corresponding: true
  - given_name: Josiah
    surname: Carberry
    affiliation: 2
    email: j.carberry@orcid.org
  - given_name: Markus
    surname: Konkol
    affiliation: "1, *"
  - given_name: Nikolaus
    surname: Copernicus
    # authors can have multiple affiliations, which can also be used to mark deceased coauthors
    affiliation: "3, †"
# If you have more than one corresponding author, add them manually using the following structure (note the commas):
# Two authors: Daniel Nüst (daniel.nuest@uni-muenster.de) and Josiah Carberry (j.carberry@orcid.org)
# Three authors or more: Daniel Nüst (daniel.nuest@uni-muenster.de), Josiah Carberry (j.carberry@orcid.org), and Markus Konkol (m.konkol@wwu.de)
# If the following line is uncommented, the "corresponding: true" above are ignored
#correspongdingauthors: Daniel Nüst (daniel.nuest@uni-muenster.de) and Josiah Carberry (j.carberry@orcid.org)
# If an author is deceased, please mark the respective author name(s) with a dagger '†' and add a further affiliation; put the decease date in the 'address' field", see 'Nikolaus Copernicus' in template.
# If authors contributed equally, please mark the respective author names with an asterisk '*' and add a further affiliation: 'These authors contributed equally to this work.'", see template.
affiliation:
  - code: 1
    address: Institute for Geoinformatics, University of Münster, 48149 Münster, Germany
  - code: 2
    address: Psychoceramics, Wesleyan University, Middletown, CT, United States
  - code: 3
    address: University of Ferrara, Ferrara, Italy
  - code: "†"
    address: deceased, 24 May 1543
  - code: "*"
    address: These authors contributed equally to this work.
abstract: |
  The abstract goes here.
  It can also be on _multiple lines_.
bibliography: sample.bib
running:
  title: R Markdown Template for Copernicus
  author: Nüst et al.
# This section is mandatory even if you declare that no competing interests are present.
competinginterests: |
  The authors declare no competing interests.
# See https://publications.copernicus.org/for_authors/licence_and_copyright.html, normally used for transferring the copyright, if needed. 
# Note: additional copyright statements for affiliated software or data need to be placed in the data availability section. 
copyrightstatement: |
  The author's copyright for this publication is transferred to institution/company. 
### The following commands are for the statements about the availability of data sets and/or software code corresponding to the manuscript.
### It is strongly recommended to make use of these sections in case data sets and/or software code have been part of your research the article is based on.
### Note: unless stated otherwise, software and data affiliated with the manuscript are assumed to be published under the same licence as the article (currently Creative Commons 4.0)
availability:
  #code: |
  #  use this to add a statement when having only software code available
  #data: |
  #  use this to add a statement when having only data sets available
  codedata: |
    use this to add a statement when having data sets and software code available
  sample: |
    use this section when having geoscientific samples available
videosupplement: |
  use this section when having video supplements available
authorcontribution: |
  Daniel wrote the package. Josiah thought about poterry. Markus filled in for a second author.
disclaimer: |
  We like Copernicus.
acknowledgements: |
  Thanks to the rticles contributors!
appendix: |
  \section{Figures and tables in appendices}
  Regarding figures and tables in appendices, the following two options are possible depending on your general handling of figures and tables in the manuscript environment:
  \subsection{Option 1}
  If you sorted all figures and tables into the sections of the text, please also sort the appendix figures and appendix tables into the respective appendix sections.
  They will be correctly named automatically.
  \subsection{Option 2}
  If you put all figures after the reference list, please insert appendix tables and figures after the normal tables and figures.
  
  To rename them correctly to A1, A2, etc., please add the following commands in front of them:
  `\appendixfigures` needs to be added in front of appendix figures
  `\appendixtables` needs to be added in front of appendix tables
  
  Please add `\clearpage` between each table and/or figure. Further guidelines on figures and tables can be found below.
output:
  rticles::copernicus_article: 
    highlight: NULL
    keep_tex: true
  bookdown::pdf_book:
    base_format: rticles::copernicus_article # for using bookdown features like \@ref()
---

\introduction[Introduction]

Introduction text goes here.
You can change the name of the section if necessary using `\introduction[modified heading]`.

The following settings can or must be configured in the header of this file and are bespoke for Copernicus manuscripts:

- The `journal` you are submitting to using the official abbreviation. You can use the function `rticles::copernicus_journal_abbreviations(name = '...')` to search the existing journals.

- Specific sections of the manuscript:

  - `running` with `title` and `author`

  - `competinginterests`

  - `copyrightstatement` (optional)

  - `availability` (strongly recommended if any used), one of `code`, `data`, or `codedata`

  - `authorcontribution`

  - `disclaimer`

  - `acknowledgements`

See the defaults and examples from the skeleton and the official Copernicus documentation for details.

**Please note:** Per [their
guidelines](https://publications.copernicus.org/for_authors/manuscript_preparation.html),
Copernicus does not support additional \LaTeX{} packages or new \LaTeX{}
commands than those defined in their `.cls` file. This means that you cannot add any extra dependencies and a warning will be thrown if so.  
This extends to syntax highlighting of source code. Therefore this template sets
the parameter `highlight` in the YAML header to `NULL` to deactivate Pandoc
syntax highlighter. This prevent addition of external packages for highlighting
inserted by Pandoc. However, it might be desirable to have syntax highlight
available in preprints or for others reasons. Please see
`?rmarkdown::pdf_document` for available options to activate highlighting.

**Important**: Always double-check with the official manuscript preparation
guidelines at
[https://publications.copernicus.org/for_authors/manuscript_preparation.html](https://publications.copernicus.org/for_authors/manuscript_preparation.html),
especially the sections "Technical instructions for LaTeX" and "Manuscript
composition". Please contact Daniel Nüst, `daniel.nuest@uni-muenster.de`, with
any problems.

# Content section one

## Subsection Heading Here

Subsection text here. 

### Subsubsection Heading Here

Subsubsection text here. 

# Content section with citations

See the [R Markdown docs for bibliographies and citations](http://rmarkdown.rstudio.com/authoring_bibliographies_and_citations.html).

Copernicus supports biblatex and a sample bibliography is in file `sample.bib`.
Read [@Feynman1963118], and [see @Dirac1953888].

# Content section with R code chunks

```{r, echo = FALSE}
sum <- 1 + 41
```

You should always use `echo = FALSE` on R Markdown code blocks as they add formatting and styling not desired by Copernicus.
The hidden workflow results in `r sum`.

You can add verbatim code snippets without extra styles by using ` ``` ` without additional instructions.

```
sum <- 1 + 41
```

# Content section with list

If you want to insert a list, you must

- leave

- empty lines

- between each list item

because the `\tightlist` format used by R Markdown is not supported in the Copernicus template. Example:

```
- leave

- empty lines

- between each list item
```

# Examples from the official template

## FIGURES

When figures and tables are placed at the end of the MS (article in one-column style), please add \clearpage between bibliography and first table and/or figure as well as between each table and/or figure.

### ONE-COLUMN FIGURES

Include a 12cm width figure of Nikolaus Copernicus from [Wikipedia](https://en.wikipedia.org/wiki/File:Nikolaus_Kopernikus.jpg) with caption using R Markdown.

```{r, out.width = "8.3cm", echo = FALSE, fig.cap = "one column figure"}
knitr::include_graphics("Nikolaus_Kopernikus.jpg")
```

### TWO-COLUMN FIGURES

You can also include a larger figure.

```{r, out.width = "12cm", echo = FALSE, fig.cap = "two column figure"}
knitr::include_graphics("Nikolaus_Kopernikus.jpg")
```

## TABLES

You can ad \LaTeX table in an R Markdown document to meet the template requirements.

### ONE-COLUMN TABLE

\begin{table}[t]
\caption{TEXT}
\begin{tabular}{l c r}
\tophline

a & b & c \\
\middlehline
1 & 2 & 3 \\

\bottomhline
\end{tabular}
\belowtable{Table Footnotes}
\end{table}

### TWO-COLUMN TABLE

\begin{table*}[t]
\caption{TEXT}
\begin{tabular}{l c r}
\tophline

a & b & c \\
\middlehline
1 & 2 & 3 \\

\bottomhline
\end{tabular}
\belowtable{Table footnotes}
\end{table*}

## MATHEMATICAL EXPRESSIONS

All papers typeset by Copernicus Publications follow the math typesetting regulations given by the IUPAC Green Book (IUPAC: Quantities, Units and Symbols in Physical Chemistry, 2nd Edn., Blackwell Science, available at: http://old.iupac.org/publications/books/gbook/green_book_2ed.pdf, 1993).

Physical quantities/variables are typeset in italic font (t for time, T for Temperature)

Indices which are not defined are typeset in italic font (x, y, z, a, b, c)

Items/objects which are defined are typeset in roman font (Car A, Car B)

Descriptions/specifications which are defined by itself are typeset in roman font (abs, rel, ref, tot, net, ice)

Abbreviations from 2 letters are typeset in roman font (RH, LAI)

Vectors are identified in bold italic font using \vec{x}

Matrices are identified in bold roman font

Multiplication signs are typeset using the LaTeX commands `\times` (for vector products, grids, and exponential notations) or `\cdot`

The character * should not be applied as mutliplication sign

## EQUATIONS

### Single-row equation

Unnumbered equations (i.e. using `$$` and getting inline preview in RStudio) are not supported by Copernicus.

\begin{equation}
1 \times 1 \cdot 1 = 42
\end{equation}

\begin{equation}
A = \pi r^2
\end{equation}

\begin{equation}
x=\frac{2b\pm\sqrt{b^{2}-4ac}}{2c}.  
\end{equation}

### Multiline equation

\begin{align}
& 3 + 5 = 8\\
& 3 + 5 = 8\\
& 3 + 5 = 8
\end{align}

## MATRICES

$$
\begin{matrix}
x & y & z\\
x & y & z\\
x & y & z\\
\end{matrix}
$$

## ALGORITHM/PROGRAMMING CODE

If you want to use algorithms, you need to make sure yourself that the \LaTeX packages `algorithms` and `algorithmicx` are installed so that `algorithm.sty` respectively `algorithmic.sty` can be loaded by the Copernicus template. Both need to be available through your preferred \LaTeX{} distribution. With TinyTeX (or TeX Live), you can do so by running `tinytex::tlmgr_install(c("algorithms", "algorithmicx"))`

```{r, echo = FALSE, eval = tinytex::is_tinytex()}
tinytex::tlmgr_install(c("algorithms", "algorithmicx"))
```

Copernicus staff will no accept any additional packages from your LaTeX source code, so please stick to these two acceptable packages. They are needed to use the example below

\begin{algorithm}
\caption{Algorithm Caption}
\label{a1}
\begin{algorithmic}
\STATE $i\gets 10$
\IF {$i\geq 5$} 
        \STATE $i\gets i-1$
\ELSE
        \IF {$i\leq 3$}
                \STATE $i\gets i+2$
        \ENDIF
\ENDIF
\end{algorithmic}
\end{algorithm}

## CHEMICAL FORMULAS AND REACTIONS

For formulas embedded in the text, please use `\chem{}`, e.g. \chem{A \rightarrow B}.

The reaction environment creates labels including the letter R, i.e. (R1), (R2), etc.

- `\rightarrow` should be used for normal (one-way) chemical reactions

- `\rightleftharpoons` should be used for equilibria

- `\leftrightarrow` should be used for resonance structures

\begin{reaction}
A \rightarrow B \\
\end{reaction}
\begin{reaction}
Coper \rightleftharpoons nicus \\
\end{reaction}
\begin{reaction}
Publi \leftrightarrow cations
\end{reaction}

## PHYSICAL UNITS

Please use `\unit{}` (allows to save the math/`$` environment) and apply the exponential notation, for example \( 3.14\,\unit{km\,h^{-1}} \) (using LaTeX mode: `\( 3.14\,\unit{...} \)`) or \unit{0.872\,m\,s^{-1}} (using only `\unit{0.872\,m\,s^{-1}}`).

\conclusions[Conclusions]

The conclusion goes here.
You can modify the section name with  `\conclusions[modified heading if necessary]`.

---
title: Template for Oxford University Press papers
author:
  - name: Alice Anonymous
    email: alice@example.com
    corresponding_author: TRUE # Automatic footnote using corresponding_author
    affiliation:
      - ABC
      - DEF
    biography: |
      A promising young researcher working on her thesis project.
#    biography_pic: "/PATH/TO/image.png"
#    biography_pic_width: "1in"
  - name: Bob Security
    email: bob@example.com
    affiliation: DEF
    footnote: 1 # Footnote using reference
  - name: Cat Memes
    email: cat@anotheru.edu
    affiliation: Another University
    footnote:
        - 1
        - 2
address:
  - code: ABC
    department: Department of Biology
    organization: University of Idaho
    street: 123 Main Street
    #postcode: 
    city: Boise
    state: Idaho 07458 # Mix and match elements to get proper address
    country: United States
  - code: DEF
    address: Address in one element deprecated, but works
  - code: Another University
    address: Address for Another University
footnote:
  - code: 1
    text: "Equal contribution"
  - code: 2
    text: "Current email address: [cat@example.com](mailto:cat@example.com)"
abstract:
  - "This is the first paragraph of the abstract. It has several sentences making it go over several lines. For this it needs to have a lot of text." 
  - "This is the second paragraph."
  - "**Motivation:** You can also have some paragraphs start with bold face."
keywords:
  - keyword1
  - keyword2
  - keyword3
#boxedlist: # Not fully compatible with all document formats
#  - First point
#  - Second point
competing_interests: |
  There are no competing interest.
author_contributions: |
  AA did all the work. The others are just freeloaders.
acknowledgments: |
  This is an acknowledgement.

  It consists of two paragraphs.

bibliography: mybibfile.bib # Includes refs in OUP example template
## When using `citation_package = "default"`, a CSL file can be used
#csl: https://www.zotero.org/styles/oxford-university-press-note
output:
  rticles::oup_article:
    oup_version: 1 # 1 = 2020 CTAN OUP CLS package; 0 = 2009 OUP CLS package
    journal: "Journal Name"
    document_style: "contemporary" # Can be contemporary, modern, traditional
    papersize: "large" # Can be large, medium, small
    #citation_package: "default" # Uncomment when using a CSL; default "natbib"
    namedate: TRUE # Set FALSE to use numeric refs; Default FALSE
    #number_sections: FALSE # Uncomment to not number sections; default TRUE
    #number_lines: TRUE # Use `lineno` package - Default FALSE
    #number_lines_options: ["mathlines","switch"]  # Options for latex lineno package.
    #onecolumn: TRUE # Uncomment for one column format; default FALSE
    extra_dependencies:
      - booktabs # to use with knitr::kable() example below
      
## Example of pandoc's variable
#urlcolor: orange
#linkcolor: green
#citecolor: red
header-includes:
  #- \usepackage[nomarkers,tablesfirst]{endfloat} # For figures and tables at end
  - \theoremstyle{thmstyleone} # Theorem stuff from OUP template
  - \newtheorem{theorem}{Theorem} #  meant for continuous numbers. %%\newtheorem{theorem}{Theorem}[section] # meant for sectionwise numbers. optional argument [theorem] produces theorem numbering sequence instead of independent numbers for Proposition
  - \newtheorem{proposition}[theorem]{Proposition} # %%\newtheorem{proposition}{Proposition}" # to get separate numbers for theorem and proposition etc.
  - \theoremstyle{thmstyletwo}
  - \newtheorem{example}{Example}
  - \newtheorem{remark}{Remark}
  - \theoremstyle{thmstylethree}
  - \newtheorem{definition}{Definition}
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(
  echo = FALSE, # By default, hide code; set to TRUE to see code
  fig.pos = 'th', # Places figures at top or here
  out.width = '100%', dpi = 300, # Figure resolution and size
  fig.env="figure"
) # Latex figure environment

options(knitr.table.format = "latex") # For kable tables to write LaTeX table directly
```

# Introduction

This template is based on the generic OUP authoring template available on CTAN under [oup-authoring-template](https://www.ctan.org/pkg/oup-authoring-template). The CTAN template includes LaTeX documentation and a sample LaTeX document that provide far more details regarding the full functionality of the format. Here, only the basic functioning of the Rmarkdown adaptation of the format is demonstrated.

## A subsection

A numbered list:

1) First point
2) Second point
    - Subpoint
    
A bullet list:

* First point
* Second point

## Notes

* Extra white space in document will tend to disappear as text is filled in.
* Code blocks tend to generate lots of empty white space when `echo=TRUE` for some reason.

# Literature citations

By default, citations are handled by `natbib` using a numeric citation format. To use name-date citations, sets `namedate: TRUE` in the YAML header.

Here are two sample references: 

* **author (year) example:** @horvath2018dna showed some really cool things. Only seems to work properly if `namedate: TRUE`. 
* **(author year) example:** This is a well known result [@ji20123d]. 

The bibliography will appear at the end of the document.

Though not normally available in the OUP LaTeX format, [CSL style files](https://www.zotero.org/styles) can also be used with the Rmarkdown adaptation by setting in the YAML header `citation_package: "default"` and defining the `csl` element to be the path towards the style file.

# Equations

An equation without a label for cross-referencing:

$$
E=mc^2
$$

An inline equation: $y=ax+b$

An equation with a label for cross-referencing:

\begin{equation}\label{eq:eq1}
\int^{r_2}_0 F(r,\varphi){\rm d}r\,{\rm d}\varphi = 1
\end{equation}

This equation can be referenced as follows: Eq. \ref{eq:eq1}

# Inserting R figures

The code below creates a figure. The code is included in the output because `echo=TRUE`.

```{r fig1, fig.cap="This is the first figure.",echo=TRUE}
plot(1:10,main="Some data",xlab="Distance (cm)",
     ylab="Time (hours)")
```

You can reference this figure as follows: Fig. \ref{fig:fig1}.

## Figures spanning two-columns

Figures can span two columns be setting `fig.env="figure*"`.

```{r fig2, fig.cap="This is a wide figure.",fig.env="figure*"}
plot(1:5,pch=19,main="Some wide data",
     xlab="Distance (cm)",ylab="Time (hours)")
```

Reference to second figure: Fig. \ref{fig:fig2}

# Tables

## Generate a table using `xtable`

```{r xtabletable, results="asis", echo=TRUE}
df = data.frame(ID=1:3,code=letters[1:3])

# Creates tables that follow OUP guidelines 
# using xtable
library(xtable) 
print(xtable(df,caption="This is a xtable table.",
             label="tab:tab1"),
      comment=FALSE,caption.placement="top")
```

You can reference this table as follows: Table \ref{tab:tab1}.

## Generate a table using `kable`

```{r kabletable, echo=TRUE}
df = data.frame(ID=1:3,code=letters[1:3])

# kable can alse be used for creating tables
knitr::kable(df,caption="This is a kable table.",
             booktabs=TRUE,label="tab2")
```

You can reference this table as follows: Table \ref{tab:tab2}.

## Table spanning two columns

Tables can span two columns be setting `table.envir = "table*"` in `knitr::kable`.

```{r widetable, echo=TRUE}
df = data.frame(ID=1:3,code1=letters[1:3],
                code2=letters[4:6],
                code3=letters[7:9],
                code4=letters[10:12],
                code5=letters[13:15])

# kable can alse be used for creating tables
knitr::kable(df,caption="This is a wide kable table.",
             #format="latex",
             table.envir="table*",
             booktabs=TRUE,label="tab3")
```

# Cross-referencing sections

You can cross-reference sections and subsections as follows: Section \ref{literature-citations} and Section \ref{a-subsection}.

***Note:*** the last section in the document will be used as the section title for the bibliography.

For more portable and flexible referencing of sections, equations, figures and tables, use [`bookdown::pdf_document2`](https://github.com/rstudio/bookdown) with YAML header option `base_format: rticles::oup_article`.

# Appendices {-}

::: {.appendices latex=true}

# Section title of first appendix

blabla

## Subsection title of first appendix

and so on....
:::

# References

---
title: Template for preparing your research report submission to Royal Society Open Science using RMarkdown
author:
  - name: Alice Anonymous
    affiliation: "1,2"
  - name: Bob Security
    affiliation: "2"
address:
  - code: "1"
    address: Some Institute of Technology, Department, Street, City, State, Zip
  - code: "2"
    address: Another University Department, Street, City, State, Zip

corresp_author_name:  "B. Security"
corresp_author_email: "bob@email.com"

subject:
  - "subject 1"
  - "subject 2"
  - "subject 3"

keywords:
  - one
  - two
  - optional
  - optional
  - optional

abstract: |
  The abstract text goes here. The abstract text goes here. The abstract text goes here. The abstract text goes here. The abstract text goes here. The abstract text goes here. The abstract text goes here. The abstract text goes here.

## Remove this if not required
ethics: |
  Please provide details on the ethics.
  
data_accessibility: |
  Please provide details on the data availability.

author_contributions: |
  Please provide details of author contributions here.

## Remove this if not required
conflict_of_interest: |
  Please declare any conflict of interest here.

## Remove this if not required
funding: |
  Please provide details on funding

## Remove this if not required
disclaimer: |
  Please provide disclaimer text here.

## Remove this if not required
acknowledgements: |
  Please include your acknowledgments here, set in a single paragraph. Please do not include any acknowledgments in the Supporting Information, or anywhere else in the manuscript.

bibliography: sample.bib

## change to true to add optional line numbering
lineno: false

site: bookdown::bookdown_site
output: 
  bookdown::pdf_book:
    base_format: rticles::rsos_article
---

# Insert A head here

This demo file is intended to serve as a "starter file"" for articles submitted to the [Royal Society Open Science](http://rsos.royalsocietypublishing.org/) journal using `RMarkdown`.

Place `\EndFirstPage` at the point where the plain text on the first page stops. Warning: excess text will be hidden behind the copyright box. The example below contains line 1 to 19 in the code. Lines 14 to 17 are hidden behind the copyright box.

## Insert B head here

Subsection text here.

### Insert C head here

Subsubsection text here.

Line 1

Line 2

Line 3

Line 4

Line 5

Line 6

Line 7

Line 8

Line 9

Line 10

Line 11

Line 12

Line 13

Line 14

Line 15

Line 16

Line 17

Line 18

Line 19

\EndFirstPage

# Lists

* one
* two
* three

* fruits
    + apples
        - macintosh
        - red delicious
    + pears
    + peaches
* vegetables
    + broccoli
    + chard

## Citations

Blabla \cite{Lannes} blabla. Blabla \cite{HJ2} blabla. Blabla \cite{BF, Lannes} blabla. Blabla \cite{Benjamin1967, HJ2, HJ3, HP2} blabla.

### Headling level 3

Subsubsection text here.

# R code

R code can be added as usual. Fig. \@ref(fig:nice-plot) is a an example.

```{r echo = TRUE}
summary(lm(mpg ~ disp, data = mtcars))
```

```{r}
summary(mtcars)
```

```{r nice-plot, fig.cap="The caption"}
plot(mtcars[, 1:3])
```

---
classoptions: # Look at guideline at https://www.ctan.org/tex-archive/macros/latex/contrib/mnras
  - fleqn
  - usenatbib
title: Short Paper
shorttitle: Short Paper
shortauthor: K. T. Smith et al.
authors:
  - name: Keith T. Smith
    email: mn@ras.org.uk
    affiliations: [1]
  - name: A. N. Other
    affiliations: [2]
  - name: Third Author
    affiliations: [2,3]
  - name: Fourth Author
    affiliations: [3]
affiliations:
  - number: 1
    name: Royal Astronomical Society, Burlington House, Piccadilly, London W1J 0BQ, UK
  - number: 2
    name: Department, Institution, Street Address, City Postal Code, Country
  - number: 3
    name: Another Department, Different Institution, Street Address, City Postal Code, Country
abstract: |
  This is a simple template for authors to write new MNRAS papers.
  The abstract should briefly describe the aims, methods, and main results of the paper.
  It should be a single paragraph not more than 250 words (200 words for Letters).
  No references should appear in the abstract.
keywords: ["keyword1", "keyword2", "keyword3"]
# When pandoc citeproc is prefered
# csl: mnras.csl
bibliography: references.bib
output: 
  rticles::mnras_article:
    citation_package: natbib
---


# Introduction

This is a simple template for authors to write new MNRAS papers.  See
`mnras_sample.tex` for a more complex example, and `mnras_guide.tex` for a full
user guide.

All papers should start with an Introduction section, which sets the work
in context, cites relevant earlier studies in the field by @Author2012,
and describes the problem the authors aim to solve @Others2013.

# Methods, Observations, Simulations etc.

Normally the next section describes the techniques the authors used.  It is
frequently split into subsections, such as Section \ref{maths} below.

## Maths

Labels are auto--generated, i.e. this one has `\label{maths}`.

Simple mathematics can be inserted into the flow of the text e.g. $2\times3=6$
or $v=220$ km s$^{-1}$, but more complicated expressions should be entered as
a numbered equation:

\begin{equation}
  x=\frac{-b\pm\sqrt{b^2-4ac}}{2a}
  \label{eq:quadratic}
\end{equation}

Refer back to them as e.g. equation (\ref{eq:quadratic}).

## Figures and tables

Figures and tables should be placed at logical positions in the text. Don't
worry about the exact layout, which will be handled by the publishers.

Figures are referred to as e.g. Fig. \ref{fig:example_figure}, and tables as
e.g. Table \ref{tab:example_table}.

\begin{figure}
  % To include a figure from a file named example.*
  % Allowable file formats are eps or ps if compiling using latex
  % or pdf, png, jpg if compiling using pdflatex
  \includegraphics[width=\columnwidth]{example}
    \caption{This is an example figure. Captions appear below each figure.
  Give enough detail for the reader to understand what they're looking at,
  but leave detailed discussion to the main body of the text.}
    \label{fig:example_figure}
\end{figure}

\begin{table}
  \centering
  \caption{This is an example table. Captions appear above each table.
  Remember to define the quantities, symbols and units used.}
  \label{tab:example_table}
  \begin{tabular}{lccr} % four columns, alignment for each
    \hline
    A & B & C & D\\
    \hline
    1 & 2 & 3 & 4\\
    2 & 4 & 6 & 8\\
    3 & 5 & 7 & 9\\
    \hline
  \end{tabular}
\end{table}

# Conclusions

The last numbered section should briefly summarise what has been done, and
describe the final conclusions which the authors draw from their work.

# Acknowledgements {-}

The Acknowledgements section is not numbered. Here you can thank helpful
colleagues, acknowledge funding agencies, telescopes and facilities used etc.
Try to keep it short.

# References {-}

<div id="refs"></div>

\appendix

# Some extra material

If you want to present additional material which would interrupt the flow of the
main paper, it can be placed in an Appendix which appears after the list of
references.

---
title: Full title of the paper (Capitalized)
author:
  - name: Dominik Leutnant
    affil: 1,2,\ddagger,*
    orcid: 0000-0003-3293-2315
  - name: John Doe
    affil: 2, \dagger, \ddagger
affiliation:
  - num: 1
    address: |
      Muenster University of Applied Sciences - 
      Institute for Infrastructure, Water, Resources, Environment
      Correnstr. 25, 48149 Muenster, Germany
    email: leutnant@fh-muenster.de
  - num: 2
    address: |
      Your department
      Street, City, Country
    email: mail@mail.com
# author citation list in chicago format
authorcitation: |
  Leutnant, D.; Doe, J.
# firstnote to eighthnote
firstnote: |
  Current address: Updated affiliation
secondnote: |
  These authors contributed equally to this work.
correspondence: |
  leutnant@fh-muenster.de; Tel.: +XX-000-00-0000.
# document options
journal: notspecified
type: article
status: submit
# front matter
simplesummary: |
  A Simple summary goes here.
abstract: |
  A single paragraph of about 200 words maximum. For research articles, 
  abstracts should give a pertinent overview of the work. We strongly encourage
  authors to use the following style of structured abstracts, but without 
  headings: 1) Background: Place the question addressed in a broad context and
  highlight the purpose of the study; 2) Methods: Describe briefly the main
  methods or treatments applied; 3) Results: Summarize the article's main 
  findings; and 4) Conclusion: Indicate the main conclusions or interpretations. 
  The abstract should be an objective representation of the article, it must not 
  contain results which are not presented and substantiated in the main text and 
  should not exaggerate the main conclusions.
# back matter
keywords: |
  keyword 1; keyword 2; keyword 3 (list three to ten pertinent keywords specific 
  to the article, yet reasonably common within the subject discipline.).
acknowledgement: |
  All sources of funding of the study should be disclosed. Please clearly 
  indicate grants that you have received in support of your research work. 
  Clearly state if you received funds for covering the costs to publish in open 
  access.
authorcontributions: |
  For research articles with several authors, a short paragraph specifying their 
  individual contributions must be provided. The following statements should be 
  used ``X.X. and Y.Y. conceive and designed the experiments; X.X. performed the 
  experiments; X.X. and Y.Y. analyzed the data; W.W. contributed 
  reagents/materials/analysis tools; Y.Y. wrote the paper.'' Authorship must be
  limited to those who have contributed substantially to the work reported.
funding: |
  Please add: ``This research received no external funding'' or ``This research 
  was funded by NAME OF FUNDER grant number XXX.'' and  and ``The APC was funded 
  by XXX''. Check carefully that the details given are accurate and use the 
  standard spelling of funding agency names at 
  \url{https://search.crossref.org/funding}, any errors may affect your future 
  funding.
institutionalreview: |
  In this section, you should add the Institutional Review Board Statement and 
  approval number, if relevant to your study. You might choose to exclude 
  this statement if the study did not require ethical approval. Please note 
  that the Editorial Office might ask you for further information. Please add 
  “The study was conducted in accordance with the Declaration of Helsinki, 
  and approved by the Institutional Review Board (or Ethics Committee) of 
  NAME OF INSTITUTE (protocol code XXX and date of approval).” for studies 
  involving humans. OR “The animal study protocol was approved by the 
  Institutional Review Board (or Ethics Committee) of NAME OF INSTITUTE 
  (protocol code XXX and date of approval).” for studies involving animals. 
  OR “Ethical review and approval were waived for this study due to REASON 
  (please provide a detailed justification).” OR “Not applicable” for
   studies not involving humans or animals.
informedconsent: |
  Any research article describing a study involving humans should contain this 
  statement. Please add ``Informed consent was obtained from all subjects 
  involved in the study.'' OR ``Patient consent was waived due to REASON 
  (please provide a detailed justification).'' OR ``Not applicable'' for 
  studies not involving humans. You might also choose to exclude this statement 
  if the study did not involve humans.
  
  Written informed consent for publication must be obtained from participating 
  patients who can be identified (including by the patients themselves). Please 
  state ``Written informed consent has been obtained from the patient(s) to 
  publish this paper'' if applicable.
dataavailability: |
  We encourage all authors of articles published in MDPI journals to share 
  their research data. In this section, please provide details regarding where 
  data supporting reported results can be found, including links to publicly 
  archived datasets analyzed or generated during the study. Where no new data 
  were created, or where data is unavailable due to privacy or ethical 
  re-strictions, a statement is still required. Suggested Data Availability 
  Statements are available in section “MDPI Research Data Policies” at 
  \url{https://www.mdpi.com/ethics}.
conflictsofinterest: |
  Declare conflicts of interest or state 'The authors declare no conflict of 
  interest.' Authors must identify and declare any personal circumstances or
  interest that may be perceived as inappropriately influencing the
  representation or interpretation of reported research results. Any role of the
  funding sponsors in the design of the study; in the collection, analyses or 
  interpretation of data in the writing of the manuscript, or in the decision to 
  publish the results must be declared in this section. If there is no role, 
  please state 'The founding sponsors had no role in the design of the study; 
  in the collection, analyses, or interpretation of data; in the writing of the 
  manuscript, an in the decision to publish the results'.
sampleavailability: |
  Samples of the compounds ...... are available from the authors.
supplementary: |
 The following supporting information can be downloaded at:  
 \linksupplementary{s1}, Figure S1: title; Table S1: title; Video S1: title.
abbreviations:
  - short: MDPI
    long: Multidisciplinary Digital Publishing Institute
  - short: DOAJ
    long: Directory of open access journals
  - short: TLA
    long: Three letter acronym
  - short: LD 
    long: linear dichroism
bibliography: mybibfile.bib
appendix: appendix.tex
endnotes: false
output: 
  rticles::mdpi_article:
    extra_dependencies: longtable
---

# Version

This Rmd-skeleton uses the mdpi Latex template published 2023-03-25. 
However, the official template gets more frequently updated than the **rticles**
package. Therefore, please make sure prior to paper submission, that you're 
using the most recent .cls, .tex and .bst files 
(available [here](http://www.mdpi.com/authors/latex)).

# Article Header Information

The YAML header includes information needed mainly for formatting the front and 
back matter of the article. Required elements include:

```yaml
title: Title of the paper
author:
  - name: first and last name
    affil: |
      One or more comma seperated numbers corresponding to affilitation
      and one or more  comma seperated symbols corresponding 
      optional notes.
    orcid: optional orcid number
affiliation:  
  - num: 1,..., n for each affiliation
    address: required
    email: required
authorcitation: |
  Lastname, F.
correspondence: |
  email@email.com; Tel.: +XX-000-00-0000.
journal: notspecified
type: article
status: submit
```

Journal options are in Table \ref{tab:mdpinames}. The `status` variable should 
generally not be changed by authors. The `type` variable describes 
the type of of submission and defaults to `article` but can be replaced with any of the ones in Table \ref{tab:mdpitype}

```{r mdpitype, echo = FALSE}
type <- c("abstract, addendum, article, book, bookreview, briefreport, 
casereport, comment, commentary, communication, conferenceproceedings, 
correction, conferencereport, entry, expressionofconcern, extendedabstract, 
datadescriptor, editorial, essay, erratum, hypothesis, interestingimage, 
obituary, opinion, projectreport, reply, retraction, review, perspective, 
protocol, shortnote, studyprotocol, systematicreview, supfile, 
technicalnote, viewpoint, guidelines, registeredreport, tutorial")
knitr::kable(rticles::string_to_table(type, 3), 
             col.names = NULL, format = "latex", booktab = TRUE, 
             caption = "MDPI article types.")
```

## Journal Specific YAML variables

```yaml
# for journal Diversity,
# add the Life Science Identifier using:
lsid: http://zoobank.org/urn:lsid:zoobank.org:act:nnnn


# for journal Applied Sciences
# add featured application
featuredapplication: |
  Authors are encouraged to provide a concise 
  description of the specific application or 
  a potential application of the work. This 
  section is not mandatory.

# for the journal Data
# add dataset doi and license
dataset: https://doi.org/10.1000/182
datasetlicense: CC-BY-4.0

# for the journal Toxins
# add key contributions
keycontributions: |
  The breakthroughs or highlights of the manuscript. 
  Authors can write one or two sentences to describe 
  the most important part of the paper.

# for the journal Encyclopedia
encyclopediadef: |
  For entry manuscripts only: please provide a brief overview
  of the entry title instead of an abstract.
entrylink: The Link to this entry published on the encyclopedia platform.

# for the journal Advances in Respiratory Medicine
# add highlights
addhighlights: |
  This is an obligatory section in “Advances in Respiratory Medicine”, 
  whose goal is to increase the discoverability and readability of the
  article via search engines and other scholars. Highlights should not 
  be a copy of the abstract, but a simple text allowing the reader to 
  quickly and simplified find out what the article is about and what can 
  be cited from it. Each of these parts should be devoted up to 2~bullet 
  points.

```


\startlandscape
```{r, mdpinames, echo=FALSE, results='asis'}
mdpi_journals <- "acoustics, actuators, addictions, admsci, adolescents, aerobiology, aerospace, agriculture, agriengineering, agrochemicals, agronomy, ai, air, algorithms, allergies, alloys, analytica, analytics, anatomia, animals, antibiotics, antibodies, antioxidants, applbiosci, appliedchem, appliedmath, applmech, applmicrobiol, applnano, applsci, aquacj, architecture, arm, arthropoda, arts, asc, asi, astronomy, atmosphere, atoms, audiolres, automation, axioms, bacteria, batteries, bdcc, behavsci, beverages, biochem, bioengineering, biologics, biology, biomass, biomechanics, biomed, biomedicines, biomedinformatics, biomimetics, biomolecules, biophysica, biosensors, biotech, birds, bloods, blsf, brainsci, breath, buildings, businesses, cancers, carbon, cardiogenetics, catalysts, cells, ceramics, challenges, chemengineering, chemistry, chemosensors, chemproc, children, chips, cimb, civileng, cleantechnol, climate, clinpract, clockssleep, cmd, coasts, coatings, colloids, colorants, commodities, compounds, computation, computers, condensedmatter, conservation, constrmater, cosmetics, covid, crops, cryptography, crystals, csmf, ctn, curroncol, cyber, dairy, data, ddc, dentistry, dermato, dermatopathology, designs, devices, diabetology, diagnostics, dietetics, digital, disabilities, diseases, diversity, dna, drones, dynamics, earth, ebj, ecologies, econometrics, economies, education, ejihpe, electricity, electrochem, electronicmat, electronics, encyclopedia, endocrines, energies, eng, engproc, entomology, entropy, environments, environsciproc, epidemiologia, epigenomes, est, fermentation, fibers, fintech, fire, fishes, fluids, foods, forecasting, forensicsci, forests, foundations, fractalfract, fuels, future, futureinternet, futurepharmacol, futurephys, futuretransp, galaxies, games, gases, gastroent, gastrointestdisord, gels, genealogy, genes, geographies, geohazards, geomatics, geosciences, geotechnics, geriatrics, grasses, gucdd, hazardousmatters, healthcare, hearts, hemato, hematolrep, heritage, higheredu, highthroughput, histories, horticulturae, hospitals, humanities, humans, hydrobiology, hydrogen, hydrology, hygiene, idr, ijerph, ijfs, ijgi, ijms, ijns, ijpb, ijtm, ijtpp, ime, immuno, informatics, information, infrastructures, inorganics, insects, instruments, inventions, iot, j, jal, jcdd, jcm, jcp, jcs, jcto, jdb, jeta, jfb, jfmk, jimaging, jintelligence, jlpea, jmmp, jmp, jmse, jne, jnt, jof, joitmc, jor, journalmedia, jox, jpm, jrfm, jsan, jtaer, jvd, jzbg, kidneydial, kinasesphosphatases, knowledge, land, languages, laws, life, liquids, literature, livers, logics, logistics, lubricants, lymphatics, machines, macromol, magnetism, magnetochemistry, make, marinedrugs, materials, materproc, mathematics, mca, measurements, medicina, medicines, medsci, membranes, merits, metabolites, metals, meteorology, methane, metrology, micro, microarrays, microbiolres, micromachines, microorganisms, microplastics, minerals, mining, modelling, molbank, molecules, mps, msf, mti, muscles, nanoenergyadv, nanomanufacturing, nanomaterials, ncrna, ndt, network, neuroglia, neurolint, neurosci, nitrogen, notspecified, nri, nursrep, nutraceuticals, nutrients, obesities, oceans, ohbm, onco, oncopathology, optics, oral, organics, organoids, osteology, oxygen, parasites, parasitologia, particles, pathogens, pathophysiology, pediatrrep, pharmaceuticals, pharmaceutics, pharmacoepidemiology, pharmacy, philosophies, photochem, photonics, phycology, physchem, physics, physiologia, plants, plasma, platforms, pollutants, polymers, polysaccharides, poultry, powders, preprints, proceedings, processes, prosthesis, proteomes, psf, psych, psychiatryint, psychoactives, publications, quantumrep, quaternary, qubs, radiation, reactions, receptors, recycling, regeneration, religions, remotesensing, reports, reprodmed, resources, rheumato, risks, robotics, ruminants, safety, sci, scipharm, sclerosis, seeds, sensors, separations, sexes, signals, sinusitis, skins, smartcities, sna, societies, socsci, software, soilsystems, solar, solids, spectroscj, sports, standards, stats, std, stresses, surfaces, surgeries, suschem, sustainability, symmetry, synbio, systems, targets, taxonomy, technologies, telecom, test, textiles, thalassrep, thermo, tomography, tourismhosp, toxics, toxins, transplantology, transportation, traumacare, traumas, tropicalmed, universe, urbansci, uro, vaccines, vehicles, venereology, vetsci, vibration, virtualworlds, viruses, vision, waste, water, wem, wevj, wind, women, world, youth, zoonoticdis"

knitr::kable(rticles::string_to_table(mdpi_journals, 8),
             col.names = NULL,
             format = "latex",
             booktabs = TRUE, 
             caption = "MDPI journal names.",
             longtable = TRUE)

```
\finishlandscape




# Introduction

The introduction should briefly place the study in a broad context and highlight
why it is important. It should define the purpose of the work and its
significance. The current state of the research field should be reviewed
carefully and key publications cited. Please highlight controversial and
diverging hypotheses when necessary. Finally, briefly mention the main aim of
the work and highlight the principal conclusions. As far as possible, please
keep the introduction comprehensible to scientists outside your particular
field of research. Citing a journal paper [@bertrand-krajewski_distribution_1998;
@leutnant_stormwater_2016]. And now citing a book reference @gujer_systems_2008.
Some MDPI journals use Chicago and others use APA, this template should choose
the correct citation format for you once you specify the journal in the YAML
header.

To use endnotes, change `endnotes: true` in the YAML header, then use
`\endnote{This is an endnote.}`.


# Materials and Methods

Materials and Methods should be described with sufficient details to allow 
others to replicate and build on published results. Please note that publication 
of your manuscript implicates that you must make all materials, data, computer 
code, and protocols associated with the publication available to readers. Please
disclose at the submission stage any restrictions on the availability of 
materials or information. New methods and protocols should be described in 
detail while well-established methods can be briefly described and appropriately
cited.

Research manuscripts reporting large datasets that are deposited in a publicly 
available database should specify where the data have been deposited and provide
the relevant accession numbers. If the accession numbers have not yet been
obtained at the time of submission, please state that they will be provided
during review. They must be provided prior to publication.

Interventionary studies involving animals or humans, and other studies require
ethical approval must list the authority that provided approval and the
corresponding ethical approval code.

# Results

This section may be divided by subheadings. It should provide a concise and
precise description of the experimental results, their interpretation as well
as the experimental conclusions that can be drawn.

## Subsection Heading Here

Subsection text here.

### Subsubsection Heading Here

Bulleted lists look like this:

* First bullet
* Second bullet
* Third bullet

Numbered lists can be added as follows:

1. First item
2. Second item
3. Third item

The text continues here.

## Figures, Tables and Schemes

All figures and tables should be cited in the main text as Figure \ref{fig:fig1}, 
\ref{tab:tab1}, etc. To get cross-reference to figure generated by R chunks 
include the `\\label{}` tag in the `fig.cap` attribute of the R chunk: 
`fig.cap = "Fancy Caption\\label{fig:plot}"`.

```{r fig1, echo=FALSE, fig.width=3, fig.cap="A figure added with a code chunk.\\label{fig:fig1}"}
x = rnorm(10)
y = rnorm(10)
plot(x, y)
```


When making tables using `kable`, it is suggested to use
the `format="latex"` and `tabl.envir="table"` arguments
to ensure table numbering and compatibility with the mdpi
document class.

```{r tab1, echo=FALSE}
knitr::kable(mtcars[1:5, 1:3], format = "latex", 
             booktabs = TRUE, 
             caption = "This is a table caption. Tables should be placed in the 
             main text near to the first time they are~cited.", 
             align = 'ccc', centering = FALSE,
             table.envir = "table", position = "H")
```



For a very wide table, landscape layouts are allowed.


\startlandscape

```{r tab2, echo=FALSE}
df <- data.frame(`Title 1` = c("Entry 1", "Entry 2"),
                 `Title 2` = c("Data", "Data"),
                 `Title 3` = c("Data", "Data"),
                 `Title 4` = c("This cell has some longer content that runs over
                               two lines",
                               "Data"))
knitr::kable(df, format = "latex", 
             booktabs = TRUE, 
             caption = "This is a very wide table", 
             align = 'ccc', centering = FALSE,
             table.envir = "table", position = "H")
```

\finishlandscape

## Formatting of Mathematical Components

This is an example of an equation:

$$
a = 1.
$$

If you want numbered equations use Latex and wrap in the equation environment:

\begin{equation}
a = 1,
\end{equation}

the text following an equation need not be a new paragraph. Please punctuate 
equations as regular text.

```{comment}
If the documentclass option "submit" is chosen, please insert a blank line before and after any math environment (equation and eqnarray environments). This ensures correct linenumbering. The blank line should be removed when the documentclass option is changed to "accept" because the text following an equation should not be a new paragraph.
```

This is the example 2 of equation:

\begin{adjustwidth}{-\extralength}{0cm}
\begin{equation}
a = b + c + d + e + f + g + h + i + j + k + l + m + n + o + p + q + r + s + t + 
u + v + w + x + y + z
\end{equation}
\end{adjustwidth}

Theorem-type environments (including propositions, lemmas, corollaries etc.) 
can be formatted as follows:

Example of a theorem:

::: {.Theorem latex=true}
Example text of a theorem
:::

The text continues here. Proofs must be formatted as follows:

Example of a proof:

::: {.proof latex="[Proof of Theorem1]"}
Text of the proof. Note that the phrase ``of Theorem 1'' is optional if it is 
clear which theorem is being referred to.
:::

The text continues here.

# Discussion

Authors should discuss the results and how they can be interpreted in 
perspective of previous studies and of the working hypotheses. The findings and 
their implications should be discussed in the broadest context possible. Future 
research directions may also be highlighted.

# Conclusion

This section is not mandatory, but can be added to the manuscript if the
discussion is unusually long or complex.

# Patents

This section is not mandatory, but may be added if there are patents resulting
from the work reported in this manuscript.

---
title: |
  Taylor & Francis Rmarkdown template for authors (\LaTeX\-based 
  \textsf{Interact} layout + Chicago author-date reference style)
type: ARTICLE TEMPLATE
author:
  - name: A. N. Author
    affil: a
    email: latex.helpdesk@tandf.co.uk
  - name: John Smith
    affil: b
    email: john.smith@uni-freiburg.de
  - name: Dominik Leutnant
    affil: c, \dagger, \ddagger
    email: leutnant@fh-muenster.de
affiliation:
  - num: a
    address: |
      Taylor & Francis, 4 Park Square, Milton Park, Abingdon, UK
  - num: b
    address: |
      Institut für Informatik, Albert-Ludwigs-Universität, Freiburg, Germany
  - num: c
    address: |
      Muenster University of Applied Sciences - 
      Institute for Infrastructure, Water, Resources, Environment,
      Correnstr. 25, 48149 Münster, Germany
bibliography: interactcadsample.bib
appendix: appendix.tex
abstract: |
  This template is for authors who are preparing a manuscript for a Taylor & 
  Francis journal using the \LaTeX\ document preparation system and the 
  `interact} class file, which is available via selected journals' home 
  pages on the Taylor & Francis website.
keywords: |
  Sections; lists; figures; tables; mathematics; fonts; references; appendices
header-includes: |
  \usepackage{hyperref}
  \usepackage[utf8]{inputenc}
  \def\tightlist{}
output: rticles::tf_article
---

# Introduction

In order to assist authors in the process of preparing a manuscript for a journal, the Taylor & Francis '\textsf{Interact}' layout style has been implemented as a \LaTeXe\ class file based on the `article` document class. A \textsc{Bib}\TeX\ bibliography style file and a sample bibliography are also provided in order to assist with the formatting of your references.

Commands that differ from or are provided in addition to standard \LaTeXe\ are described in this document, which is _not_ a substitute for a \LaTeXe\ tutorial.

The `interactcadsample.tex` file can be used as a template for a manuscript by cutting, pasting, inserting and deleting text as appropriate, using the preamble and the \LaTeX\ environments provided (e.g.\ `\begin{abstract}`, `\begin{keywords}`).

## The \textsf{Interact} class file

The `interact` class file preserves the standard \LaTeXe\ interface such that any document that can be produced using `article.cls` can also be produced with minimal alteration using the `interact` class file as described in this document.

If your article is accepted for publication it will be typeset as the journal requires in Minion Pro and/or Myriad Pro. Since most authors will not have these fonts installed, the page make-up is liable to alter slightly with the change of font. Also, the `interact` class file produces only single-column format, which is preferred for peer review and will be converted to two-column format by the typesetter if necessary during preparation of the proofs. Please therefore do not try to match the typeset format exactly, but use the standard \LaTeX\ fonts instead and ignore details such as slightly long lines of text or figures/tables not appearing in exact synchronization with their citations in the text: these details will be dealt with by the typesetter. Similarly, it is unnecessary to spend time addressing warnings in the log file -- if your .tex file compiles to produce a PDF document that correctly shows how you wish your paper to appear, such warnings will not prevent your source files being imported into the typesetter's program.

## Submission of manuscripts prepared using _\LaTeX_

Manuscripts for possible publication should be submitted to the Editors for review as directed in the journal's Instructions for Authors, and in accordance with any technical instructions provided in the journal's ScholarOne Manuscripts or Editorial Manager site. Your \LaTeX\ source file(s), the class file and any graphics files will be required in addition to the final PDF version when final, revised versions of accepted manuscripts are submitted.

Please ensure that any author-defined macros used in your article are gathered together in the preamble of your .tex file, i.e.\ before the `\begin{document}` command. Note that if serious problems are encountered in the coding of a document (missing author-defined macros, for example), the typesetter may resort to rekeying it.

# Using the `interact` class file

For convenience, simply copy the `interact.cls` file into the same directory as your manuscript files (you do not need to install it in your \TeX\ distribution). In order to use the `interact` document class, replace the command `\documentclass{article}` at the beginning of your document with the command `\documentclass{interact}`.

The following document-class options should _not_ be used with the `interact` class file:

* `10pt`, `11pt`, `12pt` -- unavailable;
* `oneside`, `twoside` -- not necessary, `oneside` is the default;
* `leqno`, `titlepage` -- should not be used;
* `twocolumn` -- should not be used;
* `onecolumn` -- not necessary as it is the default style.

To prepare a manuscript for a journal that is printed in A4 (two column) format, use the `largeformat` document-class option provided by `interact.cls`; otherwise the class file produces pages sized for B5 (single column) format by default. The `geometry` package should not be used to make any further adjustments to the page dimensions.

<!-- If your manuscript has supplementary content you can prepare this using the `suppldata` document-class option, which will suppress the `article history' date. This option must _not_ be used on any primary content. -->

# Additional features of the `interact` class file

## Title, authors' names and affiliations, abstracts and article types

## Abbreviations

A list of abbreviations may be included if required, enclosed within an `abbreviations` environment, i.e.\ `\begin{abbreviations}`\ldots`\end{abbreviations}`, immediately following the `abstract` environment.


## Keywords

A list of keywords may be included if required, enclosed within a `keywords` environment, i.e.\ `\begin{keywords}`\ldots`\end{keywords}`. Additional keywords in other languages (preceded by a translation of the word `keywords`) may also be included within the `keywords` environment if required.


## Subject classification codes

AMS, JEL or PACS classification codes may be included if required. The `interact` class file provides an `amscode` environment, i.e.\ `\begin{amscode}`\ldots`\end{amscode}`, a `jelcode` environment, i.e.\ `\begin{jelcode}`\ldots`\end{jelcode}`, and a `pacscode` environment, i.e.\ `\begin{pacscode}`\ldots`\end{pacscode}` to assist with this.


## Additional footnotes to the title or authors' names

<!-- The `\thanks` command may be used to create additional footnotes to the title or authors' names if required. Footnote symbols for this purpose should be used in the order -->
<!-- $^\ast$~(coded as `$^\ast$`), $\dagger$~(`$\dagger$`), $\ddagger$~(`$\ddagger$`), $\S$~(`$\S$`), $\P$~(`$\P$`), $\|$~(`$\|$`), -->
<!-- $\dagger\dagger$~(`$\dagger\dagger$`), $\ddagger\ddagger$~(`$\ddagger\ddagger$`), $\S\S$~(`$\S\S$`), $\P\P$~(`$\P\P$`). -->

Note that any `footnote`s to the main text will automatically be assigned the superscript symbols 1, 2, 3, etc. by the class file.^[If preferred, the `endnotes` package may be used to set the notes at the end of your text, before the bibliography. The symbols will be changed to match the style of the journal if necessary by the typesetter.]

# Embedding R code

## Code chunks

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
```

```{r cars}
summary(cars)
```

## Including Plots

You can also embed plots, for example:

```{r pressure, echo=FALSE, out.width='80%'}
plot(pressure)
```

Note that the `echo = FALSE` parameter was added to the code chunk to prevent printing of the R code that generated the plot.

# Some guidelines for using the standard features of \LaTeX

## Sections

The \textsf{Interact} layout style allows for five levels of section heading, all of which are provided in the `interact` class file using the standard \LaTeX\ commands `\section`, `\subsection`, `\subsubsection`, `\paragraph` and `\subparagraph`. Numbering will be automatically generated for all these headings by default.

## Lists

Numbered lists are produced using the `enumerate` environment, which will number each list item with arabic numerals by default. For example,

1. first item
2. second item
3. third item

Alternative numbering styles can be achieved by inserting an optional argument in square brackets to each `item`, e.g.\ `\item[(i)] first item`\, to create a list numbered with roman numerals at level one.

Bulleted lists are produced using the `itemize` environment. For example,

* First bulleted item
* Second bulleted item
* Third bulleted item

## Figures

```{r pressure-plot, fig.show='hide'}
plot(pressure)
```

The `interact` class file will deal with positioning your figures in the same way as standard \LaTeX. It should not normally be necessary to use the optional `[htb]` location specifiers of the `figure` environment in your manuscript; you may, however, find the `[p]` placement option or the `endfloat` package useful if a journal insists on the need to separate figures from the text.

Figure captions appear below the figures themselves, therefore the `\caption` command should appear after the body of the figure. For example, Figure~\ref{sample-figure} with caption and sub-captions is produced using the following commands:
```
\begin{figure}
\centering
\subfigure[An example of an individual figure sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{path/to/fig}}}\hspace{5pt}
\subfigure[A slightly shorter sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{path/to/fig}}}
\caption{Example of a two-part figure with individual sub-captions
 showing that captions are flush left and justified if greater
 than one line of text.} \label{sample-figure}
\end{figure}
```
\begin{figure}
\centering
\subfigure[An example of an individual figure sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{`r knitr::fig_chunk('pressure-plot', 'pdf')`}}}\hspace{5pt}
\subfigure[A slightly shorter sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{`r knitr::fig_chunk('pressure-plot', 'pdf')`}}}
\caption{Example of a two-part figure with individual sub-captions
 showing that captions are flush left and justified if greater
 than one line of text.} \label{sample-figure}
\end{figure}

To ensure that figures are correctly numbered automatically, the `\label` command should be included just after the `\caption` command, or in its argument.

The `\subfigure` command requires `subfigure.sty`, which is called in the preamble of the `interacttfssample.tex` file (to allow your choice of an alternative package if preferred) and included in the \textsf{Interact} \LaTeX\ bundle for convenience. Please supply any additional figure macros used with your article in the preamble of your .tex file.

The source files of any figures will be required when the final, revised version of a manuscript is submitted. Authors should ensure that these are suitable (in terms of lettering size, etc.) for the reductions they envisage.

The `epstopdf` package can be used to incorporate encapsulated PostScript (.eps) illustrations when using PDF\LaTeX, etc. Please provide the original .eps source files rather than the generated PDF images of those illustrations for production purposes.


## Tables

The `interact` class file will deal with positioning your tables in the same way as standard \LaTeX. It should not normally be necessary to use the optional `[htb]` location specifiers of the `table` environment in your manuscript; you may, however, find the `[p]` placement option or the `endfloat` package useful if a journal insists on the need to separate tables from the text.

The `tabular` environment can be used as shown to create tables with single horizontal rules at the head, foot and elsewhere as appropriate. The captions appear above the tables in the \textsf{Interact} style, therefore the `\tbl` command should be used before the body of the table. For example, Table~\ref{sample-table} is produced using the following commands:
\begin{table}
\tbl{Example of a table showing that its caption is as wide as
 the table itself and justified.}
{\begin{tabular}{lcccccc} \toprule
 & \multicolumn{2}{l}{Type} \\ \cmidrule{2-7}
 Class & One & Two & Three & Four & Five & Six \\ \midrule
 Alpha\textsuperscript{a} & A1 & A2 & A3 & A4 & A5 & A6 \\
 Beta & B2 & B2 & B3 & B4 & B5 & B6 \\
 Gamma & C2 & C2 & C3 & C4 & C5 & C6 \\ \bottomrule
\end{tabular}}
\tabnote{\textsuperscript{a}This footnote shows how to include
 footnotes to a table if required.}
\label{sample-table}
\end{table}
```
\begin{table}
\tbl{Example of a table showing that its caption is as wide as
 the table itself and justified.}
{\begin{tabular}{lcccccc} \toprule
 & \multicolumn{2}{l}{Type} \\ \cmidrule{2-7}
 Class & One & Two & Three & Four & Five & Six \\ \midrule
 Alpha\textsuperscript{a} & A1 & A2 & A3 & A4 & A5 & A6 \\
 Beta & B2 & B2 & B3 & B4 & B5 & B6 \\
 Gamma & C2 & C2 & C3 & C4 & C5 & C6 \\ \bottomrule
\end{tabular}}
\tabnote{\textsuperscript{a}This footnote shows how to include
 footnotes to a table if required.}
\label{sample-table}
\end{table}
```

To ensure that tables are correctly numbered automatically, the `\label` command should be included just before `\end{table}`.

The `\toprule`, `\midrule`, `\bottomrule` and `\cmidrule` commands are those used by `booktabs.sty`, which is called by the `interact` class file and included in the \textsf{Interact} \LaTeX\ bundle for convenience. Tables produced using the standard commands of the `tabular` environment are also compatible with the `interact` class file.


## Landscape pages

If a figure or table is too wide to fit the page it will need to be rotated, along with its caption, through 90$^{\circ}$ anticlockwise. Landscape figures and tables can be produced using the `rotating` package, which is called by the `interact` class file. The following commands (for example) can be used to produce such pages.
```
\setcounter{figure}{1}
\begin{sidewaysfigure}
\centerline{\epsfbox{figname.eps}}
\caption{Example landscape figure caption.}
\label{landfig}
\end{sidewaysfigure}
```
```
\setcounter{table}{1}
\begin{sidewaystable}
 \tbl{Example landscape table caption.}
  {\begin{tabular}{@{}llllcll}
    .
    .
    .
  \end{tabular}}\label{landtab}
\end{sidewaystable}
```
Before any such float environment, use the `\setcounter` command as above to fix the numbering of the caption (the value of the counter being the number given to the preceding figure or table). Subsequent captions will then be automatically renumbered accordingly. The `\epsfbox` command requires `epsfig.sty`, which is called by the `interact` class file and is also included in the \textsf{Interact} \LaTeX\ bundle for convenience.

Please note that if the `endfloat` package is used, one or both of the commands
```
\DeclareDelayedFloatFlavor{sidewaysfigure}{figure}
\DeclareDelayedFloatFlavor{sidewaystable}{table}
```
will need to be included in the preamble of your .tex file, after the `endfloat` package is loaded, in order to process any landscape figures and/or tables correctly.


## Theorem-like structures

A predefined `proof` environment is provided by the `amsthm` package (which is called by the `interact` class file), as follows:
\begin{proof}
More recent algorithms for solving the semidefinite programming relaxation are particularly efficient, because they explore the structure of the MAX-CUT problem.
\end{proof}
\noindent This was produced by simply typing:
```
\begin{proof}
More recent algorithms for solving the semidefinite programming
relaxation are particularly efficient, because they explore the
structure of the MAX-CUT problem.
\end{proof}
```
Other theorem-like environments (theorem, definition, remark, etc.) need to be defined as required, e.g.\ using `\newtheorem{theorem}{Theorem}` in the preamble of your .tex file (see the preamble of `interactcadsample.tex` for more examples). You can define the numbering scheme for these structures however suits your article best. Please note that the format of the text in these environments may be changed if necessary to match the style of individual journals by the typesetter during preparation of the proofs.


## Mathematics

### Displayed mathematics

The `interact` class file will set displayed mathematical formulas centred on the page without equation numbers if you use the `displaymath` environment or the equivalent `\[...\]` construction. For example, the equation
\[
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\]
was typeset using the commands
```
\[
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\]
```

For those of your equations that you wish to be automatically numbered sequentially throughout the text for future reference, use the `equation` environment, e.g.
\begin{equation}
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\end{equation}
was typeset using the commands
```
\begin{equation}
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\end{equation}
```

Part numbers for sets of equations may be generated using the `subequations` environment, e.g.
\begin{subequations} \label{subeqnexample}
\begin{equation}
     \varepsilon \rho w_{tt}(s,t) = N[w_{s}(s,t),w_{st}(s,t)]_{s},
     \label{subeqnparta}
\end{equation}
\begin{equation}
     w_{tt}(1,t)+N[w_{s}(1,t),w_{st}(1,t)] = 0,
     \label{subeqnpartb}
\end{equation}
\end{subequations}
which was typeset using the commands
```
\begin{subequations} \label{subeqnexample}
\begin{equation}
     \varepsilon \rho w_{tt}(s,t) = N[w_{s}(s,t),w_{st}(s,t)]_{s},
     \label{subeqnparta}
\end{equation}
\begin{equation}
     w_{tt}(1,t)+N[w_{s}(1,t),w_{st}(1,t)] = 0,   \label{subeqnpartb}
\end{equation}
\end{subequations}
```
<!-- This is made possible by the `amsmath` package, which is called by the class file. If you put a `\label` just after the `\begin{subequations}` command, references can be made to the collection of equations, i.e.\ `(\ref{subeqnexample})' in the example above. Or, as the example also shows, you can label and refer to each equation individually -- i.e.\ `(\ref{subeqnparta})' and `(\ref{subeqnpartb})'. -->

Displayed mathematics should be given end-of-line punctuation appropriate to the running text sentence of which it forms a part, if required.

### Math fonts

#### Superscripts and subscripts
Superscripts and subscripts will automatically come out in the correct size in a math environment (i.e.\ enclosed within `\(...\)` or `$...$` commands in running text, or within `\[...\]` or the `equation` environment for displayed equations). Sub/superscripts that are physical variables should be italic, whereas those that are labels should be roman (e.g.\ $C_p$, $T_\mathrm{eff}$). If the subscripts or superscripts need to be other than italic, they must be coded individually.

#### Upright Greek characters and the upright partial derivative sign
Upright lowercase Greek characters can be obtained by inserting the letter `u` in the control code for the character, e.g.\ `\umu` and `\upi` produce $\umu$ (used, for example, in the symbol for the unit microns -- $\umu\mathrm{m}$) and $\upi$ (the ratio of the circumference of a circle to its diameter). Similarly, the control code for the upright partial derivative $\upartial$ is `\upartial`. Bold lowercase as well as uppercase Greek characters can be obtained by `{\bm \gamma}`, for example, which gives ${\bm \gamma}$, and `{\bm \Gamma}`, which gives ${\bm \Gamma}$.


# Acknowledgement(s) {-}

An unnumbered section, e.g.\ `\section*{Acknowledgements}`, may be used for thanks, etc.\ if required and included _in the non-anonymous version_ before any Notes or References.

# Disclosure statement {-}

An unnumbered section, e.g.\ `\section*{Disclosure statement}`, may be used to declare any potential conflict of interest and included _in the non-anonymous version_ before any Notes or References, after any Acknowledgements and before any Funding information.

# Funding {-}

An unnumbered section, e.g.\ `\section*{Funding}`, may be used for grant details, etc.\ if required and included _in the non-anonymous version_ before any Notes or References.

# Notes on contributor(s) {-}

An unnumbered section, e.g.\ `\section*{Notes on contributors}`, may be included _in the non-anonymous version_ if required. A photograph may be added if requested.

# Nomenclature/Notation {-}

An unnumbered section, e.g.\ `\section*{Nomenclature}` (or `\section*{Notation}`), may be included if required, before any Notes or References.

# Notes {-}

An unnumbered `Notes` section may be included before the References (if using the `endnotes` package, use the command `\theendnotes` where the notes are to appear, instead of creating a `\section*`).

# References

## References cited in the text

## The list of references

References should be listed at the end of the main text in alphabetical order by authors' surnames, then chronologically (earliest first). If references have the same author(s), editor(s), etc., arrange by year of publication, with undated works at the end.
A single-author entry precedes a multi-author entry that begins with the same name.
If the reference list contains two or more items by the same author(s) in the same year, add a, b, etc. and list them alphabetically by title.
Successive entries by two or more authors when only the first author is the same are alphabetized by co-authors' surnames.
If a reference has more than ten named authors, list only the first seven, followed by 'et al.'.
If a reference has no author or editor, order by title; if a date of publication is impossible to find, use `n.d.' in its place.

The following list shows some sample references prepared in the Taylor & Francis Chicago author-date style.

[@Ade09; @Alb05]

---
title: Short Paper
author:
  - name: Alice Anonymous
    email: alice@example.com
    affiliation: Some Institute of Technology
    correspondingauthor: true
    footnote: 1
  - name: Bob Security
    email: bob@example.com
    affiliation: Another University
  - name: Cat Memes
    email: cat@example.com
    affiliation: Another University
    footnote: 2
  - name: Derek Zoolander
    email: derek@example.com
    affiliation: Some Institute of Technology
    footnote: 2
address:
  - code: Some Institute of Technology
    organization: Big Wig University
    addressline: 1 main street
    city: Gotham
    state: State
    postcode: 123456
    country: United States
  - code: Another University
    organization: Department
    addressline: A street 29
    postcode: 2054 NX
    city: Manchester,
    country: The Netherlands
footnote:
  - code: 1
    text: "This is the first author footnote."
  - code: 2
    text: "Another author footnote."
abstract: |
  This is the abstract.

  It consists of two paragraphs.
keywords: 
  - keyword1
  - keyword2
journal: "An awesome journal"
date: "`r Sys.Date()`"
linenumbers: false
numbersections: true
bibliography: mybibfile.bib
biblio-style: elsarticle-harv # author year style for natbib - use 'elsarticle-num' or 'elsarticle-num-names' for numbered scheme
classoption: preprint, 3p, authoryear # remove authoryear is not using `elsarticle-harv`
# Use a CSL with `citation_package = "default"`
# csl: https://www.zotero.org/styles/elsevier-harvard
output: 
  rticles::elsevier_article:
    keep_tex: true
    citation_package: natbib
---

Please make sure that your manuscript follows the guidelines in the 
Guide for Authors of the relevant journal. It is not necessary to 
typeset your manuscript in exactly the same way as an article, 
unless you are submitting to a camera-ready copy (CRC) journal.

For detailed instructions regarding the elsevier article class, see   <https://www.elsevier.com/authors/policies-and-guidelines/latex-instructions>

# Bibliography styles

Here are two sample references: @Feynman1963118 [@Dirac1953888].

By default, natbib will be used with the `authoryear` style, set in `classoption` variable in YAML and with `elsearticle-harv.bst` which is among provided style by `elsarticle` documentclass. Other available style are `elsarticle-num.bst` and `elsarticle-num-names.bst` — the first one can be used for the numbered scheme, second one for numbered with new options of natbib.sty. 

You can sets extra options with `natbiboptions` variable in YAML header. Example 
```yaml
natbiboptions: longnamesfirst,angle,semicolon
```

There are various more specific bibliography styles available at
<https://support.stmdocs.in/wiki/index.php?title=Model-wise_bibliographic_style_files>. 
To use one of these, add it in the header using, for example, `biblio-style: model1-num-names`.

## Using CSL 

If `citation_package` is set to `default` in `elsevier_article()`, then pandoc is used for citations instead of `natbib`. In this case, the `csl` option is used to format the references. Alternative `csl` files are available from <https://www.zotero.org/styles?q=elsevier>. These can be downloaded
and stored locally, or the url can be used as in the example header.

# Equations

Here is an equation:
$$ 
  f_{X}(x) = \left(\frac{\alpha}{\beta}\right)
  \left(\frac{x}{\beta}\right)^{\alpha-1}
  e^{-\left(\frac{x}{\beta}\right)^{\alpha}}; 
  \alpha,\beta,x > 0 .
$$

Here is another:
\begin{align}
  a^2+b^2=c^2.
\end{align}

Inline equations: $\sum_{i = 2}^\infty\{\alpha_i^\beta\}$

# Figures and tables

Figure \ref{fig2} is generated using an R chunk.

```{r fig2, fig.width = 5, fig.height = 5, fig.align='center', out.width="50%", fig.cap = "\\label{fig2}A meaningless scatterplot.", echo = FALSE}
plot(runif(25), runif(25))
```

# Tables coming from R

Tables can also be generated using R chunks, as shown in Table \ref{tab1} for example.

```{r tab1, echo = TRUE}
knitr::kable(head(mtcars)[,1:4], 
    caption = "\\label{tab1}Caption centered above table"
)
```

# References {-}

<!--
Please keep the below portion in your issue and delete the portion below. Your issue will be closed if any of the above boxes is not checked. In certain (rare) cases, you may be exempted if you give a brief explanation (e.g., you are only making a suggestion for improvement). Thanks!
-->

---

By filing an issue to this repo, I promise that

- [ ] I have fully read the issue guide at https://yihui.name/issue/.
- [ ] I have provided the necessary information about my issue.
    - If I'm asking a question, I have already asked it on Stack Overflow or RStudio Community, waited for at least 24 hours, and included a link to my question there.
    - If I'm filing a bug report, I have included a minimal, self-contained, and reproducible example, and have also included `xfun::session_info('rticles')`. I have upgraded all my packages to their latest versions (e.g., R, RStudio, and R packages), and also tried the development version: `remotes::install_github('rstudio/rticles')`.
    - If I have posted the same issue elsewhere, I have also mentioned it in this issue.
- [ ] I have learned the Github Markdown syntax, and formatted my issue correctly.

I understand that my issue may be closed if I don't fulfill my promises.

---
documentclass: jss
author:
  - name: FirstName LastName
    orcid: 0000-0000-0000-0000
    affiliation: University/Company
    # use this syntax to add text on several lines
    address: |
      | First line
      | Second line
    email: \email{name@company.com}
    url: https://posit.co
  - name: Second Author
    orcid: 0000-0000-0000-0000
    affiliation: 'Affiliation \AND'
    # To add another line, use \AND at the end of the previous one as above
  - name: Third Author
    orcid: 0000-0000-0000-0000
    address: |
      | Department of Statistics and Mathematics,
      | Faculty of Biosciences,
      | Universitat Autònoma de Barcelona
    affiliation: |
      | Universitat Autònoma 
      | de Barcelona
    # use a different affiliation in adress field (differently formated here)
    affiliation2: Universitat Autònoma de Barcelona
title:
  formatted: "A Capitalized Title: Something about a Package \\pkg{foo}"
  # If you use tex in the formatted title, also supply version without
  plain:     "A Capitalized Title: Something about a Package foo"
  # For running headers, if needed
  short:     "\\pkg{foo}: A Capitalized Title"
abstract: >
  The abstract of the article.
keywords:
  # at least one keyword must be supplied
  formatted: [keywords, not capitalized, "\\proglang{Java}"]
  plain:     [keywords, not capitalized, Java]
preamble: >
  \usepackage{amsmath}
output: rticles::jss_article
---

```{r, setup, include=FALSE}
options(prompt = 'R> ', continue = '+ ')
```

# Introduction

This template demonstrates some of the basic LaTeX that you need to know to create a JSS article.

## Code formatting

In general, don't use Markdown, but use the more precise LaTeX commands instead:

* \proglang{Java}
* \pkg{plyr}

One exception is inline code, which can be written inside a pair of backticks (i.e., using the Markdown syntax).

If you want to use LaTeX commands in headers, you need to provide a `short-title` attribute. You can also provide a custom identifier if necessary. See the header of Section \ref{r-code} for example.

# \proglang{R} code {short-title="R code" #r-code}

Can be inserted in regular R markdown blocks.

```{r}
x <- 1:10
x
```

## Features specific to \pkg{rticles} {short-title="Features specific to rticles"}

* Adding short titles to section headers is a feature specific to \pkg{rticles} (implemented via a Pandoc Lua filter). This feature is currently not supported by Pandoc and we will update this template if [it is officially supported in the future](https://github.com/jgm/pandoc/issues/4409).
* Using the `\AND` syntax in the `author` field to add authors on a new line. This is a specific to the `rticles::jss_article` format.

---
title: "Untitled"
short: "A shorter title"
journal: "AER" # AER, AEJ, PP, JEL
month: "`r format(Sys.Date(), '%m')`"
year: "`r format(Sys.Date(), '%Y')`"
vol: 1
issue: 1
jel:
  - A10
  - A11
keywords:
  - first keyword
  - second keyword
author:
  - name: Alice Anonymous
    firstname: Alice
    surname: Anonymous
    email: alice@example.com
    affiliation: Some Institute of Technology
  - name: Bob Security
    firstname: Bob
    surname: Security
    email: bob@example.com
    affiliation: Another University
acknowledgements: |
  Acknowledgements
abstract: |
  Abstract goes here
output: rticles::aea_article
---

American Economic Review Pointers:

\begin{itemize}
\item Do not use an "Introduction" heading. Begin your introductory material
before the first section heading.

\item Avoid style markup (except sparingly for emphasis).

\item Avoid using explicit vertical or horizontal space.

\item Captions are short and go below figures but above tables.

\item The tablenotes or figurenotes environments may be used below tables
or figures, respectively, as demonstrated below.

\item If you have difficulties with the mathtime package, adjust the package
options appropriately for your platform. If you can't get it to work, just
remove the package or see our technical support document online (please
refer to the author instructions).

\item If you are using an appendix, it goes last, after the bibliography.
Use regular section headings to make the appendix headings.

\item If you are not using an appendix, you may delete the appendix command
and sample appendix section heading.

\item Either the natbib package or the harvard package may be used with bibtex.
To include one of these packages, uncomment the appropriate usepackage command
above. Note: you can't use both packages at once or compile-time errors will result.

\end{itemize}

\section{First Section in Body}

Sample figure:

\begin{figure}
Figure here.

\caption{Caption for figure below.}
\begin{figurenotes}
Figure notes without optional leadin.
\end{figurenotes}
\begin{figurenotes}[Source]
Figure notes with optional leadin (Source, in this case).
\end{figurenotes}
\end{figure}

Sample table:

\begin{table}
\caption{Caption for table above.}

\begin{tabular}{lll}
& Heading 1 & Heading 2 \\
Row 1 & 1 & 2 \\
Row 2 & 3 & 4%
\end{tabular}
\begin{tablenotes}
Table notes environment without optional leadin.
\end{tablenotes}
\begin{tablenotes}[Source]
Table notes environment with optional leadin (Source, in this case).
\end{tablenotes}
\end{table}

References here (manual or bibTeX). If you are using bibTeX, add your bib file
name in place of BibFile in the bibliography command.
% Remove or comment out the next two lines if you are not using bibtex.
\bibliographystyle{aea}
\bibliography{references}

% The appendix command is issued once, prior to all appendices, if any.
\appendix

\section{Mathematical Appendix}

---
title: "Untitled"
short_title: "Untitled"
short_author: "Author 1 et. al."
authors: 
- name: "Author 1"
  affiliation: "Address"
  city: "City"
  country: "Country"
  email: "email1\\@example.com" # optional
- name: "Author 2"
  affiliation: "Address2"
  city: "City2"
  country: "Country2"
- name: "Author 3"
  affiliation: "Address2"
  city: "City2"
  country: "Country2"
  email: "email2\\@example.com"
abstract: |
  Abstract goes here
keywords: keywords
# bibliography: bibliography.bib
output: rticles::rss_article
---

# Introduction

This template demonstrates some of the basic latex you'll need to know to create a RSS article.

# R code

Can be inserted in regular R markdown blocks.

```{r}
x <- 1:10
x
```

---
title_full: Template for preparing a submission to Bioinformatics using RMarkdown
title_short: Bioinformatics Rmd Template

# One of the following below. See https://academic.oup.com/bioinformatics/pages/instructions_for_authors#Types%20of%20Manuscript
# one of `Original Paper`, `Discovery Note`, `Applications Note`, `Review`, `Letter to the Editor`, `Conference Paper`    
manuscript_type: Application Note

# change accordingly
copyrightyear: '`r format(Sys.Date(), "%Y")`'
pubyear: '`r format(Sys.Date(), "%Y")`'

# One of the following below. See https://academic.oup.com/bioinformatics/pages/instructions_for_authors#Detailed%20Scope%20Guidelines
# Genome analysis
# Sequence analysis
# Phylogenetics
# Structural bioinformatics
# Gene expression
# Genetic and population analysis
# Systems biology
# Data and text mining
# Databases and ontologies
# Bioimage informatics
subject_section:  Genome analysis

access_date:
  - day: DD
    month: MM
    year: YY
      
author:
  - name: Alice Anonymous
    affiliation: "1,2"
  - name: Bob Security
    affiliation: "1"
      
address:
  - code: 1
    address: Some Institute of Technology, Department, Street, City, State, Zip
  - code: 2
    address: Another University Department, Street, City, State, Zip
 
# Full email address to be given, preferably an institution email address.  
corresponding_author_text: "To whom correspondence should be addressed. E-mail: bob\\@email.com"
corresponding_author_email: "bob\\@email.com"
  
motivation: |
  This section should specifically state the scientific question within the context of the field of study.
  
results: |
  This section should summarize the scientific advance or novel results of the study, and its impact on computational biology.

availability: |
  This section should state software availability if the paper focuses mainly on software development or on the implementation of an algorithm. Examples are: 'Freely available on the web at XXX.' Website implemented in Perl, MySQL and Apache, with all major browsers supported'; or 'Source code and binaries freely available for download at URL, implemented in C++ and supported on linux and MS Windows'. The complete address (URL) should be given. If the manuscript describes new software tools or the implementation of novel algorithms the software must be freely available to non-commercial users. Authors must also ensure that the software is available for a full TWO YEARS following publication. The editors of Bioinformatics encourage authors to make their source code available and, if possible, to provide access through an open source license.

supplementary_info: |
  Supplementary data are available at Bioinformatics Online.

output:
  rticles::bioinformatics_article:
    citation_package: natbib
    
bibliography: bibliography.bib
---

Introduction
============

Cite others using bracket notation [@pepe2003statistical]. Can also cite with @zou2005regularization.

<!-- naked refs don't work because of the \nolinkurl problems -->
<!-- Or refer to specific people e.g. -@Yoo03 like so. -->

Instructions for authors are available [online](http://www.oxfordjournals.org/our_journals/bioinformatics/for_authors/general.html).

Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Approach
============

Here is how to include math equations in the document (bounded by `$$`):

$$
\begin{aligned}
(x+y)^3&=(x+y)(x+y)^2\\
       &=(x+y)(x^2+2xy+y^2) \label{eqn:example} \\
       &=x^3+3x^2y+3xy^3+x^3. 
\end{aligned}
$$

Describe the approach. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

<!--
problems with longtable and 2-column format. see pnas_template and https://github.com/jgm/pandoc/issues/1023

  Species                    CBS     CV     G3
  ----------------------- ------ ------ ------
  1\. Acetaldehyde           0.0    0.0    0.0
  2\. Vinyl alcohol          9.1    9.6   13.5
  3\. Hydroxyethylidene     50.8   51.2   54.0

  : Comparison of the fitted potential energy surfaces and ab initio
  benchmark electronic energy calculations
-->

Describe the approach. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Describe the approach. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Describe the approach. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

```{r figure, echo = FALSE, fig.width = 3.5, fig.cap = 'Figure from an Rmd chunk.'}
plot(rnorm(10000))
```

Methods
============

Detailed methods. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Detailed methods. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Detailed methods. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Sub-Method
-------------

Details for Method 1. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Details for Method 1. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Details for Method 1. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Details for Method 1. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Method 2
-------------

Details for Method 2. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Details for Method 2. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Details for Method 2. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Details for Method 2. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Discussion
=============

Discussion of results. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Discussion of results. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Discussion of results. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Discussion of results. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Conclusion
=============

Anything else? Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Anything else? Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Anything else? Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Anything else? Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum. Introduce your topic. Lorem ipsum ad nauseum.

Acknowledgements {.unnumbered}
==============

These should be included at the end of the text and not in footnotes. Please ensure you acknowledge all sources of funding, see funding section below.

Details of all funding sources for the work in question should be given in a separate section entitled 'Funding'. This should appear before the 'Acknowledgements' section.

Funding {.unnumbered}
==============
The following rules should be followed:

- The sentence should begin: ‘This work was supported by …’ -
- The full official funding agency name should be given, i.e. ‘National Institutes of Health’, not ‘NIH’ (full RIN-approved list of UK funding agencies)
- Grant numbers should be given in brackets as follows: ‘[grant number xxxx]’
- Multiple grant numbers should be separated by a comma as follows: ‘[grant numbers xxxx, yyyy]’
- Agencies should be separated by a semi-colon (plus ‘and’ before the last funding agency) 
- Where individuals need to be specified for certain sources of funding the following text should be added after the relevant agency or grant number 'to [author initials]'.

An example is given here: ‘This work was supported by the National Institutes of Health [AA123456 to C.S., BB765432 to M.H.]; and the Alcohol & Education Research Council [hfygr667789].’

Oxford Journals will deposit all NIH-funded articles in PubMed Central. See Depositing articles in repositories – information for authors for details. Authors must ensure that manuscripts are clearly indicated as NIH-funded using the guidelines above.

---
title: |
  Taylor & Francis Rmarkdown template for authors (\LaTeX\-based 
  \textsf{Interact} layout + Chicago author-date reference style)
type: ARTICLE TEMPLATE
author:
  - name: A. N. Author
    affil: a
    email: latex.helpdesk@tandf.co.uk
  - name: John Smith
    affil: b
    email: john.smith@uni-freiburg.de
  - name: Dominik Leutnant
    affil: c, \dagger, \ddagger
    email: leutnant@fh-muenster.de
affiliation:
  - num: a
    address: |
      Taylor & Francis, 4 Park Square, Milton Park, Abingdon, UK
  - num: b
    address: |
      Institut für Informatik, Albert-Ludwigs-Universität, Freiburg, Germany
  - num: c
    address: |
      Muenster University of Applied Sciences - 
      Institute for Infrastructure, Water, Resources, Environment,
      Correnstr. 25, 48149 Münster, Germany
thanks:
  author:
  - name: A. N. Author
    email: latex.helpdesk@tandf.co.uk
bibliography: interactcadsample.bib
appendix: appendix.tex
abstract: |
  This template is for authors who are preparing a manuscript for a Taylor & 
  Francis journal using the \LaTeX\ document preparation system and the 
  `interact} class file, which is available via selected journals' home 
  pages on the Taylor & Francis website.
keywords: |
  Sections; lists; figures; tables; mathematics; fonts; references; appendices
header-includes: |
  \usepackage{hyperref}
  \usepackage[utf8]{inputenc}
  \def\tightlist{}
output: rticles::tf_article
---

# Introduction

In order to assist authors in the process of preparing a manuscript for a journal, the Taylor & Francis '\textsf{Interact}' layout style has been implemented as a \LaTeXe\ class file based on the `article` document class. A \textsc{Bib}\TeX\ bibliography style file and a sample bibliography are also provided in order to assist with the formatting of your references.

Commands that differ from or are provided in addition to standard \LaTeXe\ are described in this document, which is _not_ a substitute for a \LaTeXe\ tutorial.

The `interactcadsample.tex` file can be used as a template for a manuscript by cutting, pasting, inserting and deleting text as appropriate, using the preamble and the \LaTeX\ environments provided (e.g.\ `\begin{abstract}`, `\begin{keywords}`).

## The \textsf{Interact} class file

The `interact` class file preserves the standard \LaTeXe\ interface such that any document that can be produced using `article.cls` can also be produced with minimal alteration using the `interact` class file as described in this document.

If your article is accepted for publication it will be typeset as the journal requires in Minion Pro and/or Myriad Pro. Since most authors will not have these fonts installed, the page make-up is liable to alter slightly with the change of font. Also, the `interact` class file produces only single-column format, which is preferred for peer review and will be converted to two-column format by the typesetter if necessary during preparation of the proofs. Please therefore do not try to match the typeset format exactly, but use the standard \LaTeX\ fonts instead and ignore details such as slightly long lines of text or figures/tables not appearing in exact synchronization with their citations in the text: these details will be dealt with by the typesetter. Similarly, it is unnecessary to spend time addressing warnings in the log file -- if your .tex file compiles to produce a PDF document that correctly shows how you wish your paper to appear, such warnings will not prevent your source files being imported into the typesetter's program.

## Submission of manuscripts prepared using _\LaTeX_

Manuscripts for possible publication should be submitted to the Editors for review as directed in the journal's Instructions for Authors, and in accordance with any technical instructions provided in the journal's ScholarOne Manuscripts or Editorial Manager site. Your \LaTeX\ source file(s), the class file and any graphics files will be required in addition to the final PDF version when final, revised versions of accepted manuscripts are submitted.

Please ensure that any author-defined macros used in your article are gathered together in the preamble of your .tex file, i.e.\ before the `\begin{document}` command. Note that if serious problems are encountered in the coding of a document (missing author-defined macros, for example), the typesetter may resort to rekeying it.

# Using the `interact` class file

For convenience, simply copy the `interact.cls` file into the same directory as your manuscript files (you do not need to install it in your \TeX\ distribution). In order to use the `interact` document class, replace the command `\documentclass{article}` at the beginning of your document with the command `\documentclass{interact}`.

The following document-class options should _not_ be used with the `interact` class file:

* `10pt`, `11pt`, `12pt` -- unavailable;
* `oneside`, `twoside` -- not necessary, `oneside` is the default;
* `leqno`, `titlepage` -- should not be used;
* `twocolumn` -- should not be used;
* `onecolumn` -- not necessary as it is the default style.

To prepare a manuscript for a journal that is printed in A4 (two column) format, use the `largeformat` document-class option provided by `interact.cls`; otherwise the class file produces pages sized for B5 (single column) format by default. The `geometry` package should not be used to make any further adjustments to the page dimensions.

<!-- If your manuscript has supplementary content you can prepare this using the `suppldata` document-class option, which will suppress the `article history' date. This option must _not_ be used on any primary content. -->

# Additional features of the `interact` class file

## Title, authors' names and affiliations, abstracts and article types

## Abbreviations

A list of abbreviations may be included if required, enclosed within an `abbreviations` environment, i.e.\ `\begin{abbreviations}`\ldots`\end{abbreviations}`, immediately following the `abstract` environment.


## Keywords

A list of keywords may be included if required, enclosed within a `keywords` environment, i.e.\ `\begin{keywords}`\ldots`\end{keywords}`. Additional keywords in other languages (preceded by a translation of the word `keywords`) may also be included within the `keywords` environment if required.


## Subject classification codes

AMS, JEL or PACS classification codes may be included if required. The `interact` class file provides an `amscode` environment, i.e.\ `\begin{amscode}`\ldots`\end{amscode}`, a `jelcode` environment, i.e.\ `\begin{jelcode}`\ldots`\end{jelcode}`, and a `pacscode` environment, i.e.\ `\begin{pacscode}`\ldots`\end{pacscode}` to assist with this.


## Additional footnotes to the title or authors' names

<!-- The `\thanks` command may be used to create additional footnotes to the title or authors' names if required. Footnote symbols for this purpose should be used in the order -->
<!-- $^\ast$~(coded as `$^\ast$`), $\dagger$~(`$\dagger$`), $\ddagger$~(`$\ddagger$`), $\S$~(`$\S$`), $\P$~(`$\P$`), $\|$~(`$\|$`), -->
<!-- $\dagger\dagger$~(`$\dagger\dagger$`), $\ddagger\ddagger$~(`$\ddagger\ddagger$`), $\S\S$~(`$\S\S$`), $\P\P$~(`$\P\P$`). -->

Note that any `footnote`s to the main text will automatically be assigned the superscript symbols 1, 2, 3, etc. by the class file.^[If preferred, the `endnotes` package may be used to set the notes at the end of your text, before the bibliography. The symbols will be changed to match the style of the journal if necessary by the typesetter.]

# Embedding R code

## Code chunks

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
```

```{r cars}
summary(cars)
```

## Including Plots

You can also embed plots, for example:

```{r pressure, echo=FALSE, out.width='80%'}
plot(pressure)
```

Note that the `echo = FALSE` parameter was added to the code chunk to prevent printing of the R code that generated the plot.

# Some guidelines for using the standard features of \LaTeX

## Sections

The \textsf{Interact} layout style allows for five levels of section heading, all of which are provided in the `interact` class file using the standard \LaTeX\ commands `\section`, `\subsection`, `\subsubsection`, `\paragraph` and `\subparagraph`. Numbering will be automatically generated for all these headings by default.

## Lists

Numbered lists are produced using the `enumerate` environment, which will number each list item with arabic numerals by default. For example,

1. first item
2. second item
3. third item

Alternative numbering styles can be achieved by inserting an optional argument in square brackets to each `item`, e.g.\ `\item[(i)] first item`\, to create a list numbered with roman numerals at level one.

Bulleted lists are produced using the `itemize` environment. For example,

* First bulleted item
* Second bulleted item
* Third bulleted item

## Figures

```{r pressure-plot, fig.show='hide'}
plot(pressure)
```

The `interact` class file will deal with positioning your figures in the same way as standard \LaTeX. It should not normally be necessary to use the optional `[htb]` location specifiers of the `figure` environment in your manuscript; you may, however, find the `[p]` placement option or the `endfloat` package useful if a journal insists on the need to separate figures from the text.

Figure captions appear below the figures themselves, therefore the `\caption` command should appear after the body of the figure. For example, Figure~\ref{sample-figure} with caption and sub-captions is produced using the following commands:
```
\begin{figure}
\centering
\subfigure[An example of an individual figure sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{path/to/fig}}}\hspace{5pt}
\subfigure[A slightly shorter sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{path/to/fig}}}
\caption{Example of a two-part figure with individual sub-captions
 showing that captions are flush left and justified if greater
 than one line of text.} \label{sample-figure}
\end{figure}
```
\begin{figure}
\centering
\subfigure[An example of an individual figure sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{`r knitr::fig_chunk('pressure-plot', 'pdf')`}}}\hspace{5pt}
\subfigure[A slightly shorter sub-caption.]{%
\resizebox*{5cm}{!}{\includegraphics{`r knitr::fig_chunk('pressure-plot', 'pdf')`}}}
\caption{Example of a two-part figure with individual sub-captions
 showing that captions are flush left and justified if greater
 than one line of text.} \label{sample-figure}
\end{figure}

To ensure that figures are correctly numbered automatically, the `\label` command should be included just after the `\caption` command, or in its argument.

The `\subfigure` command requires `subfigure.sty`, which is called in the preamble of the `interacttfssample.tex` file (to allow your choice of an alternative package if preferred) and included in the \textsf{Interact} \LaTeX\ bundle for convenience. Please supply any additional figure macros used with your article in the preamble of your .tex file.

The source files of any figures will be required when the final, revised version of a manuscript is submitted. Authors should ensure that these are suitable (in terms of lettering size, etc.) for the reductions they envisage.

The `epstopdf` package can be used to incorporate encapsulated PostScript (.eps) illustrations when using PDF\LaTeX, etc. Please provide the original .eps source files rather than the generated PDF images of those illustrations for production purposes.


## Tables

The `interact` class file will deal with positioning your tables in the same way as standard \LaTeX. It should not normally be necessary to use the optional `[htb]` location specifiers of the `table` environment in your manuscript; you may, however, find the `[p]` placement option or the `endfloat` package useful if a journal insists on the need to separate tables from the text.

The `tabular` environment can be used as shown to create tables with single horizontal rules at the head, foot and elsewhere as appropriate. The captions appear above the tables in the \textsf{Interact} style, therefore the `\tbl` command should be used before the body of the table. For example, Table~\ref{sample-table} is produced using the following commands:
\begin{table}
\tbl{Example of a table showing that its caption is as wide as
 the table itself and justified.}
{\begin{tabular}{lcccccc} \toprule
 & \multicolumn{2}{l}{Type} \\ \cmidrule{2-7}
 Class & One & Two & Three & Four & Five & Six \\ \midrule
 Alpha\textsuperscript{a} & A1 & A2 & A3 & A4 & A5 & A6 \\
 Beta & B2 & B2 & B3 & B4 & B5 & B6 \\
 Gamma & C2 & C2 & C3 & C4 & C5 & C6 \\ \bottomrule
\end{tabular}}
\tabnote{\textsuperscript{a}This footnote shows how to include
 footnotes to a table if required.}
\label{sample-table}
\end{table}
```
\begin{table}
\tbl{Example of a table showing that its caption is as wide as
 the table itself and justified.}
{\begin{tabular}{lcccccc} \toprule
 & \multicolumn{2}{l}{Type} \\ \cmidrule{2-7}
 Class & One & Two & Three & Four & Five & Six \\ \midrule
 Alpha\textsuperscript{a} & A1 & A2 & A3 & A4 & A5 & A6 \\
 Beta & B2 & B2 & B3 & B4 & B5 & B6 \\
 Gamma & C2 & C2 & C3 & C4 & C5 & C6 \\ \bottomrule
\end{tabular}}
\tabnote{\textsuperscript{a}This footnote shows how to include
 footnotes to a table if required.}
\label{sample-table}
\end{table}
```

To ensure that tables are correctly numbered automatically, the `\label` command should be included just before `\end{table}`.

The `\toprule`, `\midrule`, `\bottomrule` and `\cmidrule` commands are those used by `booktabs.sty`, which is called by the `interact` class file and included in the \textsf{Interact} \LaTeX\ bundle for convenience. Tables produced using the standard commands of the `tabular` environment are also compatible with the `interact` class file.


## Landscape pages

If a figure or table is too wide to fit the page it will need to be rotated, along with its caption, through 90$^{\circ}$ anticlockwise. Landscape figures and tables can be produced using the `rotating` package, which is called by the `interact` class file. The following commands (for example) can be used to produce such pages.
```
\setcounter{figure}{1}
\begin{sidewaysfigure}
\centerline{\epsfbox{figname.eps}}
\caption{Example landscape figure caption.}
\label{landfig}
\end{sidewaysfigure}
```
```
\setcounter{table}{1}
\begin{sidewaystable}
 \tbl{Example landscape table caption.}
  {\begin{tabular}{@{}llllcll}
    .
    .
    .
  \end{tabular}}\label{landtab}
\end{sidewaystable}
```
Before any such float environment, use the `\setcounter` command as above to fix the numbering of the caption (the value of the counter being the number given to the preceding figure or table). Subsequent captions will then be automatically renumbered accordingly. The `\epsfbox` command requires `epsfig.sty`, which is called by the `interact` class file and is also included in the \textsf{Interact} \LaTeX\ bundle for convenience.

Please note that if the `endfloat` package is used, one or both of the commands
```
\DeclareDelayedFloatFlavor{sidewaysfigure}{figure}
\DeclareDelayedFloatFlavor{sidewaystable}{table}
```
will need to be included in the preamble of your .tex file, after the `endfloat` package is loaded, in order to process any landscape figures and/or tables correctly.


## Theorem-like structures

A predefined `proof` environment is provided by the `amsthm` package (which is called by the `interact` class file), as follows:
\begin{proof}
More recent algorithms for solving the semidefinite programming relaxation are particularly efficient, because they explore the structure of the MAX-CUT problem.
\end{proof}
\noindent This was produced by simply typing:
```
\begin{proof}
More recent algorithms for solving the semidefinite programming
relaxation are particularly efficient, because they explore the
structure of the MAX-CUT problem.
\end{proof}
```
Other theorem-like environments (theorem, definition, remark, etc.) need to be defined as required, e.g.\ using `\newtheorem{theorem}{Theorem}` in the preamble of your .tex file (see the preamble of `interactcadsample.tex` for more examples). You can define the numbering scheme for these structures however suits your article best. Please note that the format of the text in these environments may be changed if necessary to match the style of individual journals by the typesetter during preparation of the proofs.


## Mathematics

### Displayed mathematics

The `interact` class file will set displayed mathematical formulas centred on the page without equation numbers if you use the `displaymath` environment or the equivalent `\[...\]` construction. For example, the equation
\[
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\]
was typeset using the commands
```
\[
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\]
```

For those of your equations that you wish to be automatically numbered sequentially throughout the text for future reference, use the `equation` environment, e.g.
\begin{equation}
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\end{equation}
was typeset using the commands
```
\begin{equation}
 \hat{\theta}_{w_i} = \hat{\theta}(s(t,\mathcal{U}_{w_i}))
\end{equation}
```

Part numbers for sets of equations may be generated using the `subequations` environment, e.g.
\begin{subequations} \label{subeqnexample}
\begin{equation}
     \varepsilon \rho w_{tt}(s,t) = N[w_{s}(s,t),w_{st}(s,t)]_{s},
     \label{subeqnparta}
\end{equation}
\begin{equation}
     w_{tt}(1,t)+N[w_{s}(1,t),w_{st}(1,t)] = 0,
     \label{subeqnpartb}
\end{equation}
\end{subequations}
which was typeset using the commands
```
\begin{subequations} \label{subeqnexample}
\begin{equation}
     \varepsilon \rho w_{tt}(s,t) = N[w_{s}(s,t),w_{st}(s,t)]_{s},
     \label{subeqnparta}
\end{equation}
\begin{equation}
     w_{tt}(1,t)+N[w_{s}(1,t),w_{st}(1,t)] = 0,   \label{subeqnpartb}
\end{equation}
\end{subequations}
```
<!-- This is made possible by the `amsmath` package, which is called by the class file. If you put a `\label` just after the `\begin{subequations}` command, references can be made to the collection of equations, i.e.\ `(\ref{subeqnexample})' in the example above. Or, as the example also shows, you can label and refer to each equation individually -- i.e.\ `(\ref{subeqnparta})' and `(\ref{subeqnpartb})'. -->

Displayed mathematics should be given end-of-line punctuation appropriate to the running text sentence of which it forms a part, if required.

### Math fonts

#### Superscripts and subscripts
Superscripts and subscripts will automatically come out in the correct size in a math environment (i.e.\ enclosed within `\(...\)` or `$...$` commands in running text, or within `\[...\]` or the `equation` environment for displayed equations). Sub/superscripts that are physical variables should be italic, whereas those that are labels should be roman (e.g.\ $C_p$, $T_\mathrm{eff}$). If the subscripts or superscripts need to be other than italic, they must be coded individually.

#### Upright Greek characters and the upright partial derivative sign
Upright lowercase Greek characters can be obtained by inserting the letter `u` in the control code for the character, e.g.\ `\umu` and `\upi` produce $\umu$ (used, for example, in the symbol for the unit microns -- $\umu\mathrm{m}$) and $\upi$ (the ratio of the circumference of a circle to its diameter). Similarly, the control code for the upright partial derivative $\upartial$ is `\upartial`. Bold lowercase as well as uppercase Greek characters can be obtained by `{\bm \gamma}`, for example, which gives ${\bm \gamma}$, and `{\bm \Gamma}`, which gives ${\bm \Gamma}$.


# Acknowledgement(s) {-}

An unnumbered section, e.g.\ `\section*{Acknowledgements}`, may be used for thanks, etc.\ if required and included _in the non-anonymous version_ before any Notes or References.

# Disclosure statement {-}

An unnumbered section, e.g.\ `\section*{Disclosure statement}`, may be used to declare any potential conflict of interest and included _in the non-anonymous version_ before any Notes or References, after any Acknowledgements and before any Funding information.

# Funding {-}

An unnumbered section, e.g.\ `\section*{Funding}`, may be used for grant details, etc.\ if required and included _in the non-anonymous version_ before any Notes or References.

# Notes on contributor(s) {-}

An unnumbered section, e.g.\ `\section*{Notes on contributors}`, may be included _in the non-anonymous version_ if required. A photograph may be added if requested.

# Nomenclature/Notation {-}

An unnumbered section, e.g.\ `\section*{Nomenclature}` (or `\section*{Notation}`), may be included if required, before any Notes or References.

# Notes {-}

An unnumbered `Notes` section may be included before the References (if using the `endnotes` package, use the command `\theendnotes` where the notes are to appear, instead of creating a `\section*`).

# References

## References cited in the text

## The list of references

References should be listed at the end of the main text in alphabetical order by authors' surnames, then chronologically (earliest first). If references have the same author(s), editor(s), etc., arrange by year of publication, with undated works at the end.
A single-author entry precedes a multi-author entry that begins with the same name.
If the reference list contains two or more items by the same author(s) in the same year, add a, b, etc. and list them alphabetically by title.
Successive entries by two or more authors when only the first author is the same are alphabetized by co-authors' surnames.
If a reference has more than ten named authors, list only the first seven, followed by 'et al.'.
If a reference has no author or editor, order by title; if a date of publication is impossible to find, use `n.d.' in its place.

The following list shows some sample references prepared in the Taylor & Francis Chicago author-date style.

[@Blair1977; @Alb05]

---
title: Capitalized Title Here
author:
  # see ?rjournal_article for more information
  - name: Author One
    affiliation: Affiliation
    address:
    - line 1
    - line 2
    url: https://journal.r-project.org
    orcid: 0000-0002-9079-593X
    email:  author1@work
  - name: Author Two
    url: https://journal.r-project.org
    email: author2@work
    orcid: 0000-0002-9079-593X
    affiliation: Affiliation 1
    address:
    - line 1 affiliation 1
    - line 2 affiliation 1
    affiliation2: Affiliation 2
    address2:
    - line 1 affiliation 2
    - line 2 affiliation 2
  - name: Author Three
    url: https://journal.r-project.org
    email: author3@work
    affiliation: Affiliation
    address:
    - line 1 affiliation
    - line 2 affiliation
abstract: >
  An abstract of less than 150 words.
preamble: |
  % Any extra LaTeX you need in the preamble
  
# per R journal requirement, the bib filename should be the same as the output 
# tex file. Don't forget to rename the bib file and change this example value.
bibliography: RJreferences.bib

output: rticles::rjournal_article
---

## Introduction

Introductory section which may include references in parentheses
[@R], or cite a reference such as @R in the text.

## Section title in sentence case

This section may contain a figure such as Figure \ref{fig:Rlogo}.

```{r, Rlogo, echo=FALSE, fig.cap='The logo of R.', out.width='2in', fig.align='center', fig.pos='htbp'}
knitr::include_graphics('Rlogo-5.png')
```

## Another section

There will likely be several sections, perhaps including code snippets, such as:

```{r}
x <- 1:10
plot(x)
```

## Summary

This file is only a basic article template. For full details of _The R Journal_ style and information on how to prepare your article for submission, see the [Instructions for Authors](https://journal.r-project.org/share/author-guide.pdf).

### About this format and the R Journal requirements

`rticles::rjournal_article` will help you build the correct files requirements: 

* A R file will be generated automatically using `knitr::purl` - see
https://bookdown.org/yihui/rmarkdown-cookbook/purl.html for more information.
* A tex file will be generated from this Rmd file and correctly included in
`RJwapper.tex` as expected to build `RJwrapper.pdf`.
* All figure files will be kept in the default rmarkdown `*_files` folder. This
happens because `keep_tex = TRUE` by default in `rticles::rjournal_article`
* Only the bib filename is to modifed. An example bib file is included in the
template (`RJreferences.bib`) and you will have to name your bib file as the
tex, R, and pdf files.

---
title: Title here

author: 
- name: Author 1
  affiliation: Department of YYY, University of XXX
  email: abc@def
  
- name: Author 2
  affiliation: Department of ZZZ, University of WWW
  email: djf@wef

keywords:
- key
- dictionary
- word

abstract: |
  The text of your summary.  Should not exceed 225 words.

bibliography: bibliography.bib
output: rticles::biometrics_article
month: "`r format(Sys.Date(), '%b')`"
year: "`r format(Sys.Date(), '%Y')`"
referee: true # Papers submitted to Biometrics should ALWAYS be prepared
              # using the referee option!!!! Turn off only to preview
              # two column-format
---

# Introduction {#intro}

Your text comes here. Separate text sections with

# Section title {#sec:1}

Text with citations by @heagerty2000time, [@pepe2003statistical].

## Subsection title {#sec:2}

as required [@hoerl1970ridge; @zou2005regularization]. Don't forget to give each section
and subsection a unique label (see Sect. \ref{sec:1}).

#### Paragraph headings 

Use paragraph headings as needed.

## Equations

Here is an equation:

$$ f_{X}(x) = \left(\frac{\alpha}{\beta}\right)\left(\frac{x}{\beta}\right)^{\alpha-1}e^{-\left(\frac{x}{\beta}\right)^{\alpha}}; \alpha,\beta,x > 0 $$

Here is another:
\begin{align}
a^2+b^2=c^2
\end{align}

Inline equations: $\sum_{i = 2}^\infty\{\alpha_i^\beta\}$

# Figures and tables


## Figures coming from R

#### Normal figure embedded in text

```{r fig2, fig.width = 4, fig.height = 4, fig.cap = "Output from `pdf()`", echo = FALSE, dev = "pdf"}
plot(runif(25) ~ runif(25))
```

\clearpage

## Tables coming from R


```{r tab1, results = 'asis'}
print(xtable::xtable(head(mtcars)[,1:4], 
caption = "Caption centered under table", label = "tab1"), 
comment = FALSE, timestamp = FALSE, caption.placement = "top")
```

Table \ref{tab1} shows these numbers. Some of those numbers are plotted in Figure \ref{fig:fig1}.


```{r tab2}
head(mtcars[,1:4])
```


# References

---
title: This is a title and this is too
# Optional short title inside square brackets, for the running headers.
shorttitle: A subtitle goes on another line
shortauthors: Paul & Vanden Wyngaerd
author:
- name: Waltraud Paul
  affiliation: CNRS, CRLAO
  address: 105, Bd. Raspail, 75005 Paris waltraud.paul\@ehess.fr
- name: Guido Vanden Wyngaerd
  affiliation: KU Leuven
classoption: [cm, linguex]
#
# Possible classoptions:
# - [times] for Times font (default if no option is chosen)
# - [cm] for Computer Modern font
# - [lucida] for Lucida font (not freely available)
# - [brill] open type font, freely downloadable for non-commercial use from
#   http://www.brill.com/about/brill-fonts; requires xetex
# - [charis] for CharisSIL font, freely downloadable from http://software.sil.org/charis/
# - for the Brill an CharisSIL fonts, you have to use the XeLatex
#   typesetting engine (not pdfLatex)
# - for headings, tables, captions, etc., Fira Sans is
#   used: https://www.fontsquirrel.com/fonts/fira-sans
# - [biblatex] for using biblatex (the default is natbib, DO NOT LOAD the
#   natbib package in this file, it is loaded automatically via the document
#   class glossa.cls)
# - [linguex] loads the linguex example package
#
# !!! A note on the use of linguex: in glossed examples, the third line of the
# example (the translation) needs to be prefixed with \glt. This is to allow a
# first line with the name of the language and the source of the example. See
# example (2) in the text for an illustration.
#
# !!! A note on the use of bibtex: for PhD dissertations to typeset correctly
# in the references list, the Address field needs to contain the city
# (for US cities in the format "Santa Cruz, CA")
#
bibliography: sample.bib
# The bibliography style is set automatically by glossa.cls when using
# either natbib or biblatex.
# Pandoc's citeproc is not supported.
#
abstract: |
  This document provides a full overview of the information relating to Glossa 
  submissions. This information includes (i) the author guidelines, and (ii)
  the stylesheet. So as to provide instruction both by example and by rule,
  this document has been formatted in accordance with the stylesheet it contains.
# Specify keywords here:
keywords: stylesheet, glossa, article
# To add the word count, uncomment the following option and replace the number
# with the document word count.
# wordcount: 1000
output: 
  rticles::glossa_article:
    citation_package: natbib
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE)
```

# Author guidelines

## Submission information

Submissions should be made electronically through the [Glossa
website](http://glossa.ubiquitypress.com).

Prior to submission, please add a word count (including footnotes and
references) directly under the paper title. Then convert your paper into
a single PDF file, containing all tables and figures. Non-PDF files or
separately provided files may be returned prior to review. Separate
image files may be requested if the submission is accepted for
publication.

Please ensure that you consider the following guidelines when preparing
your manuscript. Failure to do so may delay the processing of your
submission. A downloadable version of the style guide is available
[`here`](https://github.com/guidovw/Glossalatex/blob/master/glossa-template.pdf).
Text formatting in accordance with the stylesheet is required for the
accepted version only.

For LaTeX submissions, please download the Latex resources
[`here`](https://github.com/guidovw/Glossalatex).

All files must be anonymised during the initial submission (including
information in the file properties). Only after editorial acceptance
should you add author details to the manuscript files.

Once a submission has been completed, the submitting author is able to
fully track the status of the paper and complete requested revisions via
their online profile.

## Article types

### Research articles

Research articles must describe the outcomes and application of
unpublished original research. These should make a substantial
contribution to knowledge and understanding in the subject matter and
should be supported by relevant examples, figures and tabulated data.
Research articles must be no more than 13,000 words in length. Authors
are allowed to add appendices with supplementary material that will be
hosted separately from the article itself, and receive their own,
properly referenced, DOI. These materials will not be typeset. See below
on how to provide supplementary/data files.

### Overview articles

Overview articles must describe the state-of-the art in a given
subdiscipline or a specific topic in linguistics. They should be very
accessible, aimed at an audience of MA students or interested
colleagues. Overview articles must be no more than 13,000 words in
length. Authors are allowed to add appendices with supplementary
material that will be hosted separately from the article itself, and
receive their own, properly referenced, DOI. These materials will not be
typeset. See below on how to provide supplementary/data files.

### Book reviews

Book reviews present critical appraisals of recent books in linguistics,
with a preference for monographs, handbooks, and grammars. They can
cover topics such as current controversies or the historical development
of studies as well as issues of regional or temporal focus. Papers
should critically engage with the relevant body of extant literature.
Book reviews should be no longer than 3,000 words in length.

### Review articles

Review articles present longer critical appraisals of one or more recent
books containing an original contribution or perspective on the book(s)
reviewed. Review articles will be reviewed by the editors and/ or
members of the editorial board. Review articles should be no longer than
6,000 words in length.

### Squibs

Squibs are short notes (5,000 words max.) that make a scintillating
point by calling attention to a theoretically unexpected observation
about language, without the need for a developed analysis or solution.

### Special Collections

Special Collections are papers devoted to a particular topic, and edited
by a team of guest editors. Contributions to special collections are
subject to the normal process of blind peer review. Upon publication,
papers within a special collection will be collated within their own
special collection page. If you are interested in submitting or
guest-editing a Special Collection, please contact [the
editors](https://www.glossa-journal.org/about/editorialteam/).

### Word limits

All word limits mentioned above include referencing and citation, but
they exclude appendices, data files and other supplementary material.
Please note that if you have data or supplementary files, they should be
treated as outlined in the section **data availability/supplementary
files** below, and not as part of the main submission file.

## Permissions

The author is responsible for obtaining all permissions required prior
to submission of the manuscript. Permission and owner details should be
mentioned for all third-party content included in the submission or used
in the research.

If a method or tool is introduced in the study, including software,
questionnaires, and scales, the license this is available under and any
requirement for permission for use should be stated. If an existing
method or tool is used in the research, it is the author's
responsibility to check the license and obtain the necessary
permissions.

# Style sheet {#ss}

The Glossa style sheet is based on the [The Generic Style Rules for
Linguistics](http://www.eva.mpg.de/linguistics/past-research-resources/resources/generic-style-rules.html)
(December 2014 version), developed under a CC-BY licence by Martin
Haspelmath. It was slightly modified for Glossa by Waltraud Paul and
Guido Vanden Wyngaerd in November 2015, and again in May 2021.

## Structure

### Title page

The title should not contain any capitalisation apart from the first
word and words that need capitals in any context. In the final version
of the accepted paper, the title is followed by the first and last name
of the author(s), their affiliation, and e-mail. First names should not
include only initials.

Anonymisation: The names of all authors, affiliations, contact details,
biography (optional) and the corresponding author details must be
completed online as part of the submission process but should not be
added to the submitted files until after editorial acceptance.

### Abstract

Articles must have the main text prefaced by an abstract of no more than
250 words summarising the main arguments and conclusions of the article.
A list of up to six key words should be placed below the abstract. The
abstract and keywords should also be added to the metadata when making
the initial online submission. The abstract is automatically attached to
the email message inviting reviewers to review the paper.

### Main text

Articles are subdivided into numbered sections (and possibly
subsections, numbered 1.1 etc., and subsubsections, numbered 1.1.1
etc.), with a bold-faced heading in each case. The numbering always
begins with 1, not 0. Section headings do not end with a period, and
have no special capitalisation.

### Unnumbered sections

The conclusion is the last numbered section. It may be followed by
several (optional) unnumbered sections, in this order:

-   Abbreviations

-   Data availability/Supplementary files

-   Ethics and consent

-   Funding information

-   Acknowledgements

-   Competing interests

-   Authors' contributions

Of these, only the Competing interests statement is mandatory, and, if
your paper contains glossed examples, the Abbreviations section. More
explanation on the content of these sections is provided below.

### References

All references cited within the submission must be listed at the end of
the main text file.

## Numbered examples and formulae

Examples from languages other than English must *all* be glossed (with
word-by-word alignment) and translated, even if the translation seems
obvious. The Leipzig Glossing Rules are recommended as basic guidelines,
and can be found
[here](http://www.eva.mpg.de/lingua/resources/glossing-rules.php). A
full list of all the glosses used must be provided in the Abbreviations
section. Example numbers are enclosed in parentheses, and left-aligned.
Examples are numbered consecutively. When an earlier example is
repeated, it gets a new number. Example sentences usually have normal
capitalization at the beginning and normal punctuation. The gloss line
has no capitalization and no punctuation.

```{=latex}
\ex. \ag. Ich   kenne das Kind, dem du geholfen hast.\\
I.\textsc{nom} know the child.\textsc{acc} \textsc{dem.dat} you.\textsc{nom} helped have\\
\glt `I know the child that you helped.'
\bg. Ich kenne das Kind, dem du nicht geholfen hast. \\
I.\textsc{nom} know  the child.\textsc{acc} \textsc{dem.dat} you.\textsc{nom} \textsc{neg} helped   have\\
\glt `I know the child that you didn’t help.’
```

When the example is not a complete sentence, there is no capitalization
and no full stop at the end. If the name of the language is added, the
source of the example, or any extra information, this information must
be added on an extra first line of the example (with the name of the
language in italics).\footnote{Examples in footnotes are numbered with lower case Roman numerals enclosed between brackets:

\ex.
\a. Colorless green ideas sleep furiously.
\b. *The child seems sleeping.

More text can follow the example.}

```{=latex}
% optional line for the name of the language (italics), source, etc. Note the absence of \exg., instead use \ex. (and \a. \b. for subdivisions) when this optional line is present. Use \exg. etc. if this line is absent (as in the previous example)
\ex. \textit{German} \citep{coetsem:2000} \\
% original foreign language example preceded by \gll
\gll das Kind, dem du geholfen hast\\  
the child.\textsc{nom} \textsc{dem.dat} you.\textsc{nom}  helped have\\ % gloss line
\glt `the child that you helped' % translation, preceded by \glt
```

Ungrammatical examples can be given a parenthesized idiomatic
translation. A literal translation may be given in parentheses after the
idiomatic translation.

The use of any nonstandard layout in examples beyond what is illustrated
above is strongly discouraged, as this will increase production time
(and cost) of your paper, as well as increase the chances of the HTML
version including errors in some browsers/screen sizes. If you feel an
example needs additional explanation, try as much as possible to provide
this in the text that goes with the example. If nonstandard layout is
essential, then please raise this with the editorial team to discuss the
options available.

Formulae must be proofed carefully by the author. Editors will not edit
formulae. If special software has been used to create formulae, the way
they are laid out is the way they will appear in the publication.

## Use of footnotes/endnotes {#fn}

Use footnotes rather than endnotes (we refer to these as 'Notes' in the
online publication). These will appear at the bottom of each page. Notes
should be used only where crucial clarifying information needs to be
conveyed.

Avoid using notes for purposes of referencing; use in-text citations
instead. If in-text citations cannot be used, a source can be cited as
part of a note. Please insert the footnote marker after the end
punctuation.

The footnote reference number normally follows a period or a comma,
though exceptionally it may follow an individual word. Footnote numbers
start with 1. Examples in footnotes have the numbers (i), (ii), etc.

## Tables and figures

Tables and figures are treated as floats in typesetting. This means that
their placement on the page will not necessarily be where you put them
in your manuscript, as this may lead to large parts of the page ending
up white (e.g. when a table or figure does not fit on the current page
anymore and wraps onto the following page). For this reason, you must
always refer to tables and figures in the running text, as in the
following example: "In certain languages, the superlative transparently
contains the comparative morphologically, as illustrated in table
[1](#tbl:table1){reference-type="ref" reference="tbl:table1"}
[@Bobaljik2012 46]." Do not refer to tables and figures using the words
"following", "below" or "above", as the final placement of your table or
figure may be different from where you placed them in your manuscript.

Table: {#tbl:table1} Morphological containment

            [Pos]{.smallcaps}   [Cmpr]{.smallcaps}   [Sprl]{.smallcaps}
----------- ------------------- -------------------- -------------------- ----------
Persian     kam                 kam-tar              kam-tar-in           'little'
Cimbrian    šüa                 šüan-ar              šüan-ar-ste          'pretty'
Czech       mlad-ý              mlad-ší              nej-mlad-ší          'young'
Hungarian   nagy                nagy-obb             leg-nagy-obb         'big'
Latvian     zil-ais             zil-âk-ais           vis-zil-âk-ais       'blue'
Ubykh       nüs^w^              c'a-nüs^w^           a-c'a-nüs^w^         'pretty'

Tables and figures are numbered consecutively. Each table and each
figure has a caption. The caption is placed above figures and tables,
with only the figure or table number in bold. If the caption is not a
complete sentence, it is not followed by a period. Examples are shown in
the captions of table [1](#tbl:table1){reference-type="ref"
reference="tbl:table1"} and figure
[1](#fig:glossalogo){reference-type="ref" reference="fig:glossalogo"}.


```{r fig-glossa, fig.cap="The Glossa logo (design by Linnea Vanden Wyngaerd)", out.width="0.5\\textwidth", fig.align="center"}
knitr::include_graphics("glossa.png")
```


Figures should be included in the main text for the purpose of peer
review. Once the paper is accepted, all figures must be uploaded
separately as supplementary files, if possible in colour and at a
resolution of at least 300dpi. No file should be larger than 20MB.
Standard formats accepted are: [jpg, tiff, gif, png, eps]{.smallcaps}.
For line drawings, please provide the original vector file (e.g. .ai, or
.eps).

Tables must be created using a word processor's table function, not
tabbed text. Tables should be included in the manuscript.

Tables should not include:

-   Rotated text

-   Colour to denote meaning (it will not display the same on all
    devices)

-   Images

-   Diagonal lines

-   Multiple parts (e.g. "table 1a" and "table 1b"). These should either
    be merged into one table, or separated into "table 1" and "table 2".

If there are more columns than can fit on a single page, the table will
be rotated by 90 degrees to fit on the page. Do not use tables that
cannot fit onto a single page.

Tree diagrams should be treated as examples, not as figures. If your
figure or tree diagram includes text, then for the best match with the
typeset text use the font [Charis
SIL](https://software.sil.org/charis/download/), or [Fira
Sans](https://www.fontsquirrel.com/fonts/fira-sans). These fonts also
support the International Phonetical Alphabet (IPA) symbols.

## In-text citations

The short reference form used in the text consists of the author's
surname and the publication year, followed by page numbers where
necessary. Brackets surround the year, except if the citation is already
inside brackets, in which case there are no brackets around the year. If
there are more than two authors, the first name plus *et al.* can be
used.

-   @murray:1983 [514] point out that ...

-   The notation we use to represent this is borrowed from theories
    according to which $\phi$-features occur in a so-called feature
    geometry [@mccarthy:1999 248-250].

-   Baker et al. (1989) = @baker:1989

When multiple citations are listed, they are separated by semicolons and
listed in chronological order. Multiple references to the same author do
not repeat redundant information.

-   Multiple authors have belaboured this point
    [@chomsky:1981; @chomsky:1986a; @chomsky:1986; @iverson:1989; @casali:1998a; @blevins:2004; @franks:2005].

Surnames with internal complexity have upper or lower case according to
how the author spells his/her own name, e.g.:

-   It has been claimed by @swart:1998 and @belder:2011 that meaning is
    compositional.

Chinese and Korean names may be treated in a special way: as the
surnames are often not very distinctive, the full name may be given in
the in-text citation, e.g.

-   ...the neutral negation *bù* is compatible with stative and activity
    verbs (cf. Teng Shou-hsin 1973; Hsieh Miao-Ling 2001; Lin
    Jo-wang 2003)

## References {#sec:refs}

The following rules apply:

-   The names of authors and editors should be given in their full form
    as in the publication, without truncation of given names.

-   All author and editor names are given in the order "Lastname,
    Firstname".

-   When there are more than two authors (or editors), each pair of
    names is separated by an ampersand.

-   Page numbers of journals are obligatory (issue numbers preferred).

-   Journal titles are not abbreviated.

-   Main title and subtitle are separated by a colon, not by a period.

-   Titles of works written in a language that readers cannot be
    expected to know should be accompanied by a translation, given in
    square brackets [@Li1999].

-   No author names are omitted, i.e. et al. is not used in the
    references.

There are four standard reference types: journal article, book, article
in edited book, thesis. Works that do not fit easily into these types
should be assimilated to them to the extent that this is possible. See
the bibliography at the end of this article for examples.

Surnames with internal complexity are never treated in a special way.
Thus, Dutch or German surnames that begin with *van* or *von* (e.g. van
Riemsdijk) or French and Dutch surnames that begin with with *de* (e.g.
de Saussure) are alphabetized under the first part, even though they
begin with a lower-case letter. Thus, the following names are sorted
alphabetically as indicated:

-   Da Milano, Federica

-   de Groot, Casper

-   De Schutter, Georges

-   de Saussure, Ferdinand

-   van der Auwera, Johan

-   Van Langendonck, Willy

-   van Riemsdijk, Henk

-   von Humboldt, Wilhelm

Capitalise all lexical words (title case) in journal titles and titles
of book series. Capitalise only the first word (plus proper names and
the first word after a colon) for book and dissertation titles, and
article and chapter titles. The logic is to use title case for the
titles that are recurring, lower case for those that are not.

Names of book series are optional; they directly follow the book title,
without intervening punctuation. They appear between brackets, have
title case, and Roman font. They may be accompanied by an (optional)
issue number.

Glossa style in Citation Style Language (CSL) is available
[here](https://www.zotero.org/styles?q=Glossa). Many thanks to Mark
Dingemanse for creating this style.

## Typographical matters

### Capitalisation

Sentences, proper names and titles/headings/captions start with a
capital letter, but there is no special capitalisation ('title case')
within English titles/headings, neither in the article title nor in
section headings or figure captions. Capitalisation is also used after
the colon in titles, i.e. for the beginning of subtitles. Capitalisation
in the references section follows its own rules (see section
[2.6](#sec:refs){reference-type="ref" reference="sec:refs"}).

Please refrain from the use of FULL CAPS (except for abbreviations).

### Italics

Italics are used in the following cases:

-   for technical terms and all object-language forms (letters, words,
    phrases, sentences) that are cited within the text, unless they are
    phonetic transcriptions or phonological representations in IPA.

-   for emphasis within the text of a particular word that is not a
    technical term.

-   for emphasis within a quotation, with the indication \[emphasis
    mine/ours\] at the end of the quotation.

-   for the name of the language in examples.

In numbered examples, do not use italics to highlight particular parts
of the example; use bold instead.

### Small caps

Small caps are used for grammatical categories in the interlinear
glosses in examples (e.g. [fut, neg, sg, obl]{.smallcaps}, etc.). They
are also used for indicating stressed syllables or words in example
sentences.

### Boldface and other highlighting

Boldface can be used to draw the reader's attention to particular
aspects of a linguistic example, whether given within the text or as a
numbered example. Full caps, underlining, or italics are not normally
used for highlighting.

### Quotation marks

Double quotation marks are used

-   when a passage from another work is cited in the text.

-   when a technical term or other expression is mentioned that the
    author does not want to adopt.

Ellipsis in a quotation is indicated by \[...\].

Single quotation marks are used exclusively for linguistic meanings,
e.g.

-   Latin *habere* 'have' is not cognate with Old English *hafian*
    'have'.

Quotes within quotes are not treated in a special way. Note that
quotations from other languages should be translated (inline if they are
short, in a footnote if they are longer).

### Abbreviations

When a complex term that is not widely known is referred to frequently,
it may be abbreviated (e.g. DOC for "double-object construction"). The
abbreviation should be given in the text when it is first used.
Abbreviations of uncommon expressions are not used in headings or
captions, and they should be avoided at the beginning of a chapter or
major section.

The abbreviations used in glossed examples should all be listed in a
separate section following the conclusions. For a list of standard
abbreviations, refer to the [Leipzig glossing
rules](https://www.eva.mpg.de/lingua/resources/glossing-rules.php).

# Submission preparation checklist

As part of the submission process, authors are required to check off
their submission's compliance with all of the following items, and
submissions may be returned to authors that do not adhere to these
guidelines.

1.  The submission has not been previously published, nor is it being
    considered for publication by another journal (or an explanation has
    been provided in Comments to the Editor).

2.  Any third-party-owned materials used have been identified with
    appropriate credit lines, and permission obtained from the copyright
    holder for all formats of the journal.

3.  All authors have given permission to be listed on the submitted
    paper and satisfy the [authorship
    guidelines](http://glossa.ubiquitypress.com/about/authorship/).

4.  The original submission file is exclusively in the PDF document
    format. (Accepted papers may be submitted in any of the following
    formats: Latex, OpenOffice, Microsoft Word, [rtf]{.smallcaps}, or
    WordPerfect.)

5.  All [doi]{.smallcaps}s for the references have been provided, when
    available.

6.  Tables and figures are all cited in the text. Tables and figures are
    included within the text document upon first submission, whilst for
    the final version of the accepted paper, figure files are uploaded
    as supplementary files.

7.  Figures/images have a resolution of at least 300dpi. Each file is no
    more than 20Mb per file. The files are in one of the following
    formats: [jpg, tiff, gif, png, eps]{.smallcaps} (to maximise
    quality, the original source file is preferred).

8.  The author(s) agree to edit their text to adhere to the stylistic
    and bibliographic requirements outlined in the [Author
    Guidelines](https://www.glossa-journal.org/about/submissions#authorGuidelines),
    should the paper be editorially accepted.

9.  All references to the author(s) have been removed from the paper
    (following the instructions to ensure [blind peer
    review](https://www.glossa-journal.org/help/view/editorial/topic/000044)).
    Aside from omitting the author's name, this entails only referring
    to your own work in the third person (do not use 'Author 1' or a
    similar replacement for your own name), and removing your name and
    any additional metadata from the document's file properties. Also
    check the acknowledgments and the funding information sections for
    identifying information.

# Copyright notice

Authors who publish with this journal agree to the following terms:

1.  Authors retain copyright and grant the journal right of first
    publication with the work simultaneously licensed under a [Creative
    Commons Attribution
    License](http://creativecommons.org/licenses/by/3.0/) that allows
    others to share the work with an acknowledgement of the work's
    authorship and initial publication in this journal. (See [The Effect
    of Open Access](http://opcit.eprints.org/oacitation-biblio.html).)

2.  Authors are able to enter into separate, additional contractual
    arrangements for the non-exclusive distribution of the journal's
    published version of the work (e.g., post it to an institutional
    repository or publish it in a book), with an acknowledgement of its
    initial publication in this journal.

# Privacy statement

The names and email addresses entered in this journal site will be used
exclusively for the stated purposes of this journal and will not be made
available for any other purpose or to any other party. The full privacy
policy can be viewed
[here](https://www.glossa-journal.org/about/privacy-policy/).

# Publication fees

Authors publishing in Glossa face no financial obligation for the
publication of their article. The [Open Library of
Humanities](https://www.openlibhums.org) (OLH) will take up all fees for
publishing. OLH is a charitable organisation dedicated to publishing
open access scholarship, and is funded by an international consortium of
libraries, who wish to make scholarly publishing fairer, more
accessible, and rigorously preserved for the digital future. Prospective
authors are encouraged to check if their academic library is a funder of
OLH.

Authors who have access to funds earmarked for Article Processing
Charges (via a research grant or through their institution) are asked to
use those funds to cover the APC of their publication in Glossa.

Authors without access to such funds will be asked to declare upon
submission that they have contacted their institutional representatives
to check about possible funding for this purpose, and that they have
found that no such funds are available to them. The fees required for
publication will then be paid by the OLH.

# Conclusion

The conclusion is the last numbered section, and any ensuing sections
are unnumbered.

# Abbreviations (mandatory) {#abbrev .unnumbered}

[acc]{.smallcaps} = accusative, [dat]{.smallcaps} = dative,
[dem]{.smallcaps} = demonstrative, [nom]{.smallcaps} = nominative,
[pl]{.smallcaps} = plural, [sg]{.smallcaps} = singular

For the standard abbreviations to be used here, refer to the [Leipzig
glossing
rules](https://www.eva.mpg.de/lingua/resources/glossing-rules.php).

# Data availability/Supplementary files (optional) {#data-availabilitysupplementary-files-optional .unnumbered}

The journal encourages authors to make all data associated with their
submission openly available, according to the FAIR principles (Findable,
Accessible, Interoperable, Reusable). More information can be found
[`here`](https://www.glossa-journal.org/about/editorialpolicies/#data-policy).

If data/supplementary files are to be associated with the accepted
paper, one of the options below should be followed:

1.  upload the files to your chosen open repository and make note of the
    DOI that they will provide (most suitable for datasets or
    information that act as foundations to the research being published;
    this option makes the files more findable and more citable).

2.  upload the files to the journal system during the submission
    process, as 'data files'. The journal will then host them as part of
    the publication and provide them with a DOI (most suitable for
    non-data files or very short pieces of information, although option
    1 is also suitable for these if the author prefers).

In both cases, a 'Data availability' or 'Supplementary files' section
must be added prior to the reference list that provides a title and very
short summary of the files for each file. If option 1 was selected, you
should also provide the DOI in this section. For example:

Supplementary file 1: Appendix. Scientific data related to the
experiments. DOI:

Ideally, supplementary files are also cited in the main text. Please
note that neither of the above two options will result in the files
being typeset, so please ensure that they are in publishable format when
you upload the accepted paper.

# Ethics and consent (optional) {#ethics-and-consent-optional .unnumbered}

Research involving human subjects, human material, or human data, must
have been performed in accordance with the Declaration of Helsinki.
Where applicable, the studies must have been approved by an appropriate
ethics committee. In the published paper, the authors should include a
statement detailing this approval, including the name of the ethics
committee and reference number of the approval. The identity of the
research subject(s) should be anonymised whenever possible. For research
involving human subjects, informed consent to participate in the study
must be obtained from participants (or their legal guardian).

# Funding information (optional) {#funding-information-optional .unnumbered}

Should the research have received a funding grant, then the grant
provider and grant number can be detailed in this section.

# Acknowledgements (optional) {#acknowledgements-optional .unnumbered}

The authors wish to thank Martin Haspelmath for providing the generic
style sheet for linguistics, and Kai von Fintel for giving permission to
use and modify the *Semantics & Pragmatics* Latex template, bibliography
style, and document class.

# Competing interests (mandatory) {#competing-interests-mandatory .unnumbered}

If any of the authors have any competing interests then these must be
declared. Consult the [Competing
Interests](http://www.glossa-journal.org/about/competinginterests/)
section on the Glossa website for more information. If there are no
competing interests to declare then the following statement should be
present: "The author(s) has/have no competing interests to declare".

# Authors' contributions (optional) {#contrib .unnumbered}

Here you can provide a sentence or a short paragraph detailing the
contribution of each author to the paper.

---
title: "Template for Preparing Your Manuscript Submission to LIPIcs Using RMarkdown"
titlerunning: "LIPIcs rticles" # optional, please use if title is longer than one line
format: "a4paper" # for A4 paper format use option "a4paper", for US-letter use option "letterpaper"
hyphenation: "UKenglish" # for british hyphenation rules use option "UKenglish", for american hyphenation rules use option "USenglish"
authorcolumns: false # activate a two columnstyle for the authors; only available in case of more than 6 authors
numberwithinsect: false # for section-numbered lemmas etc.
cleveref: true # for enabling cleveref support
autoref: true # for enabling autoref support
anonymous: false # for anonymousing the authors (e.g. for double-blind review)
thm-restate: true # for enabling thm-restate support
author:
  # mandatory, please use full name; only 1 author per \author macro; first two parameters are mandatory, other parameters can be empty. Please provide at least the name of the affiliation and the country. The full address is optional
  - name: John Q. Public
    affiliation: "Dummy University Computing Laboratory, [optional: Address], Country \\and My second affiliation, Country \\and \\url{http://www.myhomepage.edu}"
    email: johnqpublic@dummyuni.org
    orcid: "https://orcid.org/0000-0002-1825-0097"
    funding: "(Optional) author-specific funding acknowledgements"
  - name: Joan R. Public
    footnote: Optional footnote, e.g. to mark corresponding author
    affiliation: "Department of Informatics, Dummy College, [optional: Address], Country"
    email: joanrpublic@dummycollege.org
abstract: |
  Lorem ipsum dolor sit amet, consectetur adipiscing elit.
  Praesent convallis orci arcu, eu mollis dolor.
  Aliquam eleifend suscipit lacinia.
  Maecenas quam mi, porta ut lacinia sed, convallis ac dui. 
  Lorem ipsum dolor sit amet, consectetur adipiscing elit.
  Suspendisse potenti.
bibliography: bibliography
authorrunning: "J.&thinsp;Q. Public and J.&thinsp;R. Public" # mandatory. First: Use abbreviated first/middle names. Second (only in severe cases): Use first author plus 'et al.'
# A "thin space" character, ' ' or &thinsp;, is used between the two first names.
copyright: "John Q. Public and Joan R. Public" # mandatory, please use full first names. LIPIcs license is "CC-BY";  http://creativecommons.org/licenses/by/3.0/
ccdesc:
  # Please choose ACM 2012 classifications from https://dl.acm.org/ccs/ccs_flat.cfm
  concept_significance: "100"
  concept_desc: "Replace ccsdesc macro with valid one, e.g., 'Information systems $\\rightarrow$ Question answering'"
keywords: "keyword one, keyword 2, three"
# OPTIONAL:
acknowledgements: "I want to thank \\dots"
category: "Invited paper"
relatedversion: "A full version of the paper is available at https://..." # optional, e.g. full version hosted on arXiv, HAL, or other respository/website
supplement: "See code at https://github.com/.. and data at https://doi.org/..." # optional, e.g. related research data, source code, ... hosted on a repository like zenodo, figshare, GitHub, ...
funding: "(Optional) general funding statement \\dots" # optional, to capture a funding statement, which applies to all authors. Please enter author specific funding statements as fifth argument of the \author macro.
nolinenumbers: false # disable line numbering
hideLIPIcs: false # remove references to LIPIcs series (logo, DOI, ...), e.g. when preparing a pre-final version to be uploaded to arXiv or another public repository
# You will be asked to fill these in on submission with the correct information; following fields are hidded if hideLIPIcs: true:
volumemacros: |
  \EventEditors{John Q. Open and Joan R. Access}
  \EventNoEds{2}
  \EventLongTitle{42nd Conference on Very Important Topics (CVIT 2016)}
  \EventShortTitle{CVIT 2016}
  \EventAcronym{CVIT}
  \EventYear{2016}
  \EventDate{December 24--27, 2016}
  \EventLocation{Little Whinging, United Kingdom}
  \EventLogo{}
  \SeriesVolume{42}
  \ArticleNo{23}
# appendix _after_ the bibliography
appendix: |
  # Styles of lists, enumerations, and descriptions
  
  List of different predefined enumeration styles:
  
  \begin{itemize}
  \item \verb|\begin{itemize}...\end{itemize}|
  \item \dots
  \item \dots
  %\item \dots
  \end{itemize}
  
  \begin{enumerate}
  \item \verb|\begin{enumerate}...\end{enumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{enumerate}
  
  \begin{alphaenumerate}
  \item \verb|\begin{alphaenumerate}...\end{alphaenumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{alphaenumerate}
  
  \begin{romanenumerate}
  \item \verb|\begin{romanenumerate}...\end{romanenumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{romanenumerate}
  
  \begin{bracketenumerate}
  \item \verb|\begin{bracketenumerate}...\end{bracketenumerate}|
  \item \dots
  \item \dots
  %\item \dots
  \end{bracketenumerate}
  
  \begin{description}
  \item[Description 1] \verb|\begin{description} \item[Description 1]  ...\end{description}|
  \item[Description 2] Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et   leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus   massa sit amet neque.
  \item[Description 3]  \dots
  %\item \dots
  \end{description}
  
  \cref{testenv-proposition} and \autoref{testenv-proposition} ...
  
  # Theorem-like environments
  
  List of different predefined enumeration styles:
  
  \begin{theorem}\label{testenv-theorem}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{theorem}
  
  \begin{lemma}\label{testenv-lemma}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{lemma}
  
  \begin{corollary}\label{testenv-corollary}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{corollary}
  
  \begin{proposition}\label{testenv-proposition}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{proposition}
  
  \begin{exercise}\label{testenv-exercise}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{exercise}
  
  \begin{definition}\label{testenv-definition}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{definition}
  
  \begin{example}\label{testenv-example}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{example}
  
  \begin{note}\label{testenv-note}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{note}
  
  \begin{note*}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{note*}
  
  \begin{remark}\label{testenv-remark}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{remark}
  
  \begin{remark*}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{remark*}
  
  \begin{claim}\label{testenv-claim}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{claim}
  
  \begin{claim*}\label{testenv-claim2}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{claim*}
  
  \begin{proof}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{proof}
  
  \begin{claimproof}
  Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.
  \end{claimproof}
  List of different predefined enumeration styles:
output:
  rticles::lipics_article: default
  # To use with bookdown feature
  bookdown::pdf_book:
    base_format: rticles::lipics_article
---

```{r setup, include = FALSE}
# deactivate addition of preamble when this format is used with bookdown
options(bookdown.theorem.preamble = FALSE)
```

# Typesetting instructions -- Summary

LIPIcs is a series of open access high-quality conference proceedings across all fields in informatics established in cooperation with Schloss Dagstuhl.
In order to do justice to the high scientific quality of the conferences that publish their proceedings in the LIPIcs series, which is ensured by the thorough review process of the respective events, we believe that LIPIcs proceedings must have an attractive and consistent layout matching the standard of the series.
Moreover, the quality of the metadata, the typesetting and the layout must also meet the requirements of other external parties such as indexing service, DOI registry, funding agencies, among others. The guidelines contained in this document serve as the baseline for the authors, editors, and the publisher to create documents that meet as many different requirements as possible.

Please comply with the following instructions when preparing your article for a LIPIcs proceedings volume.

## Minimum requirements {.unnumbered}

- Use pdflatex and an up-to-date \LaTeX{} system.
- Use further \LaTeX{} packages and custom made macros carefully and only if required.
- Use the provided sectioning macros: `\section` (`#` in Markdown), `\subsection` (`##` in Markdown), `\subsubsection` (`###` in Markdown), 
  `\paragraph` (`####` in Markdown), `\paragraph*` ((`#### header {.unnumbered}` in Markdown)), and `\subparagraph*` (`##### header {.unnumbered}` in Markdown).
-  Provide suitable graphics of at least 300dpi (preferably in PDF format).
-  Use BibTeX and keep the standard style (`plainurl`) for the bibliography.
-  Please try to keep the warnings log as small as possible. Avoid overfull `\hboxes` and any kind of warnings/errors with the referenced BibTeX entries.
-  Use a spellchecker to correct typos.

## Mandatory metadata macros {.unnumbered}

**NOTE**: _The following macros are set via the YAML header in the R Markdown template._

Please set the values of the metadata macros carefully since the information parsed from these macros will be passed to publication servers, catalogues and search engines.
Avoid placing macros inside the metadata macros. The following metadata macros/environments are mandatory:

- `\title` and, in case of long titles, `\titlerunning`.
- `\author`, one for each author, even if two or more authors have the same affiliation.
- `\authorrunning` and `\Copyright` (concatenated author names)\\
The `\author` macros and the `\Copyright` macro should contain full author names (especially with regard to the first name), while `\authorrunning` should contain abbreviated first names.
- `\ccsdesc` (ACM classification, see \url{https://www.acm.org/publications/class-2012}).
- `\keywords` (a comma-separated list of keywords).
- `\relatedversion` (if there is a related version, typically the ``full version''); please make sure to provide a persistent URL, e.\,g., at arXiv.
- `\begin{abstract}...\end{abstract}`.

#### Please do not \ldots {.unnumbered}
<!-- Do not override the \texttt{\seriesstyle}-defaults} -->
Generally speaking, please do not override the `lipics-v2019`-style defaults. To be more specific, a short checklist also used by Dagstuhl Publishing during the final typesetting is given below.
In case of `non-compliance` with these rules Dagstuhl Publishing will remove the corresponding parts of \LaTeX{} code and *replace it with the `lipics-v2019` defaults*. In serious cases, we may reject the LaTeX-source and expect the corresponding author to revise the relevant parts.

- Do not use a different main font. (For example, the `times` package is forbidden.)
- Do not alter the spacing of the `lipics-v2019.cls` style file.
- Do not use `enumitem` and `paralist`. (The `enumerate` package is preloaded, so you can use
 `\begin{enumerate}[(a)]` or the like.)
- Do not use "self-made" sectioning commands (e.\,g., `\bf My Paragraph}`).
- Do not hide large text blocks using comments or `\iffalse` $\ldots$ `\fi` constructions.
- Do not use conditional structures to include/exclude content. Instead, please provide only the content that should be published -- in one file -- and nothing else.
- Do not wrap figures and tables with text. In particular, the package `wrapfig` is not supported.
- Do not change the bibliography style. In particular, do not use author-year citations. (The
`natbib` package is not supported.)

\enlargethispage{\baselineskip}

This is only a summary containing the most relevant details. Please read the complete document "LIPIcs: Instructions for Authors and the `lipics-v2019` Class" for all details and don't hesitate to contact Dagstuhl Publishing ([mailto:publishing@dagstuhl.de](publishing@dagstuhl.de)) in case of questions or comments:
[http://drops.dagstuhl.de/styles/lipics-v2019/lipics-v2019-authors/lipics-v2019-authors-guidelines.pdf](`http://drops.dagstuhl.de/styles/lipics-v2019/lipics-v2019-authors/lipics-v2019-authors-guidelines.pdf).

# Lorem ipsum dolor sit amet

Lorem ipsum dolor sit amet, consectetur adipiscing elit \cite{DBLP:journals/cacm/Knuth74}. Praesent convallis orci arcu, eu mollis dolor. Aliquam eleifend suscipit lacinia. Maecenas quam mi, porta ut lacinia sed, convallis ac dui. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Suspendisse potenti. Donec eget odio et magna ullamcorper vehicula ut vitae libero. Maecenas lectus nulla, auctor nec varius ac, ultricies et turpis. Pellentesque id ante erat. In hac habitasse platea dictumst. Curabitur a scelerisque odio. Pellentesque elit risus, posuere quis elementum at, pellentesque ut diam. Quisque aliquam libero id mi imperdiet quis convallis turpis eleifend.

\begin{lemma}[Lorem ipsum]
\label{lemma:lorem}
Vestibulum sodales dolor et dui cursus iaculis. Nullam ullamcorper purus vel turpis lobortis eu tempus lorem semper. Proin facilisis gravida rutrum. Etiam sed sollicitudin lorem. Proin pellentesque risus at elit hendrerit pharetra. Integer at turpis varius libero rhoncus fermentum vitae vitae metus.
\end{lemma}


\begin{proof}
Cras purus lorem, pulvinar et fermentum sagittis, suscipit quis magna.

\begin{claim}
content...
\end{claim}
\begin{claimproof}
content...
\end{claimproof}

\end{proof}

\begin{corollary}[Curabitur pulvinar, \cite{DBLP:books/mk/GrayR93}]
\label{lemma:curabitur}
Nam liber tempor cum soluta nobis eleifend option congue nihil imperdiet doming id quod mazim placerat facer possim assum. Lorem ipsum dolor sit amet, consectetuer adipiscing elit, sed diam nonummy nibh euismod tincidunt ut laoreet dolore magna aliquam erat volutpat.
\end{corollary}

\begin{proposition}\label{prop1}
This is a proposition
\end{proposition}

\autoref{prop1} and \cref{prop1} \ldots

## Curabitur dictum felis id sapien

Curabitur dictum \cref{lemma:curabitur} felis id sapien \autoref{lemma:curabitur} mollis ut venenatis tortor feugiat. Curabitur sed velit diam. Integer aliquam, nunc ac egestas lacinia, nibh est vehicula nibh, ac auctor velit tellus non arcu. Vestibulum lacinia ipsum vitae nisi ultrices eget gravida turpis laoreet. Duis rutrum dapibus ornare. Nulla vehicula vulputate iaculis. Proin a consequat neque. Donec ut rutrum urna. Morbi scelerisque turpis sed elit sagittis eu scelerisque quam condimentum. Pellentesque habitant morbi tristique senectus et netus et malesuada fames ac turpis egestas. Aenean nec faucibus leo. Cras ut nisl odio, non tincidunt lorem. Integer purus ligula, venenatis et convallis lacinia, scelerisque at erat. Fusce risus libero, convallis at fermentum in, dignissim sed sem. Ut dapibus orci vitae nisl viverra nec adipiscing tortor condimentum \cite{DBLP:journals/cacm/Dijkstra68a}. Donec non suscipit lorem. Nam sit amet enim vitae nisl accumsan pretium.

\begin{lstlisting}[caption={Useless code},label=list:8-6,captionpos=t,float,abovecaptionskip=-\medskipamount]
for i:=maxint to 0 do
begin
    j:=square(root(i));
end;
\end{lstlisting}

## Proin ac fermentum augue

Proin ac fermentum augue. Nullam bibendum enim sollicitudin tellus egestas lacinia euismod orci mollis. Nulla facilisi. Vivamus volutpat venenatis sapien, vitae feugiat arcu fringilla ac. Mauris sapien tortor, sagittis eget auctor at, vulputate pharetra magna. Sed congue, dui nec vulputate convallis, sem nunc adipiscing dui, vel venenatis mauris sem in dui. Praesent a pretium quam. Mauris non mauris sit amet eros rutrum aliquam id ut sapien. Nulla aliquet fringilla sagittis. Pellentesque eu metus posuere nunc tincidunt dignissim in tempor dolor. Nulla cursus aliquet enim. Cras sapien risus, accumsan eu cursus ut, commodo vel velit. Praesent aliquet consectetur ligula, vitae iaculis ligula interdum vel. Integer faucibus faucibus felis.

- Ut vitae diam augue.
- Integer lacus ante, pellentesque sed sollicitudin et, pulvinar adipiscing sem.
- Maecenas facilisis, leo quis tincidunt egestas, magna ipsum condimentum orci, vitae facilisis nibh turpis et elit.

\begin{remark}
content...
\end{remark}

# Pellentesque quis tortor

Nec urna malesuada sollicitudin. Nulla facilisi. Vivamus aliquam tempus ligula eget ornare. Praesent eget magna ut turpis mattis cursus. Aliquam vel condimentum orci. Nunc congue, libero in gravida convallis \cite{DBLP:conf/focs/HopcroftPV75}, orci nibh sodales quam, id egestas felis mi nec nisi. Suspendisse tincidunt, est ac vestibulum posuere, justo odio bibendum urna, rutrum bibendum dolor sem nec tellus.

\begin{lemma} [Quisque blandit tempus nunc]
Sed interdum nisl pretium non. Mauris sodales consequat risus vel consectetur. Aliquam erat volutpat. Nunc sed sapien ligula. Proin faucibus sapien luctus nisl feugiat convallis faucibus elit cursus. Nunc vestibulum nunc ac massa pretium pharetra. Nulla facilisis turpis id augue venenatis blandit. Cum sociis natoque penatibus et magnis dis parturient montes, nascetur ridiculus mus.
\end{lemma}

Fusce eu leo nisi. Cras eget orci neque, eleifend dapibus felis. Duis et leo dui. Nam vulputate, velit et laoreet porttitor, quam arcu facilisis dui, sed malesuada risus massa sit amet neque.

# Morbi eros magna

Morbi eros magna, vestibulum non posuere non, porta eu quam. Maecenas vitae orci risus, eget imperdiet mauris. Donec massa mauris, pellentesque vel lobortis eu, molestie ac turpis. Sed condimentum convallis dolor, a dignissim est ultrices eu. Donec consectetur volutpat eros, et ornare dui ultricies id. Vivamus eu augue eget dolor euismod ultrices et sit amet nisi. Vivamus malesuada leo ac leo ullamcorper tempor. Donec justo mi, tempor vitae aliquet non, faucibus eu lacus. Donec dictum gravida neque, non porta turpis imperdiet eget. Curabitur quis euismod ligula. 

---
title: "Untitled"
short_title: "Untitled"
short_author: "Author 1 et. al."
authors: 
- name: "Author 1"
  affiliation: "Address"
  city: "City"
  country: "Country"
  email: "email1\\@example.com" # optional
- name: "Author 2"
  affiliation: "Address2"
  city: "City2"
  country: "Country2"
- name: "Author 3"
  affiliation: "Address2"
  city: "City2"
  country: "Country2"
  email: "email2\\@example.com"
abstract: |
  Abstract goes here
keywords: keywords
bibliography: "bibliography"
output: rticles::rss_article
---

# Introduction

This template demonstrates some of the basic latex you'll need to know to create a RSS article.

# R code

Can be inserted in regular R markdown blocks.

```{r}
x <- 1:10
x
```

# Contributing to rticles

We welcome contributions to the **rticles** package. 

You can contribute in many ways: 

* By opening issues to give feedback and share ideas.
* By fixing typos in documentations
* By submitting Pull Request (PR) to fix some opened issues
* By submitting Pull Request (PR) to suggest some new features. (It is considered good practice to open issues before to discuss ideas)

## To submit a contribution using a Pull Request:

1.  [Fork](https://github.com/rstudio/rticles/fork) the repository and make your changes in a new branch specific to the PR. It is ok to edit a file in this repository using the `Edit` button on Github if the change is simple enough.

2. For significant changes (e.g not required for fixing typos), ensure that you have signed the [individual](https://www.rstudio.com/wp-content/uploads/2014/06/rstudioindividualcontributoragreement.pdf) or [corporate](https://www.rstudio.com/wp-content/uploads/2014/06/rstudiocorporatecontributoragreement.pdf) contributor agreement as appropriate. You can send the signed copy to <jj@posit.co>.

3.  Submit the [pull request](https://help.github.com/articles/using-pull-requests). It is ok to submit as draft if you are still working on it but would like some feedback from us. It always good to share in the open that you are working on it.

4. You will be asked to check that you're PR meets some requirements. See the [PR template](https://pkgs.rstudio.com/rticles/PULL_REQUEST_TEMPLATE.html).

We'll try to be as responsive as possible in reviewing and accepting pull requests. Appreciate your contributions very much!

---
title: Template for preparing your research report submission to PNAS using RMarkdown

# Use letters for affiliations, numbers to show equal authorship (if applicable) and to indicate the corresponding author
author:
  - name: Alice Anonymous
    affiliation: a,1,2
  - name: Bob Security
    affiliation: a,b
address:
  - code: a
    address: Some Institute of Technology, Department, Street, City, State, Zip
  - code: b
    address: Another University Department, Street, City, State, Zip

corresponding_author:
  code: 2
  text: "To whom correspondence should be addressed. E-mail: bob@email.com"

# For footer text
lead_author_surname: Anonymous

## Remove this if not required    
equal_authors:
  code: 1
  text: "A.O.(Author One) and A.T. (Author Two) contributed equally to this work (remove if not applicable)."


author_contributions: |
  Please provide details of author contributions here.

## Remove this if not required
conflict_of_interest: |
  Please declare any conflict of interest here.

abstract: |
  Please provide an abstract of no more than 250 words in a single paragraph. Abstracts should explain to the general reader the major contributions of the article. References in the abstract must be cited in full within the abstract itself and cited in the text.


significance: |
  Authors must submit a 120-word maximum statement about the significance of their research paper written at a level understandable to an undergraduate educated scientist outside their field of speciality. The primary goal of the Significance Statement is to explain the relevance of the work in broad context to a broad readership. The Significance Statement appears in the paper itself and is required for all research papers.

acknowledgements: |
  Please include your acknowledgments here, set in a single paragraph. Please do not include any acknowledgments in the Supporting Information, or anywhere else in the manuscript.

keywords:
  - one
  - two
  - optional
  - optional
  - optional

## must be one of: pnasresearcharticle (usual two-column layout), pnasmathematics (one column layout), or pnasinvited (invited submissions only)
pnas_type: pnasresearcharticle

bibliography: pnas-sample.bib
csl: pnas.csl

## change to true to add optional line numbering
lineno: false

output: rticles::pnas_article
---


This PNAS journal template is provided to help you write your work in the
correct journal format. Instructions for use are provided below.

Note: please start your introduction without including the word
"Introduction" as a section heading (except for math articles in the
Physical Sciences section); this heading is implied in the first
paragraphs.

Guide to using this template {.unnumbered}
========================================

Please note that whilst this template provides a preview of the typeset
manuscript for submission, to help in this preparation, it will not
necessarily be the final publication layout. For more detailed
information please see the [PNAS Information for
Authors](http://www.pnas.org/site/authors/format.xhtml).


Author Affiliations {#author-affiliations .unnumbered}
-------------------

Include department, institution, and complete address, with the
ZIP/postal code, for each author. Use lower case letters to match
authors with institutions, as shown in the example. Authors with an
ORCID ID may supply this information at submission.

Submitting Manuscripts {#submitting-manuscripts .unnumbered}
----------------------

All authors must submit their articles at
[PNAScentral](http://www.pnascentral.org/cgi-bin/main.plex). If you are
using Overleaf to write your article, you can use the "Submit to PNAS"
option in the top bar of the editor window.

Format {#format .unnumbered}
------

Many authors find it useful to organize their manuscripts with the
following order of sections; Title, Author Affiliation, Keywords,
Abstract, Significance Statement, Results, Discussion, Materials and
methods, Acknowledgments, and References. Other orders and headings are
permitted.

Manuscript Length {#manuscript-length .unnumbered}
-----------------

PNAS generally uses a two-column format averaging 67 characters,
including spaces, per line. The maximum length of a Direct Submission
research article is six pages and a PNAS PLUS research article is ten
pages including all text, spaces, and the number of characters displaced
by figures, tables, and equations. When submitting tables, figures,
and/or equations in addition to text, keep the text for your manuscript
under 39,000 characters (including spaces) for Direct Submissions and
72,000 characters (including spaces) for PNAS PLUS.

References {#references .unnumbered}
----------

References should be cited in numerical order as they appear in text;
this will be done automatically via bibtex, e.g. @belkin2002using and
@berard1994embedding [@coifman2005geometric]. All references, including
for the SI, should be included in the main manuscript file. References
appearing in both sections should not be duplicated. SI references
included in tables should be included with the main reference section.

Data Archival {#data-archival .unnumbered}
-------------

PNAS must be able to archive the data essential to a published article.
Where such archiving is not possible, deposition of data in public
databases, such as GenBank, ArrayExpress, Protein Data Bank, Unidata,
and others outlined in the Information for Authors, is acceptable.



Language-Editing Services {#language-editing-services .unnumbered}
-------------------------

Prior to submission, authors who believe their manuscripts would benefit
from professional editing are encouraged to use a language-editing
service (see list at www.pnas.org/site/authors/language-editing.xhtml).
PNAS does not take responsibility for or endorse these services, and
their use has no bearing on acceptance of a manuscript for publication.

![Placeholder image of a frog with a long example caption to show
justification setting.<span data-label="fig:frog"></span>](frog.png)

Digital Figures {#sec:figures .unnumbered}
---------------

Only TIFF, EPS, and high-resolution PDF for Mac or PC are allowed for
figures that will appear in the main text, and images must be final
size. Authors may submit U3D or PRC files for 3D images; these must be
accompanied by 2D representations in TIFF, EPS, or high-resolution PDF
format. Color images must be in RGB (red, green, blue) mode. Include the
font files for any text.

Figures and Tables should be labelled and referenced in the standard way
using the `\label{}` and `\ref{}` commands.

Figure \[fig:frog\] shows an example of how to insert a column-wide
figure. To insert a figure wider than one column, please use the
`\begin{figure*}...\end{figure*}` environment. Figures wider than one
column should be sized to 11.4 cm or 17.8 cm wide.

Single column equations {#single-column-equations .unnumbered}
-----------------------

Authors may use 1- or 2-column equations in their article, according to
their preference.

To allow an equation to span both columns, options are to use the
`\begin{figure*}...\end{figure*}` environment mentioned above for
figures, or to use the `\begin{widetext}...\end{widetext}` environment
as shown in equation \[eqn:example\] below.

Please note that this option may run into problems with floats and
footnotes, as mentioned in the [cuted package
documentation](http://texdoc.net/pkg/cuted). In the case of problems
with footnotes, it may be possible to correct the situation using
commands `\footnotemark` and `\footnotetext`.

$$\begin{aligned}
(x+y)^3&=(x+y)(x+y)^2\\
       &=(x+y)(x^2+2xy+y^2) \label{eqn:example} \\
       &=x^3+3x^2y+3xy^3+x^3. 
\end{aligned}$$



<!-- pandoc writes all tables using longtable, which fails in 2-column mode

  Species                    CBS     CV     G3
  ----------------------- ------ ------ ------
  1\. Acetaldehyde           0.0    0.0    0.0
  2\. Vinyl alcohol          9.1    9.6   13.5
  3\. Hydroxyethylidene     50.8   51.2   54.0

  : Comparison of the fitted potential energy surfaces and ab initio
  benchmark electronic energy calculations

-->

Supporting Information (SI) {#supporting-information-si .unnumbered}
---------------------------


The main text of the paper must stand on its own without the SI. Refer
to SI in the manuscript at an appropriate point in the text. Number
supporting figures and tables starting with S1, S2, etc. Authors are
limited to no more than 10 SI files, not including movie files. Authors
who place detailed materials and methods in SI must provide sufficient
detail in the main text methods to enable a reader to follow the logic
of the procedures and results and also must reference the online
methods. If a paper is fundamentally a study of a new method or
technique, then the methods must be described completely in the main
text. Because PNAS edits SI and composes it into a single PDF, authors
must provide the following file formats only.

### SI Text {#si-text .unnumbered}

Supply Word, RTF, or LaTeX files (LaTeX files must be accompanied by a
PDF with the same file name for visual reference).

### SI Figures {#si-figures .unnumbered}

Provide a brief legend for each supporting figure after the supporting
text. Provide figure images in TIFF, EPS, high-resolution PDF, JPEG, or
GIF format; figures may not be embedded in manuscript text. When saving
TIFF files, use only LZW compression; do not use JPEG compression. Do
not save figure numbers, legends, or author names as part of the image.
Composite figures must be pre-assembled.

### 3D Figures {#d-figures .unnumbered}

Supply a composable U3D or PRC file so that it may be edited and
composed. Authors may submit a PDF file but please note it will be
published in raw format and will not be edited or composed.

### SI Tables {#si-tables .unnumbered}

Supply Word, RTF, or LaTeX files (LaTeX files must be accompanied by a
PDF with the same file name for visual reference); include only one
table per file. Do not use tabs or spaces to separate columns in Word
tables.

### SI Datasets {#si-datasets .unnumbered}

Supply Excel (.xls), RTF, or PDF files. This file type will be published
in raw format and will not be edited or composed.

### SI Movies {#si-movies .unnumbered}

Supply Audio Video Interleave (avi), Quicktime (mov), Windows Media
(wmv), animated GIF (gif), or MPEG files and submit a brief legend for
each movie in a Word or RTF file. All movies should be submitted at the
desired reproduction size and length. Movies should be no more than 10
MB in size.

### Still images {#still-images .unnumbered}

Authors must provide a still image from each video file. Supply TIFF,
EPS, high-resolution PDF, JPEG, or GIF files.

### Appendices {#appendices .unnumbered}

PNAS prefers that authors submit individual source files to ensure
readability. If this is not possible, supply a single PDF file that
contains all of the SI associated with the paper. This file type will be
published in raw format and will not be edited or composed.


<!-- Leave these lines as they are at the end of your .Rmd file to ensure placement of methods & acknowledgements sections before the references-->
\showmatmethods
\showacknow
\pnasbreak

---
# Supported options: 
#   sn-nature:       Style for submissions to Nature Portfolio journals
#   sn-basic:        Basic Springer Nature Reference Style/Chemistry Reference Style
#   sn-mathphys:     Math and Physical Sciences Reference Style
#   sn-aps:          American Physical Society (APS) Reference Style
#   sn-vancouver:    Vancouver Reference Style
#   sn-apa:          APA Reference Style 
#   sn-chicago:      Chicago-based Humanities Reference Style
#   default:         Default

classoptions: 
  - sn-basic      
  # - Numbered      # Optional: Use numbered references instead of namedate references (only for sn-nature, sn-basic, sn-vancouver, sn-chicago, sn-mathphys or sn-nature)
  # - referee       # Optional: Use double line spacing 
  # - lineno        # Optional: Add line numbers
  # - iicol         # Optional: Double column layour

title: Article Title
titlerunning: Article Title runing

authors: 
  - prefix: Dr.
    firstname: Leading
    particle: van 
    lastname: Author
    suffix: III
    naturename: Poet Laureate
    degrees: MSc, PhD
    email: abc@def
    affiliation: [1,2]
    corresponding: TRUE
    equalcont: These authors contributed equally to this work.
    
  - firstname: Second
    lastname: Author
    affiliation: 2
    equalcont: These authors contributed equally to this work.


affiliations:
  - number: 1
    corresponding: TRUE
    info:
      orgdiv: Department
      orgname: Organization
    address:
        street: Street
        city: City
        postcode: 100190
        state: State
        country: Country
  - number: 2
    corresponding: TRUE
    info:
      orgname: Other Organisation
    
  
keywords:
  - key
  - dictionary
  - word
  
pacs: 
  jel:
    - "D8"
    - "H51"
  msc:
    - "35A01"
    - "65L10"

# Sample for unstructured abstract 
# abstract: |
#   The abstract serves both as a general introduction to the topic and as a brief, non-technical summary of the main results and their implications. Authors are advised to check the author instructions for the journal they are submitting to for word limits and if structural elements like subheadings, citations, or equations are permitted.

# Sample for structured abstract
abstract: |
  **Purpose**: The abstract serves both as a general introduction to the topic and as a brief, non-technical summary of the main results and their implications. The abstract must not include subheadings (unless expressly permitted in the journal's Instructions to Authors), equations or citations. As a guide the abstract should not exceed 200 words. Most journals do not set a hard limit however authors are advised to check the author instructions for the journal they are submitting to.

  **Methods:** The abstract serves both as a general introduction to the topic and as a brief, non-technical summary of the main results and their implications. The abstract must not include subheadings (unless expressly permitted in the journal's Instructions to Authors), equations or citations. As a guide the abstract should not exceed 200 words. Most journals do not set a hard limit however authors are advised to check the author instructions for the journal they are submitting to.

  **Results:** The abstract serves both as a general introduction to the topic and as a brief, non-technical summary of the main results and their implications. The abstract must not include subheadings (unless expressly permitted in the journal's Instructions to Authors), equations or citations. As a guide the abstract should not exceed 200 words. Most journals do not set a hard limit however authors are advised to check the author instructions for the journal they are submitting to.

  **Conclusion:** The abstract serves both as a general introduction to the topic and as a brief, non-technical summary of the main results and their implications. The abstract must not include subheadings (unless expressly permitted in the journal's Instructions to Authors), equations or citations. As a guide the abstract should not exceed 200 words. Most journals do not set a hard limit however authors are advised to check the author instructions for the journal they are submitting to.}

bibliography: bibliography.bib

header-includes: |
  %% Per the spinger doc, new theorem styles can be included using built in style, 
  %% but it seems the don't work so commented below
  %\theoremstyle{thmstyleone}%
  \newtheorem{theorem}{Theorem}%  meant for continuous numbers
  %%\newtheorem{theorem}{Theorem}[section]% meant for sectionwise numbers
  %% optional argument [theorem] produces theorem numbering sequence instead of independent numbers for Proposition
  \newtheorem{proposition}[theorem]{Proposition}%
  %%\newtheorem{proposition}{Proposition}% to get separate numbers for theorem and proposition etc.

  %% \theoremstyle{thmstyletwo}%
  \theoremstyle{remark}
  \newtheorem{example}{Example}%
  \newtheorem{remark}{Remark}%

  %% \theoremstyle{thmstylethree}%
  \theoremstyle{definition}
  \newtheorem{definition}{Definition}%

output: rticles::springer_article
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = FALSE,
                      out.extra = "")  # This forces knitr to label all figures.
```

# Introduction {#sec1}

The Introduction section, of referenced text @bib1 expands on the background of the work (some overlap with the Abstract is acceptable). The introduction should not include subheadings.

Springer Nature does not impose a strict layout as standard however authors are advised to check the individual requirements for the journal they are planning to submit to as there may be journal-level preferences. 
When preparing your text please also be aware that some stylistic choices are not supported in full text XML (publication version), including coloured font. 
These will not be replicated in the typeset article if it is accepted.

# Results {#sec2}

Sample body text. 
Sample body text. 
Sample body text. 
Sample body text.
Sample body text.
Sample body text.
Sample body text. 
Sample body text.

# This is an example for first level head---section head {#sec3}

## This is an example for second level head---subsection head {#subsec2}

### This is an example for third level head---subsubsection head {#subsubsec2}

Sample body text. 
Sample body text. 
Sample body text.
Sample body text.
Sample body text.
Sample body text. 
Sample body text.

# Equations {#sec4}

Equations in \LaTeX\ can either be inline or on-a-line by itself ("display equations"). For
inline equations use the `$...$` commands. E.g.: The equation
$H\psi = E \psi$ is written via the command `$H \psi = E \psi$`.

For display equations (with auto generated equation numbers)
one can use the equation or align environments:

\begin{equation}
\|\tilde{X}(k)\|^2 \leq\frac{\sum\limits_{i=1}^{p}\left\|\tilde{Y}_i(k)\right\|^2+\sum\limits_{j=1}^{q}\left\|\tilde{Z}_j(k)\right\|^2 }{p+q}.\label{eq1}
\end{equation}


where,
\begin{align}
D_\mu &=  \partial_\mu - ig \frac{\lambda^a}{2} A^a_\mu \nonumber \\
F^a_{\mu\nu} &= \partial_\mu A^a_\nu - \partial_\nu A^a_\mu + g f^{abc} A^b_\mu A^a_\nu \label{eq2}
\end{align}

Notice the use of `\nonumber` in the align environment at the end
of each line, except the last, so as not to produce equation numbers on
lines where no equation numbers are required. The `\label{}` command
should only be used at the last line of an align environment where
`\nonumber` is not used.

\begin{equation}
Y_\infty = \left( \frac{m}{\textrm{GeV}} \right)^{-3}
    \left[ 1 + \frac{3 \ln(m/\textrm{GeV})}{15}
    + \frac{\ln(c_2/5)}{15} \right]
\end{equation}

The class file also supports the use of `\mathbb{}`, `\mathscr{}` and
`\mathcal{}` commands. As such `\mathbb{R}`, `\mathscr{R}`
and `\mathcal{R}` produces $\mathbb{R}$, $\mathscr{R}$ and $\mathcal{R}$
respectively (refer Subsubsection\ \ref{subsubsec2}).

# Tables {#sec5}

Tables can be inserted via the normal `knitr::kable()` function or other table-generating packages. 

```{r tab1}
knitr::kable(head(pressure), 
             format = "latex", 
             caption = "Caption text")
```

Tables can also be inserted via the normal table and tabular environment. To put
footnotes inside tables you should use `\footnotetext[]{...}` tag.
The footnote appears just below the table itself (refer Tables~\ref{tab1} and \ref{tab2}).
For the corresponding footnotemark use `\footnotemark[...]`

\begin{table}[h]
\caption{Caption text}\label{tab1}%
\begin{tabular}{@{}llll@{}}
\toprule
Column 1 & Column 2  & Column 3 & Column 4\\
\midrule
row 1    & data 1   & data 2  & data 3  \\
row 2    & data 4   & data 5\footnotemark[1]  & data 6  \\
row 3    & data 7   & data 8  & data 9\footnotemark[2]  \\
\botrule
\end{tabular}
\footnotetext{Source: This is an example of table footnote. This is an example of table footnote.}
\footnotetext[1]{Example for a first table footnote. This is an example of table footnote.}
\footnotetext[2]{Example for a second table footnote. This is an example of table footnote.}
\end{table}

\noindent
The input format for the above table is as follows:


```
\begin{table}[<placement-specifier>]
\caption{<table-caption>}\label{<table-label>}%
\begin{tabular}{@{}llll@{}}
\toprule
Column 1 & Column 2 & Column 3 & Column 4\\
\midrule
row 1 & data 1 & data 2	 & data 3 \\
row 2 & data 4 & data 5\footnotemark[1] & data 6 \\
row 3 & data 7 & data 8	 & data 9\footnotemark[2]\\
\botrule
\end{tabular}
\footnotetext{Source: This is an example of table footnote.
This is an example of table footnote.}
\footnotetext[1]{Example for a first table footnote.
This is an example of table footnote.}
\footnotetext[2]{Example for a second table footnote.
This is an example of table footnote.}
\end{table}
```

\begin{table}[h]
\caption{Example of a lengthy table which is set to full textwidth}\label{tab2}
\begin{tabular*}{\textwidth}{@{\extracolsep\fill}lcccccc}
\toprule%
& \multicolumn{3}{@{}c@{}}{Element 1\footnotemark[1]} & \multicolumn{3}{@{}c@{}}{Element 2\footnotemark[2]} \\\cmidrule{2-4}\cmidrule{5-7}%
Project & Energy & $\sigma_{calc}$ & $\sigma_{expt}$ & Energy & $\sigma_{calc}$ & $\sigma_{expt}$ \\
\midrule
Element 3  & 990 A & 1168 & $1547\pm12$ & 780 A & 1166 & $1239\pm100$\\
Element 4  & 500 A & 961  & $922\pm10$  & 900 A & 1268 & $1092\pm40$\\
\botrule
\end{tabular*}
\footnotetext{Note: This is an example of table footnote. This is an example of table footnote this is an example of table footnote this is an example of~table footnote this is an example of table footnote.}
\footnotetext[1]{Example for a first table footnote.}
\footnotetext[2]{Example for a second table footnote.}
\end{table}

\vfill\eject

In case of double column layout, tables which do not fit in single column width should be set to full text width. 
For this, you need to use `\begin{table*}` `...` `\end{table*}` instead of `\begin{table}` `...` `\end{table}` environment. Lengthy tables which do not fit in textwidth should be set as rotated table. For this, you need to use `\begin{sidewaystable}` `...` `\end{sidewaystable}` instead of `\begin{table*}` `...` `\end{table*}` environment. This environment puts tables rotated to single column width. For tables rotated to double column width, use `\begin{sidewaystable*}` `...` `\end{sidewaystable*}`.

\begin{sidewaystable}
\caption{Tables which are too long to fit, should be written using the "sidewaystable" environment as shown here}\label{tab3}
\begin{tabular*}{\textheight}{@{\extracolsep\fill}lcccccc}
\toprule%
& \multicolumn{3}{@{}c@{}}{Element 1\footnotemark[1]}& \multicolumn{3}{@{}c@{}}{Element\footnotemark[2]} \\\cmidrule{2-4}\cmidrule{5-7}%
Projectile & Energy	& $\sigma_{calc}$ & $\sigma_{expt}$ & Energy & $\sigma_{calc}$ & $\sigma_{expt}$ \\
\midrule
Element 3 & 990 A & 1168 & $1547\pm12$ & 780 A & 1166 & $1239\pm100$ \\
Element 4 & 500 A & 961  & $922\pm10$  & 900 A & 1268 & $1092\pm40$ \\
Element 5 & 990 A & 1168 & $1547\pm12$ & 780 A & 1166 & $1239\pm100$ \\
Element 6 & 500 A & 961  & $922\pm10$  & 900 A & 1268 & $1092\pm40$ \\
\botrule
\end{tabular*}
\footnotetext{Note: This is an example of table footnote this is an example of table footnote this is an example of table footnote this is an example of~table footnote this is an example of table footnote.}
\footnotetext[1]{This is an example of table footnote.}
\end{sidewaystable}

# Figures {#sec6}

As per the \LaTeX\ standards you need to use eps images for \LaTeX\ compilation and `pdf/jpg/png` images for `PDFLaTeX` compilation. 
Use the `dev` knitr option to use the approrpate format. 
This is one of the major difference between \LaTeX\ and `PDFLaTeX`.
Each image should be from a single input .eps/vector image file. 
Avoid using subfigures.
The command for inserting images for \LaTeX\ and `PDFLaTeX` can be generalized. 
The package used to insert images in `LaTeX/PDFLaTeX` is the graphicx package. 
Figures can be inserted via the normal figure environment as shown in the below example:

```{r fig1, fig.cap = "This is an example of a caption", fig.width = 5}
plot(pressure)
```

# Algorithms, Program codes and Listings {#sec7}

Packages `algorithm`, `algorithmicx` and `algpseudocode` are used for setting algorithms in \LaTeX\ using the format:

```
\begin{algorithm}
\caption{<alg-caption>}\label{<alg-label>}
\begin{algorithmic}[1]
. . .
\end{algorithmic}
\end{algorithm}
```

You may refer above listed package documentations for more details before setting `algorithm` environment. For program codes, the "program" package is required and the command to be used is `\begin{program}` `...` `\end{program}`. A fast exponentiation procedure:

Similarly, for `listings`, use the `listings` package. `\begin{lstlisting}` `...` `\end{lstlisting}` is used to set environments similar to `verbatim` environment. Refer to the `lstlisting` package documentation for more details.

A fast exponentiation procedure:

```{=latex}
\lstset{texcl=true,basicstyle=\small\sf,commentstyle=\small\rm,mathescape=true,escapeinside={(*}{*)}}
\begin{lstlisting}
begin
  for $i:=1$ to $10$ step $1$ do
      expt($2,i$);  
      newline() od                (*\textrm{Comments will be set flush to the right margin}*)
where
proc expt($x,n$) $\equiv$
  $z:=1$;
  do if $n=0$ then exit fi;
     do if odd($n$) then exit fi;                 
        comment: (*\textrm{This is a comment statement;}*)
        $n:=n/2$; $x:=x*x$ od;
     { $n>0$ };
     $n:=n-1$; $z:=z*x$ od;
  print($z$). 
end
\end{lstlisting}
```

```{=latex}
\begin{algorithm}
\caption{Calculate $y = x^n$}\label{algo1}
\begin{algorithmic}[1]
\Require $n \geq 0 \vee x \neq 0$
\Ensure $y = x^n$ 
\State $y \Leftarrow 1$
\If{$n < 0$}\label{algln2}
        \State $X \Leftarrow 1 / x$
        \State $N \Leftarrow -n$
\Else
        \State $X \Leftarrow x$
        \State $N \Leftarrow n$
\EndIf
\While{$N \neq 0$}
        \If{$N$ is even}
            \State $X \Leftarrow X \times X$
            \State $N \Leftarrow N / 2$
        \Else[$N$ is odd]
            \State $y \Leftarrow y \times X$
            \State $N \Leftarrow N - 1$
        \EndIf
\EndWhile
\end{algorithmic}
\end{algorithm}
```

:::: {.minipage latex="{\hsize}"}
\lstset{frame=single,framexleftmargin=-1pt,framexrightmargin=-17pt,framesep=12pt,linewidth=0.98\textwidth,language=pascal}
<!-- Set your language (you can change the language for each code-block optionally) -->
<!-- Start your code-block -->
::: {.lstlisting latex=true}
for i:=maxint to 0 do
begin
{ do nothing }
end;
Write('Case insensitive ');
Write('Pascal keywords.');
:::
::::

# Cross referencing {#sec8}

Figures and tables are labeled with a prefix (fig or tab, respectively) plus the chunk label. 
Other environments such as equation and align can be labelled via the `\label{#label}` command inside or just below the `\caption{}` command.
You can then use the label for cross-reference. As an example, consider
the chunk label declared for Figure\ \ref{fig:fig1} which is
fig1. 
To cross-reference it, use the command
`Figure \ref{fig:fig1}`, for which it comes up as
"Figure\ \ref{fig:fig1}".

To reference line numbers in an algorithm, consider the label declared for the line number 2 of Algorithm\ \ref{algo1} is `\label{algln2}`. To cross-reference it, use the command `\ref{algln2}` for which it comes up as line\ \ref{algln2} of Algorithm\ \ref{algo1}.

## Details on reference citations {#subsec7}

For citations of references, use\ @bib1 or [@bib2]. 

# Examples for theorem like environments {#sec10}

The documentclass for springer `sn-jnl.cls` contains 3 styling that you can use to set new default for theorems and proofs type 

`thmstyleone`

: Numbered, theorem head in bold font and theorem text in italic style

`thmstyletwo`

: Numbered, theorem head in roman font and theorem text in italic style

`thmstylethree`

: Numbered, theorem head in bold font and theorem text in roman style 

For mathematics journals, theorem styles can be included as shown in the following examples.

::: {.theorem latex=true}
Example theorem text. Example theorem text. Example theorem text. Example theorem text. Example theorem text.
Example theorem text. Example theorem text. Example theorem text. Example theorem text. Example theorem text.
Example theorem text.
:::

To add labels and subheadings, use LaTeX notation  

::: {.theorem latex="[Theorem subhead]\label{thm1}"}
Example theorem text. Example theorem text. Example theorem text. Example theorem text. Example theorem text.
Example theorem text. Example theorem text. Example theorem text. Example theorem text. Example theorem text.
Example theorem text.
:::

Other environments are proposition, example, remark, definition, proof and quote  

Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text.  

::: {.proposition latex=true}
Example proposition text. Example proposition text. Example proposition text. Example proposition text. Example proposition text. 
Example proposition text. Example proposition text. Example proposition text. Example proposition text. Example proposition text. 
:::

Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text.

::: {.example latex=true}
Phasellus adipiscing semper elit. Proin fermentum massa
ac quam. Sed diam turpis, molestie vitae, placerat a, molestie nec, leo. Maecenas lacinia. Nam ipsum ligula, eleifend
at, accumsan nec, suscipit a, ipsum. Morbi blandit ligula feugiat magna. Nunc eleifend consequat lorem. 
:::

Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text.

::: {.remark latex=true}
Phasellus adipiscing semper elit. Proin fermentum massa
ac quam. Sed diam turpis, molestie vitae, placerat a, molestie nec, leo. Maecenas lacinia. Nam ipsum ligula, eleifend
at, accumsan nec, suscipit a, ipsum. Morbi blandit ligula feugiat magna. Nunc eleifend consequat lorem. 
:::

Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text.

::: {.definition latex="[Definition sub head]"}
Example definition text. Example definition text. Example definition text. Example definition text. Example definition text. Example definition text. Example definition text. Example definition text. 
:::

Additionally a predefined "proof" environment is available. This prints a "Proof" head in italic font style and the "body text" in roman font style with an open square at the end of each proof environment. 

::: {.proof latex=true}
Example for proof text. Example for proof text. Example for proof text. Example for proof text. Example for proof text. Example for proof text. Example for proof text. Example for proof text. Example for proof text. Example for proof text. 
:::

Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text. Sample body text.

# Methods {#sec11}

Topical subheadings are allowed. Authors must ensure that their Methods section includes adequate experimental and characterization data necessary for others in the field to reproduce their work. Authors are encouraged to include RIIDs where appropriate.

**Ethical approval declarations** (only required where applicable) Any article reporting experiment/s carried out on (i)~live vertebrate (or higher invertebrates), (ii)~humans or (iii)~human samples must include an unambiguous statement within the methods section that meets the following requirements:

1. Approval: a statement which confirms that all experimental protocols were approved by a named institutional and/or licensing committee. Please identify the approving body in the methods section

2. Accordance: a statement explicitly saying that the methods were carried out in accordance with the relevant guidelines and regulations

3. Informed consent (for experiments involving humans or human tissue samples): include a statement confirming that informed consent was obtained from all participants and/or their legal guardian/s


If your manuscript includes potentially identifying patient/participant information, or if it describes human transplantation research, or if it reports results of a clinical trial then  additional information will be required. Please visit (<https://www.nature.com/nature-research/editorial-policies>) for Nature Portfolio journals, (<https://www.springer.com/gp/authors-editors/journal-author/journal-author-helpdesk/publishing-ethics/14214>) for Springer Nature journals, or (<https://www.biomedcentral.com/getpublished/editorial-policies\#ethics+and+consent>) for BMC.

# Discussion {#sec12}

Discussions should be brief and focused. In some disciplines use of Discussion or 'Conclusion' is interchangeable. It is not mandatory to use both. Some journals prefer a section 'Results and Discussion' followed by a section 'Conclusion'. Please refer to Journal-level guidance for any specific requirements.

# Conclusion {#sec13}

Conclusions may be used to restate your hypothesis or research question, restate your major findings, explain the relevance and the added value of your work, highlight any limitations of your study, describe future directions for research and recommendations.

In some disciplines use of Discussion or 'Conclusion' is interchangeable. It is not mandatory to use both. Please refer to Journal-level guidance for any specific requirements.

\backmatter

\bmhead{Supplementary information}

If your article has accompanying supplementary file/s please state so here.

Authors reporting data from electrophoretic gels and blots should supply the full unprocessed scans for key as part of their Supplementary information. This may be requested by the editorial team/s if it is missing.

Please refer to Journal-level guidance for any specific requirements.

\bmhead{Acknowledgments}

Acknowledgments are not compulsory. Where included they should be brief. Grant or contribution numbers may be acknowledged.

Please refer to Journal-level guidance for any specific requirements.

# Declarations {.unnumbered}

Some journals require declarations to be submitted in a standardised format. Please check the Instructions for Authors of the journal to which you are submitting to see if you need to complete this section. If yes, your manuscript must contain the following sections under the heading `Declarations':

* Funding
* Conflict of interest/Competing interests (check journal-specific guidelines for which heading to use)
* Ethics approval
* Consent to participate
* Consent for publication
* Availability of data and materials
* Code availability
* Authors' contributions

\noindent
If any of the sections are not relevant to your manuscript, please include the heading and write `Not applicable' for that section.


::: {.flushleft latex=true}
Editorial Policies for:

\noindent
Springer journals and proceedings: <https://www.springer.com/gp/editorial-policies>

\noindent
Nature Portfolio journals: <https://www.nature.com/nature-research/editorial-policies>

\noindent
\textit{Scientific Reports}: <https://www.nature.com/srep/journal-policies/editorial-policies>

\noindent
BMC journals: <https://www.biomedcentral.com/getpublished/editorial-policies>
:::


::: {.appendices latex=true}

# Section title of first appendix {#secA1}

An appendix contains supplementary information that is not an essential part of the text itself but which may be helpful in providing a more comprehensive understanding of the research problem or it is information that is too cumbersome to be included in the body of the paper.

For submissions to Nature Portfolio Journals please use the heading "Extended Data".  

:::

---
# Example from https://joss.readthedocs.io/en/latest/submitting.html
title: 'Gala: A Python package for galactic dynamics'
tags:
  - Python
  - astronomy
  - dynamics
  - galactic dynamics
  - milky way
authors:
  - name: Adrian M. Price-Whelan
    orcid: 0000-0003-0872-7098
    affiliation: "1, 2" # (Multiple affiliations must be quoted)
  - name: Author 2
    orcid: 0000-0000-0000-0000
    affiliation: 2
affiliations:
 - name: Lyman Spitzer, Jr. Fellow, Princeton University
   index: 1
 - name: Institution 2
   index: 2
citation_author: Price-Whelan et. al.
date: 13 August 2017
year: 2017
bibliography: paper.bib
output: rticles::joss_article
csl: apa.csl
journal: JOSS
---

# Summary

The forces on stars, galaxies, and dark matter under external gravitational
fields lead to the dynamical evolution of structures in the universe. The orbits
of these bodies are therefore key to understanding the formation, history, and
future state of galaxies. The field of "galactic dynamics," which aims to model
the gravitating components of galaxies to study their structure and evolution,
is now well-established, commonly taught, and frequently used in astronomy.
Aside from toy problems and demonstrations, the majority of problems require
efficient numerical tools, many of which require the same base code (e.g., for
performing numerical orbit integration).

``Gala`` is an Astropy-affiliated Python package for galactic dynamics. Python
enables wrapping low-level languages (e.g., C) for speed without losing
flexibility or ease-of-use in the user-interface. The API for ``Gala`` was
designed to provide a class-based and user-friendly interface to fast (C or
Cython-optimized) implementations of common operations such as gravitational
potential and force evaluation, orbit integration, dynamical transformations,
and chaos indicators for nonlinear dynamics. ``Gala`` also relies heavily on and
interfaces well with the implementations of physical units and astronomical
coordinate systems in the ``Astropy`` package [@astropy] (``astropy.units`` and
``astropy.coordinates``).

``Gala`` was designed to be used by both astronomical researchers and by
students in courses on gravitational dynamics or astronomy. It has already been
used in a number of scientific publications [@Pearson:2017] and has also been
used in graduate courses on Galactic dynamics to, e.g., provide interactive
visualizations of textbook material [@Binney:2008]. The combination of speed,
design, and support for Astropy functionality in ``Gala`` will enable exciting
scientific explorations of forthcoming data releases from the *Gaia* mission
[@gaia] by students and experts alike.

# Mathematics

Single dollars ($) are required for inline mathematics e.g. $f(x) = e^{\pi/x}$

Double dollars make self-standing equations:

$$\Theta(x) = \left\{\begin{array}{l}
0\textrm{ if } x < 0\cr
1\textrm{ else}
\end{array}\right.$$


# Citations

Citations to entries in paper.bib should be in
[rMarkdown](https://rmarkdown.rstudio.com/authoring_bibliographies_and_citations.html)
format.

For a quick reference, the following citation commands can be used:
- `@author:2001`  ->  "Author et al. (2001)"
- `[@author:2001]` -> "(Author et al., 2001)"
- `[@author1:2001; @author2:2001]` -> "(Author1 et al., 2001; Author2 et al., 2002)"

# Rendered R Figures

Figures can be plotted like so:

```{r}
plot(1:10)
```

# Acknowledgements

We acknowledge contributions from Brigitta Sipocz, Syrtis Major, and Semyeong
Oh, and support from Kathryn Johnston during the genesis of this project.

# References

---
title: "Example of journal's templates"
resource_files:
  - resources
---

```{r, setup, include = FALSE}
library(rticles)
```


```{r, child = "_child_examples.Rmd"}
```

```{r, include = FALSE}
# We generate the YAML file on the fly to render the gallery

# helper
gen_fun <- function(journal) {
  # generic case
  fun_name <- sprintf("%s_article", journal)
  out_opts <- NULL
  
  # handles special case
  if (grepl("oup_", journal)) {
    fun_name <- sprintf("oup_article")
    out_opts <- sprintf("oup_version = %s", gsub("oup_v(\\d)", "\\1", journal))
  }
  
  list(fun_name = fun_name, out_opts = out_opts)
  
}

# list of sites
articles <- lapply(journals(), function(journal) {
  name <- yaml::read_yaml(rticles:::pkg_file_template(journal, "template.yaml"))$name
  img <- file.path("resources", paste0(journal, "_article.gif"))
  href <- file.path("resources", paste0(journal, "_article.pdf"))
  repo_url <- "https://github.com/rstudio/rticles/tree/main/inst/rmarkdown/templates/"
  if (!file.exists(img) || !file.exists(href)) return(list())
  fun <- gen_fun(journal)
  list(
    title = sprintf("%s - %s", journal, name),
    yaml_format_opts = if (is.null(fun$out_opts)) "default" else c("", strwrap(sub(" = ", ": ", fun$out_opts), indent = 4)),
    yaml_format_name = fun$fun_name,
    fun = sprintf("%s()", fun$fun),
    img = img, 
    href = href,
    source = paste0(repo_url, journal)
  )
})

articles <- Filter(length, articles)
```

The examples below illustrate all the article's template included into this package. 

```{r, include = FALSE}
src <- lapply(articles, function(article) {
  glue::glue_data(article, paste(
    "## {{title}}",
    "",
    "```yaml",
    "output: ",
    "  {{yaml_format_name}}: {{glue::glue_collapse(yaml_format_opts, sep = '\n')}}",
    "```",
    "",
    "::: {.two-columns}",
    "[![]({{img}})]({{href}})",
    "",
    "* Format function: `{{fun}}`",
    "",
    "* [Template Sources]({{source}})",
    "",
    "* [PDF example]({{href}})",
    "",
    ":::",
    "\n", sep = "\n"
  ), .open = "{{", .close = "}}")
})
res <- knitr::knit_child(text = unlist(src), quiet = TRUE)
```

`r res`

```{css, echo = FALSE}
a > img {
	border: unset;
  border-style: solid;
  border-color: #FEDB00;
}

.two-columns {
  -webkit-columns: 2 300px;
  -moz-columns: 2 300px;
  columns: 2 300px;
  -webkit-column-gap: 2em;
  -moz-column-gap: 2em;
  column-gap: 2em;
}
```

---
journal: jhm
layout: draft
title: Title here
author1: Andrew N. Other
author2: Fred T. Secondauthor
currentaddress: "Current address: Some other place, Germany"
affiliation: "American Meteorological Society,Boston, Massachusetts"
exauthors: 
  - name: Ping Lu
    exaffiliation: Princeton University
    correspondingauthor: "American Meteorological Society, 45 Beacon St., Boston, MA 02108."
    email: \email{groupleader@unknown.uu}
  - name: Miao Yu
    exaffiliation: University of Waterloo
    currentaddress: "Current address: Some other place, Canada"
abstract: |
  Enter the text of your abstract here.  This is a sample American Meteorological Society (AMS) \LaTeX\ template.  This document provides authors with instructions on the use of the AMS \LaTeX\ template.  Authors should refer to the file amspaper.tex to review the actual \LaTeX\ code used to create this document. The template.tex file should be modified by authors for their own manuscript.
bibliography: amstest.bib
csl: american-meteorological-society.csl
output: rticles::ams_article
---

# Introduction

This document will provide authors with the basic American Meteorological Society (AMS) formatting guidelines. This document was created using \LaTeX\ and demonstrates how to use the \LaTeX\ template when submitting a manuscript to the AMS.  The following sections will outline the guidelines and formatting for text, math, figures, and tables while using \LaTeX\/ for a submission to the AMS. An attempt to compile amspaper.tex should be made before using the template. The files have been tested on Windows, Linux, and Mac OS using \TeX\ Live 2011 (available online at \url{http://www.tug.org/texlive/}). Feedback and questions should be sent to latex@ametsoc.org. Additional information is available on the AMS \LaTeX\ Submission Info web page (\url{http://www2.ametsoc.org/ams/index.cfm/publications/authors/journal-and-bams-authors/author-resources/latex-author-info/}).

Authors should use the empty template.tex to begin their paper. A valuable source of \LaTeX\ information is the {TeX Frequently Asked Questions} page (available online at \url{faq.tug.org}).

# Formatting text and sections

The text should be divided into sections, each with a separate heading and consecutive numbering. Note, however, that single secondary, tertiary, and quaternary sections remain unnumbered. Each section heading should be placed on a separate line using the appropriate \LaTeX\ commands.

## Secondary headings {-}

Secondary headings labeled with letters are formatted using the `## Secondary headings {-}` for a single subsection within a section or `## Secondary headings` for multiple subsections within one section.

### Tertiary headings {-}

Tertiary headings are formatted using the `### Tertiary headings {-}` for single a subsubsection within a subsection or `### Tertiary headings` for multiple subsubsections within a subsection. 

\paragraph*{Quaternary headings}
Quaternary headings are formatted using the `\paragraph*{Quaternary headings}` for a single paragraph within a subsubsection or `\paragraph{Quaternary headings}` for multiple paragraphs within a subsection.

# Citations

Citations to standard references in text should consist of the name of the author and the year of publication, for example, @poe12 or [@poe12;@alexander:2002;@Gershunov2012] using the appropriate `@key` or `[@key]` commands, respectively. A variety of citation formats can be used with the natbib package; however, the AMS prefers that authors use only the `@key` and `[@key]` commands. References should be entered in the references.bib file. For a thorough discussion of how to enter references into the references.bib database file following AMS style, please refer to the **AMS_Refs.pdf** document included in this package.

# Formatting math

The following sections will outline the basic formatting rules for mathematical symbols and units.  In addition, a review of the amspaper.tex file will show how this is done with the use of \LaTeX\ commands.  The AMS template provides the American Mathematical Society math, font, symbol, and boldface packages for use in math mode.

## Mathematical symbols

Symbols must be of the same font style both in text discussion and in displayed equations or terms (and figures should be prepared to match). Scalar single-character symbols are set italic, Greek, or script. Examples are $u$, $L$ [note that $\upsilon$ (Greek upsilon) is used instead of *v* (italic "vee") to avoid confusion with $\nu$ (Greek nu) often used for viscosity; this is handled automatically when in \LaTeX\ math mode], $w$, $x$, $y$, $z$, $f$, $g$, $r$, indices such as $i$ or $j$, and constants such as $C_D$, $k$, or $K$. Multiple-character scalar variables, abbreviations, nondimensional numbers, and acronyms for variables are set regular nonitalic: $\mathrm{LWC}$, $\mathrm{Re}$, $\mathrm{Ro}$, $\mathrm{BT}$, $\mathrm{abs}$, $\mathrm{obs}$, $\mathrm{max}$, $\mathrm{min}$, $\mathrm{Re}$/$\mathrm{Im}$ (real/imaginary), etc. For vectors, use boldface nonitalic Times Roman as in $\mathbf{V}$, $\mathbf{v}$, or $\mathbf{x}$, and $\mathbf{i}$, $\mathbf{j}$, and $\mathbf{k}$ unit vectors. Do not use the \LaTeX\ $\backslash vec$ command to denote vectors. For matrix notation, use nonitalic boldface Arial (or sans serif) font as in $\pmb{\mathsf{A}}$, $\pmb{\mathsf{B}}$, or $\pmb{\mathsf{M}}$. Note that you will need to use the $\backslash$pmb command for boldface sans serif; the $\backslash$bm command will not work. All mathematical operator abbreviations/acronyms are set lowercase regular Roman font, except $O$ (on the order of): $\sin$, $\cos$, $\tan$, $\tanh$, $\mathrm{cov}$, $\Pr$ (for probability; note same as Prandtl number), $\mathrm{const}$ (for constant), $\mathrm{c.c.}$ (complex conjugate).

## Units

Units are always set on a single line with a space separating the denominator, which is set with a superscript $-1$, $-2$, and so on, rather than using a slash for "per." Examples are g kg$^{-1}$, m$^2$ s$^{-1}$, Wm$^{-2}$, g m$^{-3}$, and m s$^{-1}$ (note that ms$^{-1}$ is the unit for "per millisecond").

## Equations

Brief equations or terms set inline in text must be set as a single-line expression because page proofs are not double spaced, for example, $\rho^{-1}p/x$ or $(1/{\rho})p/x$ or $(a-b)/(c+d)$; that is, use a superscript $-1$ for the denominator. In case of a more complicated term or equation, it should be set as an unnumbered display equation, such as

$$
x=\frac{2b\pm\sqrt{b^{2}-4ac}}{2c}.
$$

Otherwise, numbered display equations can be entered using the appropriate equation command, such as 

\begin{equation}
x=\frac{2b\pm\sqrt{b^{2}-4ac}}{2c}.  
\end{equation}

Lists of equations are punctuated as written English, and commas, semicolons, and periods are placed where appropriate. Conjunctions such as "and", "while", "when", or "for" are also typically placed before the final element in a mathematical phrase, as befits the intended mathematical meaning.  

## Figures and tables

The AMS prefers that all figures and tables are placed **at the end of the document** prior to submission. A list of tables and a list of figures will appear near the end of the PDFfile, before the actual tables and figures. These lists are necessary for submission.

For appendix figures and tables, special commands are needed to manually change the numbering to ensure that each appendix figure or table is numbered as part of the respective appendix and not as a continuation of the main paper. Use the command `\appendcaption{}` instead of the usual `caption{}` to adjust the  numbering; for example, for Table A1, you would use the command `\appendcaption{A1}`.

Note that the normal `\ref{}` command cannot be used to cite appendix figures and tables as the numbering will be incorrect. Callouts for appendix figures and tables in the text will need to be written out as plain text, for example, Fig. A1 and Table A1.

### Figures

The insertion of a sample figure (Fig. \ref{f1})  
and caption is given below (in the .tex document) and at the end of the document. Standard figure sizes are 19 (one column), 27, 33, and 39 (two columns) picas.

\begin{figure}[h]
 \centerline{\includegraphics[width=19pc]{figure01.pdf}}
  \caption{Enter the caption for your figure here.  Repeat as
  necessary for each of your figures.}\label{f1}
\end{figure}

```{r,echo=FALSE,fig.cap='test the rmd output',fig.align='center',fig.width=3.17}
plot(1:10)
```

### Tables
Each table must be numbered, provided with a caption, and mentioned specifically in the text. 
See below (in the .tex document) and at the end of the document for the formatting of a sample table (Table
\ref{t1}).

\begin{table}[h]
\caption{This is a sample table caption and table layout.}\label{t1}
\begin{center}
\begin{tabular}{ccccrrcrc}
\topline
$N$ & $X$ & $Y$ & $Z$\\
\midline
 0000 & 0000 & 0010 & 0000 \\
 0005 & 0004 & 0012 & 0000 \\
 0010 & 0009 & 0020 & 0000 \\
 0015 & 0016 & 0036 & 0002 \\
 0020 & 0030 & 0066 & 0007 \\
 0025 & 0054 & 0115 & 0024 \\
\botline
\end{tabular}
\end{center}
\end{table}

\acknowledgments
Keep acknowledgments (note correct spelling: no e between the g and m) as brief as possible. In general, acknowledge only direct help in writing or research. Financial support (e.g., grant numbers) for the work done, for an author, or for the laboratory where the work was performed is best acknowledged here rather than as footnotes to the title or to an author's name. Contribution numbers (if the work has been published by the author's institution or organization) should be included as footnotes on the title page,
not in the acknowledgments.

Please use The authors thank \ldots rather than The authors would like to thank \ldots.

The author thanks Mats Dahlgren for version one of \textsf{achemso}, and Donald Arseneau for the code taken from \textsf{cite} to move citations after punctuation. Many users have provided feedback on the class, which is reflected in all of the different demonstrations shown in this document.

\appendix[A] 

\appendixtitle{Title of Appendix}

## Appendix section

The AMS template allows authors to format an unlimited number of appendixes. To format a single appendix, use the `\appendix` command with no additional argument. Otherwise, add the appropriate one-letter argument to the `\appendix` command (e.g. `\appendix[A]`, `\appendix[B]`, `\appendix[C]`, etc.) corresponding to the appropriate appendix. 

The title of the appendix can be formatted using the `\appendixtitle{} ` command. The `##` , `###` and `\paragraph` commands are used to create sections within the appendix. (Note that the appendix title takes the place of `#` in the appendix, so the first section should begin with `##` instead of `#`.)

Equations are automatically numbered appropriately for each appendix. Here is an example of the first equation in appendix A, automatically labeled (\ref{eq:1}): 

\begin{equation}
\label{eq:1}
x=\frac{2b\pm\sqrt{b^{2}-4ac}}{2c}.  
\end{equation}

For appendix figures and tables, special commands are needed to manually change the numbering to ensure that each appendix figure or table is numbered as part of the appendix and not as a continuation of the main paper. Use the command `\appendcaption{}` instead of the usual `\caption{}` to adjust the numbering; for example, for Table A1, you would use the command `\appendcaption{A1}`. In-text callouts for each appendix figure and table will need to be written as plain text;the usual `\ref{}` command cannot be used.

\appendix[B]
\appendixtitle{File Structure of the AMS \LaTeX\ Package}

## AMS \LaTeX\ files
You will be provided with a tarred, zipped \LaTeX\ package containing 3 files. These files are

\begin{description}

\item
  your-paper-name.Rmd template for your paper
\item
  amstest.bib an example of a bibliographic database file.
\item
  figure01.pdf are sample figures.

\end{description}

## Help for Authors

Questions and feedback concerning the use of the AMS \LaTeX\ files should be directed to latex@ametsoc.org or yufreecas@gmail.com(for rmarkdown issues). Additional information is available on the AMS \LaTeX\ Submission Info web page (\url{http://www2.ametsoc.org/ams/index.cfm/publications/authors/journal-and-bams-authors/author-resources/latex-author-info/}).

\appendix[C]
\appendixtitle{Building a PDF and Submitting Your \LaTeX\ Manuscript Files to the AMS}

## Building your own PDF

There are a variety of different methods and programs that will create a final PDF from your \LaTeX\ files. The easiest method is to download one of the freely available text editors/compilers such as Rstudio to compile your files into a PDF.

## Submitting your files to the AMS for peer review

The AMS uses the Editorial Manager system for all author submissions for peer review. Editorial Manager uses the freely available \TeX\ Live 2011 distribution. This system will automatically generate a PDF from your submitted \LaTeX\ files and figures(not Rmd file, tex files will be produced when you successful knit your Rmd file).  

You should not upload your own PDF into the system. If the system does not build the PDF from your files correctly, refer to the AMS \LaTeX\ FAQ page first for possible solutions. If your PDF still does not build correctly after trying the solutions on the FAQ page, email latex@ametsoc.org for help.

## Other software
As mentioned above, there is a variety of software that can be used to edit .tex files and build a PDF.  The AMS does not support \LaTeX\/-related WYSIWYG software, such as Scientific Workplace, or WYSIWYM software, such as LyX.  \TeX\ Live (available online at \\ \url{http://www.tug.org/texlive/}) is recommended for users needing an up-to-date \LaTeX\ distribution with software that includes an editor and the ability to automatically generate a PDF.

# References {-}
\bibliography{references}

\begin{table}
\appendcaption{A1}{Here is the appendix table caption.}
\centering
\begin{tabular}{ccc}
\topline
$1$ & $2$ & $3$ \\
\midline
a&b&c \\
d&e&f \\
\botline
\end{tabular}
\end{table}

\begin{figure}
\centerline{(illustration here)}
\appendcaption{A1}{Here is the appendix figure caption.}
\end{figure}

\begin{figure}
\centerline{(illustration here)}
\appendcaption{B1}{Here is the appendix figure caption.}
\end{figure}

---
title: Template for preparing your research report submission to PeerJ using RMarkdown
preprint: false
author: 
  - name: Barbara McClintock
    affiliation: 1
    corresponding: true
    email: mcclintockb@cshl.edu
  - name: Charles E. Darwin
    affiliation: 2
affiliation:
  - code: 1
    address: Cold Spring Harbor Laboratory, One Bungtown Road Cold Spring Harbor, NY 11724
  - code: 2
    address: Down House, Luxted Rd, Downe, Orpington BR6 7JT, UK
abstract: >
  The abstract of the article.
  It can also be on *multiple* lines.
bibliography: sample.bib
output:
  rticles::peerj_article: default
  bookdown::pdf_book:
    base_format: rticles::peerj_article # for using bookdown features like \@ref()
---


# Introduction {-}

Your introduction goes here! Some examples of commonly used commands and features are listed below, to help you get started.

If you have a question, please use the help menu in the top right of the screen to get in touch. When your article or pre-print is complete, use the "Submit to PeerJ" button in the topbar to send your files to PeerJ.

## About PeerJ {-}

PeerJ is an award-winning open access publisher covering the biological and medical sciences.  PeerJ provides authors with three publication venues: *PeerJ* and *PeerJ Computer Science* (peer-reviewed academic journals) and *PeerJ PrePrints* (a 'pre-print server'). See https://peerj.com/about/publications/ for more information.

The PeerJ model allows an author to publish articles in their peer-reviewed journal via the purchase of a lifetime Publication Plan. Prices start from just \$99 (a one-off payment) which entitles an author to the lifetime ability to publish 1 article per year for free. Publication in PeerJ PrePrints is entirely free.

# Some \LaTeX{} Examples {-}

Use section and subsection commands to organize your document. \LaTeX{} handles all the formatting and numbering automatically. Use ref and label commands for cross-references.

## Figures and Tables {-}

Use the table and tabular commands for basic tables --- see Table \@ref(tab:widgets), for example. You can upload a figure (JPEG, PNG or PDF) using the project menu. To include it in your document, use the includegraphics command as in the code for Figure \@ref(fig:view) below.

Standard \LaTeX references will work as well (e.g. Fig. \ref{fig:view}).

<!-- There are three ways to include figures: -->
<!-- 1. The LaTeX way -->
<!-- 

\begin{figure}[ht]
\centering
\includegraphics[width=\linewidth]{view}
\caption{An example image.}
\label{fig:view}
\end{figure} 

 -->

<!-- 2. The RMarkdown way -->

```{r view, out.width = "100%", fig.cap = "An example image.", echo = FALSE}
knitr::include_graphics("view.jpg")
```


<!-- 3. The pandoc way -->
<!-- 

![An example image. Text *can* be processed with markdown.](view.jpg){#view width = 100%}

 -->

<!-- 
\begin{table}[ht]
\centering
\begin{tabular}{l|r}
Item & Quantity \\\hline
Widgets & 42 \\
Gadgets & 13
\end{tabular}
\caption{\label{tab:widgets}An example table.}
\end{table}
-->

Item     Quantity
------- ---------
Widgets        42
Gadgets        13

Table: (\#tab:widgets) An Example Table.

## Citations {-}

LaTeX formats citations and references automatically using the bibliography records in your .bib file, which you can edit via the project menu. Use the cite command for an inline citation, like @Figueredo:2009dg, and the citep command for a citation in parentheses [@Figueredo:2009dg].

## Mathematics {-}

\LaTeX{} is great at typesetting mathematics. Let $X_1, X_2, \ldots, X_n$ be a sequence of independent and identically distributed random variables with $\text{E}[X_i] = \mu$ and $\text{Var}[X_i] = \sigma^2 < \infty$, and let
$$S_n = \frac{X_1 + X_2 + \cdots + X_n}{n}
      = \frac{1}{n}\sum_{i}^{n} X_i$$
denote their mean. Then as $n$ approaches infinity, the random variables $\sqrt{n}(S_n - \mu)$ converge in distribution to a normal $\mathcal{N}(0, \sigma^2)$.

## Lists {-}

You can make lists with automatic numbering \dots


1. Like this,
1. and like this.

or bullet points...

- Like this,
- and like this.

or with descriptions...

- **Word** Definition
- **Concept** Explanation
- **Idea** Text


We hope you find write\LaTeX\ useful for your PeerJ submission, and please let us know if you have any feedback. Further examples with dummy text are included in the following pages.

# Methods {-}

This is an equation inserted using LaTeX syntax directly.

\begin{equation}
\cos^3 \theta =\frac{1}{4}\cos\theta+\frac{3}{4}\cos 3\theta
\label{eq:refname2}
\end{equation}

You can also use `$$..$$` to achieve the same

$$
\cos^3 \theta =\frac{1}{4}\cos\theta+\frac{3}{4}\cos 3\theta
$$

## Subsection {-}

Use `{-}` after a header section so that it is unnumbered.

#### Paragraph  

Header level 4 are equivalent to `\paragraph{}`

## Subsection {-}


You can insert figure using R code chunk with different options

```{r results, fig.width = 5, fig.height = 4, out.width = "100%", fig.cap = "In-text Picture", echo = FALSE}
time = seq(1.5, 8, 0.1)
plot(time, sin(time), type = "l", xlab = "time [s]", ylab = "amplitude [m]", 
     cex.main = 2, col = "blue", lwd = 3, font = 2, font.main = 2)
```


You can reference figure if you use **bookdown** format extensions as shown in YAML header

# Results and Discussion {-}

This is another section

## Subsection {-}

Which shows level 2

### Subsubsection {-}

And level 3 headers

### Subsubsection {-}

with multiple subsubsections

## Subsection {-}

and subsections

# Acknowledgments {-}

So long and thanks for all the fish.

# References

---
title: "Article Title"
runtitle: "Short Title"
documentclass: FrontiersinHarvard # for articles in journals using the Harvard Referencing Style (Author-Date), for Frontiers Reference Styles by Journal: https://zendesk.frontiersin.org/hc/en-us/articles/360017860337-Frontiers-Reference-Styles-by-Journal
# documentclass: FrontiersinVancouver # for articles in journals using the Vancouver Reference Style (Numbered), for Frontiers Reference Styles by Journal: https://zendesk.frontiersin.org/hc/en-us/articles/360017860337-Frontiers-Reference-Styles-by-Journal
# documentclass: frontiersinFPHY_FAMS # Vancouver Reference Style (Numbered) for articles in the journals "Frontiers in Physics" and "Frontiers in Applied Mathematics and Statistics" 
classoption: utf8
author:
  - name: First Author
    affiliation: '1'
    etal: LASTNAME # First author's last name. 
  - name: Co-Author
    affiliation: '2'
  - name: Co-Author
    affiliation: '1,3'
    email: email@uni.edu # Indicates corresponding Author
    institution: Laboratory X, Institute X, Department X, Organization X
    street: Street X
    city: City X
    state: State XX # only USA, Australia, Canada
    zip: Zip Code X
    country: Country X
affiliation:
  - id: '1'
    department: Department X
    institution: Institution X
    city: City X
    state: State XX # only USA, Australia, Canada
    country: Country X
  - id: '2' 
    department: Department X
    institution: Institution X
    city: City X
    state: State XX # only USA, Australia, Canada
    country: Country X
  - id: '3' 
    department: Department X
    institution: Institution X
    city: City X
    state: State XX # only USA, Australia, Canada
    country: Country X
# Abstract can also be provided at the 
abstract: |
  Abstract length and content varies depending on article type. Refer to 
  <http://www.frontiersin.org/about/AuthorGuidelines> for abstract requirement
  and length according to article type.
keywords: # All article types: you may provide up to 8 keywords; at least 5 are mandatory.
  - kw1
  - kw2
  - kw3
  - kw4
  - kw5
output: rticles::frontiers_article
# csl: frontiers.csl
bibliography: test.bib
# Match bibliostyle with the documentclass
biblio-style: Frontiers-Harvard # Many Frontiers journals use the Harvard referencing system (Author-date), to find the style and resources for the journal you are submitting to: https://zendesk.frontiersin.org/hc/en-us/articles/360017860337-Frontiers-Reference-Styles-by-Journal. For Humanities and Social Sciences articles please include page numbers in the in-text citations 
#biblio-style: Frontiers-Vancouver # Many Frontiers journals use the numbered referencing system, to find the style and resources for the journal you are submitting to: https://zendesk.frontiersin.org/hc/en-us/articles/360017860337-Frontiers-Reference-Styles-by-Journal
---

# Introduction {-}
Cite fancy references [@Neuro2013]. As demonstrated in @Gene2012, citations can
also be automatically reference. Multiple references are separated by semicolons
[@Neuro2013; @Neurobot2013].

# Results {-}

<!-- Comments should be HTML-style comments -->

## Subsection 1 {-}

You can use `R` chunks directly to plot graphs.  

```{r graph, echo = TRUE, message=FALSE, fig.show = "hide"}
x <- 0:100
set.seed(999)
y <- 2 * (x + rnorm(length(x), sd = 3) + 3)
plot(x, y)
```

## Subsection 2 {-}

Frontiers requires figures to be submitted individually, in the same order as
they are referred to in the manuscript. Figures will then be automatically
embedded at the bottom of the submitted manuscript. Kindly ensure that each
table and figure is mentioned in the text and in numerical order. Permission
must be obtained for use of copyrighted material from other sources (including
the web). Please note that it is compulsory to follow figure instructions.
Figures which are not according to the guidelines will cause substantial delay
during the production process.

# Discussion

# Disclosure/Conflict-of-Interest Statement {-}

<!--  
Frontiers follows the recommendations by the International Committee of Medical
Journal Editors (http://www.icmje.org/ethical_4conflicts.html) which require
that all financial, commercial or other relationships that might be perceived by
the academic community as representing a potential conflict of interest must be
disclosed. If no such relationship exists, authors will be asked to declare that
the research was conducted in the absence of any commercial or financial
relationships that could be construed as a potential conflict of interest. When
disclosing the potential conflict of interest, the authors need to address the
following points:

 - Did you or your institution at any time receive payment or services from a
   third party for any aspect of the submitted work?
 - Please declare financial relationships with entities that could be perceived
   to influence, or that give the appearance of potentially influencing, what
   you wrote in the submitted work.
 - Please declare patents and copyrights, whether pending, issued, licensed
   and/or receiving royalties relevant to the work.
 - Please state other relationships or activities that readers could perceive to
   have influenced, or that give the appearance of potentially influencing, what
   you wrote in the submitted work.
 -->

The authors declare that the research was conducted in the absence of any
commercial or financial relationships that could be construed as a potential
conflict of interest.

# Author Contributions {-}

<!--  

When determining authorship the following criteria should be observed:

 - Substantial contributions to the conception or design of the work; or the
   acquisition, analysis, or interpretation of data for the work; AND
 - Drafting the work or revising it critically for important intellectual
   content; AND
 - Final approval of the version to be published ; AND
 - Agreement to be accountable for all aspects of the work in ensuring that
   questions related to the accuracy or integrity of any part of the work are
   appropriately investigated and resolved.

Contributors who meet fewer than all 4 of the above criteria for authorship
should not be listed as authors, but they should be acknowledged.
(http://www.icmje.org/roles_a.html)

-->

The statement about the authors and contributors can be up to several sentences
long, describing the tasks of individual authors referred to by their initials
and should be included at the end of the manuscript before the References
section.


# Acknowledgments {-}

Funding:

# Supplemental Data {-}

Supplementary Material should be uploaded separately on submission, if there are
Supplementary Figures, please include the caption in the same file as the
figure. LaTeX Supplementary Material templates can be found in the Frontiers
LaTeX folder

---
title: An Rticles Template for the Transport Research Board Annual Meeting
runningheader: "Anonymous, Security, and Zoolander"
author:
  - name: Alice Anonymous
    note: Corresponding Author
    position: Graduate Student
    email: alice@example.com
    affiliation: Some Institute of Technology
  - name: Bob Security
    position: Assistant Professor
    email: bob@example.com
    affiliation: State University
  - name: Derek Zoolander
    position: Professor
    email: derek@example.com
    affiliation: Some Institute of Technology
abstract: |
  The Transportation Research Board (TRB) has unique and seemingly arbitrary requirements for manuscripts submitted for review. These requirements make it difficult to write the manuscripts quickly, and no existing \LaTeX\ style comes close to fooling the guidelines. This represents an initial effort at creating a template to meet the requirements of TRB authors using \LaTeX, R, Sweave, and/or other literate programming software.
  
keywords: ["Transportation", "Travel Behavior"]
bibliography: mybibfile.bib
biblio-style: unsrtnat
classoption:
  - numbered #  When numbered option is activated, lines are numbered.
output: rticles::trb_article
wordcount: 684
---

```{r setup, include = FALSE}
knitr::opts_chunk$set(echo = FALSE)
```


# Transportation Research Board Annual Meetings

TRB has greatly simplified the submissions to its system, meaning that this
template is no longer strictly required. However, there is a typical format
that most people still use by default, and this template implements that change.


# Features

The template has a number of features that enable quick and painless manuscript authoring.

## Mathematics

Standard pandoc / \LaTeX math environments are available.  For example, the
probability of an individual choosing alternative $i$ in a multinomial logit
model is
\begin{equation}
  P_i = \frac{exp(V_i)}{\sum_{i, j \in J}exp(V_j)} \label{eq:mnl}
\end{equation}
Equations with a `\label{eq:label}` can be referred to later in the text with
`\ref{eq:label}`, such as Equation \ref{eq:mnl}.

## Title Page

The template will automatically create a title page with the authors in the
listed order.  Near the bottom of the title page, TRB requires a count of the manuscript's
words and tables. The YAML header information contains a `wordcount` key where
this can be encoded. The number of tables is counted automatically on build; 
a default 250 words per table can be overriden with the `wordspertable` YAML
key.

The LaTeX template available from <https://github.com/chiehrosswang/TRB_LaTeX_tex>
contain automatic word counters that have not been implemented in this `rticles`
template. Authors can use the R Studio word count add-in available from
<https://github.com/benmarwick/wordcountaddin>.

## Page Layout

The document has 1 inch margins as required, with the author's names in the left
heading and the page number in the right. The running header information is set
with the `runningheader` YAML key. Paragraphs leading sections and subsections
are not indented, while all subsequent paragraphs in that section are. Section
heading types are defined as outlined by the old TRB Author's Guide.

The document is single-spaced in 12 point Times font. Times New Roman is a
proprietary font and is therefore not available by installation in open-source
software. While the differences between Times variants are negligible, Times New
Roman itself can be used in Mac OSX by compiling under `xelatex`.

## Figure and Table references

The document can use standard pandoc referencing tools for in-text
citations to figures and tables. If an R code chunk outputs a figure, the figure
number can be referred to with `\@ref(fig:chunkname)` where `chunkname` is the
name of the chunk that prints the figure.  For example, Figure \@ref(fig:figure-example)
shows a default figure made by the R chunk below.

```{r figure-example, fig.cap="Generic plot.", echo = TRUE}
# Generate some sample data, then compute mean and standard deviation
# in each group
Speed <- cars$speed
Distance <- cars$dist
plot(Speed, Distance,
     panel.first = lines(stats::lowess(Speed, Distance), lty = "dashed"),
     pch = 0, cex = 1.2, col = "blue")
```

The template setup chunk sets `echo = FALSE` for the entire document, as printing
code listings would not usually be appropriate or needed for a TRB article. But
the option is there!

The same referencing logic works for tables, with the `tab:` prefix on the
chunk name instead of `fig:` used for figures. Table \@ref(tab:table-example)
has a basic table. We recommend the `kableExtra` package for formatting 
publication-ready tables with greater control than the default `knitr::kable()`
function.

```{r table-example}
knitr::kable(mtcars[1:5, 1:6], format = "latex", table.envir = "table", 
             booktabs = TRUE, caption = "Example Table") 
```


## Bibliography styles

TRB still wants numbered, unsorted citations beginning on a new page. The
template is configured to use `natbib` with the `unsrtnat` citation style, with
some additional logic to use parentheses instead of brackets. The YAML key
`biblio-style` will allow the authors to select a different citation format, but
this is not recommended at the moment. Citations use the pandoc logic. Including
the reference in brackets `[@reference]` will print only the numeric reference;
e.g. [@Feynman1963118; @Dirac1953888]. Including the reference without brackets
`@reference` will print the authors and then the numeric reference; e.g.
@Feynman1963118.

# Author Contribution Statement

The authors confirm contribution to the paper as follows: study conception and
design: A. Anonymous, D. Zoolander; data collection: B. Security; analysis and
interpretation of results: A. Anonymous, B. Security; draft manuscript
preparation: A. Anonymous. All authors reviewed the results and approved
the final version of the manuscript.

# Acknowledgements

David Pritchard posted the original versions of this template in 2009 and
updated it in 2011, soon after TRB began allowing PDF submissions. Gregory
Macfarlane and Ross Wang made adjustments to the template, and Ross Wang now
maintains the \LaTeX template at
<https://github.com/chiehrosswang/TRB_LaTeX_tex>. Gregory Macfarlane created the `rticles` template in 2021.


# References {#references }

---
journal: jacsat
type: article
author:
  - name: Andrew N. Other
    altaff: A shared footnote
  - name: Fred T. Secondauthor
    altaff: "Current address: Some other place, Germany"
  - name: I. Ken Groupleader
    altaff: A shared footnote
    email: \email{i.k.groupleader@unknown.uu}
    phone: +123 (0)123 4445556
    fax: +123 (0)123 4445557
    aff: Department of Chemistry, Unknown University, Unknown Town
    alsoaff: Department of Chemistry, Second University, Nearby Town
  - name: Susanne K. Laborator
    email: \email{s.k.laborator@bigpharma.co}
    aff: Lead Discovery, BigPharma, Big Town, USA
  - name: Kay T. Finally
    aff: Department of Chemistry, Unknown University, Unknown Town
    alsoaff: Department of Chemistry, Second University, Nearby Town
title:
  formatted: A demonstration of the \textsf{achemso} \LaTeX\
   class\footnote{A footnote for the title}
  short: An \textsf{achemso} demo
abbr: IR,NMR,UV
keywords: American Chemical Society, \LaTeX
abstract: |
  This is an example document for the \textsf{achemso} documentclass, intended for submissions to the American Chemical Society for publication. The class is based on the standard \LaTeXe\ \textsf{report} file, and does not seek to reproduce the appearanceof a published paper.

  This is an abstract for the \textsf{achemso} document class demonstration document.  An abstract is only allowed for certain manuscript types.  The selection of \texttt{journal} and \texttt{manuscript} will determine if an abstract is valid.  If not, the class will issue an appropriate error.This is the abstract.

bibliography: acstest.bib
csl: american-chemical-society.csl
output: rticles::acs_article
---

\begin{tocentry}
Some journals require a graphical entry for the Table of Contents.
This should be laid out ``print ready'' so that the sizing of the
text is correct.

Inside the \texttt{tocentry} environment, the font used is Helvetica
8\,pt, as required by \emph{Journal of the American Chemical
Society}.

The surrounding frame is 9\,cm by 3.5\,cm, which is the maximum
permitted for  \emph{Journal of the American Chemical Society}
graphical table of content entries. The box will not resize if the
content is too big: instead it will overflow the edge of the box.

This box and the associated title will always be printed on a
separate page at the end of the document.
\end{tocentry}

# Introduction
This is a paragraph of text to fill the introduction of the
demonstration file.  The demonstration file attempts to show the
modifications of the standard \LaTeX\ macros that are implemented by
the \textsf{achemso} class.  These are mainly concerned with content,
as opposed to appearance.

# Results and discussion

## Outline

The document layout should follow the style of the journal concerned.
Where appropriate, sections and subsections should be added in the
normal way. If the class options are set correctly, warnings will be
given if these should not be present.

## References

The class makes various changes to the way that references are
handled.  The class loads \textsf{natbib}, and also the
appropriate bibliography style.  References can be made using
the normal method; the citation should be placed before any
punctuation, as the class will move it if using a superscript
citation style [@Garnier2007].
The use of \textsf{natbib} allows the use of the various citation
commands of that package have shown
something.  Long lists of authors will be
automatically truncated in most article formats, but not in
supplementary information or reviews. If you
encounter problems with the citation macros, please check that
your copy of \textsf{natbib} is up to date. The demonstration
database file \texttt{achemso-demo.bib} shows how to complete
entries correctly. Notice that ``\latin{et al.}'' is auto-formatted
using the \texttt{\textbackslash latin} command.

Multiple citations to be combined into a list can be given as
a single citation.  This uses the \textsf{mciteplus} package.
Citations other than the first of the list should be indicated
with a star.

The class also handles notes to be added to the bibliography.  These
should be given in place in the document.  As with
citations, the text should be placed before punctuation.  A note is
also generated if a citation has an optional note.  This assumes that
the whole work has already been cited: odd numbering will result if
this is not the case .

## Floats

New float types are automatically set up by the class file.  The
means graphics are included as follows (Scheme \ref{sch:example}).  As
illustrated, the float is ``here'' if possible.
\begin{scheme}
  Your scheme graphic would go here: \texttt{.eps} format\\
  for \LaTeX\, or \texttt{.pdf} (or \texttt{.png}) for pdf\LaTeX\\
  \textsc{ChemDraw} files are best saved as \texttt{.eps} files:\\
  these can be scaled without loss of quality, and can be\\
  converted to \texttt{.pdf} files easily using \texttt{eps2pdf}.\\
  %\includegraphics{graphic}
  \caption{An example scheme}
  \label{sch:example}
\end{scheme}

```{r,echo=FALSE,fig.cap='test'}
plot(1:10)
```

\begin{figure}
  As well as the standard float types \texttt{table}\\
  and \texttt{figure}, the class also recognises\\
  \texttt{scheme}, \texttt{chart} and \texttt{graph}.
  \caption{An example figure}
  \label{fgr:example}
\end{figure}

Charts, figures and schemes do not necessarily have to be labelled or
captioned.  However, tables should always have a title. It is
possible to include a number and label for a graphic without any
title, using an empty argument to the \texttt{\textbackslash caption}
macro.

The use of the different floating environments is not required, but
it is intended to make document preparation easier for authors. In
general, you should place your graphics where they make logical
sense; the production process will move them if needed.

## Math(s)

The \textsf{achemso} class does not load any particular additional
support for mathematics.  If packages such as \textsf{amsmath} are
required, they should be loaded in the preamble.  However,
the basic \LaTeX\ math(s) input should work correctly without
this.  Some inline material $y = mx + c$ or $1 + 1 = 2$
followed by some display. $$ A = \pi r^2 $$

It is possible to label equations in the usual way (Eq. \ref{eqn:example}).
\begin{equation}
  \frac{\mathrm{d}}{\mathrm{d}x} \, r^2 = 2r \label{eqn:example}
\end{equation}
This can also be used to have equations containing graphical
content. To align the equation number with the middle of the graphic,
rather than the bottom, a minipage may be used.
\begin{equation}
  \begin{minipage}[c]{0.80\linewidth}
    \centering
    As illustrated here, the width of \\
    the minipage needs to allow some  \\
    space for the number to fit in to.
    %\includegraphics{graphic}
  \end{minipage}
  \label{eqn:graphic}
\end{equation}

# Experimental

The usual experimental details should appear here.  This could
include a table, which can be referenced as Table \ref{tbl:example}.
Notice that the caption is positioned at the top of the table.
\begin{table}
  \caption{An example table}
  \label{tbl:example}
  \begin{tabular}{ll}
    \hline
    Header one  & Header two  \\
    \hline
    Entry one   & Entry two   \\
    Entry three & Entry four  \\
    Entry five  & Entry five  \\
    Entry seven & Entry eight \\
    \hline
  \end{tabular}
\end{table}

Adding notes to tables can be complicated.  Perhaps the easiest
method is to generate these using the basic
\texttt{\textbackslash textsuperscript} and
\texttt{\textbackslash emph} macros, as illustrated (Table \ref{tbl:notes}).
\begin{table}
  \caption{A table with notes}
  \label{tbl:notes}
  \begin{tabular}{ll}
    \hline
    Header one                            & Header two \\
    \hline
    Entry one\textsuperscript{\emph{a}}   & Entry two  \\
    Entry three\textsuperscript{\emph{b}} & Entry four \\
    \hline
  \end{tabular}

  \textsuperscript{\emph{a}} Some text;
  \textsuperscript{\emph{b}} Some more text.
\end{table}

The example file also loads the optional \textsf{mhchem} package, so
that formulas are easy to input: \texttt{\textbackslash ce\{H2SO4\}}
gives \ce{H2SO4}.  See the use in the bibliography file (when using
titles in the references section).

The use of new commands should be limited to simple things which will
not interfere with the production process.  For example,
\texttt{\textbackslash mycommand} has been defined in this example,
to give italic, mono-spaced text: \mycommand{some text}.

# Extra information when writing JACS Communications

When producing communications for \emph{J.~Am.\ Chem.\ Soc.}, the
class will automatically lay the text out in the style of the
journal. This gives a guide to the length of text that can be
accommodated in such a publication. There are some points to bear in
mind when preparing a JACS Communication in this way.  The layout
produced here is a \emph{model} for the published result, and the
outcome should be taken as a \emph{guide} to the final length. The
spacing and sizing of graphical content is an area where there is
some flexibility in the process.  You should not worry about the
space before and after graphics, which is set to give a guide to the
published size. This is very dependant on the final published layout.

You should be able to use the same source to produce a JACS
Communication and a normal article.  For example, this demonstration
file will work with both \texttt{type=article} and
\texttt{type=communication}. Sections and any abstract are
automatically ignored, although you will get warnings to this effect.

\begin{acknowledgement}

Please use ``The authors thank \ldots'' rather than ``The
authors would like to thank \ldots''.

The author thanks Mats Dahlgren for version one of \textsf{achemso},
and Donald Arseneau for the code taken from \textsf{cite} to move
citations after punctuation. Many users have provided feedback on the
class, which is reflected in all of the different demonstrations
shown in this document.

\end{acknowledgement}

\begin{suppinfo}

This will usually read something like: ``Experimental procedures and
characterization data for all new compounds. The class will
automatically add a sentence pointing to the information on-line:

\end{suppinfo}
## References

---
title: A demonstration of the \LaTeX class file for Statistics in Medicine with Rmarkdown
runningtitle: How to use
author:
- name: A. Uthor*
  num: a,b
- name: O. Tro
  num: b
- name: O. Vriga
  num: c
address:
- num: a
  org: Department of Incredible Research, University A, City A, Country A
- num: b
  org: Department of Applied Things, University B, City B, Country B
- num: c
  org: Very Important Stuff Committee, Institute C, City C, Country C
corres: "*Corresponding author name, This is sample corresponding address. \\email{authorone@gmail.com}"
presentaddress: This is sample for present address text this is sample for present address text
authormark: Uthor \emph{et al}.
articletype: Research article
abbreviations:
  - ANA, anti-nuclear antibodies
  - APC, antigen-presenting cells
  - IRF, interferon regulatory factor.
abstract: "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean ut elit odio. Donec fermentum tellus neque, vitae fringilla orci pretium vitae. Fusce maximus finibus facilisis. Donec ut ullamcorper turpis. Donec ut porta ipsum. Nullam cursus mauris a sapien ornare pulvinar. Aenean malesuada molestie erat quis mattis. Praesent scelerisque posuere faucibus. Praesent nunc nulla, ullamcorper ut ullamcorper sed, molestie ut est. Donec consequat libero nisi, non semper velit vulputate et. Quisque eleifend tincidunt ligula, bibendum finibus massa cursus eget. Curabitur aliquet vehicula quam non pulvinar. Aliquam facilisis tortor nec purus finibus, sit amet elementum eros sodales. Ut porta porttitor vestibulum. Integer molestie, leo ut maximus aliquam, velit dui iaculis nibh, eget hendrerit purus risus sit amet dolor. Sed sed tincidunt ex. Curabitur imperdiet egestas tellus in iaculis. Maecenas ante neque, pretium vel nisl at, lobortis lacinia neque. In gravida elit vel volutpat imperdiet. Sed ut nulla arcu. Proin blandit interdum ex sit amet laoreet. Phasellus efficitur, sem hendrerit mattis dapibus, nunc tellus ornare nisi, nec eleifend enim nibh ac ipsum. Aenean tincidunt nisl sit amet facilisis faucibus. Donec odio erat, bibendum eu imperdiet sed, gravida luctus turpis."
keywords: Class file; \LaTeX; Statist. Med.; Rmarkdown;
bibliography: bibfile.bib
output: rticles::sim_article
---

# The Article Header Information

YAML header:

```
output:
  rticles::sim_article:
    keep_tex: TRUE
```

Configure the YAML header including the following elements:

* `title`: Title

* `author`: List of author(s) containing `name` and `num`

* `address`: List containing `num` and `org` for defining `author` affiliations

* `presentaddress`: Not sure what they mean with this

* `corres`: Author and address for correspondence

* `authormark`: Short author list for header

* `received`, `revised`, `accepted`: dates of submission, revision, and acceptance of the manuscript

* `abstract`: Limited to 250 words

* `keywords`: Up to 6 keywords

* `bibliography`: BibTeX `.bib` file

* `classoption`: options of the `WileyNJD-v2` class

* `longtable`: set to `true` to include the `longtable` package, used by default from `pandoc` to convert markdown to \LaTeX code

## Remarks

1. In `authormark` use _et al._ if there are three or more authors.

2. Note the use of `num` to link names and addresses.

3. For submitting a double-spaced manuscript, add `doublespace` as an option to a `classoption` line in the YAML header: `classoption: doublespace`.

4. Keywords are separated by semicolons.

# The Body of the Article

## Mathematics

Use mathematics in Rmarkdown as usual.

## Figures and Tables

Figures are supported from R code:

```{r plot-ref, fig.cap = "Fancy Caption\\label{fig:plot}"}
x = rnorm(10)
y = rnorm(10)
plot(x, y)
```

...and can be referenced (Figure \ref{fig:plot}) by including the `\\label{}` tag in the `fig.cap` attribute of the R chunk: `fig.cap = "Fancy Caption\\label{fig:plot}"`. It is a quirky hack at the moment, see [here](https://github.com/yihui/knitr/issues/323).

Analogously, use Rmarkdown to produce tables as usual:

```{r, results = "asis"}
if (!require("xtable")) install.packages("xtable")
xt <- xtable(head(cars), caption = "A table", label = "tab:table")
print(xt, comment = FALSE)
```

Referenced via \ref{tab:table}. You can also use the YAML option `header-includes` to includes custom \LaTeX packages for tables (keep in mind that `pandoc` uses `longtables` by default, and it is hardcoded; some things may require including the package `longtable`). E.g., using `ctable`:
```
header-includes:
- \usepackage{ctable}
```
Then, just write straight-up \LaTeX code and reference is as usual (`\ref{tab:ctable}`):
```
\ctable[cap = {Short caption},
        caption = {A long, long, long, long, long caption for this table.},
        label={tab:ctable},]
        {cc}
        {
        \tnote[$\ast$]{Footnote 1}
        \tnote[$\dagger$]{Other footnote}
        \tnote[b]{Mistakes are possible.}
        }{
        \FL
        COL 1\tmark[a] & COL 2\tmark[$\ast$]
        \ML
        6.92\tmark[$\dagger$] & 0.09781 \\
        6.93\tmark[$\dagger$] & 0.09901 \\
        97 & 2000
        \LL
}
```

It is also possible to set the `YAML` option `longtable: true` and use markdown tables (or the `knitr::kable` function): `knitr::kable(head(cars))` produces the same table as the `xtable` example presented before.

## Cross-referencing

The use of the Rmarkdown equivalent of the \LaTeX cross-reference system
for figures, tables, equations, etc., is encouraged (using `[@<name>]`, equivalent of `\ref{<name>}` and `\label{<name>}`). That works well for citations in Rmarkdown, not so well for figures and tables. In that case, it is possible to revert to standard \LaTeX syntax.

## Double Spacing

If you need to double space your document for submission please use the `doublespace` option in the header.

# Bibliography

Link a `.bib` document via the YAML header, and bibliography will be printed at the very end (as usual). The default bibliography style is provided by Wiley as in `WileyNJD-AMA.bst`, do not delete that file.

Use the Rmarkdown equivalent of the \LaTeX citation system using `[@<name>]`. Example: [@Taylor1937], [@Knupp1999; @Kamm2000].

To include all citation from the `.bib` file, add `\nocite{*}` before the end of the document.

# Further information

All \LaTeX enviroments supported by the main template are supported here as well; see the `.tex` sample file [here](http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0258/homepage/la_tex_class_file.htm) for more details and example.

---
title: Paper for IOP journal
shorttitle: "Untitled"
authors:
- name: Sue Lee
  address: Department of UUU, University of VVV
  email: author@vvv.edu
  footnote: Something here
- name: Xu Li
  address: Department of WWW, University of XXX
  email: author@xxx.edu
- name: Soo Leigh
  address: Department of YYY, University of ZZZ
  email: author@zzz.edu
keywords:
  - 3 to 7 keywords
  - that do not appear in the title
abstract: |
  Abstract goes here. It should be a single paragraph of around 200 words.
acknowledgments: |
  We wish to thank...
msc: AMS classification scheme numbers go here. Delete line to omit them.
iopams: false
twocolumn: false
# Use CSL when not using natbib but pandoc's citeproc
# csl: https://www.zotero.org/styles/institute-of-physics-harvard.csl
bibliography: references.bib
biblio-style: dcu # provided by the harvard CTAN package
output: 
  rticles::iop_article:
    keep_tex: yes
    citation_package: natbib
---


# Introduction {#sec:1}

This template formats a paper to follow [the guidelines](https://publishingsupport.iopscience.iop.org/questions/latex-template/) for *Institute of Physics* journals. Please read those guidelines carefully. You will need to submit the source files (tex, bib, figures, etc.) to the journal, not this Rmd file. 

If you need to use AMS fonts, set `iopams` to `true` in the header.

If required, include MSC codes in the `msc` line in the header. Otherwise that line can be deleted.

Referencing is handled using @cleveland1990stl or in parentheses [@HK06]. By default, the Harvard system is used with BibTeX (which is accepted by all IOP journals). The following table shows the suggested settings for other possible referencing methods.

| Citation engine   |  `citation_package` | Citation style | style argument |
| ----------------- | ------------------- | -------------- | -------------- |
| pandoc            | `default`  | Harvard   | `csl: institute-of-physics-harvard.csl` |
| pandoc            | `default`  | Vancouver | `csl: institute-of-physics-numeric.csl` |
| Bibtex            | `natbib`   | Harvard   | `biblio-style: dcu`                     |
| Bibtex            | `natbib`   | Vancouver | `biblio-style: unsrt`                   |
| BibLatex          | `biblatex` | Harvard   | `biblio-style: authoryear`              |
| BibLatex          | `biblatex` | Vancouver | `biblio-style: numeric`                 |

The `biblio-style` argument will be ignored when using pandoc citations, and the `csl` argument will be ignored when using either Bibtex or BibLatex. The relevant csl files can be downloaded from `https://www.zotero.org/styles/` so they are available locally. Alternatively, use the full URL as in the example yaml.

## Subsection title {#sec:2}

Don't forget to give each section
and subsection a unique label (see Section \ref{sec:1} for an example).

#### Paragraph headings

Use paragraph headings if needed.


# Method

## Equations

Here is a displayed equation:
$$ 
  f_{X}(x) = \left(\frac{\alpha}{\beta}\right)
  \left(\frac{x}{\beta}\right)^{\alpha-1}
  e^{-\left(\frac{x}{\beta}\right)^{\alpha}}; 
  \alpha,\beta,x > 0 .
$$
and here is an inline equation: $\sum_{i = 2}^\infty\{\alpha_i^\beta\}$.


# Results

## Figures coming from R

Figure \ref{fig2} is generated using an R chunk.

```{r fig2, fig.width = 5, fig.height = 5, fig.align='center', out.width="50%", fig.cap = "\\label{fig2}A meaningless scatterplot.", echo = FALSE}
plot(runif(25), runif(25))
```

## Tables coming from R

Tables can also be generated using R chunks, as shown in Table \ref{tab1} for example.

```{r tab1, echo=FALSE}
knitr::kable(head(mtcars)[,1:4], 
    caption = "\\label{tab1}Caption above table",
    longtable = FALSE,
    booktabs=TRUE,
    format = 'latex'
)
```

# Discussion


# Conclusion

\appendix

# More things to say

This text is in the appendix.

# References {-}

---
title: A demonstration of the \LaTeX class file for Statistical Methods in Medical Research with Rmarkdown
runninghead: Uthor \emph{et al}.
author:
- name: A. Uthor*
  num: "1,2"
- name: O. Tro
  num: 2
- name: O. Vriga
  num: 3
address:
- num: 1
  org: Department of Incredible Research, University A, City A, Country A
- num: 2
  org: Department of Applied Things, University B, City B, Country B
- num: 3
  org: Very Important Stuff Committee, Institute C, City C, Country C
corrauth: "Corresponding author name, This is sample corresponding address."
email: correspondingauthor@protonmail.com
abstract: "Lorem ipsum dolor sit amet, consectetur adipiscing elit. Aenean ut elit odio. Donec fermentum tellus neque, vitae fringilla orci pretium vitae. Fusce maximus finibus facilisis. Donec ut ullamcorper turpis. Donec ut porta ipsum. Nullam cursus mauris a sapien ornare pulvinar. Aenean malesuada molestie erat quis mattis. Praesent scelerisque posuere faucibus. Praesent nunc nulla, ullamcorper ut ullamcorper sed, molestie ut est. Donec consequat libero nisi, non semper velit vulputate et. Quisque eleifend tincidunt ligula, bibendum finibus massa cursus eget. Curabitur aliquet vehicula quam non pulvinar. Aliquam facilisis tortor nec purus finibus, sit amet elementum eros sodales. Ut porta porttitor vestibulum. Integer molestie, leo ut maximus aliquam, velit dui iaculis nibh, eget hendrerit purus risus sit amet dolor. Sed sed tincidunt ex. Curabitur imperdiet egestas tellus in iaculis. Maecenas ante neque, pretium vel nisl at, lobortis lacinia neque. In gravida elit vel volutpat imperdiet. Sed ut nulla arcu. Proin blandit interdum ex sit amet laoreet. Phasellus efficitur, sem hendrerit mattis dapibus, nunc tellus ornare nisi, nec eleifend enim nibh ac ipsum. Aenean tincidunt nisl sit amet facilisis faucibus. Donec odio erat, bibendum eu imperdiet sed, gravida luctus turpis."
keywords: Class file; \LaTeX; SMMR; Rmarkdown;
classoption:
  - Royal
  - times
bibliography: bibfile
bibliographystyle: sageh
output:
  rticles::sage_article:
    keep_tex: yes
---

# The Article Header Information

YAML header:

```
output:
  rticles::sim_article:
    keep_tex: TRUE
```

Configure the YAML header including the following elements:

* `title`: Title

* `runninghead`: Author last names, use _et al._ if there are three or more authors.

* `author`: List of author(s) containing `name` and `num`

* `corrauth`: Corresponding author's name and address.

* `email`: Correspondence email

* `abstract`: Limited to 200 words

* `keywords`: Keywords for the article

* `bibliography`: BibTeX `.bib` file

* `bibliographystyle`: sageh or sagev

* `classoption`: options of the `sagej` class

## Remarks

2. `bibliographystyle`

3. `classoption`

4. Keywords are separated by commas.

# The Body of the Article

## Mathematics

Use mathematics in Rmarkdown as usual.

## Figures and Tables

Figures are supported from R code:

```{r plot-ref, fig.cap = "Fancy Caption\\label{fig:plot}", out.width='100%'}
x = rnorm(10)
y = rnorm(10)
plot(x, y)
```

...and can be referenced (Figure \ref{fig:plot}) by including the `\\label{}` tag in the `fig.cap` attribute of the R chunk: `fig.cap = "Fancy Caption\\label{fig:plot}"`. It is a quirky hack at the moment, see [here](https://github.com/yihui/knitr/issues/323).

Analogously, use Rmarkdown to produce tables as usual:

```{r, results = "asis"}
if (!require("xtable")) install.packages("xtable")
xt <- xtable(head(cars), caption = "A table", label = "tab:table")
print(xt, comment = FALSE)
```

Referenced via \ref{tab:table}. You can also use the YAML option `header-includes` to includes custom \LaTeX packages for tables (keep in mind that `pandoc` uses `longtables` by default, and it is hardcoded; some things may require including the package `longtable`). E.g., using `ctable`:
```
header-includes:
- \usepackage{ctable}
```
Then, just write straight-up \LaTeX code and reference is as usual (`\ref{tab:ctable}`):
```
\ctable[cap = {Short caption},
        caption = {A caption for this table.},
        label={tab:ctable},]
        {cc}
        {
        \tnote[$\ast$]{Footnote 1}
        \tnote[$\dagger$]{Other footnote}
        \tnote[b]{Mistakes are possible.}
        }{
        \FL
        COL 1\tmark[a] & COL 2\tmark[$\ast$]
        \ML
        6.92\tmark[$\dagger$] & 0.09781 \\
        6.93\tmark[$\dagger$] & 0.09901 \\
        97 & 2000
        \LL
}
```

It is also possible to set the `YAML` option `longtable: true` and use markdown tables (or the `knitr::kable` function): `knitr::kable(head(cars))` produces the same table as the `xtable` example presented before.

## Cross-referencing

The use of the Rmarkdown equivalent of the \LaTeX cross-reference system
for figures, tables, equations, etc., is encouraged (using `[@<name>]`, equivalent of `\ref{<name>}` and `\label{<name>}`). That works well for citations in Rmarkdown, not so well for figures and tables. In that case, it is possible to revert to standard \LaTeX syntax.

## Double Spacing

If you need to double space your document for submission please use the `doublespace` option in the header.

# Bibliography

Link a `.bib` document via the YAML header, and bibliography will be printed at the very end (as usual). The default bibliography style is provided by Wiley as in `WileyNJD-AMA.bst`, do not delete that file.

Use the Rmarkdown equivalent of the \LaTeX citation system using `[@<name>]`. Example: [@Taylor1937], [@Knupp1999; @Kamm2000].

To include all citation from the `.bib` file, add `\nocite{*}` before the end of the document.

# Further information

All \LaTeX enviroments supported by the main template are supported here as well; see the `.tex` sample file [here](http://onlinelibrary.wiley.com/journal/10.1002/(ISSN)1097-0258/homepage/la_tex_class_file.htm) for more details and example.

---
title: Titre du texte, si possible moins de 50 caractères

author: Joseph Bleau
affiliation: département de mathématiques
establishment: Cégep de Fleurimont
email: \href{mailto:jo-bleau@cegepfleurimont.qc.ca}{jo-bleau@cegepfleurimont.qc.ca}
website: \href{https://www.amq.math.ca/}{Le site de l'AMQ}

author2: Arthur Sauvé
affiliation2: département de mathématiques
establishment2: Cégep des Marguerites
email2: \href{mailto:arthur.sauve@cegepmargueriteses.qc.ca}{arthur.sauve@cegepmargueriteses.qc.ca}
website2: \href{https://www.amq.math.ca/}{Le site de l'AMQ}

abstract: |
  Dans ce Gabarit, on devra entrer tous les textes en caractères accentués, comme à l'habitude\footnote{Si vous utilisez les accents habituels, vous nous rendez le grand service de nous éviter d'avoir à modifier un texte qui ne les utiliserait pas.}. Le résumé apparaît ici. Long d'au maximum 100 mots, il peut contenir des expressions en  \emph{italique}, en \textbf{caractères gras} ou en \textsc{petites capitales}. On peut aussi utiliser des symboles particuliers comme $\Bbb{R}$, $\mathscr{F}$ ou encore $\mathscr{P}(E)$ et même des expressions mathématiques comme $f_k(x)=a x^2+bx+c$, ou encore à  l'ensemble $\mathfrak{F}$ des formules du système formel $\mathfrak{L}$ est bien défini. Il est possible de reculer dans le temps. Ainsi, on peut parler du \siecle{1} siècle de notre ère ou des \siecle{20} et \siecle{21} siècles.
  
keywords: premier mot, deuxième mot, troisième et dernier mot.

output: rticles::amq_article
---

# Structuration du texte \label{sec1}

\begin{definition}
On appelle section toute partie du texte incluse entre une annonce de section et la suivante. La même convention s'applique aux sous-sections.
\end{definition}

Les sections et sous-sections sont numérotées de façon automatique. La même règle s'applique, catégorie par catégorie, aux théorèmes, aux lemmes, aux corollaires et aux définitions.

Toutefois, on trouvera un moyen de remplacer la numérotation catégorie par catégorie par une numérotation en fonction de la section ou de la sous-section dans le préambule et c'est là aussi que vous devrez l'activer. Vous trouverez plus d'information sur ce sujet et sur bien d'autres, dans M.-P. Kluth et B. Bayart, \emph{FAQ \LaTeX~de l'équipe Grappa}\cite{faq}.

On trouvera une liste de listes de symboles disponibles pour écrire des expressions mathématiques pages 50 à 56, dans T. Oetiker, H. Partl, I. Hyna et E. Schlegl (1999). \emph{Une courte (?) introduction à \LaTeXe, ou  \LaTeXe~en 88 minutes}  \cite{oeti}.

# Les expressions mathématiques et les équations \label{sec2}

## Expressions mathématiques au fil du texte \label{fil}

Le signe de dollar permet d'insérer au fil du texte des expressions mathématiques qui apparaîtront en italique. Ainsi, lorsqu'on utilise une fonction f, pour qu'elle apparaisse comme un objet mathématique, il suffit de l'écrire $f$, entre deux signes de dollar. Les expressions peuvent être plus complexes:

Soit, $f: \Bbb{N}^{2*} \rightarrow \Bbb{R}$ telle que pour tout 
$(m,n) \in \Bbb{N}^{2*}$ on a 
$f(m+1,n+1) = f(m+1,n) + f(m,n+1)$.

## Expressions mathématiques sur une ligne dédiée \label{dediee}

On peut souhaiter que l'équation soit mise en évidence sur une ligne qui lui soit dédiée:

Soit, 
$f: \Bbb{N}^{2*} \rightarrow \Bbb{R}$ telle que pour tout $(m, n) {\in} \Bbb{N}^{2*}$ on a
\begin{equation*}
f(m+1,n+1) = f(m+1,n) \qquad+ f(m,n+1).
\end{equation*}

On peut souhaiter qu'en plus cette équation soit numérotée et qu'on puisse faire référence plus loin dans le texte à ce numéro:

Soit, 
$f:\Bbb{N}^{2*} \rightarrow \Bbb{R}$ telle que pour tout $(m,n) \in \Bbb{N}^{2*}$ on a
\begin{equation}
f(m+1,n+1) = f(m+1,n) + f(m,n+1). \label{recur}
\end{equation}

Pour faire référence à une équation numérotée, on utilise l'étiquette qui lui a été attribuée. Ainsi on peut invoquer l'équation (\ref{recur}) de la section (\ref{dediee}). Ce système est résistant aux changements de place dans le texte. Il est possible qu'il soit nécessaire de compiler plusieurs fois après une modification du texte pour assurer le suivi des références.

## Expressions mathématiques sur plusieurs lignes, avec numérotation  \label{numero}

$AC=CB$ et $AB=AC$
Il arrive qu'on ait une suite d'égalités à présenter et qu'on souhaite aligner les signes d'égalité.
On traite alors la suite d'équations comme un tableau à 3 colonnes délimitées  par le symbole de l'esperluette (et commercial).

Exemple:

\begin{theorem} Si $\vv{v} \neq \vv{0}$, alors le vecteur $\frac{1}{\| \vv{v}\|}\vv{v}$, que l'on écrit parfois $\frac{\vv{v}}{\| \vv{v}\|}$, est un vecteur unitaire de même direction et de même sens que $\vv{v}$.
\end{theorem}

La partie du théorème précédent portant sur la norme se démontre ainsi:

\begin{proof}
\begin{eqnarray}
\Big\|{\frac{1}{\| \vv{v}\|}\vv{v}} \Big\|&=& \Big |\frac{1}{\| \vv{v}\|} \Big |\| \vv{v}\|\label{norme}\\
&=&\frac{1}{\| \vv{v}\|}\| \vv{v}\|  \nonumber\\
&=&\frac{\| \vv{v}\|}{\| \vv{v}\|} \nonumber\\
&=&1 \label{nombre}
\end{eqnarray}
La comparaison des équations (\ref{norme}) et (\ref{nombre}) démontre le théorème.\end{proof}

Pour obtenir une suite d'équations non numérotées,

\begin{eqnarray*}
\Big\|{\frac{1}{\| \vv{v}\|}\vv{v}} \Big\|&=& \Big |\frac{1}{\| \vv{v}\|} \Big |\| \vv{v}\| \\
&=&\frac{1}{\| \vv{v}\|}\| \vv{v}\| \\
&=&\frac{\| \vv{v}\|}{\| \vv{v}\|} \\
&=&1
\end{eqnarray*}

## Expressions mathématiques d'une fonction définie par morceaux  \label{morceaux}

Un classique:
\begin{definition}
On appelle valeur absolue la fonction
{f}: $\Bbb{R} \rightarrow \Bbb{R}_+$ définie par
\[f(x)=
\begin{cases}
\;\;x & \text{, si } x \geq 0 \\
-x & \text{, sinon}.
\end{cases}
\]
\end{definition}

ou encore
\[f(x)=
\begin{cases}
\; \;x & \text{, si } x > 0, \\
\; \;0& \text{, si } x = 0, \\
-x & \text{, \emph{sinon}}.
\end{cases}
\]

# Les tableaux \label{tab}

\bigskip

Ce tableau (\ref{Tableau1}) comporte 2 colonnes, dans lesquelles le texte sera centré, et 3 lignes.
Sur la première ligne, les deux colonnes sont fusionnées.

 \begin{table}[ht]
\begin{center}
\begin{tabular}{|c|c|}
\hline
\multicolumn{2}{|c|}{Tableau}\\
\hline
Cellule 1&Cellule 2\\
\hline
Cellule 3&Cellule 4\\
\hline
\end{tabular}
\end{center}
\caption{ \label{Tableau1} {Modèle de tableau dans l'environnement table} }
\end{table}

On peut l'invoquer ailleurs dans le texte car il porte une étiquette. Ainsi, le tableau (\ref{Tableau1}) ne comporte que des lignes simples, alors que dans le tableau (\ref{Tableau2}) on a inséré des doubles lignes horizontales et des doubles lignes verticales.

 \begin{table}[ht]
\begin{center}
\begin{tabular}{|l||r| c| c| c| c|| c c|}
 \hline
 Nom &  Prénom & Institution & Article &  & &  &  \\ \hline \hline
   Fayard & Clotilde & École maternelle de la Métare& La maquette & 3 & 4& 5 & 6 \\ \hline
   1 &1& 2 & 3 & 4& 5& 6 &  0 \\ \hline
   1 &1& 2 & 3 & 4& 5& 6 &  0 \\ \hline
   1 &1& 2 & 3 & 4& 5& 6 &  0 \\ \hline
   1 &1& 2 & 3 & 4& 5& 6 &  0 \\ \hline

\end{tabular}
\end{center}
\caption{ \label{Tableau2} {Autre modèle de tableau dans l'environnement table} }
\end{table}


Les tableaux, comme les figures, sont des objets flottants. Cela signifie que le logiciel les insère immédiatement s'il y a suffisamment de place pour qu'il tienne dans la page. Sinon, le logiciel remplit la page avec du texte et insère le tableau en haut de la page suivante.


\begin{table}[ht]
\begin{flushright}
\begin{tabular}{ll}\
Estragon.   & -  Allons-nous-en. \\
~Vladimir.   & -  On ne peut pas. \\
~Estragon.   & -  Pourquoi ? \\
~Vladimir. & -  On attend Godot. \\
 \multicolumn{2}{r}{~~~~~~Samuel Beckett, \begin{itshape} En attendant Godot \end{itshape}} \\
 \end{tabular}
 \end{flushright}
\caption{ \label{Tableau3} {Tableau dramatique} }
\end{table}

\textsc{Attention}, cet autre tableau (\ref{tab:template}) est un peu plus sophistiqué. Lire les instructions dans le fichier source.
\bigskip

\begin{table}
\centering
\begin{tabular}{lccccc}
\toprule
& \multicolumn{5}{c}{Milieu de croissance} \\
\cmidrule(l){2-6}
Variété & 1 & 2 & 3 & 4 & 5\\
\midrule
GDS1002 & 0.962 & 0.821 & 0.356 & 0.682 & 0.801\\ 	% Contenu de la ligne no 1
NWN652 & 0.981 & 0.891 & 0.527 & 0.574 & 0.984\\ 	  % Contenu de la ligne no 2
PPD234 & 0.915 & 0.936 & 0.491 & 0.276 & 0.965\\ 		% Contenu de la ligne no 3
JSB126 & 0.828 & 0.827 & 0.528 & 0.518 & 0.926\\		% Contenu de la ligne no 4
JSB724 & 0.916 & 0.933 & 0.482 & 0.644 & 0.937\\ 		% Contenu de la ligne no 5
\midrule
\midrule
Taux moyen & 0.920 & 0.882 & 0.477 & 0.539 & 0.923\\
\bottomrule
\end{tabular}
\caption{Texte de la légende}
\label{tab:template}
\end{table}

# Les figures \label{fig}

On insère les figures en formats JPEG ou PDF.

## Insertion d'une figure avec légende étiquetée \label{fig+eti}

\begin{figure}[ht]
\centerline{\includegraphics[scale=.8]{pics/Figure1}} \caption{ \label{Modele figure1} Modèle d'une figure enregistrée en format JPEG avec légende étiquetée }
\end{figure}

\begin{figure}[ht]
\centerline{\includegraphics[scale=.99]{pics/Figure2}} \caption{ \label{Modele figure2} Modèle d'une figure enregistrée en format PDF avec  légende étiquetée}
\end{figure}

Comme pour les équations numérotées ou les sections, on peut invoquer une figure dont la légende a été étiquetée sans craindre les modifications au texte en cours de composition.

Ainsi, on peut invoquer les figures (\ref{Modele figure1}) et (\ref{Modele figure2}) pour attirer l'attention du lecteur sur la manière de contrôler la taille d'une figure.

## Insertion d'une figure avec légende manuelle \label{leg+manu}

\begin{center}
\includegraphics[scale=.99]{pics/Figure1}\\
{\small \textsc{Figure 3} -- Modèle d'une figure avec légende manuelle}
\end{center}

On ne peut pas invoquer cette figure autrement que manuellement. Nous n'encourageons pas l'insertion de figures de cette façon car dans ce cas il arrive que la figure elle-même et son titre se retrouvent sur deux pages différentes.

Tout ce qui a été étiqueté, sections, sous-sections, figures, tableaux et entrées de la bibliographie, peut être invoqué ailleurs dans le texte.

# Les citations et les notes de bas de page \label{sec5}

On peut faire des citations. Les citation courtes (5 lignes ou moins) apparaîtront au fil du texte, entre guillemets français \og Diophante vivait à une époque où les mathématiques alexandrines perdaient leur puissance créatrice.\fg\ disent Dahan-Dalmedico et Peifer\cite{daha}, p. 65.

Une citation longue (plus de 5 lignes) apparaîtra dans un paragraphe (ou plus selon le texte cité) qui lui sera dédié.

\begin{quote}  Avec Diophante, un nouveau chapitre des mathématiques s'ouvre et il est impossible de mettre en lumière le courant dont il est l'aboutissement. La vie de Diophante est très peu connue, et la période précise pendant laquelle il a vécu reste contestée (\siecle{3} siècle après J.-C.). Sa grande oeuvre, {\ les Arithmétiques}, devait comprendre, d'après ce qu'il écrit lui-même dans l'introduction, treize livres.

 Depuis le \siecle{16} siècle, seuls six livres étaient connus. Ils provenaient d'un manuscrit grec découvert en 1464 par Regiomontanus à Venise, qui était la copie d'un manuscrit plus ancien.(Dahan-Dalmedico et Peifer\cite{daha}, p. 72)\end{quote}

Il est aussi possible d'insérer des notes de bas de page. Toutefois, celles-ci sont à utiliser avec la plus grande parcimonie, et seulement quand l'auteur pense vraiment qu'il lui est impossible d'inclure une incise dans son texte \footnote {Un texte de 10 pages avec 12 notes de bas de page n'est pas acceptable.}. Les références bibliographiques, notamment, ne doivent jamais figurer en notes, mais doivent être incluses dans le texte sous les normes données ci-après. Toutes les références correspondant à celles données dans le texte doivent figurer dans la bibliographie. Nous attirons l'attention des auteurs sur le fait que l'exactitude en matière de références bibliographiques requiert que soit entreprise une vérification, voire une recherche documentaire qui est de la responsabilité de l'auteur.

# Insertion de code `R`

Il est facile d'inclure du code `R`. Par exemple:
```{r, out.width='0.9\\textwidth'}
plot(cars)
```

# Conclusion \label{sec6}

C'est à la fin de cette section qu'on retrouvera le cas échéant de brefs remerciements.

\emph{Remerciements}
A Leslie Lamport\cite{lamp}, pour la qualité impressionnante de son travail et ses précieux conseils pour la rédaction de ce document, et aux Annales des sciences mathématiques du Québec dont le gabarit nous a inspirés.

---
title: This is a title and this is too
shorttitle: A subtitle goes on another line
author:
- name: Author's name
  affiliation: Author's affiliation
  email: e-mail\@uni.edu
  thanks: other info
- name: Second author's name
  affiliation: Second author's affiliation
output: rticles::jasa_article
abstract: |
  Put your abstract here. Abstracts are limited to 200 words for
  regular articles and 100 words for Letters to the Editor. Please no
  personal pronouns, also please do not use the words ``new'' and/or
  ``novel'' in the abstract. An article usually includes an abstract, a
  concise summary of the work covered at length in the main body of the
  article.
  
# The following prints the current date (optional, set to false to remove).
date: true
classoption:
  - preprint # Set to "reprint" to use the reprint style.
# The reprint style typesets the manuscript with two columns and 10pt font size.  
#  - NumberedRefs # Uncomment to use numbered references rather than the default author-year style.
#  - trackchanges # Uncomment to track changes in the manuscript. (Use with preprint option).
#  - 12pt # Uncomment this to check if you exceeded the 12 page limit. (Use with reprint option).
#  - TurnOnLineNumbers # Uncomment to add line numbers in reprint. (Use with reprint.)

# When using the preprint style, use the following to add a notice on the first page (optional).
preprint_notice: "Author-name, JASA"
bibliography: sampbib.bib

# The Author-Year style is the default. If you want to use the numeric style,
# use "jasanum2.bst" instead.
biblio-style: jasaauthyear2.bst
---

```{r setup, include=FALSE}
# Use fig.process to rename figure files generated by R so that they comply with
# the journal naming policies. Remember to name plot chunks with the format
# "Figure1", "Figure2", etc... You will find the figure files in
# `[...]_files/figure-latex/`.

knitr::opts_chunk$set(
  echo = TRUE,
  out.width="\\reprintcolumnwidth",
  fig.process = function(x) {
    x2 = sub('-\\d+([.][a-z]+)$', '\\1', x)
    if (file.rename(x, x2)) x2 else x
  }
)

# The JASA LaTeX class depends on the LaTeX package "revtex4-1". If you are
# using a full LaTeX distro, you should make sure "revtex4-1" is installed, and
# install it if not. If you are using TinyTeX, the following code will take care
# of installing the package for you.

if (tinytex::is_tinytex() && !tinytex::check_installed('revtex4-1')) {
  tinytex::tlmgr_install("revtex4-1")
}
```

# Introduction

This sample document demonstrates the use of JASA in manuscripts 
prepared for submission to the Journal of the Acoustical Society of America. 

# Figures {#figures}

```{r Figure1, echo=FALSE, fig.cap="Caption."}
knitr::include_graphics("figsamp.jpg")
```

The only figure formats allowed for submission are the following: `.pdf`, `.ps`, `.eps`, or `.jpg`.
Figure files must be named in this fashion:
`Figure\#.xxx`, where `\#` is the figure number and `xxx` is the file format
(`Figure1.eps`, `Figure2.jpg`, `Figure3a.ps`, `Figure3b.ps`, etc).

```{r Figure2, echo=FALSE, fig.cap="A sine wave."}
t <- seq(0, 10, 0.1)
y <- sin(t)
plot(t, y, type = "l", xlab = "time", ylab = "Sine wave")
```


# Inline and display math samples

You can also include inline math, like $\sum\nolimits_{i=1}^N a_i$.

The following is a matrix.

$$
A_{m,n} = 
 \begin{pmatrix}
  a_{1,1} & a_{1,2} & \cdots & a_{1,n} \\
  a_{2,1} & a_{2,2} & \cdots & a_{2,n} \\
  \vdots  & \vdots  & \ddots & \vdots  \\
  a_{m,1} & a_{m,2} & \cdots & a_{m,n} 
 \end{pmatrix}
$$



# Citations

The code `[@key]` should usually be used for making
citations surrounded by parentheses, where `key` is the BibTeX cite-key.
If you need only the year in parentheses, you may use `@key`.

Some examples:

- Normal journal cite: [@joursamp1]

- Volume number with issue number: [@joursamp3]

- Journal article published online, not yet printed: [published
online, @sampMisc2]

- Book reference: [@booksamp1]

- In press: [in press, @inpress2]

- Website: [@websiteauthyear]

- Inproceedings: [@sampinproceedings3].



<!-- You can add your acknowledgements here (optional). -->
::: {.acknowledgments data-latex=""}
This research was supported by ...
:::

<!-- Use \appendix* for only one appendix section. -->
\appendix 

To start the appendix, use the `\appendix` command.
This signals that all following section commands refer to appendixes
instead of regular sections. Therefore, the `\appendix` command
should be used only once---to set up the section commands to act as
appendices. Thereafter normal section commands are used. The heading
for a section can be left empty. For example,

```latex
\appendix

# 
```

will produce an appendix heading that says "APPENDIX A" and

```latex
\appendix

# Background
```

will produce an appendix heading that says "APPENDIX A: BACKGROUND"
(note that the colon is set automatically).

If there is only one appendix, then the letter "A" should not
appear. This is suppressed by using the star version of the appendix
command (`\appendix*` in the place of `\appendix`).

# A little more on appendices

Observe that this appendix was started by using

```markdown
# A little more on appendices
```

Note the equation number in an appendix:

$$E=mc^2$$

---
title: This is a title and this is too
subtitle: A subtitle goes on another line
# Use the following to specify a shorter title for the header. 
# If not set, the title will be used.
title-header: A short title

author:
- name: Author's name
  affiliation: Author's affiliation
  email: e-mail@uni.edu
- name: Second author's name (if there is one)
  affiliation: Second author's affiliation
# Use the following to specify a short author name for the header. If not set, 
# it will use the authors' name
author-header: Authors

# The journal uses Cambria, Calibri, and Lekton. If you don't have access to
#  Cambria and Calibri, you can use the metrically equivalent Caladea and
#  Carlito. Caladea, Carlito, and Lekton are available for download:
#   - Caladea:   https://fontlibrary.org/en/font/caladea
#   - Carlito:   https://fontlibrary.org/en/font/carlito
#   - Lekton:    https://www.fontsquirrel.com/fonts/lekton
# 
# mainfont: Cambria # or Caladea
# licensefont: Calibri # or Carlito
# logofont: Lekton

en-variant: british # Set to "american" for American English.
single-quotes: true # To use double quotes, set single-quotes to false.
# for the example, feel free to use your preferred package for glosses or comment.
gloss: expex 

# This format uses BibLaTeX by default, as recommended by the journal.
bibliography: sample-bib.bib

abstract: |
 This is the template for \LaTeX{} users; we also have a Word template available, so feel free to use that if you're not into \LaTeX. All submissions to PiHPh should aim to follow the formatting set out in this template precisely, as there is no separate typesetting phase. Most styles in this template have been set up to insert the necessary white space where needed. You should use the styles that are provided in this template consistently to ensure that your submission is quickly processed. Do not change the margins or header/footer properties, including the material on this first page (such as volume, page numbers and DOI), which we will update when your submission is ready. Make sure to look at the user customization part of the preamble to this \texttt{.tex} source to change titles, running headers, bibliography etc. All the packages used here should be available in a recent version of \TeX Live. All articles should include an abstract in this position, of no more than 200 words.
acknowledgements: Include any acknowledgements in an unnumbered section here, rather than in a footnote early in the paper.
supplement: If you would like to post any data sets, statistical data, scripts or similar material that links to your article, you can include a description of it all at the end of the paper.
output: rticles::pihph_article
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(echo = TRUE)
```

# Heading level 1

The first paragraph under all headings will not be indented.^[This is a footnote example]  The font for everything is Cambria --- use Xe\LaTeX{} to compile the document to achieve this. Cambria should hopefully have all the transcription symbols that you will need, but if you have any problems using symbols, get in touch (pihph@\hspace{0pt}mlist.ed.ac.uk). Use normal phonological conventions when transcribing: [skweːɹ] brackets for surface/narrow transcriptions and /slantɪd/ brackets for underlying/broad transcriptions. It’s fine to use either IPA conventions (e.g., /t͡ʃ, ɾ, j, y/) or Americanist conventions (e.g., /č, ᴅ, y, ü/), but if there is any possibility of ambiguity or if you need to use a non-conventional symbol, you should explain what it stands for.

All paragraphs other than the first in a section will be indented by 0.7cm. Make sure that you use the shaftless arrow \enquote{>} for diachronic correspondences. The shafted arrow \enquote{→} (or `$\rightarrow$`) should be used for synchronic derivations. Use \enquote{smart quotation marks}, not \'straight quotation marks\' (we recommend the csquotes package, as in this template). Either British or American English spelling is fine, as long as you are consistent. It is crucial that you spellcheck and carefully proofread your piece before submission. Use a hyphen \enquote{-} only to join together two parts of a compound (as in \enquote{affrico-palatalisation}). For number ranges (as in \enquote{1999–2002}), use an en dash \enquote{--}. For all other purposes, use an em dash \enquote{---}.

## Heading level 2

Quotations of under 25 words should be included in the running text \enquote{as a wise person once said} (with an associated full reference, including page numbers). All references should follow the normal Author (date, page number) system.  Longer quotations should be set out as follows.


> This is the format for a quotation of 25 words or more, with indentation of 0.7 cm throughout the quotation on both sides and a font size of 10 points (this is set up in the template) and a reference in the text above it, unless there is a good reason to give the reference elsewhere.

All examples and anything that is not a table or figure should be given a number for reference, as normal. You can set out your examples, diagrams and other similar items in any way that you think sensible (within the general constraints of this template). We recommend the expex package for example, but you are welcome to use any others. Put the example number in brackets, but if you use subexamples the numbering is up to you. The numbers for examples should not be indented.

```{=latex}
\ex\begin{tabular}[t]{lll}
     /ɛɡzampl/ & [ɛɡzámpl̩] & `example'
   \end{tabular}
\xe

\ex\labels\begin{tabular}[t]{>{\tl}llll} % or use \pex
& /tu e/ & [tʰʉː eː] & `two a' \\
& /tu bi/ & [tʰʉː biː] & `two b'
\end{tabular}
\xe
```

If you need to include translations for examples, use single quotation marks. Do not use bold or underlining anywhere in an article (apart from where required by the template in headings and the like). Use italics for linguistic examples in the running text, for the titles of publications and for any kind of emphasis. If you encounter any problems with setting out your examples and similar things, contact us for advice (pihph@\hspace{0pt}mlist.is.ed.ac.uk).

Captions for figures and tables should be set out below the figure or table. We recommend, but do not insist, that you avoid vertical rules in your tables (we recommend the booktabs package). Otherwise, the setting of figures and tables is also up to you. Everything should be placed in your article where you would like it to appear in the published PDF. Do not place anything at the end of an article unless it clearly belongs in an appendix (that is, it consists of material that a casual reader will not want to consult, but may be of interest to specialists). You will be able to host data sets, statistical data, scripts, and the like separately (within reason) if you would like to make them available in connection with an article. Contact us if you would like to discuss this (pihph@\hspace{0pt}mlist.is.ed.ac.uk).

```{r example, fig.cap="Caption", fig.align='center'}
knitr::include_graphics("pihph-logo.png")
```

# Bibliography and citations

By default, this template uses Bib\LaTeX. To learn about Bib\LaTeX, see https://www.overleaf.com/learn/latex/Articles/Getting_started_with_BibLaTeX for a quick intro and the package documentation for detailed info. The `langsci-unified` style is used.

To cite a reference, you can use the standard pandoc syntax `@blust2009` for a citation without parentheses, as in @blust2009, and `[@blust2009]` with parenthesis [@blust2009].

These are other examples: @ramsammy2016 [p. 287], [but see @sen2016; @bermudez-otero2015]. Goldsmith is a relevant reference [-@goldsmith1990], although we should not forget @hyman1975.

# Conclusion

The following sections show the kinds of things that you might include at the end of your paper. Use the
`\section*` to produce unnumbered sections.

---
title: Short Paper for Bayesian Analyis
classoption: ba
author:
  - firstname: Alice 
    lastname: Anonymous
    email: alice@example.com
    url: www.example.com/aliceanon
    affiliationref: addr1
    footnoterefs: 
      - t1
      - t2
      - m1
  - firstname: Bob
    lastname: Security
    email: bob@example.com
    affiliationref: addr1
    footnoterefs: 
      - t3
      - m1
      - m2
  - firstname: Cat
    lastname: Memes
    email: cat@example.com
    affiliationref: addr2
    footnoterefs: 
      - t1
      - m2
affiliations:
  - ref: addr1
    name: Some Institute of Technology 
    address: Department, Street, City, State, Zip
  - ref: addr2
    name: Another University
    address: Department, Street, City, State, Zip
footnotes:
  - ref: t1
    text: "Corresponding Author"
  - ref: t2
    text: "Equal contribution"
  - ref: t3
    text: "Something"
  - ref: m1
    text: "Something"  
  - ref: m2
    text: "Something"
MSC2020primary:
  - 62C10
  - 62F15
MSC2020secondary:
  - 60K35
  - 91A27
keywords:
  - bayesian
  - statistics
supplements:
  - title: Title of Supplement A
    description: Short description of Supplement A.
  - title: Title of Supplement B
    description: Short description of Supplement B.
doi: "10.31219/osf.io/wh3wr"
arxiv: 2010.010101
acknowledgements: |
  And this is an acknowledgements section with a heading that was produced by the `acks` environment. Thank you all for helping me writing this Rmarkdown sample file.

  Also thankful to God, mom and my cats.
abstract: |
  The abstract should summarize the contents of the paper. It should be clear, descriptive, self-explanatory and not longer than 200 words. It should also be suitable for publication in abstracting services. Please avoid using math formulas as much as possible.

  This is a sample input file.  Comparing it with the output it generates can show you how to produce a simple document of your. That was the second paragraph.
date: "`r Sys.Date()`"
bibliography: sample.bib
#linenumbers: true
#numbersections: true
output: 
  bookdown::pdf_book: 
    base_format: rticles::isba_article
    md_extensions: -autolink_bare_uris #keep these off or \printead{} will fail on email addresses
---

# R Markdown

This is an R Markdown document. Markdown is a simple formatting syntax for authoring HTML, PDF, and MS Word documents. For more details on using R Markdown see <https://rmarkdown.rstudio.com>.

When you click the **Knit** button a document will be generated that includes both content as well as the output of any embedded R code chunks within the document. You can embed an R code chunk like this:

```{r cars}
summary(cars)
```

## YAML fields

For `MSC2020primary` and `MSC2020secondary`, please refer to [MSC database](https://mathscinet.ams.org/mathscinet/msc/msc2020.html).

## Including Plots

You can also embed plots, for example:

```{r pressure, echo=FALSE}
plot(pressure)
```

Note that the `echo = FALSE` parameter was added to the code chunk to prevent printing of the R code that generated the plot. Because printing is different from typewriting, there are a number of things that you have to do differently when preparing an input file than if you were just typing the document directly.  Quotation marks separates the double and single quote. 

$$a+b\geq c$$
where $a$ is a variable and $c$ is variable as well.

Dashes come in three sizes: a hyphen, an intra-word dash, a medium dash for number ranges like 1--2, and a punctuation dash in place of a comma, semicolon, colon or parentheses ---like this.

The following are some other citations to check that the bibliographic style file is working correctly: \citet{akaike}, \citet*{akivarsq},
\citet*{kstuart}, and \citet{companion}.  

# References {#references .unnumbered}

---
title: "在R Markdown文档中使用中文"
author:
  - 谢益辉
  - 邱怡轩
  - 于淼
documentclass: ctexart
keywords:
  - 中文
  - R Markdown
output:
  rticles::ctex:
    fig_caption: yes
    number_sections: yes
    toc: yes
---

# 引言

中文LaTeX文档并非难题。当然这句话得站在巨人 [CTeX](http://ctex.org) 的肩膀上才能说，它让我们只需要一句

```latex
\documentclass{ctexart} % 或者ctexrep/ctexbook
```

或者

```latex
\usepackage{ctex}
```

就轻松搞定中文LaTeX排版问题。

# 字体和选项

LaTeX包[**ctex**](http://ctan.org/pkg/ctex)支持若干种字体选项，如果你是**ctex**老用户，请注意这里我们要求的最低版本是2.2，你可能需要升级你的LaTeX包。从版本2.0开始，**ctex**支持根据不同操作系统自动选择中文字体，简直是为人类进步作出了巨大贡献，我们再也不必费尽口舌向用户解释“啊，你用Windows啊，那么你该使用什么字体；啊，你用Mac啊，又该如何如何”。

下面的YAML元数据应该能满足多数用户的需求，主要设置两项参数：文档类为`ctexart`（当然也可以是别的类），输出格式为`rticles::ctex`，其默认LaTeX引擎为XeLaTeX（真的，别纠结你的旧爱PDFLaTeX了）。

```yaml
---
documentclass: ctexart
output: rticles::ctex
---
```

`rticles::ctex`的参数都是普通的`pdf_document`参数，参见文档**rmarkdown**包的文档，这里就不赘述了。

Windows和Mac用户应该都已经有自带的中文字体了。Linux用户可以考虑 [Fandol字体](http://ctan.org/pkg/fandol)，它号称是免费的，不过我们也没太搞清楚它的来头。如果你不想操心这些问题，我们强烈建议你卸载你当前的 LaTeX 套装（TeX Live 或 MiKTeX 或 MacTeX），换上 TinyTeX，一切将会自动化搞定。

```{r eval=FALSE}
devtools::install_github(c('rstudio/rmarkdown', 'yihui/tinytex'))
tinytex::install_tinytex()
```

# R代码段

R代码用R Markdown的语法嵌入，即三个反引号开始一段代码```` ```{r} ````和三个反引号```` ``` ```` 结束一段代码：

```{r}
options(digits = 4)
fit = lm(dist ~ speed, data = cars)
coef(summary(fit))
b = coef(fit)
```

上面回归方程中的斜率是`r b[2]`，完整的回归方程为：$$ Y = `r b[1]` + `r b[2]`x$$

画图当然也是木有问题的啦，想画就说嘛，不说我怎么知道你想画呢？

```{r scatter, fig.cap='cars数据散点图以及回归直线。'}
par(mar = c(4, 4, .1, .1), las = 1)
plot(cars, pch = 19)
abline(fit, col = 'red')
```

请不要问我为什么图浮动到下一页去了，这么初级的LaTeX问题问出来信不信我扁你。

# 源代码控

这里提供的rticles模板可能由于种种原因不能满足客官的要求，LaTeX用户就是这样永无止境地调格式（唉，跟Word用户到底有啥区别呢）。若真是需要调整，你可以复制一份默认模板去改。默认模板来自 Pandoc：https://github.com/jgm/pandoc/blob/master/data/templates/default.latex 它是一个文本文件。若熟悉LaTeX的话一看就明白，只不过里面有些Pandoc变量而已；若不熟悉LaTeX我们在这里说了也白说，花几天时间好好啃一啃LaTeX入门手册吧。

# 小结

事实证明我们可以理直气壮地通过XeLaTeX将中文R Markdown转化为PDF文档，麻麻再也不用担心我的论文满屏幕都是反斜杠，朕养完小白鼠之后终于不必先折腾三个小时LaTeX再开始写实验报告了：打开RStudio，菜单File > New File > R Markdown，然后从模板中选择CTeX Documents，搞定。

---
title: A template for the *arxiv* style
authors:
  - name: David S. Hippocampus
    thanks: Use footnote for providing further information about author (webpage, alternative address)---*not* for acknowledging funding agencies. Optional.
    department: Department of Computer Science
    affiliation: Cranberry-Lemon University
    location: Pittsburgh, PA 15213
    email: hippo@cs.cranberry-lemon.edu
  - name: Elias D. Striatum
    department: Department of Electrical Engineering
    affiliation: Mount-Sheikh University
    location: Santa Narimana, Levand
    email: stariate@ee.mount-sheikh.edu
abstract: |
  Enter the text of your abstract here.
keywords:
  - blah
  - blee
  - bloo
  - these are optional and can be removed
bibliography: references.bib
biblio-style: unsrt
output: rticles::arxiv_article
---

# Introduction

Here goes an introduction text

# Headings: first level
\label{sec:headings}

You can use directly LaTeX command or Markdown text. 

LaTeX command can be used to reference other section. See Section \ref{sec:headings}.
However, you can also use **bookdown** extensions mechanism for this.

## Headings: second level

You can use equation in blocks

$$
\xi _{ij}(t)=P(x_{t}=i,x_{t+1}=j|y,v,w;\theta)= {\frac {\alpha _{i}(t)a^{w_t}_{ij}\beta _{j}(t+1)b^{v_{t+1}}_{j}(y_{t+1})}{\sum _{i=1}^{N} \sum _{j=1}^{N} \alpha _{i}(t)a^{w_t}_{ij}\beta _{j}(t+1)b^{v_{t+1}}_{j}(y_{t+1})}}
$$

But also inline i.e $z=x+y$

### Headings: third level

Another paragraph. 


# Examples of citations, figures, tables, references
\label{sec:others}

You can insert references. Here is some text [@kour2014real; @kour2014fast] and see @hadash2018estimate.

The documentation for \verb+natbib+ may be found at

You can use custom blocks with LaTeX support from **rmarkdown** to create environment.

::: {.center latex=true}
  <http://mirrors.ctan.org/macros/latex/contrib/natbib/natnotes.pdf}>
:::

Of note is the command \verb+\citet+, which produces citations
appropriate for use in inline text.  

You can insert LaTeX environment directly too.

\begin{verbatim}
   \citet{hasselmo} investigated\dots
\end{verbatim}

produces

\begin{quote}
  Hasselmo, et al.\ (1995) investigated\dots
\end{quote}

\begin{center}
  \url{https://www.ctan.org/pkg/booktabs}
\end{center}


## Figures

You can insert figure using LaTeX directly. 

See Figure \ref{fig:fig1}. Here is how you add footnotes. [^Sample of the first footnote.]

\begin{figure}
  \centering
  \fbox{\rule[-.5cm]{4cm}{4cm} \rule[-.5cm]{4cm}{0cm}}
  \caption{Sample figure caption.}
  \label{fig:fig1}
\end{figure}

But you can also do that using R.

```{r fig2, fig.cap = "Another sample figure"}
plot(mtcars$mpg)
```

You can use **bookdown** to allow references for Tables and Figures.


## Tables

Below we can see how to use tables. 

See awesome Table~\ref{tab:table} which is written directly in LaTeX in source Rmd file.

\begin{table}
 \caption{Sample table title}
  \centering
  \begin{tabular}{lll}
    \toprule
    \multicolumn{2}{c}{Part}                   \\
    \cmidrule(r){1-2}
    Name     & Description     & Size ($\mu$m) \\
    \midrule
    Dendrite & Input terminal  & $\sim$100     \\
    Axon     & Output terminal & $\sim$10      \\
    Soma     & Cell body       & up to $10^6$  \\
    \bottomrule
  \end{tabular}
  \label{tab:table}
\end{table}

You can also use R code for that.

```{r}
knitr::kable(head(mtcars), caption = "Head of mtcars table")
```


## Lists

- Item 1
- Item 2 
- Item 3

---
title: Wellcome Open Research Article Template
titlenote: The title should be detailed enough for someone to know whether the article would be of interest to them, but also concise. Please ensure the broadness and claims within the title are appropriate to the content of the article itself.
author:
  - name: Author Name1
    affil: 
    - 1
    - 2
    email: author1@email.com
  - name: Author Name2
    affil: 2
    email: author2@email.com
    corresponding: TRUE
address:
  - code: 1
    address: Address1
  - code: 2
    address: Address2
include-before: |
  Please list all authors that played a significant role in the research involved in the article. Please provide full affiliation information (including full institutional address, ZIP code and e-mail address) for all authors, and identify who is/are the corresponding author(s).
abstract: |
  Abstracts should be up to 300 words and provide a succinct summary of the article. Although the abstract should explain why the article might be interesting, care should be taken not to inappropriately over-emphasise the importance of the work described in the article. Citations should not be used in the abstract, and the use of abbreviations should be minimized. If you are writing a Research or Systematic Review article, please structure your abstract into Background, Methods, Results, and Conclusions.
keywords: |
  Please list up to eight keywords to help readers interested in your article find it more easily.

date: "`r Sys.Date()`"
bibliography: sample.bib
link-citations: TRUE
# Setting CSL will be necessary if you use `citation_packahe = "default"`
# You can download the csl file if preferred and use it locally with `csl: elsevier-vancouver.csl`
# csl: https://www.zotero.org/styles/elsevier-vancouver
output: 
  rticles::wellcomeor_article:
    citation_package: natbib
  bookdown::pdf_book:
    base_format: rticles::wellcomeor_article
    citation_package: natbib
---

*Text based on Wellcome Open Research [Overleaf Latex
template](https://www.overleaf.com/project/6131911644b635ad3aaa4cb2)*

\bigskip 

Please list all authors that played a significant role in the research involved
in the article. Please provide full affiliation information (including full
institutional address, ZIP code and e-mail address) for all authors, and
identify who is/are the corresponding author(s).

# Introduction

The format of the main body of the article is flexible: it should be concise and
in the format most appropriate to displaying the content of the article.

Some examples of commonly used \LaTeX{} commands and features are listed below,
to help you get started.

## Sections

Use section and subsection commands to organize your document. \LaTeX{} handles
all the formatting and numbering automatically. Use ref and label commands for
cross-references.

## Tables

Use the table and tabledata commands for basic tables --- see
Table \@ref(tab:widgets), for example.

```{=tex}
\begin{table}[h!]
  \hrule \vspace{0.1cm}
  \caption{\label{tab:widgets}An example of a simple table with caption.}
  \centering
  \begin{tabledata}{llr}
    \header First name & Last Name & Grade \\
    \row John & Doe & $7.5$ \\
    \row Richard & Miles & $2$ \\
  \end{tabledata}
\end{table}
```

Similarly, you can insert an R chunk and reference with 
[Bookdown referencing](https://bookdown.org/yihui/bookdown/tables.html), i.e.,
`\@ref(tab:label)`.

## Figures

You can upload a figure (JPEG, PNG or PDF) using the files menu. To include it
in your document, use the includegraphics \LaTeX{} command (see the example
below in the source code), or insert using an R chunk and reference with
[Bookdown referencing](https://bookdown.org/yihui/bookdown/figures.html), i.e.,
`\@ref(fig:label)`.

Please give figures appropriate filenames eg: figure1.pdf, figure2.png.

Figure legends should briefly describe the key messages of the figure such that
the figure can stand alone from the main text. However, all figures should also
be discussed in the article text. Each legend should have a concise title of no
more than 15 words. The legend itself should be succinct, while still explaining
all symbols and abbreviations. Avoid lengthy descriptions of methods.

For any figures reproduced from another publication (as long as appropriate
permission has been obtained from the copyright holder ---see under the heading
'Submission'), please include a line in the legend to state that: 'This figure
has been reproduced with kind permission from [include original publication
citation]'.

```{=tex}
\begin{figure} 
  \centering 
  \includegraphics[width=0.4\textwidth]{frog.jpg}
  \caption{\label{fig:your-figure}Your figure legend goes here; it should be
  succinct, while still explaining all symbols and abbreviations. } 
\end{figure}
```

## Mathematics

\LaTeX{} is great at typesetting mathematics. Let $X_1, X_2, \ldots, X_n$ be a
sequence of independent and identically distributed random variables with
$\text{E}[X_i] = \mu$ and $\text{Var}[X_i] = \sigma^2 < \infty$, and let $$S_n =
\frac{X_1 + X_2 + \cdots + X_n}{n} = \frac{1}{n}\sum_{i}^{n} X_i$$ denote their
mean. Then as $n$ approaches infinity, the random variables
$\sqrt{n}(S_n - \mu)$ converge in distribution to a normal
$\mathcal{N}(0, \sigma^2)$.

## Lists

You can make lists with automatic numbering \dots

1.  Like this,
2.  and like this.

\dots or bullet points \dots

-   Like this,
-   and like this.

# Methods

Methods should include a brief discussion of allowances made (if any) for
controlling bias or unwanted sources of variability, and the limitations of the
datasets.

# Results

This section is not essential for Web Tool papers.

# Discussion

The discussion should include the implications of the article results in view of
prior work in this field.

# Conclusions

Please state what you think are the main conclusions that can be realistically
drawn from the findings in the paper, taking care not to make claims that cannot
be supported.

## Author contributions

In order to give appropriate credit to each author of an article, the individual
contributions of each author to the manuscript should be detailed in this
section. We recommend using author initials and then stating briefly how they
contributed.

## Competing interests

All financial, personal, or professional competing interests for any of the
authors that could be construed to unduly influence the content of the article
must be disclosed and will be displayed alongside the article.

## Grant information

Please state who funded the work discussed in this article, whether it is your
employer, a grant funder etc. Please do not list funding that you have that is
not relevant to this specific piece of research. For each funder, please state
the funder's name, the grant number where applicable, and the individual to whom
the grant was assigned.

## Acknowledgements

This section should acknowledge anyone who contributed to the research or the
article but who does not qualify as an author based on the criteria provided
earlier (e.g. someone or an organisation that provided writing assistance).
Please state how they contributed; authors should obtain permission to
acknowledge from all those mentioned in the Acknowledgements section.

Please do not list grant funding in this section.

# Handling References

References can be listed in any standard referencing style that uses a numbering
system(i.e. not Harvard referencing style), and should be consistent between
references within a given article.

Reference management systems such as Zotero provide options for exporting
bibliographies as Bib\TeX{} files. Bib\TeX{} is a bibliographic tool that is
used with \LaTeX{} to help organize the user's references and create a
bibliography. This template contains an example of such a file,
\texttt{sample.bib}, which can be replaced with your own. You can \LaTeX{}
command  \verb|\cite| to create in-text citationsor by using
RMarkdown/Bookdown's citations [@Smith:2012qr], and [@Smith:2013jd]

---
title: Short Paper
author:
  - name: Alice Anonymous
    email: alice@example.com
    affiliation: Some Institute of Technology
  - name: Bob Security
    email: bob@example.com
    affiliation: Another University
abstract: |
  This is the abstract.

  It consists of two paragraphs.
bibliography: sigproc.bib
csl: acm-sig-proceedings.csl
output: rticles::acm_article
---



# Introduction 
Lorem ipsum dolor sit[@meier2012] amet, consectetur adipiscing[@fenner2012a] elit. Pellentesque rhoncus ut tellus eu tristique. Duis pharetra velit vitae viverra elementum. Nulla metus dui, pulvinar id enim at, pellentesque semper ipsum. Phasellus cursus dignissim ipsum, sed congue orci pretium quis. Maecenas rhoncus leo a cursus euismod. Fusce a erat eu ipsum tristique tempus at sed tortor. Aliquam erat volutpat. Donec at pretium lorem. Donec pretium nunc id nunc bibendum convallis. Phasellus quis enim id massa feugiat egestas hendrerit sollicitudin nibh. Sed blandit eros id tellus porta, eget ullamcorper urna posuere. Pellentesque laoreet lacus nibh, a mattis libero viverra sit amet. Sed vitae diam interdum, pharetra neque sit amet, dictum lectus.

Donec massa justo, ultricies quis facilisis sed, tristique nec metus. Vestibulum id condimentum diam. Integer semper augue id porttitor ultrices. Cras vulputate felis eu diam porttitor, ac pulvinar nisi imperdiet. Donec eros felis, imperdiet vel malesuada at, varius et quam. Phasellus facilisis non risus eu placerat. Sed ac mollis lorem.

# Evaluation
Nullam semper imperdiet orci, at lacinia est aliquet et. Sed justo nibh, aliquet et velit at, pharetra consequat velit. Nullam nec ligula sagittis, adipiscing nisl sed, varius massa. Mauris quam ante, aliquet a nunc et, faucibus imperdiet libero. Suspendisse odio tortor, bibendum vel semper sit amet, euismod ac ante. Nunc nec dignissim turpis, ac blandit massa. Donec auctor massa ac vestibulum aliquam. Fusce auctor dictum lobortis. Vivamus tortor augue, convallis quis augue sit amet, laoreet tristique quam. Donec id volutpat orci. Suspendisse at mi vel elit accumsan porta ac ut diam. Nulla ut dapibus quam.

Sed est odio, ornare in rutrum et, dapibus in urna. Suspendisse varius massa in ipsum placerat, quis tristique magna consequat. Suspendisse non convallis augue. Quisque fermentum justo et lorem volutpat euismod. Vestibulum ante ipsum primis in faucibus orci luctus et ultrices posuere cubilia Curae; Morbi sagittis interdum justo, eu consequat nisi convallis in. Sed tincidunt risus id lacinia ultrices. Phasellus ac ligula sed mi mattis lacinia ac non felis. Etiam at dui tellus.

# Conclusion
Duis nec purus sed neque porttitor tincidunt vitae quis augue. Donec porttitor aliquam ante, nec convallis nisl ornare eu. Morbi ut purus et justo commodo dignissim et nec nisl. Donec imperdiet tellus dolor, vel dignissim risus venenatis eu. Aliquam tempor imperdiet massa, nec fermentum tellus sollicitudin vulputate. Integer posuere porttitor pharetra. Praesent vehicula elementum diam a suscipit. Morbi viverra velit eget placerat pellentesque. Nunc congue augue non nisi ultrices tempor.

# References

---
references:
- id: meier2012
  title: Professinal Android 4 Application Development
  author: 
  - family: Meier
    given: Reto
  type: book
  publisher: John Wiley & Sons, Inc.
  issued:
    year: 2012
    month: 5
- id: fenner2012a
  title: One-click science marketing
  author:
  - family: Fenner
    given: Martin
  container-title: Nature Materials
  volume: 11
  URL: 'https://doi.org/10.1038/nmat3283'
  DOI: 10.1038/nmat3283
  issue: 4
  publisher: Nature Publishing Group
  page: 261-263
  type: article-journal
  issued:
    year: 2012
    month: 3
...

---
title: "child of Examples.Rmd"
---

```{r, message = TRUE, warning = TRUE, include = FALSE}
# this is to generate the GIF and PDF for the gallery
# This is done on GHA and there is a caching mechanism so that a new rendering
# occurs only when needed

library(rticles)
library(magick)

# dir setup
hash_db_dir <- "cache"
if (!dir.exists(hash_db_dir)) dir.create(hash_db_dir)
out_dir <- "resources"
if (!dir.exists(out_dir)) dir.create(out_dir)

# ignore some journals 
to_ignore <- c(
  "ctex", # exclude ctex for now (issue to build)
  "rjournal" # lives in rjtools package now.
)

for (journal in journals()) {
  hash_db_file <- file.path(hash_db_dir, xfun::with_ext(journal, ".rds"))
  out_files <- file.path(out_dir, xfun::with_ext(paste0(journal, "_article"), c("gif", "pdf")))
  # clean for ignored journal
  if (journal %in% to_ignore) {
    # clean files
    to_remove <- xfun::existing_files(c(out_files, hash_db_file))
    if (length(to_remove)) unlink(to_remove)
    next
  }
  # clean cache if no more files
  if (!all(file.exists(out_files))) unlink(hash_db_file)
  # Should we render new resource ? 
  resource_path <- rticles:::pkg_file_template(journal)
  template_files <- list.files(resource_path, recursive = TRUE)
  template_files <- setNames(
    file.path(resource_path, template_files), 
    nm = template_files)
  new_hash_db <- lapply(template_files, function(x) unname(tools::md5sum(x)))
  if (file.exists(hash_db_file)) {
    old_hash_db <- readRDS(hash_db_file)
    if (identical(old_hash_db, new_hash_db)) {
      message("No changes in templates. Skipping ",
              journal, " format.")
      next
    }
  }
  message("Rendering to PDF...")
  out_pdf <- xfun::try_silent(rticles:::render_draft(journal, quiet = TRUE))
  if (inherits(out_pdf, "try-error")) {
    warning("Error with rendering format ", journal,
            immediate. = TRUE)
    next
  }

  message("Converting to GIF...")
  pdf_content <- image_read_pdf(out_pdf, density = 72) %>% image_resize(geometry = "400x")
  out_gif <- image_write_gif(
    image = pdf_content,
    path = xfun::with_ext(out_pdf, "gif"),
    delay = 1)
  message("Retrieving built files.")
  # specific treatment for rjournal name
  if (journal == "rjournal") {
    file.rename(out_pdf, out_pdf <- file.path(dirname(out_pdf), "rjournal_article.pdf"))
    file.rename(out_gif, out_gif <- file.path(dirname(out_gif), "rjournal_article.gif"))
  }
  file.copy(out_pdf, out_dir)
  file.copy(out_gif, out_dir)
  # clean temp dir
  unlink(dirname(out_pdf), recursive = TRUE)
  # saving the new hash
  saveRDS(new_hash_db, hash_db_file)
}

```

---
title: Template for Oxford University Press papers
author:
  - name: Alice Anonymous
    email: alice@example.com
    corresponding_author: TRUE # Automatic footnote using corresponding_author
    affiliation:
      - ABC
      - DEF
    biography: |
      A promising young researcher working on her thesis project.
#    biography_pic: "/PATH/TO/image.png"
#    biography_pic_width: "1in"
  - name: Bob Security
    email: bob@example.com
    affiliation: DEF
    footnote: 1 # Footnote using reference
  - name: Cat Memes
    email: cat@anotheru.edu
    affiliation: Another University
    footnote:
        - 1
        - 2
address:
  - code: ABC
    department: Department of Biology
    organization: University of Idaho
    street: 123 Main Street
    #postcode: 
    city: Boise
    state: Idaho 07458 # Mix and match elements to get proper address
    country: United States
  - code: DEF
    address: Address in one element deprecated, but works
  - code: Another University
    address: Address for Another University
footnote:
  - code: 1
    text: "Equal contribution"
  - code: 2
    text: "Current email address: [cat@example.com](mailto:cat@example.com)"
abstract:
  - "This is the first paragraph of the abstract. It has several sentences making it go over several lines. For this it needs to have a lot of text." 
  - "This is the second paragraph."
  - "**Motivation:** You can also have some paragraphs start with bold face."
keywords:
  - keyword1
  - keyword2
  - keyword3
#boxedlist: # Not fully compatible with all document formats
#  - First point
#  - Second point
competing_interests: |
  There are no competing interest.
author_contributions: |
  AA did all the work. The others are just freeloaders.
acknowledgements: |
  This is an acknowledgement.

  It consists of two paragraphs.

bibliography: mybibfile.bib # Includes refs in OUP example template
## When using `citation_package = "default"`, a CSL file can be used
#csl: https://www.zotero.org/styles/oxford-university-press-note
output:
  rticles::oup_article:
    oup_version: 1 # 1 = 2020 CTAN OUP CLS package; 0 = 2009 OUP CLS package
    journal: "Journal Name"
    document_style: "contemporary" # Can be contemporary, modern, traditional
    papersize: "large" # Can be large, medium, small
    #citation_package: "default" # Uncomment when using a CSL; default "natbib"
    namedate: TRUE # Set FALSE to use numeric refs; Default FALSE
    #number_sections: FALSE # Uncomment to not number sections; default TRUE
    #number_lines: TRUE # Use `lineno` package - Default FALSE
    #number_lines_options: ["mathlines","switch"]  # Options for latex lineno package.
    #onecolumn: TRUE # Uncomment for one column format; default FALSE
    extra_dependencies:
      - booktabs # to use with knitr::kable() example below
      
## Example of pandoc's variable
#urlcolor: orange
#linkcolor: green
#citecolor: red
header-includes:
  #- \usepackage[nomarkers,tablesfirst]{endfloat} # For figures and tables at end
  - \theoremstyle{thmstyleone} # Theorem stuff from OUP template
  - \newtheorem{theorem}{Theorem} #  meant for continuous numbers. %%\newtheorem{theorem}{Theorem}[section] # meant for sectionwise numbers. optional argument [theorem] produces theorem numbering sequence instead of independent numbers for Proposition
  - \newtheorem{proposition}[theorem]{Proposition} # %%\newtheorem{proposition}{Proposition}" # to get separate numbers for theorem and proposition etc.
  - \theoremstyle{thmstyletwo}
  - \newtheorem{example}{Example}
  - \newtheorem{remark}{Remark}
  - \theoremstyle{thmstylethree}
  - \newtheorem{definition}{Definition}
---

```{r setup, include=FALSE}
knitr::opts_chunk$set(
  echo = FALSE, # By default, hide code; set to TRUE to see code
  fig.pos = 'th', # Places figures at top or here
  out.width = '100%', dpi = 300, # Figure resolution and size
  fig.env="figure"
) # Latex figure environment

options(knitr.table.format = "latex") # For kable tables to write LaTeX table directly
```

# Introduction

This template is based on the generic OUP authoring template available on CTAN under [oup-authoring-template](https://www.ctan.org/pkg/oup-authoring-template). The CTAN template includes LaTeX documentation and a sample LaTeX document that provide far more details regarding the full functionality of the format. Here, only the basic functioning of the Rmarkdown adaptation of the format is demonstrated.

## A subsection

A numbered list:

1) First point
2) Second point
    - Subpoint
    
A bullet list:

* First point
* Second point

## Notes

* Extra white space in document will tend to disappear as text is filled in.
* Code blocks tend to generate lots of empty white space when `echo=TRUE` for some reason.

# Literature citations

By default, citations are handled by `natbib` using a numeric citation format. To use name-date citations, sets `namedate: TRUE` in the YAML header.

Here are two sample references: 

* **author (year) example:** @horvath2018dna showed some really cool things. Only seems to work properly if `namedate: TRUE`. 
* **(author year) example:** This is a well known result [@ji20123d]. 

The bibliography will appear at the end of the document.

Though not normally available in the OUP LaTeX format, [CSL style files](https://www.zotero.org/styles) can also be used with the Rmarkdown adaptation by setting in the YAML header `citation_package: "default"` and defining the `csl` element to be the path towards the style file.

# Equations

An equation without a label for cross-referencing:

$$
E=mc^2
$$

An inline equation: $y=ax+b$

An equation with a label for cross-referencing:

\begin{equation}\label{eq:eq1}
\int^{r_2}_0 F(r,\varphi){\rm d}r\,{\rm d}\varphi = 1
\end{equation}

This equation can be referenced as follows: Eq. \ref{eq:eq1}

# Inserting R figures

The code below creates a figure. The code is included in the output because `echo=TRUE`.

```{r fig1, fig.cap="This is the first figure.",echo=TRUE}
plot(1:10,main="Some data",xlab="Distance (cm)",
     ylab="Time (hours)")
```

You can reference this figure as follows: Fig. \ref{fig:fig1}.

## Figures spanning two-columns

Figures can span two columns be setting `fig.env="figure*"`.

```{r fig2, fig.cap="This is a wide figure.",fig.env="figure*"}
plot(1:5,pch=19,main="Some wide data",
     xlab="Distance (cm)",ylab="Time (hours)")
```

Reference to second figure: Fig. \ref{fig:fig2}

# Tables

## Generate a table using `xtable`

```{r xtabletable, results="asis", echo=TRUE}
df = data.frame(ID=1:3,code=letters[1:3])

# Creates tables that follow OUP guidelines 
# using xtable
library(xtable) 
print(xtable(df,caption="This is a xtable table.",
             label="tab:tab1"),
      comment=FALSE,caption.placement="top")
```

You can reference this table as follows: Table \ref{tab:tab1}.

## Generate a table using `kable`

```{r kabletable, echo=TRUE}
df = data.frame(ID=1:3,code=letters[1:3])

# kable can alse be used for creating tables
knitr::kable(df,caption="This is a kable table.",
             booktabs=TRUE,label="tab2")
```

You can reference this table as follows: Table \ref{tab:tab2}.

## Table spanning two columns

Tables can span two columns be setting `table.envir = "table*"` in `knitr::kable`.

```{r widetable, echo=TRUE}
df = data.frame(ID=1:3,code1=letters[1:3],
                code2=letters[4:6],
                code3=letters[7:9],
                code4=letters[10:12],
                code5=letters[13:15])

# kable can alse be used for creating tables
knitr::kable(df,caption="This is a wide kable table.",
             #format="latex",
             table.envir="table*",
             booktabs=TRUE,label="tab3")
```

# Cross-referencing sections

You can cross-reference sections and subsections as follows: Section \ref{literature-citations} and Section \ref{a-subsection}.

***Note:*** the last section in the document will be used as the section title for the bibliography.

For more portable and flexible referencing of sections, equations, figures and tables, use [`bookdown::pdf_document2`](https://github.com/rstudio/bookdown) with YAML header option `base_format: rticles::oup_article`.

# Appendices {-}

::: {.appendices latex=true}

# Section title of first appendix

blabla

## Subsection title of first appendix

and so on....
:::

# References

# rjournal_article() is deprecated

    Code
      x <- rjournal_article()
    Condition
      Warning:
      `rjournal_article()` was deprecated in rticles 0.25.
      i Please use `rjtools::rjournal_pdf_article()` instead.
      i See official recommandation at https://rjournal.github.io/submissions.html

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/jss_article.R
\name{jss_article}
\alias{jss_article}
\title{Journal of Statistical Software (JSS) format.}
\usage{
jss_article(
  ...,
  keep_tex = TRUE,
  citation_package = "natbib",
  pandoc_args = NULL
)
}
\arguments{
\item{...}{Arguments to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}}

\item{keep_tex}{Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., \file{.aux}) generated by LaTeX when compiling \file{.tex} to
\file{.pdf}. To keep these files, you may set \code{options(tinytex.clean =
FALSE)}.}

\item{citation_package}{The LaTeX package to process citations, \code{natbib}
or \code{biblatex}. Use \code{default} if neither package is to be used,
which means citations will be processed via the command
\command{pandoc-citeproc}.}

\item{pandoc_args}{Additional command line options to pass to pandoc}
}
\description{
Format for creating a Journal of Statistical Software (JSS) articles. Adapted
from \url{https://www.jstatsoft.org/about/submissions}.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/copernicus_article.R
\name{copernicus_article}
\alias{copernicus_article}
\alias{copernicus_journal_abbreviations}
\title{Copernicus journals format.}
\usage{
copernicus_article(
  ...,
  keep_tex = TRUE,
  highlight = NULL,
  citation_package = "natbib",
  md_extensions = c("-autolink_bare_uris", "-auto_identifiers")
)

copernicus_journal_abbreviations(journal_name = "*")
}
\arguments{
\item{...}{Additional arguments to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}. \strong{Note}: \code{extra_dependencies} are not
allowed as Copernicus does not support additional packages included via \code{\\usepackage{}}.}

\item{keep_tex}{Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., \file{.aux}) generated by LaTeX when compiling \file{.tex} to
\file{.pdf}. To keep these files, you may set \code{options(tinytex.clean =
FALSE)}.}

\item{highlight}{Syntax highlighting style passed to Pandoc.

 Supported built-in styles include "default", "tango", "pygments", "kate",
 "monochrome", "espresso", "zenburn", "haddock", and "breezedark".

  Two custom styles are also included, "arrow", an accessible color scheme,
  and "rstudio", which mimics the default IDE theme. Alternatively, supply a
  path to a \samp{.theme} file to use
  \href{https://pandoc.org/MANUAL.html#syntax-highlighting}{a custom Pandoc
  style}. Note that custom theme requires Pandoc 2.0+.

  Pass \code{NULL} to prevent syntax highlighting.}

\item{citation_package}{The LaTeX package to process citations, \code{natbib}
or \code{biblatex}. Use \code{default} if neither package is to be used,
which means citations will be processed via the command
\command{pandoc-citeproc}.}

\item{md_extensions}{Markdown extensions to be added or removed from the
default definition of R Markdown. See the \code{\link[rmarkdown]{rmarkdown_format}} for
additional details.}

\item{journal_name}{A regular expression to filter the by the journal name, see \code{pattern} in \code{\link[base:grep]{base::grep()}}; defaults to \code{*}.}
}
\value{
An R Markdown output format.
}
\description{
Format for creating submissions to Copernicus journals.
}
\details{
This was adapted from
\url{https://publications.copernicus.org/for_authors/manuscript_preparation.html}.

An number of required and optional manuscript sections, e.g. \code{acknowledgements}, \code{competinginterests}, or \code{authorcontribution}, must be declared using the respective properties of the R Markdown header - see skeleton file.

\strong{Version:} Based on \code{copernicus_package.zip} in the version 7.5, 20 October 2023, using \code{copernicus.cls} in version 10.1.9, 16 October 2023.

\strong{Copernicus journal abbreviations:} You can use the function \code{copernicus_journal_abbreviations()} to get the journal abbreviation for all journals supported by the Copernicus article template.

\strong{Important note:} The online guidelines by Copernicus are the official resource.
Copernicus is not responsible for the community contributions made to support the template in this package.
Copernicus converts all typeset TeX files into XML, the expressions and markups have to be highly standardized.
Therefore, please keep the following in mind:
\itemize{
\item Please provide only one figure file for figures with several panels, and please do not use \verb{\\subfloat} or similar commands.
\item Please use only commands in which words, numbers, etc. are within braces (e.g. \verb{\\textrm\{TEXT\}} instead of \verb{\\rm TEXT}).
\item For algorithms, please use the syntax given in template.tex or provide your algorithm as a figure.
\item Please do not define new commands.
\item Supported packages (\verb{\\usepackage\{\}}) are already integrated in the \code{copernicus.cls}.  Please do not insert additional ones in your \code{.tex} file.
\item If you opt for syntax highlighting for your preprint or other reasons, please do not forget to use
\code{highlight = NULL} for your final file upload once your manuscript was accepted for publication.
\item Spaces in labels (\verb{\\label\{\}}) are not allowed; please make sure that no label name is assigned more than once.
\item Please do not use \verb{\\paragraph\{\}}; only \verb{\\subsubsection\{\}} is allowed.
\item It is not possible to add tables in colour.
}
}
\note{
If you use \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}, all internal references (i.e. tables and figures) must use \verb{\\ref\{\}} whereas with \code{\link[bookdown:html_document2]{bookdown::pdf_document2()}}, you can additionally use \verb{\\@ref()}.
}
\examples{
names(copernicus_journal_abbreviations())
copernicus_journal_abbreviations(journal_name = "Science Data")
\dontrun{
library("rmarkdown")
draft("MyArticle.Rmd", template = "copernicus", package = "rticles")
render("MyArticle/MyArticle.Rmd")
}
}
\references{
Manuscript preparation guidelines for authors.
\url{https://publications.copernicus.org/for_authors/manuscript_preparation.html}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/joss_article.R
\name{joss_article}
\alias{joss_article}
\title{Journal of Open Source Software (JOSS) format.}
\usage{
joss_article(journal = "JOSS", keep_md = TRUE, latex_engine = "xelatex", ...)
}
\arguments{
\item{journal}{one of "JOSS" or"JOSE"}

\item{keep_md}{Whether to retain the intermediate markdown and images.
Defaults to TRUE.}

\item{latex_engine, ...}{Arguments passed to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}}
}
\description{
Format for creating a Journal of Open Source Software (JOSS) or Journal of
Open Source Education (JOSE) articles. Adapted
from \url{https://github.com/openjournals/whedon}. As these journals take
articles as markdown, this format can be used to generate markdown from
R Markdown and to locally preview how the article will appear as PDF.
}
\details{
The following variables may be set in YAML metadata to populate fields in the
article PDF, but are only necessary fo local preview:
\verb{formatted_doi, citation_author, year, volume, issue, page, submitted, published, review_url, repository}, and \code{archive_doi}.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rjournal_article.R
\name{rjournal_article}
\alias{rjournal_article}
\title{R Journal format.}
\usage{
rjournal_article(..., keep_tex = TRUE, citation_package = "natbib")
}
\arguments{
\item{...}{Arguments to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}.}

\item{keep_tex}{Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., \file{.aux}) generated by LaTeX when compiling \file{.tex} to
\file{.pdf}. To keep these files, you may set \code{options(tinytex.clean =
FALSE)}.}

\item{citation_package}{The LaTeX package to process citations, \code{natbib}
or \code{biblatex}. Use \code{default} if neither package is to be used,
which means citations will be processed via the command
\command{pandoc-citeproc}.}
}
\description{
\ifelse{html}{\href{https://lifecycle.r-lib.org/articles/stages.html#deprecated}{\figure{lifecycle-deprecated.svg}{options: alt='[Deprecated]'}}}{\strong{[Deprecated]}}

This function is now deprecated in favor of the \href{https://rjournal.github.io/rjtools/}{\strong{rjtools}} package
which is now officialy recommanded by R Journal \url{https://rjournal.github.io/submissions.html}. See below for document
}
\section{About this format and the R Journal requirements}{
Format for creating R Journal articles. Adapted from
\url{https://journal.r-project.org/submissions.html}.

This file is only a basic article template. For full details of \emph{The R
Journal} style and information on how to prepare your article for submission,
see the \href{https://journal.r-project.org/share/author-guide.pdf}{Instructions for Authors}

\code{rticles::rjournal_article} will help you build the correct files requirements:
\itemize{
\item A R file will be generated automatically using \code{knitr::purl} - see
https://bookdown.org/yihui/rmarkdown-cookbook/purl.html for more information.
\item A tex file will be generated from this Rmd file and correctly included in
\code{RJwapper.tex} as expected to build \code{RJwrapper.pdf}.
\item All figure files will be kept in the default rmarkdown \verb{*_files} folder. This
happens because \code{keep_tex = TRUE} by default in \code{rticles::rjournal_article}
\item Only the bib filename is to be modified. An example bib file is included in the
template (\code{RJreferences.bib}) and you will have to name your bib file as the
tex, R, and pdf files.
}
}

\section{About YAML header fields}{
This section documents some of the YAML fields that can be used with this
formats.
\subsection{The \code{author} field in the YAML header}{\tabular{lll}{
   FIELD \tab TYPE \tab DESCRIPTION \cr
   \code{name} \tab \emph{required} \tab name and surname of the author \cr
   \code{affiliation} \tab \emph{required} \tab name of the author's affiliation \cr
   \code{address} \tab \emph{required} \tab at least one address line for the affiliation \cr
   \code{url} \tab \emph{optional} \tab an additional url for the author or the main affiliation \cr
   \code{orcid} \tab \emph{optional} \tab the authors ORCID if available \cr
   \code{email} \tab \emph{required} \tab the author's e-mail address \cr
   \code{affiliation2} \tab \emph{optional} \tab name of the author's 2nd affiliation \cr
   \code{address2} \tab \emph{optional} \tab address lines belonging to the author's 2nd affiliation \cr
}


\emph{Please note: Only one \code{url}, \code{orcid} and \code{email} can be provided per author.}
}

\subsection{Other YAML fields}{\tabular{lll}{
   FIELD \tab TYPE \tab DESCRIPTION \cr
   \code{bibliography} \tab \emph{with default} \tab the BibTeX file with the reference entries \cr
}

}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{journals}
\alias{journals}
\title{List available journals}
\usage{
journals()
}
\value{
A character vector of the journal names.
}
\description{
List available journal names in this package.
}
\details{
These names can be useful in two ways:
\itemize{
\item You can add \verb{_article} suffix to get the name of the output format (e.g.,
\code{\link[=rjournal_article]{rjournal_article()}}).
\item You can use the name directly in the \code{template} argument of
\code{\link[rmarkdown:draft]{rmarkdown::draft()}}.
}
}
\examples{
rticles::journals()
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/oup_article.R
\name{oup_article}
\alias{oup_article}
\title{Oxford University Press.}
\usage{
oup_article(
  oup_version = 0,
  journal = NULL,
  number_sections = FALSE,
  citation_package = ifelse(oup_version == 0, "default", "natbib"),
  papersize = c("large", "medium", "small"),
  document_style = c("contemporary", "modern", "traditional"),
  namedate = FALSE,
  onecolumn = FALSE,
  number_lines = FALSE,
  number_lines_options = NULL,
  keep_tex = TRUE,
  md_extensions = c("-autolink_bare_uris"),
  pandoc_args = NULL,
  ...
)
}
\arguments{
\item{oup_version}{set to 0 (default) to use the 2009 OUP \code{ouparticle.cls}
included or set to 1 to use the newer 2020 OUP package
\code{oup-authoring-template} available on CTAN.}

\item{journal}{journal Title. \emph{(Only useful for \code{oup_version > 0})}.}

\item{number_sections}{It will be passed to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}. Set to
TRUE by default when \code{oup_version = 1} is used.}

\item{citation_package}{The LaTeX package to process citations, \code{natbib}
or \code{biblatex}. Use \code{default} if neither package is to be used,
which means citations will be processed via the command
\command{pandoc-citeproc}.}

\item{papersize}{one of "large" (default), "medium", or "small" setting
output page size. \emph{(Only useful for \code{oup_version > 0})}}

\item{document_style}{one of "contemporary" (default), "modern", or
"traditional" setting overall style of document. \emph{(Only useful for \code{oup_version > 0})}}

\item{namedate}{a logical variable
indicating if natbib citations should be in name-date format. Defaults to
\code{FALSE}. \emph{(Only useful for \code{oup_version > 0})}}

\item{onecolumn}{a logical variable indicating if one column formatting
should be used. Defaults to \code{FALSE}. \emph{(Only useful for \code{oup_version > 0})}}

\item{number_lines, number_lines_options}{Control the usage of CTAN package
\code{lineno} in the template. Use \code{number_lines =TRUE} to activate and set
\code{number_lines_options} to change options. \emph{(Only useful for \code{oup_version > 0})}}

\item{keep_tex}{Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., \file{.aux}) generated by LaTeX when compiling \file{.tex} to
\file{.pdf}. To keep these files, you may set \code{options(tinytex.clean =
FALSE)}.}

\item{md_extensions}{Markdown extensions to be added or removed from the
default definition of R Markdown. See the \code{\link[rmarkdown]{rmarkdown_format}} for
additional details.}

\item{pandoc_args}{Additional command line options to pass to pandoc}

\item{...}{Additional arguments to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}}
}
\description{
Format for creating submissions to many Oxford University Press journals.
Adapted from
\url{https://academic.oup.com/pages/authoring/journals/preparing_your_manuscript}
and \url{https://academic.oup.com/icesjms/pages/General_Instructions}. and the
\code{oup-authoring-template} available on CTAN at
\url{https://www.ctan.org/pkg/oup-authoring-template}.
}
\details{
Note that for
\itemize{
\item \code{oup_version=0}, \code{citation_package="default"} by default,
\item \code{oup_version=1}, \code{citation_package="natbib"} by default and
\code{citation_package="biblatex"} is not supported.
}
}
\section{Pandoc requirement}{
\code{oup_version = 1} requires a minimum version of 2.10.
}

\examples{
\dontrun{
# Use old template based on `ouparticle.cls`
rmarkdown::draft("MyArticle.Rmd", template = "oup_v0", package = "rticles")
# Use new template based on `oup-authoring-template` CTAN package
rmarkdown::draft("MyArticle.Rmd", template = "oup_v1", package = "rticles")
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils.R
\name{string_to_table}
\alias{string_to_table}
\title{Split character string into table}
\usage{
string_to_table(x, n, split_regex = ", ?")
}
\arguments{
\item{x}{string to split and convert to table}

\item{n}{number of bucket to create. It will be the number of column in the
resulting data.frame}

\item{split_regex}{defaults to \verb{, ?}. Pass to \code{split} in \code{\link[base:strsplit]{base::strsplit()}}.}
}
\value{
a dataframe of \code{n} columns
}
\description{
It takes a character string with names separated by comma (e.g. journal's names)
and turns them into a table
}
\details{
If the number of elements can't be split equally in the \code{n} column, blank
cells will be created and all placed in the last column.
}
\examples{
string_to_table(paste(letters, collapse = ", "), 3)
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rss_article.R
\name{rss_article}
\alias{rss_article}
\title{Royal Statistical Society Journal Format}
\usage{
rss_article(..., keep_tex = TRUE, citation_package = "natbib")
}
\arguments{
\item{...}{Arguments to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}}

\item{keep_tex}{Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., \file{.aux}) generated by LaTeX when compiling \file{.tex} to
\file{.pdf}. To keep these files, you may set \code{options(tinytex.clean =
FALSE)}.}

\item{citation_package}{The LaTeX package to process citations, \code{natbib}
or \code{biblatex}. Use \code{default} if neither package is to be used,
which means citations will be processed via the command
\command{pandoc-citeproc}.}
}
\description{
Format for creating articles for Royal Statistical Society adapted from
\url{https://rss.org.uk/news-publication/publications/journals/submit-paper/}.
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rticles-package.R
\docType{package}
\name{rticles-package}
\alias{rticles}
\alias{rticles-package}
\title{rticles: Article Formats for R Markdown}
\description{
\if{html}{\figure{logo.png}{options: style='float: right' alt='logo' width='120'}}

A suite of custom R Markdown formats and templates for authoring journal articles and conference submissions.
}
\seealso{
Useful links:
\itemize{
  \item \url{https://github.com/rstudio/rticles}
  \item Report bugs at \url{https://github.com/rstudio/rticles/issues}
}

}
\author{
\strong{Maintainer}: Christophe Dervieux \email{cderv@posit.co} (\href{https://orcid.org/0000-0003-4474-2498}{ORCID})

Authors:
\itemize{
  \item JJ Allaire \email{jj@posit.co}
  \item Yihui Xie \email{xie@yihui.name} (\href{https://orcid.org/0000-0003-0645-5666}{ORCID})
  \item  R Foundation [copyright holder]
  \item Hadley Wickham \email{hadley@posit.co}
  \item  Journal of Statistical Software [copyright holder]
  \item Ramnath  Vaidyanathan \email{ramnath.vaidya@gmail.com} [copyright holder]
  \item  Association for Computing Machinery [copyright holder]
  \item Carl Boettiger \email{cboettig@gmail.com} [copyright holder]
  \item  Elsevier [copyright holder]
  \item Karl Broman \email{kbroman@gmail.com} [copyright holder]
  \item Kirill Mueller \email{kirill.mueller@ivt.baug.ethz.ch} [copyright holder]
  \item Bastiaan Quast \email{bquast@gmail.com} [copyright holder]
  \item Randall  Pruim \email{rpruim@gmail.com} [copyright holder]
  \item Ben Marwick \email{bmarwick@uw.edu} [copyright holder]
  \item Charlotte Wickham \email{cwickham@gmail.com} [copyright holder]
  \item Oliver Keyes \email{okeyes@wikimedia.org} [copyright holder]
  \item Miao Yu \email{yufreecas@gmail.com} [copyright holder]
  \item Daniel Emaasit \email{daniel.emaasit@gmail.com} [copyright holder]
  \item Thierry Onkelinx \email{thierry.onkelinx@inbo.be} [copyright holder]
  \item Alessandro Gasparini \email{ellessenne@gmail.com} (\href{https://orcid.org/0000-0002-8319-7624}{ORCID}) [copyright holder]
  \item Marc-Andre Desautels \email{marc-andre.desautels@cstjean.qc.ca} [copyright holder]
  \item Dominik Leutnant \email{leutnant@fh-muenster.de} (\href{https://orcid.org/0000-0003-3293-2315}{ORCID}) [copyright holder]
  \item  MDPI [copyright holder]
  \item  Taylor and Francis [copyright holder]
  \item Oğuzhan Öğreden (\href{https://orcid.org/0000-0002-9949-3348}{ORCID})
  \item Dalton Hance \email{dhance@usgs.gov}
  \item Daniel Nüst \email{daniel.nuest@uni-muenster.de} (\href{https://orcid.org/0000-0002-0024-5046}{ORCID}) [copyright holder]
  \item Petter Uvesten \email{petter.uvesten.7362@student.lu.se} [copyright holder]
  \item Elio Campitelli \email{elio.campitelli@cima.fcen.uba.ar} (\href{https://orcid.org/0000-0002-7742-9230}{ORCID}) [copyright holder]
  \item John Muschelli \email{muschellij2@gmail.com} (\href{https://orcid.org/0000-0001-6469-1750}{ORCID}) [copyright holder]
  \item Alex Hayes \email{alexpghayes@gmail.com} (\href{https://orcid.org/0000-0002-4985-5160}{ORCID})
  \item Zhian N. Kamvar \email{zkamvar@gmail.com} (\href{https://orcid.org/0000-0003-1458-7108}{ORCID}) [copyright holder]
  \item Noam Ross \email{noam.ross@gmail.com} (\href{https://orcid.org/0000-0002-2136-0000}{ORCID}) [copyright holder]
  \item Robrecht Cannoodt \email{rcannood@gmail.com} (\href{https://orcid.org/0000-0003-3641-729X}{ORCID}) (rcannood) [copyright holder]
  \item Duncan Luguern \email{duncan.luguern@gmail.com}
  \item David M. Kaplan \email{dmkaplan2000@gmail.com} (\href{https://orcid.org/0000-0001-6087-359X}{ORCID}) (dmkaplan2000) [contributor]
  \item Sebastian Kreutzer \email{sebastian.kreutzer@aber.ac.uk} (\href{https://orcid.org/0000-0002-0734-2199}{ORCID})
  \item Shixiang Wang \email{w_shixiang@163.com} (\href{https://orcid.org/0000-0001-9855-7357}{ORCID}) [contributor]
  \item Jay Hesselberth \email{jay.hesselberth@gmail.com} (\href{https://orcid.org/0000-0002-6299-179X}{ORCID}) [contributor]
  \item Rob Hyndman \email{Rob.Hyndman@monash.edu} (\href{https://orcid.org/0000-0002-2140-5352}{ORCID})
}

Other contributors:
\itemize{
  \item Posit Software, PBC [copyright holder, funder]
  \item Alfredo Hernández \email{aldomann.designs@gmail.com} (\href{https://orcid.org/0000-0002-2660-4545}{ORCID}) [contributor]
  \item Stefano Coretta \email{stefano.coretta@gmail.com} (\href{https://orcid.org/0000-0001-9627-5532}{ORCID}) (stefanocoretta) [contributor]
  \item Greg Macfarlane \email{gregmacfarlane@gmail.com} (gregmacfarlane) [contributor]
  \item Matthias Templ \email{matthias.templ@gmail.com} (\href{https://orcid.org/0000-0002-8638-5276}{ORCID}) (matthias-da) [contributor]
  \item Alvaro Uzaheta \email{alvaro.uzaheta@gess.ethz.ch} (auzaheta) [contributor]
  \item JooYoung Seo \email{jseo1005@illinois.edu} (\href{https://orcid.org/0000-0002-4064-6012}{ORCID}) [contributor]
  \item Callum Arnold \email{cal.rk.arnold@gmail.com} (arnold-c) [contributor]
  \item Dmytro Perepolkin \email{dperepolkin@gmail.com} (\href{https://orcid.org/0000-0001-8558-6183}{ORCID}) (dmi3kno) [contributor]
  \item Tom Palmer \email{remlapmot@hotmail.com} (\href{https://orcid.org/0000-0003-4655-4511}{ORCID}) (remlapmot) [contributor]
}

}
\keyword{internal}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/rsos_article.R
\name{rsos_article}
\alias{rsos_article}
\title{Royal Society Open Science journal format.}
\usage{
rsos_article(
  ...,
  keep_tex = TRUE,
  latex_engine = "xelatex",
  pandoc_args = NULL,
  includes = NULL,
  fig_crop = TRUE
)
}
\arguments{
\item{...}{Additional arguments to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}}

\item{keep_tex}{Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., \file{.aux}) generated by LaTeX when compiling \file{.tex} to
\file{.pdf}. To keep these files, you may set \code{options(tinytex.clean =
FALSE)}.}

\item{latex_engine}{LaTeX engine for producing PDF output. Options are
"pdflatex", "lualatex", "xelatex" and "tectonic".}

\item{pandoc_args}{Additional command line options to pass to pandoc}

\item{includes}{Named list of additional content to include within the
document (typically created using the \code{\link[rmarkdown]{includes}} function).}

\item{fig_crop}{Whether to crop PDF figures with the command
\command{pdfcrop}. This requires the tools \command{pdfcrop} and
\command{ghostscript} to be installed. By default, \code{fig_crop = TRUE}
if these two tools are available.}
}
\description{
Format for creating submissions to Royal Society Open Science journals.
}
\author{
Thierry Onkelinx, \email{thierry.onkelinx@inbo.be}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/article.R
\name{acm_article}
\alias{acm_article}
\alias{acs_article}
\alias{aea_article}
\alias{agu_article}
\alias{amq_article}
\alias{ams_article}
\alias{asa_article}
\alias{arxiv_article}
\alias{bioinformatics_article}
\alias{biometrics_article}
\alias{ctex_article}
\alias{ctex}
\alias{elsevier_article}
\alias{frontiers_article}
\alias{glossa_article}
\alias{ims_article}
\alias{informs_article}
\alias{iop_article}
\alias{jasa_article}
\alias{lipics_article}
\alias{lncs_article}
\alias{jedm_article}
\alias{mdpi_article}
\alias{mnras_article}
\alias{peerj_article}
\alias{pihph_article}
\alias{plos_article}
\alias{pnas_article}
\alias{sage_article}
\alias{sim_article}
\alias{springer_article}
\alias{tf_article}
\alias{trb_article}
\alias{wellcomeor_article}
\alias{isba_article}
\title{R Markdown output formats for (journal) articles}
\usage{
acm_article(...)

acs_article(
  ...,
  keep_tex = TRUE,
  md_extensions = c("-autolink_bare_uris"),
  fig_caption = TRUE
)

aea_article(..., keep_tex = TRUE, md_extensions = c("-autolink_bare_uris"))

agu_article(
  ...,
  keep_tex = TRUE,
  citation_package = "natbib",
  highlight = NULL,
  md_extensions = c("-autolink_bare_uris", "-auto_identifiers")
)

amq_article(
  ...,
  latex_engine = "xelatex",
  keep_tex = TRUE,
  fig_caption = TRUE,
  md_extensions = c("-autolink_bare_uris")
)

ams_article(..., keep_tex = TRUE, md_extensions = c("-autolink_bare_uris"))

asa_article(..., keep_tex = TRUE, citation_package = "natbib")

arxiv_article(..., keep_tex = TRUE)

bioinformatics_article(..., keep_tex = TRUE, citation_package = "natbib")

biometrics_article(..., keep_tex = TRUE, citation_package = "natbib")

ctex_article(..., template = "default", latex_engine = "xelatex")

ctex(..., template = "default", latex_engine = "xelatex")

elsevier_article(
  ...,
  keep_tex = TRUE,
  md_extensions = c("-autolink_bare_uris"),
  citation_package = "natbib"
)

frontiers_article(..., keep_tex = TRUE, citation_package = "natbib")

glossa_article(..., keep_tex = TRUE, latex_engine = "xelatex")

ims_article(
  journal = c("aoas", "aap", "aop", "aos", "sts"),
  keep_tex = TRUE,
  citation_package = "natbib",
  md_extensions = c("-autolink_bare_uris"),
  pandoc_args = NULL,
  ...
)

informs_article(..., keep_tex = TRUE, citation_package = "natbib")

iop_article(..., keep_tex = TRUE, citation_package = "natbib")

jasa_article(
  ...,
  keep_tex = TRUE,
  latex_engine = "xelatex",
  citation_package = "natbib"
)

lipics_article(
  ...,
  latex_engine = "xelatex",
  keep_tex = TRUE,
  citation_package = "natbib",
  md_extensions = c("-autolink_bare_uris", "-auto_identifiers")
)

lncs_article(..., keep_tex = TRUE, citation_package = c("default", "natbib"))

jedm_article(..., keep_tex = TRUE, citation_package = "natbib")

mdpi_article(
  ...,
  keep_tex = TRUE,
  latex_engine = "pdflatex",
  pandoc_args = NULL,
  citation_package = "natbib"
)

mnras_article(..., keep_tex = TRUE, fig_caption = TRUE)

peerj_article(..., keep_tex = TRUE)

pihph_article(
  ...,
  keep_tex = TRUE,
  latex_engine = "xelatex",
  citation_package = "biblatex"
)

plos_article(..., keep_tex = TRUE, md_extensions = c("-autolink_bare_uris"))

pnas_article(..., keep_tex = TRUE)

sage_article(..., highlight = NULL, citation_package = "natbib")

sim_article(
  ...,
  highlight = NULL,
  citation_package = "natbib",
  latex_engine = "xelatex"
)

springer_article(
  ...,
  keep_tex = TRUE,
  citation_package = "natbib",
  number_sections = TRUE,
  latex_engine = "pdflatex",
  pandoc_args = NULL
)

tf_article(..., keep_tex = TRUE, citation_package = "natbib")

trb_article(..., keep_tex = TRUE, citation_package = "natbib")

wellcomeor_article(
  ...,
  number_sections = FALSE,
  keep_tex = TRUE,
  citation_package = "natbib"
)

isba_article(
  ...,
  keep_tex = TRUE,
  highlight = NULL,
  citation_package = "natbib"
)
}
\arguments{
\item{..., number_sections, keep_tex, latex_engine, citation_package, highlight, fig_caption, md_extensions, template, pandoc_args}{Arguments passed to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}.}

\item{journal}{one of \code{"aoas"}, \code{"aap"}, \code{"aop"}, \code{"aos"}, \code{"sts"} for \code{ims_article}}
}
\value{
An R Markdown output format.
}
\description{
Most article formats are based on \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}, with a
custom Pandoc LaTeX template and different default values for other arguments
(e.g., \code{keep_tex = TRUE}).
}
\section{Details}{
 You can find more details about each output format below.
}

\section{\code{acm_article}}{
 Format for creating an Association for Computing
Machinery (ACM) articles. Adapted from
\url{https://www.acm.org/publications/proceedings-template}.
}

\section{\code{acs_article}}{
 Format for creating an American Chemical Society
(ACS) Journal articles. Adapted from
\verb{https://pubs.acs.org/page/4authors/submission/tex.html}
}

\section{\code{aea_article}}{
 Format for creating submissions to the American
Economic Association (AER, AEJ, JEL, PP).
}

\section{\code{agu_article}}{
 Format for creating a American Geophysical Union
(AGU) article. Adapted from
\url{https://www.agu.org/publish-with-agu/publish#1}.
}

\section{\code{amq_article}}{
 Ce format a été adapté du format du bulletin de
l'AMQ.
}

\section{\code{ams_article}}{
 Format for creating an American Meteorological
Society (AMS) Journal articles. Adapted from
\url{https://www.ametsoc.org/ams/index.cfm/publications/authors/journal-and-bams-authors/author-resources/latex-author-info/}.
}

\section{\code{asa_article}}{
 This format was adapted from The American
Statistician (TAS) format, but it should be fairly consistent across
American Statistical Association (ASA) journals.
}

\section{\code{arxiv_article}}{
 Adapted from the George Kour's format for
arXiv and bio-arXiv preprints. So far as I'm aware, entirely
unofficial but still a staple.
}

\section{\code{bioinformatics_article}}{
 Format for creating submissions to a Bioinformatics journal. Adapted from
\url{https://academic.oup.com/bioinformatics/pages/submission_online}.
}

\section{\code{biometrics_article}}{
 This format was adapted from the
Biometrics journal.
}

\section{\code{ctex_article}}{
 A wrapper function for
\code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}} and the default value of
\code{latex_engine} is changed to \command{xelatex}, so it works better for
typesetting Chinese documents with the LaTeX package \pkg{ctex}. The
function \code{ctex} is an alias of \code{ctex_article}.
}

\section{\code{elsevier_article}}{
 Format for creating submissions to Elsevier
journals. Adapted from
\url{https://www.elsevier.com/researcher/author/policies-and-guidelines/latex-instructions}.

It requires a minimum version of 2.10 for Pandoc.
}

\section{\code{frontiers_article}}{
 Format for creating Frontiers journal
articles. Adapted from
\url{https://www.frontiersin.org/about/author-guidelines}.
}

\section{\code{glossa_article}}{
 Format for creating submissions to Glossa: a
journal of general linguistics. Author Guidelines are available on
\href{https://www.glossa-journal.org/site/author-guidelines/}{www.glossa-journal.org}.
Template is adapted from \url{https://github.com/guidovw/Glossalatex}.
}

\section{\code{ims_article}}{
 Format for creating submissions to the Institute of Mathematical Statistics
\href{https://imstat.org/}{IMS} journals and publications. Adapted from
\url{https://github.com/vtex-soft/texsupport.ims-aoas}.

The argument \code{journal} accepts the acronym of any of the
\href{https://www.e-publications.org/ims/support/ims-instructions.html}{journals} in IMS:
\itemize{
\item \code{aap}: The Annals of Applied Probability
\item \code{aoas}: The Annals of Applied Statistics
\item \code{aop}: The Annals of Probability
\item \code{aos}: The Annals of Statistics
\item \code{sts}: Statistical Science
}
}

\section{\code{informs_article}}{
 Format for creating submissions to
INFORMS journals. Adapted from \samp{https://pubsonline.informs.org/authorportal/latex-style-files}.

It requires a minimum version of 2.10 for Pandoc.
}

\section{\code{iop_article}}{
 Format for creating submissions to
IOP journals. Adapted from \samp{https://publishingsupport.iopscience.iop.org/questions/latex-template/}.
Please read the guidelines at this link when preparing your article.
}

\section{\code{jasa_article}}{
 Format for creating submissions to the
Journal of the Acoustical Society of America. Adapted from
\url{https://acousticalsociety.org/preparing-latex-manuscripts/}.
}

\section{\code{lipics_article}}{
 Format for creating submissions to
LIPIcs - Leibniz International Proceedings Informatics - articles.
Adapted from the official Instructions for Authors at
\url{https://submission.dagstuhl.de/documentation/authors} and the
template from the archive \code{authors-lipics-v2019.zip} downloaded
with version tag v2019.2. The template is provided under The LaTeX
Project Public License (LPPL), Version 1.3c.
}

\section{\code{lncs_article}}{
 Format for creating submissions to
LNCS - Lecture Notes in Computer Science - articles.
Adapted from the official Instructions for Authors at
\url{https://www.springer.com/gp/computer-science/lncs/conference-proceedings-guidelines}
and the  template from the archive \code{LaTeX2e+Proceedings+Templates+download.zip} downloaded
with version tag 2.21.
}

\section{\code{jedm_article}}{
 Format for creating Journal of Educational
Data Mining (JEDM) articles. Adapted from
\url{https://jedm.educationaldatamining.org/index.php/JEDM/information/authors}.
}

\section{\code{mdpi_article}}{
 Format for creating submissions to
Multidisciplinary Digital Publishing Institute (MDPI) journals. Adapted
from \url{https://www.mdpi.com/authors/latex}.

Possible arguments for the YAML header are:
\itemize{
\item \code{title} title of the manuscript
\item \code{author} list of authors, containing \code{name}, \code{affil}, and \code{orcid} (optional)
\item \code{affiliation} list containing \code{num}, \code{address}, and \code{email} for defining \code{author} affiliations
\item \code{authorcitation} string with last name and first intial of authors as expected to be shown in a reference
\item \code{firstnote} can include \code{firstnote} through \code{eightnote} that correspond to footnote marks in \code{affil}
\item \code{correspondence} contact information of the corresponding author
\item \code{journal} short name (case sensitive) of the journal, see template for options
\item \code{type} usually "article" but see template for options
\item \code{status} usually "submit"
\item \code{simplesummary} optional, may depend on specific journal
\item \code{abstract} abstract, limited to 200 words
\item \code{keywords} 3 to 10 keywords seperated with a semicolon
\item \code{acknowledgement} acknowledgement backmatter (optional)
\item \code{authorcontributions} report authorship contributions (optional)
\item \code{funding} research funding statement
\item \code{institutionalreview} IRB statements (optional)
\item \code{informedconsent} Informed consent statements for human research (optional)
\item \code{dataavailability} Links to datasets or archives (optional)
\item \code{conflictsofinterest} Conflict of interest statement (see journal  instructions)
\item \code{sampleavailability} Sample availability statement (optional)
\item \code{supplementary} Supplementary data statement, see template for example (optional)
\item \code{abbreviations} list of abbreviations containing \code{short} and \code{long}
\item \code{bibliography} BibTeX \code{.bib} file
\item \code{appendix} name of appendix tex file
\item \code{endnote} boolean, if \code{TRUE} will print list of endnotes if included in text (optional)
\item \code{header-includes}: custom additions to the header, before the \verb{\\begin\{document\}} statement
\item \code{include-after}: for including additional LaTeX code before the \verb{\\end\{document\}} statement
}
}

\section{\code{mnras_article}}{
 Format for creating an Monthly Notices of
Royal Astronomical Society (MNRAS) Journal articles. Adapted from
\url{https://ras.ac.uk}.
}

\section{\code{peerj_article}}{
 Format for creating submissions to The PeerJ
Journal. This was adapted from the
\href{https://www.overleaf.com/latex/templates/latex-template-for-peerj-journal-and-pre-print-submissions/ptdwfrqxqzbn}{PeerJ Overleaf Template}.
}

\section{\code{pihph_article}}{
 Format for creating submissions to the Papers
in Historical Phonology
(\url{http://journals.ed.ac.uk/pihph/about/submissions}). Adapted from
\url{https://github.com/pihph/templates}. This format works well with
\code{latex_engine = "xelatex"} and \code{citation_package="biblatex"},
which are the default. It may not work correctly if you change these value.
In that case, please open an issue and, a PR to contribute a change in the
template.
}

\section{\code{plos_article}}{
 Format for creating submissions to PLOS
journals. Adapted from \url{https://journals.plos.org/ploscompbiol/s/latex}.
}

\section{\code{pnas_article}}{
 Format for creating submissions to PNAS
journals.
}

\section{\code{sage_article}}{
 Format for creating submissions to Sage
Journals. Based on the official Sage Journals Class.
Available at \verb{https://uk.sagepub.com/sites/default/files/sage_latex_template_4.zip}.

Possible arguments for the YAML header are:
\itemize{
\item \code{title} title of the manuscript
\item \code{runninghead} short author list for header
\item \code{author} list of authors, containing \code{name} and \code{num}
\item \code{address} list containing \code{num} and \code{org} for defining \code{author} affiliations
\item \code{corrauth} corresponding author name and address
\item \code{email} correspondence email
\item \code{abstract} abstract, limited to 200 words
\item \code{keywords} keywords for the article
\item \code{bibliography} BibTeX \code{.bib} file name
\item \code{classoption} options of the \code{sagej} class
\item \code{header-includes}: custom additions to the header, before the \verb{\\begin\{document\}} statement
\item \code{include-after}: for including additional LaTeX code before the \verb{\\end\\\{document\}} statement
}
}

\section{\code{sim_article}}{
 Format for creating submissions to Statistics in
Medicine. Based on the official Statistics in Medicine
at \verb{https://authorservices.wiley.com/author-resources/Journal-Authors/Prepare/new-journal-design.html}.

This format uses xelatex by default as PDF engine to support the specific NJD fonts, per guideline.

Possible arguments for the YAML header are:
\itemize{
\item \code{title} title of the manuscript
\item \code{author} list of authors, containing \code{name} and \code{num}
\item \code{address} list containing \code{num} and \code{org} for defining \code{author} affiliations
\item \code{presentaddress} not sure what they mean with this
\item \code{corres} author and address for correspondence
\item \code{authormark} short author list for header
\item \code{received}, \code{revised}, \code{accepted} dates of submission, revision, and acceptance of the manuscript
\item \code{abstract} abstract, limited to 250 words
\item \code{keywords} up to 6 keywords
\item \code{abbreviations}, list of abbreviations and description separated by a comma
\item \code{bibliography} BibTeX \code{.bib} file
\item \code{classoption} options of the \code{WileyNJD} class
\item \code{longtable} set to \code{true} to include the \code{longtable} package, used by default from \code{pandoc} to convert markdown to LaTeX code
\item \code{header-includes}: custom additions to the header, before the \verb{\\begin\{document\}} statement
\item \code{include-after}: for including additional LaTeX code before the \verb{\\end\{document\}} statement
}
}

\section{\code{springer_article}}{
 This format was adapted from the Springer
Macro package for Springer Journals.
}

\section{\code{tf_article}}{
 Format for creating submissions to a Taylor & Francis journal. Adapted from
\samp{https://www.tandf.co.uk/journals/authors/InteractCADLaTeX.zip}.
}

\section{\code{trb_article}}{
 Format for creating submissions to the Transportation
Research Board Annual Meeting. Adapted from
\samp{https://www.overleaf.com/latex/templates/transportation-research-board-trb-latex-template/jkfndnnkkksw},
which in turn is hosted at \samp{https://github.com/chiehrosswang/TRB_LaTeX_tex}
}

\section{\code{wellcomeor_article}}{
 Format for creating submissions to
Wellcome Open Research. Adapted from <overleaf.com/latex/templates/wellcome-open-research-article-template/hsmhhbpxvvbj>.
}

\section{\code{isba_article}}{
 Format for creating submissions to Bayesian analysis.
Based on the official Bayesian analysis \href{https://www.e-publications.org/isba/support/}{class}.
Template shows how to use this format as a base format for \code{bookdown::pdf_book}, but it can very well be used on its own (with limitations that figure referencing will not work).
Note that the template sets \code{md_extensions} to exclude \code{-autolink_bare_uris} because otherwise author emails produce error

Possible arguments for the YAML header are:
\itemize{
\item \code{title} title of the manuscript. Shorter version of the title can be provided as \code{runtitle}.
\item \code{classoption} should equal \code{ba} or \verb{ba,preprint} for supplementary article.``
\item \code{author} list of authors, containing \code{firstname}, \code{lastname}, \code{email}, \code{url}, \code{affiliationref} (as code) and \code{footnoterefs} (as list of codes)
\item \code{affiliations} list containing \code{ref} (code for defining \code{author} affiliations), institution \code{name} and \code{address} itself
\item \code{footnotes} a list of two-element entries: \code{ref} and \code{text}
\item \code{abstract} abstract, limited to 250 words
\item \code{MSC2020primary}, \code{MSC2020primary} lists of codes from \href{https://mathscinet.ams.org/mathscinet/msc/msc2020.html}{MCS2020 database}
\item \code{keywords} a list of keywords
\item \code{supplements} a list of entries with two elements \code{title} and \code{description}
\item \code{doi} DOI of the article
\item \code{arxiv} Arxiv id
\item \code{acknowledgements} acknowledgement text, limited to 250 words
\item \code{bibliography} BibTeX \code{.bib} file
\item \code{longtable} set to \code{true} to include the \code{longtable} package, used by default from \code{pandoc} to convert markdown to LaTeX code
\item \code{header-includes}: custom additions to the header, before the \verb{\\begin\{document\}} statement
\item \code{include-after}: for including additional LaTeX code before the \verb{\\end\{document\}} statement
}
}

\examples{
\dontrun{
rmarkdown::draft("MyArticle.Rmd", template = "acm", package = "rticles")
rmarkdown::draft("MyArticle.Rmd", template = "asa", package = "rticles")
}
}

% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/ieee_article.R
\name{ieee_article}
\alias{ieee_article}
\title{IEEE Transactions journal format.}
\usage{
ieee_article(
  draftmode = c("final", "draft", "draftcls", "draftclsnofoot"),
  hyphenfixes = "op-tical net-works semi-conduc-tor",
  IEEEspecialpaper = "",
  with_ifpdf = FALSE,
  with_cite = FALSE,
  with_amsmath = FALSE,
  with_algorithmic = FALSE,
  with_subfig = FALSE,
  with_array = FALSE,
  with_dblfloatfix = FALSE,
  keep_tex = TRUE,
  pandoc_args = NULL,
  md_extensions = c("-autolink_bare_uris"),
  ...
)
}
\arguments{
\item{draftmode}{Specify the draft mode to control spacing and whether images
should be rendered. Valid options are: \code{"final"} (default), \code{"draft"},
\code{"draftcls"}, or \code{"draftclsnofoot"}.}

\item{hyphenfixes}{A \code{character} value that provides the correct
hyphenations for ambiguous words. Separate new words with spaces.}

\item{IEEEspecialpaper}{A \code{character} value containing the publication's
special paper designation.}

\item{with_ifpdf}{A \code{logical} value turning on (\code{TRUE}) or off
(\code{FALSE}) the \code{ifpdf} LaTeX package.}

\item{with_cite}{A \code{logical} value turning on (\code{TRUE}) or off
(\code{FALSE}) the \code{cite} LaTeX package.}

\item{with_amsmath}{A \code{logical} value turning on (\code{TRUE}) or off
(\code{FALSE}) the \code{amsmath} LaTeX package.}

\item{with_algorithmic}{A \code{logical} value turning on (\code{TRUE}) or
off (\code{FALSE}) the \code{algorithmic} LaTeX package.}

\item{with_subfig}{A \code{logical} value turning on (\code{TRUE}) or off
(\code{FALSE}) the \code{subfig} LaTeX package.}

\item{with_array}{A \code{logical} value turning on (\code{TRUE}) or off
(\code{FALSE}) the \code{array} LaTeX package.}

\item{with_dblfloatfix}{A \code{logical} value turning on (\code{TRUE}) or
off (\code{FALSE}) the \code{dblfloatfix} LaTeX package.}

\item{keep_tex}{Keep the intermediate tex file used in the conversion to PDF.
Note that this argument does not control whether to keep the auxiliary
files (e.g., \file{.aux}) generated by LaTeX when compiling \file{.tex} to
\file{.pdf}. To keep these files, you may set \code{options(tinytex.clean =
FALSE)}.}

\item{pandoc_args}{Additional command line options to pass to pandoc}

\item{md_extensions}{Markdown extensions to be added or removed from the
default definition of R Markdown. See the \code{\link[rmarkdown]{rmarkdown_format}} for
additional details.}

\item{...}{Additional arguments to \code{\link[rmarkdown:pdf_document]{rmarkdown::pdf_document()}}}
}
\description{
Format for creating submissions to IEEE Transaction journals. Adapted from
\url{https://www.ieee.org/publications_standards/publications/authors/author_templates.html}
}
\details{
Presently, only the \code{"conference"} paper mode offered by the
\code{IEEEtran.cls} is supported.
}
\references{
Shell, Michael. "How to use the IEEEtran LATEX class." Journal of LATEX Class
Files 1.11 (2002): 10-20.
\url{http://mirrors.rit.edu/CTAN/macros/latex/contrib/IEEEtran/IEEEtran_HOWTO.pdf}
}
